# All Global changes to build and install go here.
# Per the below section about __spec_install_pre, any rpm
# environment changes that affect %%install need to go
# here before the %%install macro is pre-built.

# Disable LTO in userspace packages.
%global _lto_cflags %{nil}

# Option to enable compiling with clang instead of gcc.
%bcond_with toolchain_clang

%if %{with toolchain_clang}
%global toolchain clang
%endif

# Compile the kernel with LTO (only supported when building with clang).
%bcond_with clang_lto

%if %{with clang_lto} && %{without toolchain_clang}
{error:clang_lto requires --with toolchain_clang}
%endif

# Cross compile on copr for arm
# See https://bugzilla.redhat.com/1879599
%if 0%{?_with_cross_arm:1}
%global _target_cpu armv7hl
%global _arch arm
%global _build_arch arm
%global _with_cross    1
%endif

# RPM macros strip everything in BUILDROOT, either with __strip
# or find-debuginfo.sh. Make use of __spec_install_post override
# and save/restore binaries we want to package as unstripped.
%define buildroot_unstripped %{_builddir}/root_unstripped
%define buildroot_save_unstripped() \
(cd %{buildroot}; cp -rav --parents -t %{buildroot_unstripped}/ %1 || true) \
%{nil}
%define __restore_unstripped_root_post \
    echo "Restoring unstripped artefacts %{buildroot_unstripped} -> %{buildroot}" \
    cp -rav %{buildroot_unstripped}/. %{buildroot}/ \
%{nil}

# The kernel's %%install section is special
# Normally the %%install section starts by cleaning up the BUILD_ROOT
# like so:
#
# %%__spec_install_pre %%{___build_pre}\
#     [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf "${RPM_BUILD_ROOT}"\
#     mkdir -p `dirname "$RPM_BUILD_ROOT"`\
#     mkdir "$RPM_BUILD_ROOT"\
# %%{nil}
#
# But because of kernel variants, the %%build section, specifically
# BuildKernel(), moves each variant to its final destination as the
# variant is built.  This violates the expectation of the %%install
# section.  As a result we snapshot the current env variables and
# purposely leave out the removal section.  All global wide changes
# should be added above this line otherwise the %%install section
# will not see them.
%global __spec_install_pre %{___build_pre}

# Replace '-' with '_' where needed so that variants can use '-' in
# their name.
%define uname_suffix %{lua:
	local flavour = rpm.expand('%{?1:+%{1}}')
	flavour = flavour:gsub('-', '_')
	if flavour ~= '' then
		print(flavour)
	end
}

# This returns the main kernel tied to a debug variant. For example,
# kernel-debug is the debug version of kernel, so we return an empty
# string. However, kernel-64k-debug is the debug version of kernel-64k,
# in this case we need to return "64k", and so on. This is used in
# macros below where we need this for some uname based requires.
%define uname_variant %{lua:
	local flavour = rpm.expand('%{?1:%{1}}')
	_, _, main, sub = flavour:find("(%w+)-(.*)")
	if main then
		print("+" .. main)
	end
}


# At the time of this writing (2019-03), RHEL8 packages use w2.xzdio
# compression for rpms (xz, level 2).
# Kernel has several large (hundreds of mbytes) rpms, they take ~5 mins
# to compress by single-threaded xz. Switch to threaded compression,
# and from level 2 to 3 to keep compressed sizes close to "w2" results.
#
# NB: if default compression in /usr/lib/rpm/redhat/macros ever changes,
# this one might need tweaking (e.g. if default changes to w3.xzdio,
# change below to w4T.xzdio):
#
# This is disabled on i686 as it triggers oom errors

%ifnarch i686
%define _binary_payload w3T.xzdio
%endif

Summary: The Linux kernel
%if 0%{?fedora}
%define secure_boot_arch x86_64
%else
%define secure_boot_arch x86_64 aarch64 s390x ppc64le
%endif

# Signing for secure boot authentication
%ifarch %{secure_boot_arch}
%global signkernel 1
%else
%global signkernel 0
%endif

# Sign modules on all arches
%global signmodules 1

# Compress modules only for architectures that build modules
%ifarch noarch
%global zipmodules 0
%else
%global zipmodules 1
%endif

%ifarch x86_64
%global efiuki 1
%else
%global efiuki 0
%endif

# Default compression algorithm
%global compression xz
%global compression_flags --compress
%global compext xz
%if %{zipmodules}
%global zipsed -e 's/\.ko$/\.ko.%compext/'
# for parallel xz processes, replace with 1 to go back to single process
%endif

%if 0%{?fedora}
%define primary_target fedora
%else
%define primary_target rhel
%endif

#
# genspec.sh variables
#

# Include Fedora files
%global include_fedora 0
# Include RHEL files
%global include_rhel 1
# Provide Patchlist.changelog file
%global patchlist_changelog 0
# Set debugbuildsenabled to 1 to build separate base and debug kernels
#  (on supported architectures). The kernel-debug-* subpackages will
#  contain the debug kernel.
# Set debugbuildsenabled to 0 to not build a separate debug kernel, but
#  to build the base kernel using the debug configuration. (Specifying
#  the --with-release option overrides this setting.)
%define debugbuildsenabled 1
# define buildid .local
%define specversion 5.14.0
%define patchversion 5.14
%define pkgrelease 546
%define kversion 5
%define tarfile_release 5.14.0-546.el9
# This is needed to do merge window version magic
%define patchlevel 14
# This allows pkg_release to have configurable %%{?dist} tag
%define specrelease 546%{?buildid}%{?dist}
# This defines the kabi tarball version
%define kabiversion 5.14.0-546.el9

#
# End of genspec.sh variables
#

%define pkg_release %{specrelease}

# libexec dir is not used by the linker, so the shared object there
# should not be exported to RPM provides
%global __provides_exclude_from ^%{_libexecdir}/kselftests

# The following build options are enabled by default, but may become disabled
# by later architecture-specific checks. These can also be disabled by using
# --without <opt> in the rpmbuild command, or by forcing these values to 0.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# kernel PAE (only valid for ARM (lpae))
%define with_pae       %{?_without_pae:       0} %{?!_without_pae:       1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-zfcpdump (s390 specific kernel for zfcpdump)
%define with_zfcpdump  %{?_without_zfcpdump:  0} %{?!_without_zfcpdump:  1}
# kernel-64k (aarch64 kernel with 64K page_size)
%define with_arm64_64k %{?_without_arm64_64k: 0} %{?!_without_arm64_64k: 1}
# kernel-rt (x86_64 and aarch64 only PREEMPT_RT enabled kernel)
%define with_realtime  %{?_without_realtime:  0} %{?!_without_realtime:  1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
%define with_cross_headers   %{?_without_cross_headers:   0} %{?!_without_cross_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# bpf tool
%define with_bpftool   %{?_without_bpftool:   0} %{?!_without_bpftool:   1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-abi-stablelists
%define with_kernel_abi_stablelists %{?_without_kernel_abi_stablelists: 0} %{?!_without_kernel_abi_stablelists: 1}
# internal samples and selftests
%define with_selftests %{?_without_selftests: 0} %{?!_without_selftests: 1}
#
# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the pae kernel (--with paeonly):
%define with_paeonly   %{?_with_paeonly:      1} %{?!_with_paeonly:      0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}
# Only build the realtime kernel (--with rtonly):
%define with_rtonly    %{?_with_rtonly:       1} %{?!_with_rtonly:       0}
# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}
# Temporarily disable kabi checks until RC.
%define with_kabichk 0
# Control whether we perform a compat. check against DUP ABI.
%define with_kabidupchk %{?_with_kabidupchk:  1} %{?!_with_kabidupchk:   0}
#
# Control whether to run an extensive DWARF based kABI check.
# Note that this option needs to have baseline setup in SOURCE300.
%define with_kabidwchk %{?_without_kabidwchk: 0} %{?!_without_kabidwchk: 1}
%define with_kabidw_base %{?_with_kabidw_base: 1} %{?!_with_kabidw_base: 0}
#
# Control whether to install the vdso directories.
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}
#
# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}
#
# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}
#
# build a release kernel on rawhide
%define with_release   %{?_with_release:      1} %{?!_with_release:      0}

# verbose build, i.e. no silent rules and V=1
%define with_verbose %{?_with_verbose:        1} %{?!_with_verbose:      0}

#
# check for mismatched config options
%define with_configchecks %{?_without_configchecks:        0} %{?!_without_configchecks:        1}

#
# gcov support
%define with_gcov %{?_with_gcov:1}%{?!_with_gcov:0}

#
# ipa_clone support
%define with_ipaclones %{?_without_ipaclones: 0} %{?!_without_ipaclones: 1}

# Want to build a vanilla kernel build without any non-upstream patches?
%define with_vanilla %{?_with_vanilla: 1} %{?!_with_vanilla: 0}

%if 0%{?fedora}
# Kernel headers are being split out into a separate package
%define with_headers 0
%define with_cross_headers 0
# no ipa_clone for now
%define with_ipaclones 0
# no stablelist
%define with_kernel_abi_stablelists 0
# Fedora builds these separately
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%endif

%if %{with_verbose}
%define make_opts V=1
%else
%define make_opts -s
%endif

%if %{with toolchain_clang}
%ifarch s390x ppc64le
%global llvm_ias 0
%else
%global llvm_ias 1
%endif
%global clang_make_opts HOSTCC=clang CC=clang LLVM_IAS=%{llvm_ias}
%if %{with clang_lto}
%global clang_make_opts %{clang_make_opts} LD=ld.lld HOSTLD=ld.lld AR=llvm-ar NM=llvm-nm HOSTAR=llvm-ar HOSTNM=llvm-nm
%endif
%global make_opts %{make_opts} %{clang_make_opts}
# clang does not support the -fdump-ipa-clones option
%global with_ipaclones 0
%endif

# turn off debug kernel and kabichk for gcov builds
%if %{with_gcov}
%define with_debug 0
%define with_kabichk 0
%define with_kabidupchk 0
%define with_kabidwchk 0
%define with_kabidw_base 0
%define with_kernel_abi_stablelists 0
%endif

# turn off kABI DWARF-based check if we're generating the base dataset
%if %{with_kabidw_base}
%define with_kabidwchk 0
%endif

# kpatch_kcflags are extra compiler flags applied to base kernel
# -fdump-ipa-clones is enabled only for base kernels on selected arches
%if %{with_ipaclones}
%ifarch x86_64 ppc64le
%define kpatch_kcflags -fdump-ipa-clones
%else
%define with_ipaclones 0
%endif
%endif

%define make_target bzImage
%define image_install_path boot

%define KVERREL %{version}-%{release}.%{_target_cpu}
%define KVERREL_RE %(echo %KVERREL | sed 's/+/[+]/g')
%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if 0%{!?nopatches:1}
%define nopatches 0
%endif

%if %{with_vanilla}
%define nopatches 1
%endif

%if %{with_release}
%define debugbuildsenabled 1
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug
# Needed because we override almost everything involving build-ids
# and debuginfo generation. Currently we rely on the old alldebug setting.
%global _build_id_links alldebug

# kernel PAE is only built on ARMv7
%ifnarch armv7hl
%define with_pae 0
%endif

# RT kernel is only built on x86_64 and aarch64
%ifnarch x86_64 aarch64
%define with_realtime 0
%endif

# if requested, only build base kernel
%if %{with_baseonly}
%define with_pae 0
%define with_debug 0
%define with_realtime 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# if requested, only build pae kernel
%if %{with_paeonly}
%define with_up 0
%define with_debug 0
%define with_realtime 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_up 0
%define with_realtime 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# if requested, only build realtime kernel
%if %{with_rtonly}
%define with_up 0
%define with_pae 0
%define with_debug 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# turn off kABI DUP check and DWARF-based check if kABI check is disabled
%if !%{with_kabichk}
%define with_kabidupchk 0
%define with_kabidwchk 0
%endif

%if %{with_vdso_install}
%define use_vdso 1
%endif

# selftests require bpftool to be built.  If bpftools is disabled, then disable selftests
%if %{with_bpftool} == 0
%define with_selftests 0
%endif

%ifnarch noarch
%define with_kernel_abi_stablelists 0
%endif

# Overrides for generic default options

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define doc_build_fail true
%endif

%if 0%{?fedora}
# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%define with_debug 0
%endif
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_realtime 0
%define with_headers 0
%define with_cross_headers 0
%define with_tools 0
%define with_perf 0
%define with_bpftool 0
%define with_selftests 0
%define with_debug 0
%define all_arch_configs kernel-%{version}-*.config
%endif

# sparse blows up on ppc
%ifnarch ppc64le
%define with_sparse 0
%endif

# zfcpdump mechanism is s390 only
%ifnarch s390x
%define with_zfcpdump 0
%endif

# 64k variant only for aarch64
%ifnarch aarch64
%define with_arm64_64k 0
%endif

%if 0%{?fedora}
# This is not for Fedora
%define with_zfcpdump 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%define all_arch_configs kernel-%{version}-i?86*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs kernel-%{version}-x86_64*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define use_vdso 0
%define all_arch_configs kernel-%{version}-ppc64le*.config
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs kernel-%{version}-s390x.config
%define kernel_image arch/s390/boot/bzImage
%define vmlinux_decompressor arch/s390/boot/compressed/vmlinux
%endif

%ifarch %{arm}
%define all_arch_configs kernel-%{version}-arm*.config
%define skip_nonpae_vdso 1
%define asmarch arm
%define hdrarch arm
%define make_target bzImage
%define kernel_image arch/arm/boot/zImage
# http://lists.infradead.org/pipermail/linux-arm-kernel/2012-March/091404.html
%define kernel_mflags KALLSYMS_EXTRA_PASS=1
# we only build headers/perf/tools on the base arm arches
# just like we used to only build them on i386 for x86
%ifnarch armv7hl
%define with_headers 0
%define with_cross_headers 0
%endif
# These currently don't compile on armv7
%define with_selftests 0
%endif

%ifarch aarch64
%define all_arch_configs kernel-%{version}-aarch64*.config
%define asmarch arm64
%define hdrarch arm64
%define make_target vmlinuz.efi
%define kernel_image arch/arm64/boot/vmlinuz.efi
%endif

# Should make listnewconfig fail if there's config options
# printed out?
%if %{nopatches}
%define with_configchecks 0
%endif

# To temporarily exclude an architecture from being built, add it to
# %%nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We only build kernel-headers on the following...
%if 0%{?fedora}
%define nobuildarches i386
%else
%define nobuildarches i386 i686 %{arm}
%endif

%ifarch %nobuildarches
# disable BuildKernel commands
%define with_up 0
%define with_debug 0
%define with_pae 0
%define with_zfcpdump 0
%define with_arm64_64k 0
%define with_realtime 0

%define with_debuginfo 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_selftests 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%if 0%{?fedora}
%define cpupowerarchs %{ix86} x86_64 ppc64le %{arm} aarch64
%else
%define cpupowerarchs i686 x86_64 ppc64le aarch64
%endif

%if 0%{?use_vdso}

%if 0%{?skip_nonpae_vdso}
%define _use_vdso 0
%else
%define _use_vdso 1
%endif

%else
%define _use_vdso 0
%endif

# If build of debug packages is disabled, we need to know if we want to create
# meta debug packages or not, after we define with_debug for all specific cases
# above. So this must be at the end here, after all cases of with_debug or not.
%define with_debug_meta 0
%if !%{debugbuildsenabled}
%if %{with_debug}
%define with_debug_meta 1
%endif
%define with_debug 0
%endif


#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  coreutils, systemd >= 203-2, /usr/bin/kernel-install
%define initrd_prereq  dracut >= 027


Name: kernel
License: ((GPL-2.0-only WITH Linux-syscall-note) OR BSD-2-Clause) AND ((GPL-2.0-only WITH Linux-syscall-note) OR BSD-3-Clause) AND ((GPL-2.0-only WITH Linux-syscall-note) OR CDDL-1.0) AND ((GPL-2.0-only WITH Linux-syscall-note) OR Linux-OpenIB) AND ((GPL-2.0-only WITH Linux-syscall-note) OR MIT) AND ((GPL-2.0-or-later WITH Linux-syscall-note) OR BSD-3-Clause) AND ((GPL-2.0-or-later WITH Linux-syscall-note) OR MIT) AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND BSD-3-Clause-Clear AND GFDL-1.1-no-invariants-or-later AND GPL-1.0-or-later AND (GPL-1.0-or-later OR BSD-3-Clause) AND (GPL-1.0-or-later WITH Linux-syscall-note) AND GPL-2.0-only AND (GPL-2.0-only OR Apache-2.0) AND (GPL-2.0-only OR BSD-2-Clause) AND (GPL-2.0-only OR BSD-3-Clause) AND (GPL-2.0-only OR CDDL-1.0) AND (GPL-2.0-only OR GFDL-1.1-no-invariants-or-later) AND (GPL-2.0-only OR GFDL-1.2-no-invariants-only) AND (GPL-2.0-only WITH Linux-syscall-note) AND GPL-2.0-or-later AND (GPL-2.0-or-later OR BSD-2-Clause) AND (GPL-2.0-or-later OR BSD-3-Clause) AND (GPL-2.0-or-later OR CC-BY-4.0) AND (GPL-2.0-or-later WITH GCC-exception-2.0) AND (GPL-2.0-or-later WITH Linux-syscall-note) AND ISC AND LGPL-2.0-or-later AND (LGPL-2.0-or-later OR BSD-2-Clause) AND (LGPL-2.0-or-later WITH Linux-syscall-note) AND LGPL-2.1-only AND (LGPL-2.1-only OR BSD-2-Clause) AND (LGPL-2.1-only WITH Linux-syscall-note) AND LGPL-2.1-or-later AND (LGPL-2.1-or-later WITH Linux-syscall-note) AND (Linux-OpenIB OR GPL-2.0-only) AND (Linux-OpenIB OR GPL-2.0-only OR BSD-2-Clause) AND Linux-man-pages-copyleft AND MIT AND (MIT OR GPL-2.0-only) AND (MIT OR GPL-2.0-or-later) AND (MIT OR LGPL-2.1-only) AND (MPL-1.1 OR GPL-2.0-only) AND (X11 OR GPL-2.0-only) AND (X11 OR GPL-2.0-or-later) AND Zlib
URL: https://www.kernel.org/
Version: %{specversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
%if 0%{?fedora}
ExclusiveArch: noarch x86_64 s390x %{arm} aarch64 ppc64le
%else
ExclusiveArch: noarch i386 i686 x86_64 s390x %{arm} aarch64 ppc64le
%endif
ExclusiveOS: Linux
%ifnarch %{nobuildarches}
Requires: kernel-core-uname-r = %{KVERREL}
Requires: kernel-modules-uname-r = %{KVERREL}
Requires: kernel-modules-core-uname-r = %{KVERREL}
Provides: installonlypkg(kernel)
%endif


#
# List the packages used during the kernel build
#
BuildRequires: kmod, bash, coreutils, tar, git-core, which
BuildRequires: bzip2, xz, findutils, gzip, m4, perl-interpreter, perl-Carp, perl-devel, perl-generators, make, diffutils, gawk, %compression
BuildRequires: gcc, binutils, redhat-rpm-config, hmaccalc, bison, flex, gcc-c++
BuildRequires: net-tools, hostname, bc, elfutils-devel
BuildRequires: dwarves
BuildRequires: python3-devel
BuildRequires: gcc-plugin-devel
BuildRequires: kernel-rpm-macros >= 185-9
# glibc-static is required for a consistent build environment (specifically
# CONFIG_CC_CAN_LINK_STATIC=y).
BuildRequires: glibc-static
%if %{with_headers}
BuildRequires: rsync
%endif
%if %{with_doc}
BuildRequires: xmlto, asciidoc, python3-sphinx, python3-sphinx_rtd_theme, python3-pyyaml
%endif
%if %{with_sparse}
BuildRequires: sparse
%endif
%if %{with_perf}
BuildRequires: zlib-devel binutils-devel newt-devel perl(ExtUtils::Embed) bison flex xz-devel
BuildRequires: audit-libs-devel python3-setuptools
BuildRequires: java-devel
BuildRequires: libbpf-devel >= 0.6.0-1
BuildRequires: libbabeltrace-devel
BuildRequires: libtraceevent-devel
%ifnarch %{arm} s390x
BuildRequires: numactl-devel
%endif
%ifarch aarch64
BuildRequires: opencsd-devel >= 1.2.1
%endif
%endif
%if %{with_tools}
BuildRequires: gettext ncurses-devel
BuildRequires: libcap-devel libcap-ng-devel
# The following are rtla requirements
BuildRequires: python3-docutils
BuildRequires: libtraceevent-devel
BuildRequires: libtracefs-devel

%ifnarch s390x
BuildRequires: pciutils-devel
%endif
%ifarch i686 x86_64
BuildRequires: libnl3-devel
%endif
%endif
%if %{with_tools} || %{signmodules} || %{signkernel}
BuildRequires: openssl-devel
%endif
%if %{with_bpftool}
BuildRequires: python3-docutils
BuildRequires: zlib-devel binutils-devel
%endif
%if %{with_selftests}
BuildRequires: clang llvm fuse-devel
%ifarch x86_64
BuildRequires: lld
%endif
%ifnarch %{arm}
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-devel libcap-ng-devel rsync libmnl-devel
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
%if %{with_debuginfo}
BuildRequires: rpm-build, elfutils
BuildConflicts: rpm < 4.13.0.1-19
BuildConflicts: dwarves < 1.13
# Most of these should be enabled after more investigation
%undefine _include_minidebuginfo
%undefine _find_debuginfo_dwz_opts
%undefine _unique_build_ids
%undefine _unique_debug_names
%undefine _unique_debug_srcs
%undefine _debugsource_packages
%undefine _debuginfo_subpackages
# Remove -q option below to provide 'extracting debug info' messages
%global _find_debuginfo_opts -r -q
%global _missing_build_ids_terminate_build 1
%global _no_recompute_build_ids 1
%endif
%if %{with_kabidwchk} || %{with_kabidw_base}
BuildRequires: kabi-dw
%endif

%if %{signkernel}%{signmodules}
BuildRequires: openssl
%if %{signkernel}
# ELN uses Fedora signing process, so exclude
%if 0%{?rhel}%{?centos} && !0%{?eln}
BuildRequires: system-sb-certs
%endif
%ifarch x86_64 aarch64
BuildRequires: nss-tools
BuildRequires: pesign >= 0.10-4
%endif
%endif
%endif

%if %{with_cross}
BuildRequires: binutils-%{_build_arch}-linux-gnu, gcc-%{_build_arch}-linux-gnu
%define cross_opts CROSS_COMPILE=%{_build_arch}-linux-gnu-
%define __strip %{_build_arch}-linux-gnu-strip
%endif

# These below are required to build man pages
%if %{with_perf}
BuildRequires: xmlto
%endif
%if %{with_perf} || %{with_tools}
BuildRequires: asciidoc
%endif

%if %{with toolchain_clang}
BuildRequires: clang
%endif

%if %{with clang_lto}
BuildRequires: llvm
BuildRequires: lld
%endif

%if %{efiuki}
BuildRequires: dracut >= 057-67.git20240812.el9
# For dracut UEFI uki binaries
BuildRequires: binutils
# For the initrd
BuildRequires: lvm2
# For systemd-stub
BuildRequires: systemd-boot-unsigned
# For systemd-pcrphase
BuildRequires: systemd-udev >= 252-1
# For UKI kernel cmdline addons
BuildRequires: systemd-ukify
# For TPM operations in UKI initramfs
BuildRequires: tpm2-tools
# For Azure CVM specific udev rules
BuildRequires: WALinuxAgent-cvm
# For UKI sb cert
%if 0%{?centos}
BuildRequires: centos-sb-certs >= 9.0-23
%else
BuildRequires: redhat-sb-certs >= 9.4-0.1
%endif
%endif

# Because this is the kernel, it's hard to get a single upstream URL
# to represent the base without needing to do a bunch of patching. This
# tarball is generated from a src-git tree. If you want to see the
# exact git commit you can run
#
# xzcat -qq ${TARBALL} | git get-tar-commit-id
Source0: linux-%{tarfile_release}.tar.xz

Source1: Makefile.rhelver
Source2: kernel.changelog

%if %{signkernel}

# Name of the packaged file containing signing key
%ifarch ppc64le
%define signing_key_filename kernel-signing-ppc.cer
%endif
%ifarch s390x
%define signing_key_filename kernel-signing-s390.cer
%endif

%define secureboot_ca_0 %{_datadir}/pki/sb-certs/secureboot-ca-%{_arch}.cer
%define secureboot_key_0 %{_datadir}/pki/sb-certs/secureboot-kernel-%{_arch}.cer

%if 0%{?centos}
%define pesign_name_0 centossecureboot201
%else
%ifarch x86_64 aarch64
%define pesign_name_0 redhatsecureboot501
%endif
%ifarch s390x
%define pesign_name_0 redhatsecureboot302
%endif
%ifarch ppc64le
%define pesign_name_0 redhatsecureboot701
%endif
%endif

# signkernel
%endif

Source20: mod-denylist.sh
Source21: mod-sign.sh
Source22: parallel_xz.sh

%define modsign_cmd %{SOURCE21}

%if 0%{?include_rhel}
Source23: x509.genkey.rhel

Source24: kernel-aarch64-rhel.config
Source25: kernel-aarch64-debug-rhel.config
Source26: mod-extra.list.rhel

Source27: kernel-ppc64le-rhel.config
Source28: kernel-ppc64le-debug-rhel.config
Source29: kernel-s390x-rhel.config
Source30: kernel-s390x-debug-rhel.config
Source31: kernel-s390x-zfcpdump-rhel.config
Source32: kernel-x86_64-rhel.config
Source33: kernel-x86_64-debug-rhel.config

Source34: filter-x86_64.sh.rhel
Source35: filter-armv7hl.sh.rhel
Source37: filter-aarch64.sh.rhel
Source38: filter-ppc64le.sh.rhel
Source39: filter-s390x.sh.rhel
Source40: filter-modules.sh.rhel

Source41: x509.genkey.centos
# ARM64 64K page-size kernel config
Source42: kernel-aarch64-64k-rhel.config
Source43: kernel-aarch64-64k-debug-rhel.config

Source44: kernel-x86_64-rt-rhel.config
Source45: kernel-x86_64-rt-debug-rhel.config
Source46: kernel-aarch64-rt-rhel.config
Source47: kernel-aarch64-rt-debug-rhel.config
%endif

%if 0%{?include_fedora}
Source50: x509.genkey.fedora
Source51: mod-extra.list.fedora

Source52: kernel-aarch64-fedora.config
Source53: kernel-aarch64-debug-fedora.config
Source54: kernel-armv7hl-fedora.config
Source55: kernel-armv7hl-debug-fedora.config
Source56: kernel-armv7hl-lpae-fedora.config
Source57: kernel-armv7hl-lpae-debug-fedora.config
Source60: kernel-ppc64le-fedora.config
Source61: kernel-ppc64le-debug-fedora.config
Source62: kernel-s390x-fedora.config
Source63: kernel-s390x-debug-fedora.config
Source64: kernel-x86_64-fedora.config
Source65: kernel-x86_64-debug-fedora.config

Source67: filter-x86_64.sh.fedora
Source68: filter-armv7hl.sh.fedora
Source70: filter-aarch64.sh.fedora
Source71: filter-ppc64le.sh.fedora
Source72: filter-s390x.sh.fedora
Source73: filter-modules.sh.fedora
%endif

Source75: partial-kgcov-snip.config
Source80: generate_all_configs.sh
Source81: process_configs.sh

Source82: update_scripts.sh

Source84: mod-internal.list
Source85: mod-partner.list
Source86: mod-kvm.list

Source100: rheldup3.x509
Source101: rhelkpatch1.x509
Source102: rhelimaca1.x509
Source103: rhelima.x509
Source104: rhelima_centos.x509
Source105: nvidiagpuoot001.x509

%if 0%{?centos}
%define ima_signing_cert %{SOURCE104}
%else
%define ima_signing_cert %{SOURCE103}
%endif

%define ima_cert_name ima.cer

Source150: dracut-virt.conf

Source151: uki_create_addons.py
Source152: uki_addons.json

Source200: check-kabi

Source201: Module.kabi_aarch64
Source202: Module.kabi_ppc64le
Source203: Module.kabi_s390x
Source204: Module.kabi_x86_64

Source210: Module.kabi_dup_aarch64
Source211: Module.kabi_dup_ppc64le
Source212: Module.kabi_dup_s390x
Source213: Module.kabi_dup_x86_64

Source300: kernel-abi-stablelists-%{kabiversion}.tar.bz2
Source301: kernel-kabi-dw-%{kabiversion}.tar.bz2

# Sources for kernel-tools
Source2000: cpupower.service
Source2001: cpupower.config
Source2002: kvm_stat.logrotate

# Some people enjoy building customized kernels from the dist-git in Fedora and
# use this to override configuration options. One day they may all use the
# source tree, but in the mean time we carry this to support the legacy workflow
Source3000: merge.pl
Source3001: kernel-local
%if %{patchlist_changelog}
Source3002: Patchlist.changelog
%endif

Source4000: README.rst
Source4001: rpminspect.yaml
Source4002: gating.yaml

## Patches needed for building this package

%if !%{nopatches}

Patch1: patch-%{patchversion}-redhat.patch
%endif

# empty final patch to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch

# END OF PATCH DEFINITIONS

%description
The kernel meta package

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf [-o] <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf(o) \
%if %{-o:0}%{!-o:1}\
Provides: kernel = %{specversion}-%{pkg_release}\
%endif\
Provides: kernel-%{_target_cpu} = %{specversion}-%{pkg_release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): ((linux-firmware >= 20150904-56.git6ebf5d57) if linux-firmware)\
Recommends: linux-firmware\
Requires(preun): systemd >= 200\
Conflicts: xfsprogs < 4.3.0-1\
Conflicts: xorg-x11-drv-vmmouse < 13.0.99\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package cross-headers
Summary: Header files for the Linux kernel for use by cross-glibc
%description cross-headers
Kernel-cross-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
cross-glibc package.


%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Provides: installonlypkg(kernel)
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Requires: bzip2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
Summary: Debug information for package perf
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|.*%%{_libdir}/libperf-jvmti.so(\.debug)?|XXX' -o perf-debuginfo.list}

%package -n python3-perf
Summary: Python bindings for apps which will manipulate perf events
%description -n python3-perf
The python3-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%package -n python3-perf-debuginfo
Summary: Debug information for package perf python bindings
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n python3-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{python3_sitearch}/perf.*so(\.debug)?|XXX' -o python3-perf-debuginfo.list}

%package -n libperf
Summary: The perf library from kernel source
%description -n libperf
This package contains the kernel source perf library.

%package -n libperf-devel
Summary: Developement files for the perf library from kernel source
Requires: libperf = %{version}-%{release}
%description -n libperf-devel
This package includes libraries and header files needed for development
of applications which use perf library from kernel source.

%package -n libperf-debuginfo
Summary: Debug information for package libperf
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n libperf-debuginfo
This package provides debug information for the libperf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libdir}/libperf.so.*(\.debug)?|XXX' -o libperf-debuginfo.list}

# with_perf
%endif

%if %{with_tools}
%package -n kernel-tools
Summary: Assortment of tools for the Linux kernel
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides:  cpufreq-utils = 1:009-0.6.p1
Provides:  cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:1.5-16
Requires: kernel-tools-libs = %{version}-%{release}
%endif
%define __requires_exclude ^%{_bindir}/python
%description -n kernel-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n kernel-tools-libs
Summary: Libraries for the kernels-tools
%description -n kernel-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n kernel-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
Requires: kernel-tools = %{version}-%{release}
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
%endif
Requires: kernel-tools-libs = %{version}-%{release}
Provides: kernel-tools-devel
%description -n kernel-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n kernel-tools-debuginfo
Summary: Debug information for package kernel-tools
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n kernel-tools-debuginfo
This package provides debug information for package kernel-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/bootconfig(\.debug)?|.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|.*%%{_bindir}/lsgpio(\.debug)?|.*%%{_bindir}/gpio-hammer(\.debug)?|.*%%{_bindir}/gpio-event-mon(\.debug)?|.*%%{_bindir}/gpio-watch(\.debug)?|.*%%{_bindir}/iio_event_monitor(\.debug)?|.*%%{_bindir}/iio_generic_buffer(\.debug)?|.*%%{_bindir}/lsiio(\.debug)?|.*%%{_bindir}/intel-speed-select(\.debug)?|.*%%{_bindir}/page_owner_sort(\.debug)?|.*%%{_bindir}/slabinfo(\.debug)?|.*%%{_sbindir}/intel_sdsi(\.debug)?|XXX' -o kernel-tools-debuginfo.list}

%package -n rtla
Summary: Real-Time Linux Analysis tools
Requires: libtraceevent
Requires: libtracefs
%description -n rtla
The rtla meta-tool includes a set of commands that aims to analyze
the real-time properties of Linux. Instead of testing Linux as a black box,
rtla leverages kernel tracing capabilities to provide precise information
about the properties and root causes of unexpected results.

%package -n rv
Summary: RV: Runtime Verification
%description -n rv
Runtime Verification (RV) is a lightweight (yet rigorous) method that
complements classical exhaustive verification techniques (such as model
checking and theorem proving) with a more practical approach for
complex systems.
The rv tool is the interface for a collection of monitors that aim
analysing the logical and timing behavior of Linux.

# with_tools
%endif

%if %{with_bpftool}

%define bpftoolversion 7.5.0

%package -n bpftool
Summary: Inspection and simple manipulation of eBPF programs and maps
Version: %{bpftoolversion}
%description -n bpftool
This package contains the bpftool, which allows inspection and simple
manipulation of eBPF programs and maps.

%package -n bpftool-debuginfo
Summary: Debug information for package bpftool
Version: %{bpftoolversion}
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{specversion}-%{release}
AutoReqProv: no
%description -n bpftool-debuginfo
This package provides debug information for the bpftool package.

%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_sbindir}/bpftool(\.debug)?|XXX' -o bpftool-debuginfo.list}

# Setting "Version:" above overrides the internal {version} macro,
# need to restore it here
%define version %{specversion}

# with_bpftool
%endif

%if %{with_selftests}

%package selftests-internal
Summary: Kernel samples and selftests
Requires: binutils, bpftool, iproute-tc, nmap-ncat, python3, fuse-libs, keyutils
%description selftests-internal
Kernel sample programs and selftests.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libexecdir}/(ksamples|kselftests)/.*|XXX' -o selftests-debuginfo.list}

%define __requires_exclude ^liburandom_read.so.*$

# with_selftests
%endif

%define kernel_gcov_package() \
%package %{?1:%{1}-}gcov\
Summary: gcov graph and source files for coverage data collection.\
%description %{?1:%{1}-}gcov\
%{?1:%{1}-}gcov includes the gcov graph and source files for gcov coverage collection.\
%{nil}

%package -n kernel-abi-stablelists
Summary: The Red Hat Enterprise Linux kernel ABI symbol stablelists
AutoReqProv: no
%description -n kernel-abi-stablelists
The kABI package contains information pertaining to the Red Hat Enterprise
Linux kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

%if %{with_kabidw_base}
%package kernel-kabidw-base-internal
Summary: The baseline dataset for kABI verification using DWARF data
Group: System Environment/Kernel
AutoReqProv: no
%description kernel-kabidw-base-internal
The package contains data describing the current ABI of the Red Hat Enterprise
Linux kernel, suitable for the kabi-dw tool.
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
# Explanation of the find_debuginfo_opts: We build multiple kernels (debug
# pae etc.) so the regex filters those kernels appropriately. We also
# have to package several binaries as part of kernel-devel but getting
# unique build-ids is tricky for these userspace binaries. We don't really
# care about debugging those so we just filter those out and remove it.
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
%description %{?1:%{1}-}debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} --keep-section '.BTF' -p '.*\/usr\/src\/kernels/.*|XXX' -o ignored-debuginfo.list -p '/.*/%%{KVERREL_RE}%{?1:[+]%{1}}/.*|/.*%%{KVERREL_RE}%{?1:\+%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_package(m) \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Provides: kernel%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-devel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
Requires(pre): findutils\
Requires: findutils\
Requires: perl-interpreter\
Requires: openssl-devel\
Requires: elfutils-libelf-devel\
Requires: bison\
Requires: flex\
Requires: make\
Requires: gcc\
%if %{-m:1}%{!-m:0}\
Requires: kernel-devel-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
%description %{?1:%{1}-}devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates an empty kernel-<subpackage>-devel-matched package that
# requires both the core and devel packages locked on the same version.
#	%%kernel_devel_matched_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_matched_package(m) \
%package %{?1:%{1}-}devel-matched\
Summary: Meta package to install matching core and devel packages for a given %{?2:%{2} }kernel\
Requires: kernel%{?1:-%{1}}-devel = %{version}-%{release}\
Requires: kernel%{?1:-%{1}}-core = %{version}-%{release}\
%description %{?1:%{1}-}devel-matched\
This meta package is used to install matching core and devel packages for a given %{?2:%{2} }kernel.\
%{nil}

#
# kernel-<variant>-ipaclones-internal package
#
%define kernel_ipaclones_package() \
%package %{?1:%{1}-}ipaclones-internal\
Summary: *.ipa-clones files generated by -fdump-ipa-clones for kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
AutoReqProv: no\
%description %{?1:%{1}-}ipaclones-internal\
This package provides *.ipa-clones files.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-internal package.
#	%%kernel_modules_internal_package <subpackage> <pretty-name>
#
%define kernel_modules_internal_package() \
%package %{?1:%{1}-}modules-internal\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-internal = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-internal-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-internal\
This package provides kernel modules for the %{?2:%{2} }kernel package for Red Hat internal usage.\
%{nil}

%if %{with_realtime}
#
# this macro creates a kernel-<subpackage>-kvm package
# %%kernel_kvm_package <subpackage>
#
%define kernel_kvm_package() \
%package %{?1:%{1}-}kvm\
Summary: KVM modules for package kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-kvm-%{_target_cpu} = %{version}-%{release}\
AutoReq: no\
%description -n kernel%{?1:-%{1}}-kvm\
This package provides KVM modules for package kernel%{?1:-%{1}}.\
%{nil}
%endif

#
# This macro creates a kernel-<subpackage>-modules-extra package.
#	%%kernel_modules_extra_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_extra_package(m) \
%package %{?1:%{1}-}modules-extra\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Provides: kernel%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-extra = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-extra-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-extra\
This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules package.
#	%%kernel_modules_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_package(m) \
%package %{?1:%{1}-}modules\
Summary: kernel modules to match the %{?2:%{2}-}core kernel\
Provides: kernel%{?1:-%{1}}-modules-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-modules-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-modules = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules\
This package provides commonly used kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-core package.
#	%%kernel_modules_core_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_core_package(m) \
%package %{?1:%{1}-}modules-core\
Summary: Core kernel modules to match the %{?2:%{2}-}core kernel\
Provides: kernel%{?1:-%{1}}-modules-core-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-modules-core-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-modules-core = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-core-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-core\
This package provides essential kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# this macro creates a kernel-<subpackage> meta package.
#	%%kernel_meta_package <subpackage>
#
%define kernel_meta_package() \
%package %{1}\
summary: kernel meta-package for the %{1} kernel\
Requires: kernel-%{1}-core-uname-r = %{KVERREL}%{uname_suffix %{1}}\
Requires: kernel-%{1}-modules-uname-r = %{KVERREL}%{uname_suffix %{1}}\
Requires: kernel-%{1}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{1}}\
%if "%{1}" == "rt" || "%{1}" == "rt-debug"\
Requires: realtime-setup\
%endif\
Provides: installonlypkg(kernel)\
%description %{1}\
The meta-package for the %{1} kernel\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] [-m] [-o] <subpackage>
#
%define kernel_variant_package(n:mo) \
%package %{?1:%{1}-}core\
Summary: %{variant_summary}\
Provides: kernel-%{?1:%{1}-}core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel)\
%if %{-m:1}%{!-m:0}\
Requires: kernel-core-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
Requires: kernel-%{?1:%{1}-}-modules-core-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
%{expand:%%kernel_reqprovconf %{?1:%{1}} %{-o:%{-o}}}\
%if %{?1:1} %{!?1:0} \
%{expand:%%kernel_meta_package %{?1:%{1}}}\
%endif\
%{expand:%%kernel_devel_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_devel_matched_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_core_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_extra_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%if %{-m:0}%{!-m:1}\
%{expand:%%kernel_modules_internal_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%if 0%{!?fedora:1}\
%{expand:%%kernel_modules_partner_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif\
%{expand:%%kernel_debuginfo_package %{?1:%{1}}}\
%endif\
%if %{efiuki}\
%if "%{1}" != "rt" && "%{1}" != "rt-debug"\
%package %{?1:%{1}-}uki-virt\
Summary: %{variant_summary} unified kernel image for virtual machines\
Provides: installonlypkg(kernel)\
Provides: kernel-%{?1:%{1}-}uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): systemd >= 252-20\
%package %{?1:%{1}-}uki-virt-addons\
Summary: %{variant_summary} unified kernel image addons for virtual machines\
Provides: installonlypkg(kernel)\
Requires: kernel%{?1:-%{1}}-uki-virt = %{version}-%{release}\
Requires(pre): systemd >= 252-20\
%endif\
%endif\
%if "%{1}" == "rt" || "%{1}" == "rt-debug"\
%{expand:%%kernel_kvm_package %{?1:%{1}}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif \
%if %{with_gcov}\
%{expand:%%kernel_gcov_package %{?1:%{1}}}\
%endif\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-partner package.
#	%%kernel_modules_partner_package <subpackage> <pretty-name>
#
%define kernel_modules_partner_package() \
%package %{?1:%{1}-}modules-partner\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-modules-partner-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-partner-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-partner = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-partner-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-partner\
This package provides kernel modules for the %{?2:%{2} }kernel package for Red Hat partners usage.\
%{nil}

# Now, each variant package.

%if %{with_pae}
%define variant_summary The Linux kernel compiled for Cortex-A15
%kernel_variant_package lpae
%description lpae-core
This package includes a version of the Linux kernel with support for
Cortex-A15 devices with LPAE and HW virtualisation support
%endif

%if %{with_zfcpdump}
%define variant_summary The Linux kernel compiled for zfcpdump usage
%kernel_variant_package -o zfcpdump
%description zfcpdump-core
The kernel package contains the Linux kernel (vmlinuz) for use by the
zfcpdump infrastructure.
# with_zfcpdump
%endif

%if %{with_arm64_64k}
%define variant_summary The Linux kernel compiled for 64k pagesize usage
%kernel_variant_package 64k
%description 64k-core
The kernel package contains a variant of the ARM64 Linux kernel using
a 64K page size.
%endif

%if %{with_arm64_64k} && %{with_debug}
%define variant_summary The Linux kernel compiled with extra debugging enabled
%if !%{debugbuildsenabled}
%kernel_variant_package -m 64k-debug
%else
%kernel_variant_package 64k-debug
%endif
%description 64k-debug-core
The debug kernel package contains a variant of the ARM64 Linux kernel using
a 64K page size.
This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with_realtime}
%define variant_summary The Linux kernel compiled with PREEMPT_RT enabled
%kernel_variant_package rt
%description rt-core
This package includes a version of the Linux kernel compiled with PREEMPT_RT
(real-time preemption support).
%endif

%if %{with_debug} && %{with_realtime}
%define variant_summary The Linux kernel compiled with PREEMPT_RT enabled
%kernel_variant_package rt-debug
%description rt-debug-core
This package includes a version of the Linux kernel compiled with PREEMPT_RT
(real-time preemption support) and has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if !%{debugbuildsenabled}
%kernel_variant_package -m debug
%else
%kernel_variant_package debug
%endif
%description debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

# And finally the main -core package

%define variant_summary The Linux kernel
%kernel_variant_package
%description core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

%if %{efiuki}
%description debug-uki-virt
Prebuilt debug unified kernel image for virtual machines.

%description debug-uki-virt-addons
Prebuilt debug unified kernel image addons for virtual machines.

%description uki-virt
Prebuilt default unified kernel image for virtual machines.

%description uki-virt-addons
Prebuilt default unified kernel image addons for virtual machines.
%endif

%if %{with_ipaclones}
%kernel_ipaclones_package
%endif

%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
      echo "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='git apply'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME}.spec ; then
    if [ "${patch:0:8}" != "patch-%{kversion}." ] ; then
      echo "ERROR: Patch  $patch  not listed as a source patch in specfile"
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz)  gunzip  < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.xz)  unxz    < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%setup -q -n kernel-%{tarfile_release} -c
mv linux-%{tarfile_release} linux-%{KVERREL}

cd linux-%{KVERREL}
cp -a %{SOURCE1} .

%if !%{nopatches}

ApplyOptionalPatch patch-%{patchversion}-redhat.patch
%endif

ApplyOptionalPatch linux-kernel-test.patch

# END OF PATCH APPLICATIONS

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl
mv COPYING COPYING-%{version}-%{release}

# This Prevents scripts/setlocalversion from mucking with our version numbers.
touch .scmversion

# Mangle /usr/bin/python shebangs to /usr/bin/python3
# Mangle all Python shebangs to be Python 3 explicitly
# -p preserves timestamps
# -n prevents creating ~backup files
# -i specifies the interpreter for the shebang
# This fixes errors such as
# *** ERROR: ambiguous python shebang in /usr/bin/kvm_stat: #!/usr/bin/python. Change it to python3 (or python2) explicitly.
# We patch all sources below for which we got a report/error.
pathfix.py -i "%{__python3}" -p -n \
	tools/kvm/kvm_stat/kvm_stat \
	scripts/show_delta \
	scripts/diffconfig \
	scripts/bloat-o-meter \
	scripts/jobserver-exec \
	tools \
	Documentation \
	scripts/clang-tools

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
fi
mkdir configs
cd configs

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/kernel-*.config .
cp %{SOURCE80} .
# merge.pl
cp %{SOURCE3000} .
# kernel-local
cp %{SOURCE3001} .
FLAVOR=%{primary_target} SPECVERSION=%{version} ./generate_all_configs.sh %{debugbuildsenabled}

# Merge in any user-provided local config option changes
%ifnarch %nobuildarches
for i in %{all_arch_configs}
do
  mv $i $i.tmp
  ./merge.pl %{SOURCE3001} $i.tmp > $i
%if %{with_gcov}
  echo "Merging with gcov options"
  cat %{SOURCE75}
  mv $i $i.tmp
  ./merge.pl %{SOURCE75} $i.tmp > $i
%endif
  rm $i.tmp
done
%endif

%if %{with clang_lto}
for i in *aarch64*.config *x86_64*.config; do
  sed -i 's/# CONFIG_LTO_CLANG_THIN is not set/CONFIG_LTO_CLANG_THIN=y/' $i
  sed -i 's/CONFIG_LTO_NONE=y/# CONFIG_LTO_NONE is not set/' $i
done
%endif

# Add DUP and kpatch certificates to system trusted keys for RHEL
%if 0%{?rhel}
%if %{signkernel}%{signmodules}
openssl x509 -inform der -in %{SOURCE100} -out rheldup3.pem
openssl x509 -inform der -in %{SOURCE101} -out rhelkpatch1.pem
openssl x509 -inform der -in %{SOURCE102} -out rhelimaca1.pem
openssl x509 -inform der -in %{SOURCE105} -out nvidiagpuoot001.pem
cat rheldup3.pem rhelkpatch1.pem rhelimaca1.pem nvidiagpuoot001.pem > ../certs/rhel.pem
%if %{signkernel}
%ifarch s390x ppc64le
openssl x509 -inform der -in %{secureboot_ca_0} -out secureboot.pem
cat secureboot.pem >> ../certs/rhel.pem
%endif
%endif
for i in *.config; do
  sed -i 's@CONFIG_SYSTEM_TRUSTED_KEYS=""@CONFIG_SYSTEM_TRUSTED_KEYS="certs/rhel.pem"@' $i
done
%endif
%endif

# Adjust FIPS module name for RHEL
%if 0%{?rhel}
for i in *.config; do
  sed -i 's/CONFIG_CRYPTO_FIPS_NAME=.*/CONFIG_CRYPTO_FIPS_NAME="Red Hat Enterprise Linux %{rhel} - Kernel Cryptographic API"/' $i
done
%endif

cp %{SOURCE81} .
OPTS=""
%if %{with_configchecks}
	OPTS="$OPTS -w -n -c"
%endif
%if %{with clang_lto}
for opt in %{clang_make_opts}; do
  OPTS="$OPTS -m $opt"
done
%endif
RHJOBS=$RPM_BUILD_NCPUS PACKAGE_NAME=kernel ./process_configs.sh $OPTS ${specversion}

cp %{SOURCE82} .
RPM_SOURCE_DIR=$RPM_SOURCE_DIR ./update_scripts.sh %{primary_target}

# We may want to override files from the primary target in case of building
# against a flavour of it (eg. centos not rhel), thus override it here if
# necessary
if [ "%{primary_target}" == "rhel" ]; then
%if 0%{?centos}
  echo "Updating scripts/sources to centos version"
  RPM_SOURCE_DIR=$RPM_SOURCE_DIR ./update_scripts.sh centos
%else
  echo "Not updating scripts/sources to centos version"
%endif
fi

# end of kernel config
%endif

cd ..
# # End of Configs stuff

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -delete >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -delete >/dev/null

cd ..

###
### build
###
%build

rm -rf %{buildroot_unstripped} || true
mkdir -p %{buildroot_unstripped}

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

# Note we need to disable these flags for cross builds because the flags
# from redhat-rpm-config assume that host == target so target arch
# flags cause issues with the host compiler.
%if !%{with_cross}
%define build_hostcflags  %{?build_cflags}
%define build_hostldflags %{?build_ldflags}
%endif

%define make %{__make} %{?cross_opts} %{?make_opts} HOSTCFLAGS="%{?build_hostcflags}" HOSTLDFLAGS="%{?build_hostldflags}"

InitBuildVars() {
    # Initialize the kernel .config file and create some variables that are
    # needed for the actual build process.

    Variant=$1

    # Pick the right kernel config file
    Config=kernel-%{version}-%{_target_cpu}${Variant:+-${Variant}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Variant:++${Variant}}

    KernelVer=%{version}-%{release}.%{_target_cpu}${Variant:++${Variant}}

    # make sure EXTRAVERSION says what we want it to say
    # Trim the release if this is a CI build, since KERNELVERSION is limited to 64 characters
    ShortRel=$(perl -e "print \"%{release}\" =~ s/\.pr\.[0-9A-Fa-f]{32}//r")
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -${ShortRel}.%{_target_cpu}${Variant:++${Variant}}/" Makefile

    # if pre-rc1 devel kernel, must fix up PATCHLEVEL for our versioning scheme
    # if we are post rc1 this should match anyway so this won't matter
    perl -p -i -e 's/^PATCHLEVEL.*/PATCHLEVEL = %{patchlevel}/' Makefile

    %{make} %{?_smp_mflags} mrproper
    cp configs/$Config .config

    %if %{signkernel}%{signmodules}
    cp configs/x509.genkey certs/.
    %endif

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    KCFLAGS="%{?kcflags}"

    # add kpatch flags for base kernel
    if [ "$Variant" == "" ]; then
        KCFLAGS="$KCFLAGS %{?kpatch_kcflags}"
    fi
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    DoVDSO=$3
    Variant=$4
    InstallName=${5:-vmlinuz}

    DoModules=1
    if [ "$Variant" = "zfcpdump" ]; then
	    DoModules=0
    fi

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

%if %{with_gcov}
    # Make build directory unique for each variant, so that gcno symlinks
    # are also unique for each variant.
    if [ -n "$Variant" ]; then
        ln -s $(pwd) ../linux-%{KVERREL}-${Variant}
    fi
    echo "GCOV - continuing build in: $(pwd)"
    pushd ../linux-%{KVERREL}${Variant:+-${Variant}}
    pwd > ../kernel${Variant:+-${Variant}}-gcov.list
%endif

    InitBuildVars $Variant

    echo BUILDING A KERNEL FOR ${Variant} %{_target_cpu}...

    %{make} ARCH=$Arch olddefconfig >/dev/null

    # This ensures build-ids are unique to allow parallel debuginfo
    perl -p -i -e "s/^CONFIG_BUILD_SALT.*/CONFIG_BUILD_SALT=\"%{KVERREL}\"/" .config
    %{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} $MakeTarget %{?sparse_mflags} %{?kernel_mflags}
    if [ $DoModules -eq 1 ]; then
	%{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} modules %{?sparse_mflags} || exit 1
    fi

    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/systemtap
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif

%ifarch %{arm} aarch64
    %{make} ARCH=$Arch dtbs INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    %{make} ARCH=$Arch dtbs_install INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    cp -r $RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/dtb
    find arch/$Arch/boot/dts -name '*.dtb' -type f -delete
%endif

    # Start installing the results
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/config
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/System.map

    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/lib/modules/$KernelVer/zImage.stub-$KernelVer || :
    fi

    %if %{signkernel}
    if [ "$KernelImage" = vmlinux ]; then
        # We can't strip and sign $KernelImage in place, because
        # we need to preserve original vmlinux for debuginfo.
        # Use a copy for signing.
        $CopyKernel $KernelImage $KernelImage.tosign
        KernelImage=$KernelImage.tosign
        CopyKernel=cp
    fi

    # Sign the image if we're using EFI
    # aarch64 kernels are gziped EFI images
    KernelExtension=${KernelImage##*.}
    if [ "$KernelExtension" == "gz" ]; then
        SignImage=${KernelImage%.*}
    else
        SignImage=$KernelImage
    fi

    %ifarch x86_64 aarch64
    %pesign -s -i $SignImage -o vmlinuz.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
    %endif
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
	rpm-sign --key "%{pesign_name_0}" --lkmsign $SignImage --output vmlinuz.signed
    elif [ "$DoModules" == "1" -a "%{signmodules}" == "1" ]; then
	chmod +x scripts/sign-file
	./scripts/sign-file -p sha256 certs/signing_key.pem certs/signing_key.x509 $SignImage vmlinuz.signed
    else
	mv $SignImage vmlinuz.signed
    fi
    %endif

    if [ ! -s vmlinuz.signed ]; then
        echo "pesigning failed"
        exit 1
    fi
    mv vmlinuz.signed $SignImage
    if [ "$KernelExtension" == "gz" ]; then
        gzip -f9 $SignImage
    fi
    # signkernel
    %endif

    $CopyKernel $KernelImage \
                $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    cp $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/$InstallName

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    (cd $RPM_BUILD_ROOT/%{image_install_path} && sha512hmac $InstallName-$KernelVer) > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
    cp $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac $RPM_BUILD_ROOT/lib/modules/$KernelVer/.vmlinuz.hmac

    if [ $DoModules -eq 1 ]; then
	# Override $(mod-fw) because we don't want it to install any firmware
	# we'll get it from the linux-firmware package and we don't want conflicts
	%{make} %{?_smp_mflags} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT %{?_smp_mflags} modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi

%if %{with_gcov}
    # install gcov-needed files to $BUILDROOT/$BUILD/...:
    #   gcov_info->filename is absolute path
    #   gcno references to sources can use absolute paths (e.g. in out-of-tree builds)
    #   sysfs symlink targets (set up at compile time) use absolute paths to BUILD dir
    find . \( -name '*.gcno' -o -name '*.[chS]' \) -exec install -D '{}' "$RPM_BUILD_ROOT/$(pwd)/{}" \;
%endif

    # add an a noop %%defattr statement 'cause rpm doesn't like empty file list files
    echo '%%defattr(-,-,-)' > ../kernel${Variant:+-${Variant}}-ldsoconf.list
    if [ $DoVDSO -ne 0 ]; then
        %{make} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
        if [ -s ldconfig-kernel.conf ]; then
             install -D -m 444 ldconfig-kernel.conf \
                $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
	     echo /etc/ld.so.conf.d/kernel-$KernelVer.conf >> ../kernel${Variant:+-${Variant}}-ldsoconf.list
        fi

        rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/vdso/.build-id
    fi

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # CONFIG_KERNEL_HEADER_TEST generates some extra files in the process of
    # testing so just delete
    find . -name *.h.s -delete
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ ! -e Module.symvers ]; then
        touch Module.symvers
    fi
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    cp $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/symvers.gz

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidupchk}
    echo "**** kABI DUP checking is enabled in kernel SPEC file. ****"
    if [ -e $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find DUP reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidw_base}
    # Don't build kabi base for debug kernels
    if [ "$Variant" != "zfcpdump" -a "$Variant" != "debug" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf

        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
        tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

        echo "**** GENERATING DWARF-based kABI baseline dataset ****"
        chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
        $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
            "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
            "$(pwd)" \
            "$RPM_BUILD_ROOT/kabidw-base/%{_target_cpu}${Variant:+.${Variant}}" || :

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

%if %{with_kabidwchk}
    if [ "$Variant" != "zfcpdump" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf
        if [ -d "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" ]; then
            mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
            tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

            echo "**** GENERATING DWARF-based kABI dataset ****"
            chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
                "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
                "$(pwd)" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :

            echo "**** kABI DWARF-based comparison report ****"
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh compare \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :
            echo "**** End of kABI DWARF-based comparison report ****"
        else
            echo "**** Baseline dataset for kABI DWARF-BASED comparison report not found ****"
        fi

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/tracing
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/spdxcheck.py

%ifarch s390x
    # CONFIG_EXPOLINE_EXTERN=y produces arch/s390/lib/expoline/expoline.o
    # which is needed during external module build.
    if [ -f arch/s390/lib/expoline/expoline.o ]; then
      cp -a --parents arch/s390/lib/expoline/expoline.o $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi
%endif

    # Files for 'make scripts' to succeed with kernel-devel.
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/security/selinux/include
    cp -a --parents security/selinux/include/classmap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents security/selinux/include/initial_sid_to_string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/include/tools
    cp -a --parents tools/include/tools/be_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/tools/le_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # Files for 'make prepare' to succeed with kernel-devel.
    cp -a --parents tools/include/linux/compiler* $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux/types.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/build/Build.include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/build/fixdep.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/sync-check.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/bpf/resolve_btfids $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp --parents security/selinux/include/policycap_names.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents security/selinux/include/policycap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp -a --parents tools/include/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/vdso $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/scripts/utilities.mak $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/subcmd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/*.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/*.[ch] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/include/objtool/*.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/bpf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/bpf/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    if [ -f tools/objtool/objtool ]; then
      cp -a tools/objtool/objtool $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -f tools/objtool/fixdep ]; then
      cp -a tools/objtool/fixdep $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    if [ -f arch/%{asmarch}/kernel/module.lds ]; then
      cp -a --parents arch/%{asmarch}/kernel/module.lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +
%ifarch ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    if [ -d tools/arch/%{asmarch}/include ]; then
      cp -a --parents tools/arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi
%ifarch aarch64
    # arch/arm64/include/asm/xen references arch/arm
    cp -a --parents arch/arm/include/asm/xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    # arch/arm64/include/asm/opcodes.h references arch/arm
    cp -a --parents arch/arm/include/asm/opcodes.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    # include the machine specific headers for ARM variants, if available.
%ifarch %{arm}
    if [ -d arch/%{asmarch}/mach-${Variant}/include ]; then
      cp -a --parents arch/%{asmarch}/mach-${Variant}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    # include a few files for 'make prepare'
    cp -a --parents arch/arm/tools/gen-mach-types $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/arm/tools/mach-types $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

%endif
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    # Cross-reference from include/perf/events/sof.h
    cp -a sound/soc/sof/sof-audio.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/sound/soc/sof
%ifarch i686 x86_64
    # files for 'make prepare' to succeed with kernel-devel
    cp -a --parents arch/x86/entry/syscalls/syscall_32.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscall_64.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_32.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_common.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/purgatory.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/stack.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/setup-x86_64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/entry64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/ctype.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents scripts/syscalltbl.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents scripts/syscallhdr.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents tools/arch/x86/include/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/lib $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/lib/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/tools/gen-insn-attr-x86.awk $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%endif
    # Clean up intermediate tools files
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +

    # Make sure the Makefile, version.h, and auto.conf have a matching
    # timestamp so that external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile \
        $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h \
        $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    eu-readelf -n vmlinux | grep "Build ID" | awk '{print $NF}' > vmlinux.id
    cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    if [ -n "%{vmlinux_decompressor}" ]; then
	    eu-readelf -n  %{vmlinux_decompressor} | grep "Build ID" | awk '{print $NF}' > vmlinux.decompressor.id
	    # Without build-id the build will fail. But for s390 the build-id
	    # wasn't added before 5.11. In case it is missing prefer not
	    # packaging the debuginfo over a build failure.
	    if [ -s vmlinux.decompressor.id ]; then
		    cp vmlinux.decompressor.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.decompressor.id
		    cp %{vmlinux_decompressor} $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer/vmlinux.decompressor
	    fi
    fi
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
        LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking \
      'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt(l_|2x00)(pci|usb)_probe|register_netdevice'
    collect_modules_list block \
      'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm \
      'drm_open|drm_init'
    collect_modules_list modesetting \
      'drm_crtc_init'

    # detect missing or incorrect license tags
    ( find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name '*.ko' | xargs /sbin/modinfo -l | \
        grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' ) && exit 1

    remove_depmod_files()
    {
        # remove files that will be auto generated by depmod at rpm -i time
        pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
            # in case below list needs to be extended, remember to add a
            # matching ghost entry in the files section as well
            rm -f modules.{alias,alias.bin,builtin.alias.bin,builtin.bin} \
                  modules.{dep,dep.bin,devname,softdep,symbols,symbols.bin}
        popd
    }

    remove_depmod_files

    # Identify modules in the kernel-modules-extras package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer $(realpath configs/mod-extra.list)
    # Identify modules in the kernel-modules-extras package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE84} internal
%if 0%{!?fedora:1}
    # Identify modules in the kernel-modules-partner package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE85} partner
%endif
    if [ "$Variant" = "rt" ] || [ "$Variant" = "rt-debug" ]; then
        # Identify modules in the kernel-rt-kvm package
        %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE86} kvm
    fi

    #
    # Generate the kernel-core and kernel-modules files lists
    #

    # Copy the System.map file for depmod to use, and create a backup of the
    # full module tree so we can restore it after we're done filtering
    cp System.map $RPM_BUILD_ROOT/.
    cp configs/filter-*.sh $RPM_BUILD_ROOT/.
    pushd $RPM_BUILD_ROOT
    mkdir restore
    cp -r lib/modules/$KernelVer/* restore/.

    # don't include anything going into kernel-modules-extra in the file lists
    xargs rm -rf < mod-extra.list
    # don't include anything going int kernel-modules-internal in the file lists
    xargs rm -rf < mod-internal.list
%if 0%{!?fedora:1}
    # don't include anything going int kernel-modules-partner in the file lists
    xargs rm -rf < mod-partner.list
%endif
    if [ "$Variant" = "rt" ] || [ "$Variant" = "rt-debug" ]; then
        # don't include anything going into kernel-rt-kvm in the file lists
        xargs rm -rf < mod-kvm.list
    fi

    if [ $DoModules -eq 1 ]; then
	# Find all the module files and filter them out into the core and
	# modules lists.  This actually removes anything going into -modules
	# from the dir.
	find lib/modules/$KernelVer/kernel -name *.ko | sort -n > modules.list
	./filter-modules.sh modules.list %{_target_cpu}
	rm filter-*.sh

	# Run depmod on the resulting module tree and make sure it isn't broken
	depmod -b . -aeF ./System.map $KernelVer &> depmod.out
	if [ -s depmod.out ]; then
	    echo "Depmod failure"
	    cat depmod.out
	    exit 1
	else
	    rm depmod.out
	fi
    else
	# Ensure important files/directories exist to let the packaging succeed
	echo '%%defattr(-,-,-)' > modules.list
	echo '%%defattr(-,-,-)' > k-d.list
	mkdir -p lib/modules/$KernelVer/kernel
	# Add files usually created by make modules, needed to prevent errors
	# thrown by depmod during package installation
	touch lib/modules/$KernelVer/modules.order
	touch lib/modules/$KernelVer/modules.builtin
    fi

%if %{efiuki}
    if [ "$Variant" != "rt" ] && [ "$Variant" != "rt-debug" ]; then
        popd

        # RHEL/CentOS specific .SBAT entries
%if 0%{?centos}
        SBATsuffix="centos"
%else
        SBATsuffix="rhel"
%endif
        SBAT=$(cat <<- EOF
	linux,1,Red Hat,linux,$KernelVer,mailto:secalert@redhat.com
	linux.$SBATsuffix,1,Red Hat,linux,$KernelVer,mailto:secalert@redhat.com
	kernel-uki-virt.$SBATsuffix,1,Red Hat,kernel-uki-virt,$KernelVer,mailto:secalert@redhat.com
	EOF
	)

        KernelUnifiedImageDir="$RPM_BUILD_ROOT/lib/modules/$KernelVer"
        KernelUnifiedImage="$KernelUnifiedImageDir/$InstallName-virt.efi"
    
        mkdir -p $KernelUnifiedImageDir
    
        dracut --conf=%{SOURCE150} \
               --confdir=$(mktemp -d) \
               --verbose \
               --kver "$KernelVer" \
               --kmoddir "$RPM_BUILD_ROOT/lib/modules/$KernelVer/" \
               --logfile=$(mktemp) \
               --uefi \
               --sbat "$SBAT" \
               --kernel-image $(realpath $KernelImage) \
               --kernel-cmdline 'console=tty0 console=ttyS0' \
    	   $KernelUnifiedImage

        KernelAddonsDirOut="$KernelUnifiedImage.extra.d"
        mkdir -p $KernelAddonsDirOut
        python3 %{SOURCE151} %{SOURCE152} $KernelAddonsDirOut virt %{primary_target} %{_target_cpu}

%if %{signkernel}

%if 0%{?centos}
	UKI_secureboot_name=centossecureboot204
%else
	UKI_secureboot_name=redhatsecureboot504
%endif
	UKI_secureboot_cert=%{_datadir}/pki/sb-certs/secureboot-uki-virt-%{_arch}.cer

        %pesign -s -i $KernelUnifiedImage -o $KernelUnifiedImage.signed -a %{secureboot_ca_0} -c $UKI_secureboot_cert -n $UKI_secureboot_name
        if [ ! -s $KernelUnifiedImage.signed ]; then
          echo "pesigning failed"
          exit 1
        fi
        mv $KernelUnifiedImage.signed $KernelUnifiedImage

      for addon in "$KernelAddonsDirOut"/*; do
        %pesign -s -i $addon -o $addon.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
        rm -f $addon
        mv $addon.signed $addon
      done

# signkernel
%endif

      # hmac sign the UKI for FIPS
      KernelUnifiedImageHMAC="$KernelUnifiedImageDir/.$InstallName-virt.efi.hmac"
      echo "hmac sign the UKI for FIPS"
      echo "Creating hmac file: $KernelUnifiedImageHMAC"
      (cd $KernelUnifiedImageDir && sha512hmac $InstallName-virt.efi) > $KernelUnifiedImageHMAC;

        pushd $RPM_BUILD_ROOT

    # Variant != rt && Variant != rt-debug
    fi
# efiuki
%endif

    remove_depmod_files

    # Go back and find all of the various directories in the tree.  We use this
    # for the dir lists in kernel-core
    find lib/modules/$KernelVer/kernel -mindepth 1 -type d | sort -n > module-dirs.list

    # Cleanup
    rm System.map
    # Just "cp -r" can be very slow: here, it rewrites _existing files_
    # with open(O_TRUNC). Many filesystems synchronously wait for metadata
    # update for such file rewrites (seen in strace as final close syscall
    # taking a long time). On a rotational disk, cp was observed to take
    # more than 5 minutes on ext4 and more than 15 minutes (!) on xfs.
    # With --remove-destination, we avoid this, and copying
    # (with enough RAM to cache it) takes 5 seconds:
    cp -r --remove-destination restore/* lib/modules/$KernelVer/.
    rm -rf restore
    popd

    # Make sure the files lists start with absolute paths or rpmbuild fails.
    # Also add in the dir entries
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/k-d.list > ../kernel${Variant:+-${Variant}}-modules.list
    sed -e 's/^lib*/%dir \/lib/' %{?zipsed} $RPM_BUILD_ROOT/module-dirs.list > ../kernel${Variant:+-${Variant}}-modules-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/modules.list >> ../kernel${Variant:+-${Variant}}-modules-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-extra.list >> ../kernel${Variant:+-${Variant}}-modules-extra.list

    # Cleanup
    rm -f $RPM_BUILD_ROOT/k-d.list
    rm -f $RPM_BUILD_ROOT/modules.list
    rm -f $RPM_BUILD_ROOT/module-dirs.list
    rm -f $RPM_BUILD_ROOT/mod-extra.list
    rm -f $RPM_BUILD_ROOT/mod-internal.list
%if 0%{!?fedora:1}
    rm -f $RPM_BUILD_ROOT/mod-partner.list
%endif
    if [ "$Variant" = "rt" ] || [ "$Variant" = "rt-debug" ]; then
        rm -f $RPM_BUILD_ROOT/mod-kvm.list
    fi

%if %{with_cross}
    make -C $RPM_BUILD_ROOT/lib/modules/$KernelVer/build M=scripts clean
    make -C $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/bpf/resolve_btfids clean
    sed -i 's/REBUILD_SCRIPTS_FOR_CROSS:=0/REBUILD_SCRIPTS_FOR_CROSS:=1/' $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile
%endif

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir

    # This is going to create a broken link during the build, but we don't use
    # it after this point.  We need the link to actually point to something
    # when kernel-devel is installed, and a relative link doesn't work across
    # the F17 UsrMove feature.
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%ifnarch armv7hl
    # Generate vmlinux.h and put it to kernel-devel path
    # zfcpdump build does not have btf anymore
    if [ "$Variant" != "zfcpdump" ]; then
        # Build the bootstrap bpftool to generate vmlinux.h
        make -C tools/bpf/bpftool bootstrap
        tools/bpf/bpftool/bootstrap/bpftool btf dump file vmlinux format c > $RPM_BUILD_ROOT/$DevelDir/vmlinux.h
    fi
%endif

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -delete

    # Red Hat UEFI Secure Boot CA cert, which can be used to authenticate the kernel
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer
%if %{signkernel}
    install -m 0644 %{secureboot_ca_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
        install -m 0644 %{secureboot_key_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
    fi
    %endif
%endif

%if 0%{?rhel}
    # Red Hat IMA code-signing cert, which is used to authenticate package files
    install -m 0644 %{ima_signing_cert} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{ima_cert_name}
%endif

%if %{signmodules}
    if [ $DoModules -eq 1 ]; then
        # Save the signing keys so we can sign the modules in __modsign_install_post
        cp certs/signing_key.pem certs/signing_key.pem.sign${Variant:++${Variant}}
        cp certs/signing_key.x509 certs/signing_key.x509.sign${Variant:++${Variant}}
        %ifarch s390x ppc64le
        if [ ! -x /usr/bin/rpm-sign ]; then
            install -m 0644 certs/signing_key.x509.sign${Variant:++${Variant}} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
            openssl x509 -in certs/signing_key.pem.sign${Variant:++${Variant}} -outform der -out $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
            chmod 0644 $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
        fi
        %endif
    fi
%endif

%if %{with_ipaclones}
    MAXPROCS=$(echo %{?_smp_mflags} | sed -n 's/-j\s*\([0-9]\+\)/\1/p')
    if [ -z "$MAXPROCS" ]; then
        MAXPROCS=1
    fi
    if [ "$Variant" == "" ]; then
        mkdir -p $RPM_BUILD_ROOT/$DevelDir-ipaclones
        find . -name '*.ipa-clones' | xargs -i{} -r -n 1 -P $MAXPROCS install -m 644 -D "{}" "$RPM_BUILD_ROOT/$DevelDir-ipaclones/{}"
    fi
%endif

%if %{with_gcov}
    popd
%endif
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVERREL}


%if %{with_debug}
BuildKernel %make_target %kernel_image %{_use_vdso} debug
%if %{with_arm64_64k}
BuildKernel %make_target %kernel_image %{_use_vdso} 64k-debug
%endif
%if %{with_realtime}
BuildKernel %make_target %kernel_image %{_use_vdso} rt-debug
%endif
%endif

%if %{with_zfcpdump}
BuildKernel %make_target %kernel_image %{_use_vdso} zfcpdump
%endif

%if %{with_arm64_64k}
BuildKernel %make_target %kernel_image %{_use_vdso} 64k
%endif

%if %{with_pae}
BuildKernel %make_target %kernel_image %{use_vdso} lpae
%endif

%if %{with_realtime}
BuildKernel %make_target %kernel_image %{use_vdso} rt
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image %{_use_vdso}
%endif

%ifnarch noarch i686
%if !%{with_debug} && !%{with_zfcpdump} && !%{with_pae} && !%{with_up} && !%{with_arm64_64k} && !%{with_realtime}
# If only building the user space tools, then initialize the build environment
# and some variables so that the various userspace tools can be built.
InitBuildVars
%endif
%endif

%ifarch aarch64
%global perf_build_extra_opts CORESIGHT=1
%endif
%global perf_make \
  %{__make} %{?make_opts} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags} -Wl,-E" %{?cross_opts} -C tools/perf V=1 NO_PERF_READ_VDSO32=1 NO_PERF_READ_VDSOX32=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 NO_BIONIC=1 LIBBPF_DYNAMIC=1 LIBTRACEEVENT_DYNAMIC=1 %{?perf_build_extra_opts} prefix=%{_prefix} PYTHON=%{__python3}
%if %{with_perf}
# perf
# make sure check-headers.sh is executable
chmod +x tools/perf/check-headers.sh
%{perf_make} DESTDIR=$RPM_BUILD_ROOT all
# libperf
make -C tools/lib/perf V=1
%endif

%global tools_make \
  CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" EXTRA_CFLAGS="${RPM_OPT_FLAGS}" %{make} %{?make_opts}

%ifarch %{cpupowerarchs}
    # link against in-tree libcpupower for idle state support
    %global rtla_make %{tools_make} LDFLAGS="%{__global_ldflags} -L../../power/cpupower" INCLUDES="-I../../power/cpupower/lib"
%else
    %global rtla_make %{tools_make}
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
%{tools_make} %{?_smp_mflags} -C tools/power/cpupower CPUFREQ_BENCH=false DEBUG=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    %{tools_make} %{?_smp_mflags} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64
   pushd tools/power/x86/x86_energy_perf_policy/
   %{tools_make}
   popd
   pushd tools/power/x86/turbostat
   %{tools_make}
   popd
   pushd tools/power/x86/intel-speed-select
   %{tools_make}
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make} CFLAGS="${RPM_OPT_FLAGS}"
   popd
%endif
%endif
pushd tools/thermal/tmon/
%{tools_make}
popd
pushd tools/bootconfig/
%{tools_make}
popd
pushd tools/iio/
%{tools_make}
popd
pushd tools/gpio/
%{tools_make}
popd
# build VM tools
pushd tools/mm/
%{tools_make} CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" slabinfo page_owner_sort
popd
pushd tools/verification/rv/
%{tools_make}
popd
pushd tools/tracing/rtla
%{rtla_make}
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi
echo "${RPM_VMLINUX_H}" > ../vmlinux_h_path

%if %{with_bpftool}
%global bpftool_make \
  %{__make} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" EXTRA_LDFLAGS="%{__global_ldflags}" DESTDIR=$RPM_BUILD_ROOT %{?make_opts} VMLINUX_H="${RPM_VMLINUX_H}" V=1
pushd tools/bpf/bpftool
%{bpftool_make}
popd
%else
echo "bpftools disabled ... disabling selftests"
%endif

%if %{with_selftests}
# Unfortunately, samples/bpf/Makefile expects that the headers are installed
# in the source tree. We installed them previously to $RPM_BUILD_ROOT/usr
# but there's no way to tell the Makefile to take them from there.
%{make} %{?_smp_mflags} headers_install

# If we re building only tools without kernel, we need to generate config
# headers and prepare tree for modules building. The modules_prepare target
# will cover both.
if [ ! -f include/generated/autoconf.h ]; then
   %{make} %{?_smp_mflags} modules_prepare
fi

%{make} %{?_smp_mflags} ARCH=$Arch V=1 M=samples/bpf/ VMLINUX_H="${RPM_VMLINUX_H}" || true

# Prevent bpf selftests to build bpftool repeatedly:
export BPFTOOL=$(pwd)/tools/bpf/bpftool/bpftool

pushd tools/testing/selftests
# We need to install here because we need to call make with ARCH set which
# doesn't seem possible to do in the install section.
%{make} %{?_smp_mflags} ARCH=$Arch V=1 TARGETS="bpf cgroup mm livepatch net net/forwarding net/mptcp netfilter tc-testing memfd drivers/net/bonding iommu cachestat drivers/net" SKIP_TARGETS="" FORCE_TARGETS=1 INSTALL_PATH=%{buildroot}%{_libexecdir}/kselftests VMLINUX_H="${RPM_VMLINUX_H}" DEFAULT_INSTALL_HDR_PATH=0 install

# 'make install' for bpf is broken and upstream refuses to fix it.
# Install the needed files manually.
for dir in bpf bpf/no_alu32 bpf/cpuv4 bpf/progs; do
	# In ARK, the rpm build continues even if some of the selftests
	# cannot be built. It's not always possible to build selftests,
	# as upstream sometimes dependens on too new llvm version or has
	# other issues. If something did not get built, just skip it.
	test -d $dir || continue
	mkdir -p %{buildroot}%{_libexecdir}/kselftests/$dir
	find $dir -maxdepth 1 -type f \( -executable -o -name '*.py' -o -name settings -o \
		-name 'btf_dump_test_case_*.c' -o -name '*.ko' -o \
		-name '*.o' -exec sh -c 'readelf -h "{}" | grep -q "^  Machine:.*BPF"' \; \) -print0 | \
	xargs -0 cp -t %{buildroot}%{_libexecdir}/kselftests/$dir || true
done
ln -sr  %{buildroot}%{_libexecdir}/kselftests/bpf/bpftool %{buildroot}%{_libexecdir}/kselftests/bpf/no_alu32/bpftool

# CKI clang does not support cpuv4 so it skips this variant
ln -sr  %{buildroot}%{_libexecdir}/kselftests/bpf/bpftool %{buildroot}%{_libexecdir}/kselftests/bpf/cpuv4/bpftool || echo "selftests/bpf: no cpuv4 variant"

%buildroot_save_unstripped "usr/libexec/kselftests/bpf/test_progs"
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/test_progs-no_alu32"
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/test_progs-cpuv4"
popd
export -n BPFTOOL
%endif

%if %{with_doc}
# Make the HTML pages.
%{__make} PYTHON=/usr/bin/python3 htmldocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

# In the modsign case, we do 3 things.  1) We check the "variant" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that variant.  3) We
# grab the arch and invoke mod-sign.sh command to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Don't sign modules for the zfcpdump variant as it is monolithic.

%define __modsign_install_post \
  if [ "%{signmodules}" -eq "1" ]; then \
    if [ "%{with_pae}" -ne "0" ]; then \
       %{modsign_cmd} certs/signing_key.pem.sign+lpae certs/signing_key.x509.sign+lpae $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+lpae/ \
    fi \
    if [ "%{with_realtime}" -ne "0" ]; then \
       %{modsign_cmd} certs/signing_key.pem.sign+rt certs/signing_key.x509.sign+rt $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+rt/ \
    fi \
    if [ "%{with_debug}" -ne "0" ]; then \
         %{modsign_cmd} certs/signing_key.pem.sign+debug certs/signing_key.x509.sign+debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+debug/ \
    fi \
    if [ "%{with_arm64_64k}" -ne "0" ]; then \
       %{modsign_cmd} certs/signing_key.pem.sign+64k certs/signing_key.x509.sign+64k $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+64k/ \
    fi \
    if [ "%{with_arm64_64k}" -ne "0" ] && [ "%{with_debug}" -ne "0" ]; then \
         %{modsign_cmd} certs/signing_key.pem.sign+64k-debug certs/signing_key.x509.sign+64k-debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+64k-debug/ \
    fi \
    if [ "%{with_realtime}" -ne "0" ] && [ "%{with_debug}" -ne "0" ]; then \
         %{modsign_cmd} certs/signing_key.pem.sign+rt-debug certs/signing_key.x509.sign+rt-debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+rt-debug/ \
    fi \
    if [ "%{with_up}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign certs/signing_key.x509.sign $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/ \
    fi \
  fi \
  if [ "%{zipmodules}" -eq "1" ]; then \
    echo "Compressing kernel modules ..." \
    find $RPM_BUILD_ROOT/lib/modules/ -type f -name '*.ko' | xargs -n 16 -P${RPM_BUILD_NCPUS} -r %compression %compression_flags; \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%endif

%endif

# We don't want to package debuginfo for self-tests and samples but
# we have to delete them to avoid an error messages about unpackaged
# files.
# Delete the debuginfo for kernel-devel files
%define __remove_unwanted_dbginfo_install_post \
  if [ "%{with_selftests}" -ne "0" ]; then \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/ksamples; \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/kselftests; \
  fi \
  rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/src; \
%{nil}

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__remove_unwanted_dbginfo_install_post}\
  %{__restore_unstripped_root_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVERREL}

# re-define RPM_VMLINUX_H, because it doesn't carry over from %build
RPM_VMLINUX_H="$(cat ../vmlinux_h_path)"

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}

# copy the source over
mkdir -p $docdir
tar -h -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir
cat %{SOURCE2} | xz > $docdir/kernel.changelog.xz
chmod 0644 $docdir/kernel.changelog.xz

# with_doc
%endif

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
%{__make} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

%endif

%if %{with_cross_headers}
%if 0%{?fedora}
HDR_ARCH_LIST='arm arm64 powerpc s390 x86'
%else
HDR_ARCH_LIST='arm64 powerpc s390 x86'
%endif
mkdir -p $RPM_BUILD_ROOT/usr/tmp-headers

for arch in $HDR_ARCH_LIST; do
	mkdir $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}
	%{__make} ARCH=${arch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch} headers_install
done

find $RPM_BUILD_ROOT/usr/tmp-headers \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

# Copy all the architectures we care about to their respective asm directories
for arch in $HDR_ARCH_LIST ; do
	mkdir -p $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include
	mv $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}/include/* $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/
done

rm -rf $RPM_BUILD_ROOT/usr/tmp-headers
%endif

%if %{with_kernel_abi_stablelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE300} -C $INSTALL_KABI_PATH
# with_kernel_abi_stablelists
%endif

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT lib=%{_lib} install-bin
# remove the 'trace' symlink.
rm -f %{buildroot}%{_bindir}/trace

# For both of the below, yes, this should be using a macro but right now
# it's hard coded and we don't actually want it anyway right now.
# Whoever wants examples can fix it up!

# remove examples
rm -rf %{buildroot}/usr/lib/perf/examples
rm -rf %{buildroot}/usr/lib/perf/include

# python-perf extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
mkdir -p %{buildroot}/%{_mandir}/man1
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-man

# remove any tracevent files, eg. its plugins still gets built and installed,
# even if we build against system's libtracevent during perf build (by setting
# LIBTRACEEVENT_DYNAMIC=1 above in perf_make macro). Those files should already
# ship with libtraceevent package.
rm -rf %{buildroot}%{_libdir}/traceevent

# libperf
make -C tools/lib/perf DESTDIR=%{buildroot} prefix=%{_prefix} libdir=%{_libdir} V=1 install
rm -f %{buildroot}%{_libdir}/libperf.a
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
%{make} -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE2000} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE2001} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%endif
%ifarch x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/intel-speed-select
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make} CFLAGS="${RPM_OPT_FLAGS}" DESTDIR=%{buildroot} install
   popd
%endif
pushd tools/thermal/tmon
%{tools_make} INSTALL_ROOT=%{buildroot} install
popd
pushd tools/bootconfig
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/iio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/gpio
%{tools_make} DESTDIR=%{buildroot} install
popd
install -m644 -D %{SOURCE2002} %{buildroot}%{_sysconfdir}/logrotate.d/kvm_stat
pushd tools/kvm/kvm_stat
%{__make} INSTALL_ROOT=%{buildroot} install-tools
%{__make} INSTALL_ROOT=%{buildroot} install-man
install -m644 -D kvm_stat.service %{buildroot}%{_unitdir}/kvm_stat.service
popd
# install VM tools
pushd tools/mm/
install -m755 slabinfo %{buildroot}%{_bindir}/slabinfo
install -m755 page_owner_sort %{buildroot}%{_bindir}/page_owner_sort
popd
pushd tools/verification/rv/
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/tracing/rtla/
%{tools_make} DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_bindir}/hwnoise
rm -f %{buildroot}%{_bindir}/osnoise
rm -f %{buildroot}%{_bindir}/timerlat
(cd %{buildroot}

        ln -sf rtla ./%{_bindir}/hwnoise
        ln -sf rtla ./%{_bindir}/osnoise
        ln -sf rtla ./%{_bindir}/timerlat
)
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi

%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make} prefix=%{_prefix} bash_compdir=%{_sysconfdir}/bash_completion.d/ mandir=%{_mandir} install doc-install
popd
%endif

%if %{with_selftests}
pushd samples
install -d %{buildroot}%{_libexecdir}/ksamples
# install bpf samples
pushd bpf
install -d %{buildroot}%{_libexecdir}/ksamples/bpf
find -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/bpf \;
install -m755 *.sh %{buildroot}%{_libexecdir}/ksamples/bpf
# test_lwt_bpf.sh compiles test_lwt_bpf.c when run; this works only from the
# kernel tree. Just remove it.
rm %{buildroot}%{_libexecdir}/ksamples/bpf/test_lwt_bpf.sh
install -m644 *_kern.o %{buildroot}%{_libexecdir}/ksamples/bpf || true
install -m644 tcp_bpf.readme %{buildroot}%{_libexecdir}/ksamples/bpf
popd
# install pktgen samples
pushd pktgen
install -d %{buildroot}%{_libexecdir}/ksamples/pktgen
find . -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
find . -type f ! -executable -exec install -m644 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
popd
popd
# install mm selftests
pushd tools/testing/selftests/mm
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
popd
# install cgroup selftests
pushd tools/testing/selftests/cgroup
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/cgroup/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/cgroup/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/cgroup/{} \;
popd
# install drivers/net/mlxsw selftests
pushd tools/testing/selftests/drivers/net/mlxsw
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
popd
# install drivers/net/netdevsim selftests
pushd tools/testing/selftests/drivers/net/netdevsim
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
popd
# install drivers/net/bonding selftests
pushd tools/testing/selftests/drivers/net/bonding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/bonding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/bonding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/bonding/{} \;
popd
# install net/forwarding selftests
pushd tools/testing/selftests/net/forwarding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
popd
# install net/mptcp selftests
pushd tools/testing/selftests/net/mptcp
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
popd
# install tc-testing selftests
pushd tools/testing/selftests/tc-testing
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
popd
# install livepatch selftests
pushd tools/testing/selftests/livepatch
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
popd
# install netfilter selftests
pushd tools/testing/selftests/netfilter
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
popd

# install memfd selftests
pushd tools/testing/selftests/memfd
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
popd
# install iommu selftests
pushd tools/testing/selftests/iommu
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/iommu/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/iommu/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/iommu/{} \;
popd
# install cachestat selftests
pushd tools/testing/selftests/cachestat
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/cachestat/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/cachestat/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/cachestat/{} \;
popd
%endif

###
### clean
###

###
### scripts
###

%if %{with_tools}
%post -n kernel-tools
%systemd_post cpupower.service

%preun -n kernel-tools
%systemd_preun cpupower.service

%postun -n kernel-tools
%systemd_postun cpupower.service

%post -n kernel-tools-libs
/sbin/ldconfig

%postun -n kernel-tools-libs
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
# Note we don't run hardlink if ostree is in use, as ostree is
# a far more sophisticated hardlink implementation.
# https://github.com/projectatomic/rpm-ostree/commit/58a79056a889be8814aa51f507b2c7a4dccee526
#
# The deletion of *.hardlink-temporary files is a temporary workaround
# for this bug in the hardlink binary (fixed in util-linux 2.38):
# https://github.com/util-linux/util-linux/issues/1602
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/bin/hardlink -a ! -e /run/ostree-booted ] \
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:+%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*%{?dist}.*/$f $f > /dev/null\
     done;\
     /usr/bin/find /usr/src/kernels -type f -name '*.hardlink-temporary' -delete\
    )\
fi\
%if %{with_cross}\
    echo "Building scripts and resolve_btfids"\
    env --unset=ARCH make -C /usr/src/kernels/%{KVERREL}%{?1:+%{1}} prepare_after_cross\
%endif\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-extra package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_extra_post [<subpackage>]
#
%define kernel_modules_extra_post() \
%{expand:%%post %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-internal package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_internal_post [<subpackage>]
#
%define kernel_modules_internal_post() \
%{expand:%%post %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

%if %{with_realtime}
#
# This macro defines a %%post script for a kernel*-kvm package.
# It also defines a %%postun script that does the same thing.
#       %%kernel_kvm_post [<subpackage>]
#
%define kernel_kvm_post() \
%{expand:%%post %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}
%endif

#
# This macro defines a %%post script for a kernel*-modules-partner package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_partner_post [<subpackage>]
#
%define kernel_modules_partner_post() \
%{expand:%%post %{?1:%{1}-}modules-partner}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-partner}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_post [<subpackage>]
#
%define kernel_modules_post() \
%{expand:%%post %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
if [ ! -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}} ]; then\
	mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
	touch %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
fi\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%posttrans %{?1:%{1}-}modules}\
if [ -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}} ]; then\
	rm -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
	echo "Running: dracut -f --kver %{KVERREL}%{?1:+%{1}}"\
	dracut -f --kver "%{KVERREL}%{?1:+%{1}}" || exit $?\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-core package.
#	%%kernel_modules_core_post [<subpackage>]
#
%define kernel_modules_core_post() \
%{expand:%%posttrans %{?1:%{1}-}modules-core}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [-v <subpackage>] [-u uki-suffix]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans(v:u:) \
%{expand:%%posttrans %{?-v:%{-v*}-}%{!?-u*:core}%{?-u*:uki-%{-u*}}}\
%if 0%{!?fedora:1}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVERREL}%{?-v:+%{-v*}} || exit $?\
fi\
%endif\
rm -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?-v:+%{-v*}}\
/bin/kernel-install add %{KVERREL}%{?-v:+%{-v*}} /lib/modules/%{KVERREL}%{?-v:+%{-v*}}/vmlinuz%{?-u:-%{-u*}.efi} || exit $?\
if [[ ! -e "/boot/symvers-%{KVERREL}%{?-v:+%{-v*}}.gz" ]]; then\
    ln -s "/lib/modules/%{KVERREL}%{?-v:+%{-v*}}/symvers.gz" "/boot/symvers-%{KVERREL}%{?-v:+%{-v*}}.gz"\
    command -v restorecon &>/dev/null && restorecon "/boot/symvers-%{KVERREL}%{?-v:+%{-v*}}.gz" \
fi\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_modules_post %{?-v*}}\
%{expand:%%kernel_modules_core_post %{?-v*}}\
%{expand:%%kernel_modules_extra_post %{?-v*}}\
%{expand:%%kernel_modules_internal_post %{?-v*}}\
%if 0%{!?fedora:1}\
%{expand:%%kernel_modules_partner_post %{?-v*}}\
%endif\
%if "%{-v*}" == "rt" || "%{-v*}" == "rt-debug"\
%{expand:%%kernel_kvm_post %{?-v*}}\
%endif\
%{expand:%%kernel_variant_posttrans %{?-v*:-v %{-v*}}}\
%{expand:%%post %{?-v*:%{-v*}-}core}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
touch %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?-v:+%{-v*}}\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun [-v <subpackage>] [-u uki-suffix]
#
%define kernel_variant_preun(v:u:) \
%{expand:%%preun %{?-v:%{-v*}-}%{!?-u*:core}%{?-u*:uki-%{-u*}}}\
/bin/kernel-install remove %{KVERREL}%{?-v:+%{-v*}} || exit $?\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVERREL}%{?-v:+%{-v*}} || exit $?\
fi\
%{nil}

%if %{efiuki}
%kernel_variant_posttrans -u virt
%kernel_variant_preun -u virt
%endif

%kernel_variant_preun
%kernel_variant_post -r kernel-smp

%if %{with_pae}
%kernel_variant_preun -v lpae
%kernel_variant_post -v lpae -r (kernel|kernel-smp)
%endif

%if %{with_zfcpdump}
%kernel_variant_preun -v zfcpdump
%kernel_variant_post -v zfcpdump
%endif

%if %{with_arm64_64k}
%kernel_variant_preun -v 64k
%kernel_variant_post -v 64k
%endif

%if %{with_debug} && %{with_arm64_64k}
%kernel_variant_preun -v 64k-debug
%kernel_variant_post -v 64k-debug
%endif

%if %{with_realtime}
%kernel_variant_preun -v rt
%kernel_variant_post -v rt
%endif

%if %{with_debug} && %{with_realtime}
%kernel_variant_preun -v rt-debug
%kernel_variant_post -v rt-debug
%endif

%if %{with_debug}
%if %{efiuki}
%kernel_variant_posttrans -v debug -u virt
%kernel_variant_preun -v debug -u virt
%endif
%kernel_variant_preun -v debug
%kernel_variant_post -v debug
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
/usr/include/*
%exclude %{_includedir}/cpufreq.h
%exclude %{_includedir}/internal/
%exclude %{_includedir}/perf/
%endif

%if %{with_cross_headers}
%files cross-headers
/usr/*-linux-gnu/include/*
%endif

%if %{with_kernel_abi_stablelists}
%files -n kernel-abi-stablelists
/lib/modules/kabi-*
%endif

%if %{with_kabidw_base}
%ifarch x86_64 s390x ppc64 ppc64le aarch64
%files kernel-kabidw-base-internal
%defattr(-,root,root)
/kabidw-base/%{_target_cpu}/*
%endif
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}
%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/kernel.changelog.xz
%endif

%if %{with_perf}
%files -n perf
%{_bindir}/perf
%{_libdir}/libperf-jvmti.so
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_datadir}/perf-core/*
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf
%doc linux-%{KVERREL}/tools/perf/Documentation/examples.txt
%{_docdir}/perf-tip/tips.txt

%files -n python3-perf
%{python3_sitearch}/*

%files -n libperf
%{_libdir}/libperf.so.0
%{_libdir}/libperf.so.0.0.1

%files -n libperf-devel
%{_libdir}/libperf.so
%{_libdir}/pkgconfig/libperf.pc
%{_includedir}/perf/
%{_includedir}/internal/
%{_mandir}/man3/libperf.*
%{_mandir}/man7/libperf-counting.*
%{_mandir}/man7/libperf-sampling.*
%{_docdir}/libperf/

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo

%files -f python3-perf-debuginfo.list -n python3-perf-debuginfo

%files -f libperf-debuginfo.list -n libperf-debuginfo
%endif
# with_perf
%endif

%if %{with_tools}
%ifnarch %{cpupowerarchs}
%files -n kernel-tools
%else
%files -n kernel-tools -f cpupower.lang
%{_bindir}/cpupower
%{_datadir}/bash-completion/completions/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower
%ifarch x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%{_bindir}/intel-speed-select
%{_sbindir}/intel_sdsi
%endif
# cpupowerarchs
%endif
%{_bindir}/tmon
%{_bindir}/bootconfig
%{_bindir}/iio_event_monitor
%{_bindir}/iio_generic_buffer
%{_bindir}/lsiio
%{_bindir}/lsgpio
%{_bindir}/gpio-hammer
%{_bindir}/gpio-event-mon
%{_bindir}/gpio-watch
%{_mandir}/man1/kvm_stat*
%{_bindir}/kvm_stat
%{_unitdir}/kvm_stat.service
%config(noreplace) %{_sysconfdir}/logrotate.d/kvm_stat
%{_bindir}/page_owner_sort
%{_bindir}/slabinfo

%if %{with_debuginfo}
%files -f kernel-tools-debuginfo.list -n kernel-tools-debuginfo
%endif

%ifarch %{cpupowerarchs}
%files -n kernel-tools-libs
%{_libdir}/libcpupower.so.1
%{_libdir}/libcpupower.so.0.0.1

%files -n kernel-tools-libs-devel
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif

%files -n rtla
%{_bindir}/rtla
%{_bindir}/hwnoise
%{_bindir}/osnoise
%{_bindir}/timerlat
%{_mandir}/man1/rtla-hwnoise.1.gz
%{_mandir}/man1/rtla-osnoise-hist.1.gz
%{_mandir}/man1/rtla-osnoise-top.1.gz
%{_mandir}/man1/rtla-osnoise.1.gz
%{_mandir}/man1/rtla-timerlat-hist.1.gz
%{_mandir}/man1/rtla-timerlat-top.1.gz
%{_mandir}/man1/rtla-timerlat.1.gz
%{_mandir}/man1/rtla.1.gz

%files -n rv
%{_bindir}/rv
%{_mandir}/man1/rv-list.1.gz
%{_mandir}/man1/rv-mon-wip.1.gz
%{_mandir}/man1/rv-mon-wwnr.1.gz
%{_mandir}/man1/rv-mon.1.gz
%{_mandir}/man1/rv.1.gz

# with_tools
%endif

%if %{with_bpftool}
%files -n bpftool
%{_sbindir}/bpftool
%{_sysconfdir}/bash_completion.d/bpftool
%{_mandir}/man8/bpftool-cgroup.8.gz
%{_mandir}/man8/bpftool-gen.8.gz
%{_mandir}/man8/bpftool-iter.8.gz
%{_mandir}/man8/bpftool-link.8.gz
%{_mandir}/man8/bpftool-map.8.gz
%{_mandir}/man8/bpftool-prog.8.gz
%{_mandir}/man8/bpftool-perf.8.gz
%{_mandir}/man8/bpftool.8.gz
%{_mandir}/man8/bpftool-net.8.gz
%{_mandir}/man8/bpftool-feature.8.gz
%{_mandir}/man8/bpftool-btf.8.gz
%{_mandir}/man8/bpftool-struct_ops.8.gz

%if %{with_debuginfo}
%files -f bpftool-debuginfo.list -n bpftool-debuginfo
%defattr(-,root,root)
%endif
%endif

%if %{with_selftests}
%files selftests-internal
%{_libexecdir}/ksamples
%{_libexecdir}/kselftests
%endif

# empty meta-package
%if %{with_up}
%ifnarch %nobuildarches noarch
%files
%endif
%endif

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <use_vdso> <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{2}\
%{expand:%%files %{?1:-f kernel-%{?3:%{3}-}ldsoconf.list} %{?3:%{3}-}core}\
%{!?_licensedir:%global license %%doc}\
%%license linux-%{KVERREL}/COPYING-%{version}-%{release}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}\
%ghost /%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/.vmlinuz.hmac \
%ghost /%{image_install_path}/.vmlinuz-%{KVERREL}%{?3:+%{3}}.hmac \
%ifarch %{arm} aarch64\
/lib/modules/%{KVERREL}%{?3:+%{3}}/dtb \
%ghost /%{image_install_path}/dtb-%{KVERREL}%{?3:+%{3}} \
%endif\
%attr(0600, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
%ghost %attr(0600, root, root) /boot/System.map-%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.gz\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin*\
%ghost %attr(0600, root, root) /boot/symvers-%{KVERREL}%{?3:+%{3}}.gz\
%ghost %attr(0600, root, root) /boot/initramfs-%{KVERREL}%{?3:+%{3}}.img\
%ghost %attr(0644, root, root) /boot/config-%{KVERREL}%{?3:+%{3}}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-core.list %{?3:%{3}-}modules-core}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel\
/lib/modules/%{KVERREL}%{?3:+%{3}}/build\
/lib/modules/%{KVERREL}%{?3:+%{3}}/source\
/lib/modules/%{KVERREL}%{?3:+%{3}}/updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/weak-updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/systemtap\
%{_datadir}/doc/kernel-keys/%{KVERREL}%{?3:+%{3}}\
%if %{1}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/vdso\
%endif\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.block\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.drm\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.modesetting\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.networking\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.order\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.alias\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.alias.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin.alias.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.dep\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.dep.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.devname\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.softdep\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.symbols\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.symbols.bin\
%{expand:%%files -f kernel-%{?3:%{3}-}modules.list %{?3:%{3}-}modules}\
%{expand:%%files %{?3:%{3}-}devel}\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?3:+%{3}}\
%{expand:%%files %{?3:%{3}-}devel-matched}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-extra.list %{?3:%{3}-}modules-extra}\
%config(noreplace) /etc/modprobe.d/*-blacklist.conf\
%{expand:%%files %{?3:%{3}-}modules-internal}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/internal\
%if 0%{!?fedora:1}\
%{expand:%%files %{?3:%{3}-}modules-partner}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/partner\
%endif\
%if "%{3}" == "rt" || "%{3}" == "rt-debug"\
%{expand:%%files %{?3:%{3}-}kvm}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/kvm\
%endif\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?3}.list %{?3:%{3}-}debuginfo}\
%endif\
%endif\
%if %{efiuki}\
%if "%{3}" != "rt" && "%{3}" != "rt-debug"\
%{expand:%%files %{?3:%{3}-}uki-virt}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
%attr(0600, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.gz\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin*\
%attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi\
%attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/.%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi.hmac\
%ghost /%{image_install_path}/efi/EFI/Linux/%{?-k:%{-k*}}%{!?-k:*}-%{KVERREL}%{?3:+%{3}}.efi\
%{expand:%%files %{?3:%{3}-}uki-virt-addons}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi.extra.d/ \
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi.extra.d/*.addon.efi\
%endif\
%endif\
%if %{?3:1} %{!?3:0}\
%{expand:%%files %{3}}\
%endif\
%if %{with_gcov}\
%ifnarch %nobuildarches noarch\
%{expand:%%files -f kernel-%{?3:%{3}-}gcov.list %{?3:%{3}-}gcov}\
%endif\
%endif\
%endif\
%{nil}

%kernel_variant_files %{_use_vdso} %{with_up}
%kernel_variant_files %{_use_vdso} %{with_debug} debug
%if %{with_arm64_64k}
%kernel_variant_files %{_use_vdso} %{with_debug} 64k-debug
%endif
%kernel_variant_files %{_use_vdso} %{with_realtime} rt
%if %{with_realtime}
%kernel_variant_files %{_use_vdso} %{with_debug} rt-debug
%endif
%if %{with_debug_meta}
%files debug
%files debug-core
%files debug-devel
%files debug-devel-matched
%files debug-modules
%files debug-modules-core
%files debug-modules-extra
%if %{with_arm64_64k}
%files 64k-debug
%files 64k-debug-core
%files 64k-debug-devel
%files 64k-debug-devel-matched
%files 64k-debug-modules
%files 64k-debug-modules-extra
%endif
%endif
%kernel_variant_files %{use_vdso} %{with_pae} lpae
%kernel_variant_files %{_use_vdso} %{with_zfcpdump} zfcpdump
%kernel_variant_files %{_use_vdso} %{with_arm64_64k} 64k

%define kernel_variant_ipaclones(k:) \
%if %{1}\
%if %{with_ipaclones}\
%{expand:%%files %{?2:%{2}-}ipaclones-internal}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?2:+%{2}}-ipaclones\
%endif\
%endif\
%{nil}

%kernel_variant_ipaclones %{with_up}

# plz don't put in a version string unless you're going to tag
# and build.
#
#
%changelog
* Thu Dec 19 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-546.el9]
- net/mlx5: Update the list of the PCI supported devices (Benjamin Poirier) [RHEL-70419]
- tcp: Fix use-after-free of nreq in reqsk_timer_handler(). (Guillaume Nault) [RHEL-70449]
- crypto: rng - Fix extrng EFAULT handling (Herbert Xu) [RHEL-68420]
- Bluetooth: btmtk: adjust the position to init iso data anchor (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add 2 USB HW IDs for MT7925 (0xe118/e) (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add Mediatek MT7925 support ID 0x13d3:0x3608 (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Invert LE State flag to set invalid rather then valid (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Add DSBR support for BlazarIW, BlazarU and GaP (Bastien Nocera) [RHEL-61734]
- Bluetooth: Fix type of len in rfcomm_sock_getsockopt{,_old}() (Bastien Nocera) [RHEL-61734]
- redhat/configs: Fix Bluetooth configs for automotive (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Direct exception event to bluetooth stack (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Disable works on hci_unregister_dev (Bastien Nocera) [RHEL-61734]
- workqueue: Fix UBSAN 'subtraction overflow' error in shift_and_mask() (Bastien Nocera) [RHEL-61734]
- workqueue: Implement disable/enable for (delayed) work items (Bastien Nocera) [RHEL-61734]
- workqueue: Preserve OFFQ bits in cancel[_sync] paths (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Fix regression with fake CSR controllers 0a12:0001 (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Fix not being able to reconnect after suspend (Bastien Nocera) [RHEL-61734]
- Bluetooth: Remove debugfs directory on module init failure (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Don't fail external suspend requests (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_conn: Fix UAF in hci_enhanced_setup_sync (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add one more ID 0x13d3:0x3623 for Qualcomm WCN785x (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_event: Align BR/EDR JUST_WORKS paring with LE (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmrvl: Use IRQF_NO_AUTOEN flag in request_irq() (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Allocate memory for driver private data (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Fix not handling ZPL/short-transfer (Bastien Nocera) [RHEL-61734]
- Bluetooth: btsdio: Do not bind to non-removable CYW4373 (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Ignore errors from HCI_OP_REMOTE_NAME_REQ_CANCEL (Bastien Nocera) [RHEL-61734]
- Bluetooth: CMTP: Mark BT_CMTP as DEPRECATED (Bastien Nocera) [RHEL-61734]
- Bluetooth: replace deprecated strncpy with strscpy_pad (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Fix sending MGMT_EV_CONNECT_FAILED (Bastien Nocera) [RHEL-61734]
- Bluetooth: btrtl: Set msft ext address filter quirk for RTL8852B (Bastien Nocera) [RHEL-61734]
- Bluetooth: Use led_set_brightness() in LED trigger activate() callback (Bastien Nocera) [RHEL-61734]
- Bluetooth: btrtl: Use kvmemdup to simplify the code (Bastien Nocera) [RHEL-61734]
- Bluetooth: btrtl: Add the support for RTL8922A (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_ldisc: Use speed set by btattach as oper_speed (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_conn: Remove redundant memset after kzalloc (Bastien Nocera) [RHEL-61734]
- Bluetooth: L2CAP: Remove unused declarations (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Add support for ISO packets (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_h4: Add support for ISO packets in h4_recv.h (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x0489:0xe122 (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_uart: Add support for Amlogic HCI UART (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add MediaTek MT7925-B22M support ID 0x13d3:0x3604 (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Add support for ISO data (Bastien Nocera) [RHEL-61734]
- Bluetooth: Add a helper function to extract iso header (Bastien Nocera) [RHEL-61734]
- Bluetooth: MGMT: Ignore keys being loaded with invalid type (Bastien Nocera) [RHEL-61734]
- Revert "Bluetooth: MGMT/SMP: Fix address type when using SMP over BREDR/LE" (Bastien Nocera) [RHEL-61734]
- Bluetooth: MGMT: Fix not generating command complete for MGMT_OP_DISCONNECT (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Introduce hci_cmd_sync_run/hci_cmd_sync_run_once (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: If memdump doesn't work, re-enable IBS (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Fix not handling hibernation actions (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Fix random crash seen while removing driver (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Allow configuring drive strength of BRI (Bastien Nocera) [RHEL-61734]
- Bluetooth: SMP: Fix assumption of Central always being Initiator (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Fix LE quote calculation (Bastien Nocera) [RHEL-61734]
- Bluetooth: HCI: Invert LE State quirk to be opt-out rather then opt-in (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: avoid dup filtering when passive scanning with adv monitor (Bastien Nocera) [RHEL-61734]
- Bluetooth: l2cap: always unlock channel in l2cap_conless_channel() (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_qca: fix a NULL-pointer derefence at shutdown (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_qca: fix QCA6390 support on non-DT platforms (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_qca: don't call pwrseq_power_off() twice for QCA6390 (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_event: Fix setting DISCOVERY_FINDING for passive scanning (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: remove #ifdef around declarations (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: Fix btmtk.c undefined reference build error harder (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: Fix btmtk.c undefined reference build error (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Fix suspending with wrong filter policy (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: Fix kernel crash when entering btmtk_usb_suspend (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Fail setup on error (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: Mark all stub functions as inline (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_qca: Fix build error (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_qca: use the power sequencer for wcn7850 and wcn6855 (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_qca: make pwrseq calls the default if available (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_qca: unduplicate calls to hci_uart_register_device() (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_qca: schedule a devm action for disabling the clock (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Fix warnings for suspend and resume functions (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Add system suspend and resume handlers (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Add support for IW615 chipset (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Add support for AW693 A1 chipset (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Add support for Whale Peak2 (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Add support for BlazarU core (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: mediatek: add ISO data transmission functions (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: move btusb_recv_acl_mtk to btmtk.c (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: move btusb_mtk_[setup, shutdown] to btmtk.c (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: move btusb_mtk_hci_wmt_sync to btmtk.c (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: add callback function in btusb suspend/resume (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: rename btmediatek_data (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: mediatek: return error for failed reg access (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: mediatek: remove the unnecessary goto tag (Bastien Nocera) [RHEL-61734]
- Bluetooth: Remove hci_request.{c,h} (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Remove remaining dependencies of hci_request (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Move handling of interleave_scan (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Don't use hci_prepare_cmd (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Remove usage of hci_req_sync (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add Realtek RTL8852BE support ID 0x13d3:0x3591 (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: cleanup struct hci_dev (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Fix the sfi name for BlazarU (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: don't disable power management for QCA6390 (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci: fix build when POWER_SEQUENCING=m (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Fix spelling of *intermediate* in comment (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: use the power sequencer for QCA6390 (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Add firmware ID to firmware name (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core, hci_sync: cleanup struct discovery_state (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add RTL8852BE device 0489:e125 to device tables (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_event: Set QoS encryption from BIGInfo report (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Add handling for boot-signature timeout errors (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Update firmware names (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_bcm4377: Add BCM4388 support (Bastien Nocera) [RHEL-61734]
- Bluetooth: Add vendor-specific packet classification for ISO data (Bastien Nocera) [RHEL-61734]
- Bluetooth: iso: remove unused struct 'iso_list_data' (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Remove unnecessary memset(0) calls (Bastien Nocera) [RHEL-61734]
- Bluetooth: Use sizeof(*pointer) instead of sizeof(type) (Bastien Nocera) [RHEL-61734]
- Bluetooth: MGMT: Uninitialized variable in load_conn_param() (Bastien Nocera) [RHEL-61734]
- Bluetooth/nokia: Remove unused struct 'hci_nokia_radio_hdr' (Bastien Nocera) [RHEL-61734]
- tty: rfcomm: prefer array indexing over pointer arithmetic (Bastien Nocera) [RHEL-61734]
- tty: rfcomm: prefer struct_size over open coded arithmetic (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Prefer array indexing over pointer arithmetic (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Prefer struct_size over open coded arithmetic (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Fix irq leak (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Print Firmware Sequencer information (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: mediatek: add MT7922 subsystem reset (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: mediatek: reset the controller before downloading the fw (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: mediatek: refactor the function btusb_mtk_reset (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: apply the common btmtk_fw_get_filename (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Shutdown timer and prevent rearming when driver unloading (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Refactor btintel_set_ppag() (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: add the function to get the fw name (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_bcm4377: Increase boot timeout (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Handle FW Download Abort scenario (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Enable status prints for firmware download (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Fix Null pointer dereference in btnxpuart_flush() (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_bcm4377: Use correct unit for timeouts (Bastien Nocera) [RHEL-61734]
- Bluetooth: MGMT: Make MGMT_OP_LOAD_CONN_PARAM update existing connection (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Enable Power Save feature on startup (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: Fix BT enable failure again for QCA6390 after warm reboot (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_event: Fix setting of unicast qos interval (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Fix REVERSE_INULL issue reported by coverity (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_bcm4377: Fix msgid release (Bastien Nocera) [RHEL-61734]
- Bluetooth: Add quirk to ignore reserved PHY bits in LE Extended Adv Report (Bastien Nocera) [RHEL-61734]
- Bluetooth: L2CAP: Fix rejecting L2CAP_CONN_PARAM_UPDATE_REQ (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Fix not using correct handle (Bastien Nocera) [RHEL-61734]
- bluetooth: virtio: drop owner assignment (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Refactor and code cleanup (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Fix warning reported by sparse (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Fix not handling hdev->le_num_of_adv_sets=1 (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Fix compiler warning for multi_v7_defconfig config (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Fix compiler warnings (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Add *setup* function to download firmware (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel_pcie: Add support for PCIe transport (Bastien Nocera) [RHEL-61734]
- redhat/configs: Enable Intel Bluetooth PCIE drivers (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Export few static functions (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: Fix error code in qca_read_fw_build_info() (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_conn: Use __counted_by() and avoid -Wfamnae warning (Bastien Nocera) [RHEL-61734]
- LE Create Connection command timeout increased to 20 secs (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Add support for Filmore Peak2 (BE201) (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Add support for BlazarI (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_conn: Use struct_size() in hci_le_big_create_sync() (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Use cmd->num_cis instead of magic number (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: clean up defines (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: drop bogus module version (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: drop bogus edl header checks (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_conn, hci_sync: Use __counted_by() to avoid -Wfamnae warnings (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_conn: Use __counted_by() to avoid -Wfamnae warning (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Sort usb_device_id table by the ID (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add USB HW IDs for MT7921/MT7922/MT7925 (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: Support downloading board id specific NVM for WCN7850 (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Correct timeout macro argument used to receive control message (Bastien Nocera) [RHEL-61734]
- Bluetooth: Remove 3 repeated macro definitions (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_conn: Remove a redundant check for HFP offload (Bastien Nocera) [RHEL-61734]
- Bluetooth: Populate hci_set_hw_info for Intel and Realtek (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Fix the patch for MT7920 the affected to MT7921 (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_bcm: Limit bcm43455 baudrate to 2000000 (Bastien Nocera) [RHEL-61734]
- Bluetooth: ath3k: Fix multiple issues reported by checkpatch.pl (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_intel: Fix multiple issues reported by checkpatch.pl (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_event: Set DISCOVERY_FINDING on SCAN_ENABLED (Bastien Nocera) [RHEL-61734]
- Bluetooth: Add proper definitions for scan interval and window (Bastien Nocera) [RHEL-61734]
- Bluetooth: L2CAP: Avoid -Wflex-array-member-not-at-end warnings (Bastien Nocera) [RHEL-61734]
- Bluetooth: Add support for MediaTek MT7922 device (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_intel: Convert to platform remove callback returning void (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_bcm: Convert to platform remove callback returning void (Bastien Nocera) [RHEL-61734]
- Bluetooth: btqcomsmd: Convert to platform remove callback returning void (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Add support to download intermediate loader (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Define macros for image types (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: fix firmware check error path (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: fix info leak when fetching board id (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: fix info leak when fetching fw build id (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: generalise device address check (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: fix NVM configuration parsing (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: fix wcn3991 device address check (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: set power_ctrl_enabled on NULL returned by gpiod_get_optional() (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: fix NULL-deref on non-serdev setup (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: fix NULL-deref on non-serdev suspend (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: mediatek: Fix double free of skb in coredump (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: fix invalid device address check (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_event: Fix sending HCI_OP_READ_ENC_KEY_SIZE (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Fix triggering coredump implementation for QCA (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add Realtek RTL8852BE support ID 0x0bda:0x4853 (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Use advertised PHYs on hci_le_ext_create_conn_sync (Bastien Nocera) [RHEL-61734]
- Bluetooth: Fix type of len in {l2cap,sco}_sock_getsockopt_old() (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Fix using the same interval and window for Coded PHY (Bastien Nocera) [RHEL-61734]
- Bluetooth: ISO: Don't reject BT_ISO_QOS if parameters are unset (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtksdio: drop driver owner initialization (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmrvl_sdio: drop driver owner initialization (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_event: set the conn encrypted before conn establishes (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Fix not checking error on hci_cmd_sync_cancel_sync (Bastien Nocera) [RHEL-61734]
- Bluetooth: qca: fix device-address endianness (Bastien Nocera) [RHEL-61734]
- Bluetooth: add quirk for broken address properties (Bastien Nocera) [RHEL-61734]
- Bluetooth: Fix eir name length (Bastien Nocera) [RHEL-61734]
- Bluetooth: ISO: Align broadcast sync_timeout with connection timeout (Bastien Nocera) [RHEL-61734]
- Bluetooth: Add new quirk for broken read key length on ATS2851 (Bastien Nocera) [RHEL-61734]
- Bluetooth: mgmt: remove NULL check in add_ext_adv_params_complete() (Bastien Nocera) [RHEL-61734]
- Bluetooth: mgmt: remove NULL check in mgmt_set_connectable_complete() (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Add support Mediatek MT7920 (Bastien Nocera) [RHEL-61734]
- Bluetooth: btmtk: Add MODULE_FIRMWARE() for MT7922 (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Fix btnxpuart_close (Bastien Nocera) [RHEL-61734]
- Bluetooth: fix use-after-free in accessing skb after sending it (Bastien Nocera) [RHEL-61734]
- Bluetooth: bnep: Fix out-of-bound access (Bastien Nocera) [RHEL-61734]
- Bluetooth: btusb: Fix memory leak (Bastien Nocera) [RHEL-61734]
- Bluetooth: msft: Fix memory leak (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Fix possible buffer overflow (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Use QoS to determine which PHY to scan (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Fix overwriting request callback (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sync: Use address filtering when HCI_PA_SYNC is set (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_qca: don't use IS_ERR_OR_NULL() with gpiod_get_optional() (Bastien Nocera) [RHEL-61734]
- Bluetooth: btintel: Print Firmware Sequencer information (Bastien Nocera) [RHEL-61734]
- Bluetooth: constify the struct device_type usage (Bastien Nocera) [RHEL-61734]
- Bluetooth: btbcm: Use devm_kstrdup() (Bastien Nocera) [RHEL-61734]
- Bluetooth: btbcm: Use strreplace() (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_core: Cancel request on command timeout (Bastien Nocera) [RHEL-61734]
- Bluetooth: Disconnect connected devices before rfkilling adapter (Bastien Nocera) [RHEL-61734]
- Bluetooth: Add new state HCI_POWERING_DOWN (Bastien Nocera) [RHEL-61734]
- Bluetooth: mgmt: Remove leftover queuing of power_off work (Bastien Nocera) [RHEL-61734]
- Bluetooth: btnxpuart: Resolve TX timeout error in power save stress test (Bastien Nocera) [RHEL-61734]
- Bluetooth: btrtl: Add the support for RTL8852BT/RTL8852BE-VT (Bastien Nocera) [RHEL-61734]
- Bluetooth: hci_sysfs: make bt_class a static const structure (Bastien Nocera) [RHEL-61734]
- Bluetooth: Fix not checking for valid hdev on bt_dev_{info,warn,err,dbg} (Bastien Nocera) [RHEL-61734]
- Bluetooth: mgmt: Replace zero-length array with flexible-array member (Bastien Nocera) [RHEL-61734]
- net: sched: fix erspan_opt settings in cls_flower (Xin Long) [RHEL-54225]
- s390/hiperdispatch: Fix KASAN global-out-of-bounds report (Mete Durlu) [RHEL-69777]
- config: wifi: disable new unsupported configuration options (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: add missing locking for cfg80211 calls (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: ieee80211_i: Fix memory corruption bug in struct ieee80211_chanctx (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: fix 6 GHz scan construction (Jose Ignacio Tornos Martinez) [RHEL-67113 RHEL-68230] {CVE-2024-53055}
- wifi: cfg80211: clear wdev->cqm_config pointer on free (Jose Ignacio Tornos Martinez) [RHEL-66824 RHEL-67113] {CVE-2024-50235}
- mac80211: fix user-power when emulating chanctx (Jose Ignacio Tornos Martinez) [RHEL-67113]
- Revert "wifi: iwlwifi: remove retry loops in start" (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: don't add default link in fw restart flow (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: Fix response handling in iwl_mvm_send_recovery_cmd() (Jose Ignacio Tornos Martinez) [RHEL-67113 RHEL-68158] {CVE-2024-53059}
- wifi: iwlwifi: mvm: SAR table alignment (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: Use the sync timepoint API in suspend (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: really send iwl_txpower_constraints_cmd (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: don't leak a link on AP removal (Jose Ignacio Tornos Martinez) [RHEL-67113 RHEL-68167] {CVE-2024-53074}
- wifi: rtlwifi: rtl8192du: Don't claim USB ID 0bda:8171 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: Fix the RX aggregation in USB 3 mode (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: brcm80211: BRCM_TRACING should depend on TRACING (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: pci: early chips only enable 36-bit DMA on specific PCI hosts (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath11k: Fix invalid ring usage in full monitor mode (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath10k: Fix memory leak in management tx (Jose Ignacio Tornos Martinez) [RHEL-66777 RHEL-67113] {CVE-2024-50236}
- wifi: mac80211: skip non-uploaded keys in ieee80211_iter_keys (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: radiotap: Avoid -Wflex-array-member-not-at-end warnings (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: do not pass a stopped vif to the driver in .get_txpower (Jose Ignacio Tornos Martinez) [RHEL-66892 RHEL-67113] {CVE-2024-50237}
- wifi: mac80211: Convert color collision detection to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: Add wiphy_delayed_work_pending() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: Do not create BSS entries for unsupported channels (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: Fix setting txpower with emulate_chanctx (Jose Ignacio Tornos Martinez) [RHEL-67113]
- mac80211: MAC80211_MESSAGE_TRACING should depend on TRACING (Jose Ignacio Tornos Martinez) [RHEL-67113]
- finally take no_llseek out (Jose Ignacio Tornos Martinez) [RHEL-67113]
- net: qrtr: Update packets cloning when broadcasting (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: do not increase mcu skb refcount if retry is not supported (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: coex: add debug message of link counts on 2/5GHz bands for wl_info v7 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: brcmfmac: cfg80211: Convert comma to semicolon (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: wilc1000: Convert using devm_clk_get_optional_enabled() in wilc_bus_probe() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: wilc1000: Convert using devm_clk_get_optional_enabled() in wilc_sdio_probe() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: wilc1000: fix potential RCU dereference issue in wilc_parse_join_bss_param (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: Fix memcpy() field-spanning write warning in mwifiex_cmd_802_11_scan_ext() (Jose Ignacio Tornos Martinez) [RHEL-63924 RHEL-67113] {CVE-2024-50008}
- wifi: mac80211: use two-phase skb reclamation in ieee80211_do_stop() (Jose Ignacio Tornos Martinez) [RHEL-63370 RHEL-67113] {CVE-2024-47713}
- wifi: cfg80211: fix two more possible UBSAN-detected off-by-one errors (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: fix kernel-doc for per-link data (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7925: replace chan config with extend txpower config for clc (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7925: fix a potential array-index-out-of-bounds issue for clc (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7615: check devm_kasprintf() returned value (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7925: convert comma to semicolon (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7925: fix a potential association failure upon resuming (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: Avoid multiple -Wflex-array-member-not-at-end warnings (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7921: Check devm_kasprintf() returned value (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: check devm_kasprintf() returned value (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: avoid long MCU command timeouts during SER (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: fix uninitialized TLV data (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: always query station rx rate from firmware (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: fix rx filter setting for bfee functionality (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: shrink mt76_queue_buf (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: improve hardware restart reliability (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: connac: move mt7615_mcu_del_wtbl_all to connac (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: hold dev->mt76.mutex while disabling tx worker (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: add dummy HW offload of IEEE 802.11 fragmentation (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: reset the device after MCU timeout (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: retry mcu messages (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: set MT76_MCU_RESET early in mt7915_mac_full_reset (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: use mac80211 .sta_state op (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: change .sta_assoc callback to .sta_event (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: connac: add support for passing connection state directly (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: connac: add support for IEEE 802.11 fragmentation (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: allocate vif wcid in the same range as stations (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: disable tx worker during tx BA session enable/disable (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: add separate tx scheduling queue for off-channel tx (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: handle ieee80211_radar_detected() for MLO (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211/mac80211: use proper link ID for DFS (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: handle DFS per link (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: handle DFS per link (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: move DFS related members to links[] in wireless_dev (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: trace: unlink rdev_end_cac trace event from wiphy_netdev_evt class (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: remove label usage in ieee80211_start_radar_detection() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: introduce EHT rate support in AQL airtime (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: avoid overriding direct/MBSSID BSS with per-STA profile BSS (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: skip indicating signal for per-STA profile BSSs (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: make BSS source types public (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: replace CONFIG_PM by CONFIG_PM_SLEEP (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: Avoid RCU debug splat in __cfg80211_bss_update error paths (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: fix UBSAN noise in cfg80211_wext_siwscan() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: partially move channel change code to core (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: fix mt76_get_rate (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7603: initialize chainmask (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7603: fix reading target power from eeprom (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7603: fix mixed declarations and code (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: connac: fix checksum offload fields of connac3 RXD (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: fix NULL pointer dereference in mt7996_mcu_sta_bfer_he (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: set IEEE80211_KEY_FLAG_GENERATE_MMIE for other ciphers (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: connac: add IEEE 802.11 fragmentation support for mt7996 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: fix handling mbss enable/disable (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath12k: Avoid -Wflex-array-member-not-at-end warnings (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath11k: Avoid -Wflex-array-member-not-at-end warnings (Jose Ignacio Tornos Martinez) [RHEL-67113]
- bus: mhi: host: pci_generic: Enable EDL trigger for Foxconn modems (Jose Ignacio Tornos Martinez) [RHEL-67113]
- bus: mhi: host: pci_generic: Update EDL firmware path for Foxconn modems (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: set correct value in beamforming mcu command for mt7992 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: fix EHT beamforming capability check (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: set correct beamformee SS capability (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: fix HE and EHT beamforming capabilities (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: advertize beacon_int_min_gcd (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: fix wmm set of station interface to 3 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: fix traffic delay when switching back to working channel (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7996: use hweight16 to get correct tx antenna (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7921: fix wrong UNII-4 freq range check for the channel usage (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mt76: mt7915: fix oops on non-dbdc mt7986 (Jose Ignacio Tornos Martinez) [RHEL-63206 RHEL-67113] {CVE-2024-47715}
- wifi: rtw89: avoid reading out of bounds when loading TX power FW elements (Jose Ignacio Tornos Martinez) [RHEL-64546 RHEL-67113] {CVE-2024-49928}
- wifi: rtw89: use frequency domain RSSI (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: adjust DIG threshold to reduce false alarm (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: Convert to use jiffies macro (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: wilc1000: Re-enable RTC clock on resume (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: wilc1000: Do not operate uninitialized hardware during suspend/resume (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: brcmsmac: Use kvmemdup to simplify the code (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: properly set the rates in link cmd (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: Remove unused last_sub_index from reorder buffer (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: remove mvm prefix from iwl_mvm_tx_resp* (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: s/iwl_mvm_remove_sta_cmd/iwl_remove_sta_cmd (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: STA command structure shouldn't be mvm specific (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: s/IWL_MVM_STATION_COUNT_MAX/IWL_STATION_COUNT_MAX (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: tell the firmware about CSA with mode=1 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: refactor scan channel description a bit (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: wext: Update spelling and grammar (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: wow: add scan interval option for net-detect (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: wow: add net-detect support for 8922ae (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: wow: add wait for H2C of FW-IPS mode (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: wow: fix wait condition for AOAC report request (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: assign mac_id for vif/sta and update to TX desc (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: Fix USB/SDIO devices not transmitting beacons (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: Set correct chandef when starting CAC (Jose Ignacio Tornos Martinez) [RHEL-64603 RHEL-67113] {CVE-2024-49937}
- wifi: mac80211: scan: Use max macro (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: Check for missing VHT elements only for 5 GHz (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: fix RCU list iterations (Jose Ignacio Tornos Martinez) [RHEL-67113]
- bus: mhi: host: pci_generic: Add support for Netprisma LCUR57 and FCUN69 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: allow ESR when we the ROC expires (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: avoid NULL pointer dereference (Jose Ignacio Tornos Martinez) [RHEL-63991 RHEL-67113] {CVE-2024-49929}
- wifi: mac80211: export ieee80211_purge_tx_queue() for drivers (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rfkill: Correct parameter type for rfkill_set_hw_state_reason() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: remove redundant unlikely() around IS_ERR() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- net: rfkill: gpio: Do not load on Lenovo Yoga Tab 3 Pro YT3-X90 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: allow only CN mcc from WRDD (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: drop wrong STA selection in TX (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: bump FW API to 93 for BZ/SC devices (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: cleanup iwl_mvm_get_wd_timeout (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: use default command queue watchdog timeout (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: handle the new EML OMN failure notification (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: Stop processing MCC update if there was no change (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: add API for EML OMN frame failure (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: exit EMLSR if both links are missing beacons (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: handle the new missed beacons notification (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: add the new API for the missed beacons notification (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: rename iwl_missed_beacons_notif (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: Offload RLC/SMPS functionality to firmware (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: fix the comeback long retry times (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: cfg80211: fix bug of mapping AF3x to incorrect User Priority (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: Add non-atomic station iterator (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: lib80211: Constify struct lib80211_crypto_ops (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: lib80211: Handle const struct lib80211_crypto_ops in lib80211 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: add and improve EMLSR debug info (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: Enable channel puncturing for US/CAN from bios (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: add firmware debug points for EMLSR entry / exit (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwiif: mvm: handle the new BT notif (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: start to support the new BT profile notification (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: s/iwl_bt_coex_profile_notif/iwl_bt_coex_prof_old_notif (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: increase the time between ranging measurements (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: set the cipher for secured NDP ranging (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: Fix a race in scan abort flow (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: set ul_mu_data_disable when needed (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mei: add support for SAP version 4 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: config: label 'gl' devices as discrete (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: pcie: print function scratch before writing (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: use correct key iteration (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: remove MVM prefix from FW macros (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: add support for new REDUCE_TXPOWER_CMD versions (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: iwlwifi: mvm: prepare the introduction of V9 of REDUCED_TX_POWER (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211: don't use rate mask for offchannel TX either (Jose Ignacio Tornos Martinez) [RHEL-63376 RHEL-67113] {CVE-2024-47738}
- wifi: mac80211: refactor block ack management code (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mac80211_hwsim: correct MODULE_PARM_DESC of multi_radio (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: introduce chip support link number and driver MLO capability (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: rename roc_entity_idx to roc_chanctx_idx (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8922a: use right chanctx whenever possible in RFK flow (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852c: use right chanctx whenever possible in RFK flow (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852bx: use right chanctx whenever possible in RFK flow (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852a: use right chanctx whenever possible in RFK flow (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8851b: use right chanctx whenever possible in RFK flow (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: pass chan to rfk_band_changed() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- net: Correct spelling in headers (Jose Ignacio Tornos Martinez) [RHEL-67113]
- bus: mhi: host: make mhi_bus_type const (Jose Ignacio Tornos Martinez) [RHEL-67113]
- bus: mhi: host: pci_generic: Fix the name for the Telit FE990A (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: remove unnecessary checks for valid priv (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: Fix uninitialized variable in mwifiex_cfg80211_authenticate() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: coex: Add new Wi-Fi role format condition for function using (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: coex: Bluetooth hopping map for Wi-Fi role version 7 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: coex: Update Wi-Fi role info version 7 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: coex: Update report version of Wi-Fi firmware 0.29.90.0 for RTL8852BT (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: debugfs: support multiple adapters debugging (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: remove CPT execution branch never used (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852a: adjust ANA clock to 12M (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: correct base HT rate mask for firmware (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: remove unused C2H event ID RTW89_MAC_C2H_FUNC_READ_WOW_CAM to prevent out-of-bounds reading (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8922a: add digital compensation to avoid TX EVM degrade (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852c: support firmware with fw_element (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath9k_htc: Use __skb_set_length() for resetting urb before resubmit (Jose Ignacio Tornos Martinez) [RHEL-64609 RHEL-67113] {CVE-2024-49938}
- wifi: mwifiex: keep mwifiex_cfg80211_ops constant (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath12k: fix the stack frame size warning in ath12k_mac_op_hw_scan (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: add support for WPA-PSK-SHA256 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: fix key_mgmt setting (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: simplify WPA flags setting (Jose Ignacio Tornos Martinez) [RHEL-67113]
- Revert "wifi: ath9k: use devm for request_irq()" (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: Enable USB RX aggregation for 8822c/8822b/8821c (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: usb: Support RX aggregation (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: usb: Update the RX stats after every frame (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: usb: Init RX burst length according to USB speed (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtl8xxxu: add missing rtl8192cu USB IDs (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtl8xxxu: drop reference to staging drivers (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: wow: add net-detect support for 8852c (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: wow: add delay option for net-detect (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: wow: add WoWLAN net-detect support (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: wow: implement PS mode for net-detect (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852c: support firmware format up to v1 (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath12k: fix invalid AMPDU factor calculation in ath12k_peer_assoc_h_he() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath12k: match WMI BSS chan info structure with firmware definition (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath12k: fix BSS chan info request WMI command (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath12k: restore ASPM for supported hardwares only (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath9k: Remove error checks when creating debugfs entries (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath9k: use devm for gpio_request_one() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath9k: use devm for request_irq() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: correct VHT TX rate on 20MHz connection (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: add support for HW encryption in unicast management frames (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: avoid to add interface to list twice when SER (Jose Ignacio Tornos Martinez) [RHEL-64482 RHEL-67113] {CVE-2024-49939}
- wifi: rtw89: 8922a: Add new fields for scan offload H2C command (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8922a: new implementation for RFK pre-notify H2C (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: brcmsmac: clean up unnecessary current_ampdu_cnt and related checks (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: brcmfmac: introducing fwil query functions (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: brcmfmac: fwsignal: Use struct_size() to simplify brcmf_fws_rxreorder() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: add host mlme for AP mode (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: add host mlme for client mode (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: mwifiex: increase max_num_akm_suites (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: pass chanctx_idx to rtw89_btc_{path_}phymap() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: fw: correct chan access in assoc_cmac_tbl_g7 and update_beacon_be (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: pass rtwvif to RFK scan (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: pass rtwvif to RFK channel (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: rename sub_entity to chanctx (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: mcc: stop at a role holding chanctx (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: chan: refine MCC re-plan flow when unassign chanctx (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: always wait for both firmware loading attempts (Jose Ignacio Tornos Martinez) [RHEL-63398 RHEL-67113] {CVE-2024-47718}
- wifi: rtw89: fix typo of rtw89_phy_ra_updata_XXX (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 885xb: reset IDMEM mode to prevent download firmware failure (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: add support for hardware rfkill (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: add EVM statistics for 1SS rate (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: 8822c: Parse channel from IE to correct invalid hardware reports (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath9k: fix possible integer overflow in ath9k_get_et_stats() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath9k: Use swap() to improve ath9k_hw_get_nf_hist_mid() (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath9k: use unmanaged PCI functions in ath9k_pci_owl_loader (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: 8703b: Fix reported RX band width (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: 8822c: Fix reported RX band width (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852bt: add 8852BE-VT to Makefile and Kconfig (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852bte: add PCI entry of 8852BE-VT (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852bt: declare firmware features of RTL8852BT (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852bt: add chip_ops of RTL8852BT (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852bt: add chip_info of RTL8852BT (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852bt: rfk: use predefined string choice for DPK enable/disable (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852bt: add set_channel_rf (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: select WANT_DEV_COREDUMP (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: select WANT_DEV_COREDUMP (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: debugfs: support multiple adapters debugging (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: 8821cu: Remove VID/PID 0bda:c82c (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: usb: Support USB 3 with RTL8822CU/RTL8822BU (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw89: 8852bt: rfk: Fix spelling mistake "KIP_RESOTRE" -> "KIP_RESTORE" (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: rtw88: Set efuse->ext_lna_5g - fix typo (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath12k: Support Transmit DE stats (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath11k: fix array out-of-bound access in SoC stats (Jose Ignacio Tornos Martinez) [RHEL-64581 RHEL-67113] {CVE-2024-49930}
- wifi: ath12k: fix array out-of-bound access in SoC stats (Jose Ignacio Tornos Martinez) [RHEL-67113]
- wifi: ath11k: use work queue to process beacon tx event (Jose Ignacio Tornos Martinez) [RHEL-67113]
- Revert "wifi: ath11k: support hibernation" (Jose Ignacio Tornos Martinez) [RHEL-67113]
- Revert "wifi: ath11k: restore country code during resume" (Jose Ignacio Tornos Martinez) [RHEL-67113]
- redhat/kernel.spec.template: Link rtla against in-tree libcpupower (Tomas Glozar) [RHEL-69522]
- rtla: Documentation: Mention --deepest-idle-state (Tomas Glozar) [RHEL-69522]
- rtla/timerlat: Add --deepest-idle-state for hist (Tomas Glozar) [RHEL-69522]
- rtla/timerlat: Add --deepest-idle-state for top (Tomas Glozar) [RHEL-69522]
- rtla/utils: Add idle state disabling via libcpupower (Tomas Glozar) [RHEL-69522]
- rtla: Add optional dependency on libcpupower (Tomas Glozar) [RHEL-69522]
- tools/build: Add libcpupower dependency detection (Tomas Glozar) [RHEL-69522]
- redhat/kernel.spec.template: add extra flags for tools build (Tomas Glozar) [RHEL-69522]
- tools/rtla: Use tools/build makefiles to build rtla (Tomas Glozar) [RHEL-69522]
- of: check previous kernel's ima-kexec-buffer against memory bounds (Mamatha Inamdar) [RHEL-70361]
- Revert "igb: Disable threaded IRQ for igb_msix_other" (Corinna Vinschen) [RHEL-49817]
- igb: Disable threaded IRQ for igb_msix_other (Corinna Vinschen) [RHEL-49817]
- igb: Cleanup unused declarations (Corinna Vinschen) [RHEL-49817]
- igb: Do not bring the device up after non-fatal error (Corinna Vinschen) [RHEL-49817]
- igb: Always call igb_xdp_ring_update_tail() under Tx lock (Corinna Vinschen) [RHEL-49817]
- igb: Fix not clearing TimeSync interrupts for 82580 (Corinna Vinschen) [RHEL-49817]
- igb: cope with large MAX_SKB_FRAGS (Corinna Vinschen) [RHEL-49817]
- igb: Add MII write support (Corinna Vinschen) [RHEL-49817]
- igb: flower: validate control flags (Corinna Vinschen) [RHEL-49817]
- vsock: Update rx_bytes on read_skb() (Jon Maloy) [RHEL-66526] {CVE-2024-50169}
- iavf: add support for offloading tc U32 cls filters (Michal Schmidt) [RHEL-49814]
- iavf: refactor add/del FDIR filters (Michal Schmidt) [RHEL-49814]
- iavf: flower: validate control flags (Michal Schmidt) [RHEL-49814]
- iavf: RHEL only: re-add "legacy-rx" as a dummy priv flag (Michal Schmidt) [RHEL-49814]
- iavf: kill "legacy-rx" for good (Michal Schmidt) [RHEL-49814]
- iavf: implement modern PM ops declarations (Michal Schmidt) [RHEL-49814]

* Mon Dec 16 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-545.el9]
- net: fix data-races around sk->sk_forward_alloc (CKI Backport Bot) [RHEL-69689] {CVE-2024-53124}
- nvme-fabrics: handle zero MAXCMD without closing the connection (Maurizio Lombardi) [RHEL-71164]
- redhat: add test_klp_syscall to mod-internal.list (Ryan Sullivan) [RHEL-69931]
- blk_iocost: fix more out of bound shifts (CKI Backport Bot) [RHEL-63978] {CVE-2024-49933}
- mm: revert "mm: shmem: fix data-race in shmem_getattr()" (Rafael Aquini) [RHEL-27745 RHEL-70053] {CVE-2024-53136}
- mm: page_alloc: move mlocked flag clearance into free_pages_prepare() (Rafael Aquini) [RHEL-27745 RHEL-69683] {CVE-2024-53105}
- filemap: Fix bounds checking in filemap_read() (Rafael Aquini) [RHEL-27745 RHEL-68011] {CVE-2024-50272}
- mm/mlock: set the correct prev on failure (Rafael Aquini) [RHEL-27745]
- vmscan,migrate: fix page count imbalance on node stats when demoting pages (Rafael Aquini) [RHEL-27745]
- kasan: remove vmalloc_percpu test (Rafael Aquini) [RHEL-27745]
- mm: krealloc: Fix MTE false alarm in __do_krealloc (Rafael Aquini) [RHEL-27745 RHEL-68909] {CVE-2024-53097}
- mm: shmem: fix data-race in shmem_getattr() (Rafael Aquini) [RHEL-27745 RHEL-66818] {CVE-2024-50228}
- mm/page_alloc: let GFP_ATOMIC order-0 allocs access highatomic reserves (Rafael Aquini) [RHEL-27745 RHEL-66794] {CVE-2024-50219}
- fork: only invoke khugepaged, ksm hooks if no error (Rafael Aquini) [RHEL-27745]
- fork: do not invoke uffd on fork if error occurs (Rafael Aquini) [RHEL-27745]
- maple_tree: add regression test for spanning store bug (Rafael Aquini) [RHEL-27745 RHEL-66950] {CVE-2024-50200}
- maple_tree: correct tree corruption on spanning store (Rafael Aquini) [RHEL-27745 RHEL-66950] {CVE-2024-50200}
- mm/mglru: only clear kswapd_failures if reclaimable (Rafael Aquini) [RHEL-27745]
- mm/swapfile: skip HugeTLB pages for unuse_vma (Rafael Aquini) [RHEL-27745 RHEL-66977] {CVE-2024-50199}
- mm: don't install PMD mappings when THPs are disabled by the hw/process/vma (Rafael Aquini) [RHEL-27745]
- mm: huge_memory: add vma_thp_disabled() and thp_disabled_by_hw() (Rafael Aquini) [RHEL-27745]
- mm: khugepaged: fix the arguments order in khugepaged_collapse_file trace point (Rafael Aquini) [RHEL-27745]
- mm/mremap: fix move_normal_pmd/retract_page_tables race (Rafael Aquini) [RHEL-27745]
- secretmem: disable memfd_secret() if arch cannot set direct map (Rafael Aquini) [RHEL-27745 RHEL-66627] {CVE-2024-50182}
- memory tiers: use default_dram_perf_ref_source in log message (Rafael Aquini) [RHEL-27745 RHEL-62336]
- mm: migrate: annotate data-race in migrate_folio_unmap() (Rafael Aquini) [RHEL-27745]
- mm: avoid leaving partial pfn mappings around in error case (Rafael Aquini) [RHEL-27745]
- mm: Kconfig: fixup zsmalloc configuration (Rafael Aquini) [RHEL-27745]
- mm/damon/vaddr: protect vma traversal in __damon_va_thre_regions() with rcu read lock (Rafael Aquini) [RHEL-27745]
- sched/numa: Fix the vma scan starving issue (Rafael Aquini) [RHEL-27745]
- mm: krealloc: consider spare memory for __GFP_ZERO (Rafael Aquini) [RHEL-27745]
- mm: only enforce minimum stack gap size if it's sensible (Rafael Aquini) [RHEL-27745]
- mm/memcontrol: respect zswap.writeback setting from parent cg too (Rafael Aquini) [RHEL-27745]
- Revert "mm: skip CMA pages when they are not available" (Rafael Aquini) [RHEL-27745]
- mm: vmalloc: ensure vmap_block is initialised before adding to queue (Rafael Aquini) [RHEL-27745]
- mm: Fix missing folio invalidation calls during truncation (Rafael Aquini) [RHEL-27745]
- mm: fix endless reclaim on machines with unaccepted memory (Rafael Aquini) [RHEL-27745]
- mm/numa: no task_numa_fault() call if PMD is changed (Rafael Aquini) [RHEL-27745]
- mm/numa: no task_numa_fault() call if PTE is changed (Rafael Aquini) [RHEL-27745]
- memcg_write_event_control(): fix a user-triggerable oops (Rafael Aquini) [RHEL-27745]
- mm/page_alloc: fix pcp->count race between drain_pages_zone() vs __rmqueue_pcplist() (Rafael Aquini) [RHEL-27745]
- mm/mglru: fix ineffective protection calculation (Rafael Aquini) [RHEL-27745 RHEL-54929] {CVE-2024-42316}
- mm/hugetlb: fix possible recursive locking detected warning (Rafael Aquini) [RHEL-27745]
- mm/numa_balancing: teach mpol_to_str about the balancing mode (Rafael Aquini) [RHEL-27745]
- mm/mglru: fix overshooting shrinker memory (Rafael Aquini) [RHEL-27745 RHEL-54929] {CVE-2024-42316}
- mm/mglru: fix div-by-zero in vmpressure_calc_level() (Rafael Aquini) [RHEL-27745 RHEL-54929] {CVE-2024-42316}
- mm: ignore data-race in __swap_writepage (Rafael Aquini) [RHEL-27745]
- mm, virt: merge AS_UNMOVABLE and AS_INACCESSIBLE (Rafael Aquini) [RHEL-27745]
- mm/hugetlb: fix potential race in __update_and_free_hugetlb_folio() (Rafael Aquini) [RHEL-27745]
- mm: gup: stop abusing try_grab_folio (Rafael Aquini) [RHEL-27745]
- mm: refactor folio_undo_large_rmappable() (Rafael Aquini) [RHEL-27745]
- mm: page_ref: remove folio_try_get_rcu() (Rafael Aquini) [RHEL-27745]
- mm: mmap_lock: replace get_memcg_path_buf() with on-stack buffer (Rafael Aquini) [RHEL-27745]
- mm/memory_hotplug: prevent accessing by index=-1 (Rafael Aquini) [RHEL-27745]
- x86/mm: Cleanup prctl_enable_tagged_addr() nr_bits error checking (Rafael Aquini) [RHEL-27745]
- x86/mm: Fix LAM inconsistency during context switch (Rafael Aquini) [RHEL-27745]
- mm/page_alloc: Separate THP PCP into movable and non-movable categories (Rafael Aquini) [RHEL-27745]
- mm: fix incorrect vbq reference in purge_fragmented_block (Rafael Aquini) [RHEL-27745]
- Revert "mm: mmap: allow for the maximum number of bits for randomizing mmap_base by default" (Rafael Aquini) [RHEL-27745]
- mm/debug_vm_pgtable: drop RANDOM_ORVALUE trick (Rafael Aquini) [RHEL-27745]
- mm: mmap: allow for the maximum number of bits for randomizing mmap_base by default (Rafael Aquini) [RHEL-27745]
- mm/hugetlb: do not call vma_add_reservation upon ENOMEM (Rafael Aquini) [RHEL-27745]
- kmsan: do not wipe out origin when doing partial unpoisoning (Rafael Aquini) [RHEL-27745]
- kasan, fortify: properly rename memintrinsics (Rafael Aquini) [RHEL-27745]
- mm: Introduce AS_INACCESSIBLE for encrypted/confidential memory (Rafael Aquini) [RHEL-27745]
- mm/hugetlb: align cma on allocation order, not demotion order (Rafael Aquini) [RHEL-27745]
- mm: fix race between __split_huge_pmd_locked() and GUP-fast (Rafael Aquini) [RHEL-27745]
- mm/page_table_check: support userfault wr-protect entries (Rafael Aquini) [RHEL-27745]
- mm/slab: make __free(kfree) accept error pointers (Rafael Aquini) [RHEL-27745]
- mm/slub: handle bulk and single object freeing separately (Rafael Aquini) [RHEL-27745]
- mm/hugetlb: pass correct order_per_bit to cma_declare_contiguous_nid (Rafael Aquini) [RHEL-27745]
- mm/cma: drop incorrect alignment check in cma_init_reserved_mem (Rafael Aquini) [RHEL-27745]
- hugetlb: convert alloc_buddy_hugetlb_folio to use a folio (Rafael Aquini) [RHEL-27745]
- mm: page_alloc: use the correct THP order for THP PCP (Rafael Aquini) [RHEL-27745]
- khugepaged: use a folio throughout hpage_collapse_scan_file() (Rafael Aquini) [RHEL-27745]
- khugepaged: use a folio throughout collapse_file() (Rafael Aquini) [RHEL-27745]
- khugepaged: pass a folio to __collapse_huge_page_copy() (Rafael Aquini) [RHEL-27745]
- khugepaged: remove hpage from collapse_huge_page() (Rafael Aquini) [RHEL-27745]
- khugepaged: remove hpage from collapse_file() (Rafael Aquini) [RHEL-27745]
- khugepaged: convert alloc_charge_hpage to alloc_charge_folio (Rafael Aquini) [RHEL-27745]
- khugepaged: inline hpage_collapse_alloc_folio() (Rafael Aquini) [RHEL-27745]
- selftest/mm: ksm_functional_tests: extend test case for ksm fork/exec (Rafael Aquini) [RHEL-27745]
- selftest/mm: ksm_functional_tests: refactor mmap_and_merge_range() (Rafael Aquini) [RHEL-27745]
- mm/ksm: fix ksm exec support for prctl (Rafael Aquini) [RHEL-27745]
- mm: page_alloc: control latency caused by zone PCP draining (Rafael Aquini) [RHEL-27745]
- mm: zswap: fix shrinker NULL crash with cgroup_disable=memory (Rafael Aquini) [RHEL-27745]
- mm: turn folio_test_hugetlb into a PageType (Rafael Aquini) [RHEL-27745]
- mm: support page_mapcount() on page_has_type() pages (Rafael Aquini) [RHEL-27745]
- mm, pagemap: remove SLOB and SLQB from comments and documentation (Rafael Aquini) [RHEL-27745]
- mm: create FOLIO_FLAG_FALSE and FOLIO_TYPE_OPS macros (Rafael Aquini) [RHEL-27745]
- mm/shmem: inline shmem_is_huge() for disabled transparent hugepages (Rafael Aquini) [RHEL-27745]
- mm,swapops: update check in is_pfn_swap_entry for hwpoison entries (Rafael Aquini) [RHEL-27745]
- mm/madvise: make MADV_POPULATE_(READ|WRITE) handle VM_FAULT_RETRY properly (Rafael Aquini) [RHEL-27745]
- mm: zswap: fix writeback shinker GFP_NOIO/GFP_NOFS recursion (Rafael Aquini) [RHEL-27745]
- mm: recover pud_leaf() definitions in nopmd case (Rafael Aquini) [RHEL-27745]
- mm/treewide: align up pXd_leaf() retval across archs (Rafael Aquini) [RHEL-27745]
- mm/treewide: drop pXd_large() (Rafael Aquini) [RHEL-27745]
- mm/treewide: replace pud_large() with pud_leaf() (Rafael Aquini) [RHEL-27745]
- mm/treewide: replace pmd_large() with pmd_leaf() (Rafael Aquini) [RHEL-27745]
- mm/kasan: use pXd_leaf() in shadow_mapped() (Rafael Aquini) [RHEL-27745]
- mm/x86: drop two unnecessary pud_leaf() definitions (Rafael Aquini) [RHEL-27745]
- mm/x86: replace pgd_large() with pgd_leaf() (Rafael Aquini) [RHEL-27745]
- mm/x86: replace p4d_large() with p4d_leaf() (Rafael Aquini) [RHEL-27745]
- mm/powerpc: replace pXd_is_leaf() with pXd_leaf() (Rafael Aquini) [RHEL-27745]
- mm/powerpc: define pXd_large() with pXd_leaf() (Rafael Aquini) [RHEL-27745]
- mm: memory: fix shift-out-of-bounds in fault_around_bytes_set (Rafael Aquini) [RHEL-27745]
- mm: remove cast from page_to_nid() (Rafael Aquini) [RHEL-27745]
- mm: constify more page/folio tests (Rafael Aquini) [RHEL-27745]
- mm: constify testing page/folio flags (Rafael Aquini) [RHEL-27745]
- mm: make dump_page() take a const argument (Rafael Aquini) [RHEL-27745]
- mm: add __dump_folio() (Rafael Aquini) [RHEL-27745]
- mm: remove PageYoung and PageIdle definitions (Rafael Aquini) [RHEL-27745]
- mm: remove PageWaiters, PageSetWaiters and PageClearWaiters (Rafael Aquini) [RHEL-27745]
- mm: separate out FOLIO_FLAGS from PAGEFLAGS (Rafael Aquini) [RHEL-27745]
- mm: support order-1 folios in the page cache (Rafael Aquini) [RHEL-27745]
- mm, vmscan: prevent infinite loop for costly GFP_NOIO | __GFP_RETRY_MAYFAIL allocations (Rafael Aquini) [RHEL-27745]
- madvise:madvise_cold_or_pageout_pte_range(): allow split while folio_estimated_sharers = 0 (Rafael Aquini) [RHEL-27745]
- selftests/mm: run_vmtests.sh: add hugetlb_madv_vs_map (Rafael Aquini) [RHEL-27745 RHEL-61137]
- mm/hugetlb: restore the reservation if needed (Rafael Aquini) [RHEL-27745 RHEL-61137]
- x86/mm: delete unused cpu argument to leave_mm() (Rafael Aquini) [RHEL-27745]
- mm: memcg: don't periodically flush stats when memcg is disabled (Rafael Aquini) [RHEL-27745]
- mm: kmsan: remove runtime checks from kmsan_unpoison_memory() (Rafael Aquini) [RHEL-27745]
- mm/swap_state: update zswap LRU's protection range with the folio locked (Rafael Aquini) [RHEL-27745]
- mm: zswap: fix missing folio cleanup in writeback race path (Rafael Aquini) [RHEL-27745]
- mm/zswap: don't return LRU_SKIP if we have dropped lru lock (Rafael Aquini) [RHEL-27745]
- fs/hugetlbfs/inode.c: mm/memory-failure.c: fix hugetlbfs hwpoison handling (Rafael Aquini) [RHEL-27745]
- efi: disable mirror feature during crashkernel (Rafael Aquini) [RHEL-27745]
- mm, treewide: rename MAX_ORDER to MAX_PAGE_ORDER (Rafael Aquini) [RHEL-27745]
- mm, treewide: introduce NR_PAGE_ORDERS (Rafael Aquini) [RHEL-27745]
- mm/khugepaged: use a folio more in collapse_file() (Rafael Aquini) [RHEL-27745]
- zswap: memcontrol: implement zswap writeback disabling (Rafael Aquini) [RHEL-27745]
- mm: remove unnecessary ia64 code and comment (Rafael Aquini) [RHEL-27745]
- fs: improve dump_mapping() robustness (Rafael Aquini) [RHEL-27745]
- mm: migrate: fix getting incorrect page mapping during page migration (Rafael Aquini) [RHEL-27745 RHEL-28873] {CVE-2023-52490}
- mm: convert swap_cluster_readahead and swap_vma_readahead to return a folio (Rafael Aquini) [RHEL-27745]
- mm: return a folio from read_swap_cache_async() (Rafael Aquini) [RHEL-27745]
- mm: remove page_swap_info() (Rafael Aquini) [RHEL-27745]
- mm: convert swap_readpage() to swap_read_folio() (Rafael Aquini) [RHEL-27745]
- mm: convert swap_page_sector() to swap_folio_sector() (Rafael Aquini) [RHEL-27745]
- mm: pass a folio to swap_readpage_bdev_async() (Rafael Aquini) [RHEL-27745]
- mm: pass a folio to swap_readpage_bdev_sync() (Rafael Aquini) [RHEL-27745]
- mm: pass a folio to swap_readpage_fs() (Rafael Aquini) [RHEL-27745]
- mm: pass a folio to swap_writepage_bdev_async() (Rafael Aquini) [RHEL-27745]
- mm: pass a folio to swap_writepage_bdev_sync() (Rafael Aquini) [RHEL-27745]
- mm: pass a folio to swap_writepage_fs() (Rafael Aquini) [RHEL-27745]
- mm: pass a folio to __swap_writepage() (Rafael Aquini) [RHEL-27745]
- mm: return the folio from __read_swap_cache_async() (Rafael Aquini) [RHEL-27745]
- mm/zswap: change per-cpu mutex and buffer to per-acomp_ctx (Rafael Aquini) [RHEL-27745]
- mm/zswap: cleanup zswap_writeback_entry() (Rafael Aquini) [RHEL-27745]
- mm/zswap: cleanup zswap_load() (Rafael Aquini) [RHEL-27745]
- mm/zswap: refactor out __zswap_load() (Rafael Aquini) [RHEL-27745]
- mm/zswap: reuse dstmem when decompress (Rafael Aquini) [RHEL-27745]
- mm: convert collapse_huge_page() to use a folio (Rafael Aquini) [RHEL-27745]
- lib/maple_tree.c: fix build error due to hotfix alteration (Rafael Aquini) [RHEL-27745]
- mm/memory-failure: cast index to loff_t before shifting it (Rafael Aquini) [RHEL-27745]
- mm/memory-failure: check the mapcount of the precise page (Rafael Aquini) [RHEL-27745]
- mm/memory-failure: pass the folio and the page to collect_procs() (Rafael Aquini) [RHEL-27745]
- mm/filemap: avoid buffered read/write race to read inconsistent data (Rafael Aquini) [RHEL-27745]
- mm/readahead: do not allow order-1 folio (Rafael Aquini) [RHEL-27745]
- zswap: shrink zswap pool based on memory pressure (Rafael Aquini) [RHEL-27745]
- maple_tree: mtree_range_walk() clean up (Rafael Aquini) [RHEL-27745]
- maple_tree: don't find node end in mtree_lookup_walk() (Rafael Aquini) [RHEL-27745]
- maple_tree: use maple state end for write operations (Rafael Aquini) [RHEL-27745]
- maple_tree: remove mas_searchable() (Rafael Aquini) [RHEL-27745]
- maple_tree: separate ma_state node from status (Rafael Aquini) [RHEL-27745]
- maple_tree: clean up inlines for some functions (Rafael Aquini) [RHEL-27745]
- maple_tree: use cached node end in mas_destroy() (Rafael Aquini) [RHEL-27745]
- maple_tree: use cached node end in mas_next() (Rafael Aquini) [RHEL-27745]
- maple_tree: add end of node tracking to the maple state (Rafael Aquini) [RHEL-27745]
- maple_tree: move debug check to __mas_set_range() (Rafael Aquini) [RHEL-27745]
- maple_tree: make mas_erase() more robust (Rafael Aquini) [RHEL-27745]
- maple_tree: remove unnecessary default labels from switch statements (Rafael Aquini) [RHEL-27745]
- mm/zswap: replace kmap_atomic() with kmap_local_page() (Rafael Aquini) [RHEL-27745]
- mm: remove invalidate_inode_page() (Rafael Aquini) [RHEL-27745]
- mm: convert isolate_page() to mf_isolate_folio() (Rafael Aquini) [RHEL-27745]
- mm: convert soft_offline_in_use_page() to use a folio (Rafael Aquini) [RHEL-27745]
- mm: use mapping_evict_folio() in truncate_error_page() (Rafael Aquini) [RHEL-27745]
- mm: convert __do_fault() to use a folio (Rafael Aquini) [RHEL-27745]
- mm: make mapping_evict_folio() the preferred way to evict clean folios (Rafael Aquini) [RHEL-27745]
- fork: use __mt_dup() to duplicate maple tree in dup_mmap() (Rafael Aquini) [RHEL-27745]
- maple_tree: preserve the tree attributes when destroying maple tree (Rafael Aquini) [RHEL-27745]
- maple_tree: update check_forking() and bench_forking() (Rafael Aquini) [RHEL-27745]
- maple_tree: skip other tests when BENCH is enabled (Rafael Aquini) [RHEL-27745]
- maple_tree: update the documentation of maple tree (Rafael Aquini) [RHEL-27745]
- maple_tree: add test for mtree_dup() (Rafael Aquini) [RHEL-27745]
- maple_tree: introduce interfaces __mt_dup() and mtree_dup() (Rafael Aquini) [RHEL-27745]
- maple_tree: introduce {mtree,mas}_lock_nested() (Rafael Aquini) [RHEL-27745]
- maple_tree: add mt_free_one() and mt_attr() helpers (Rafael Aquini) [RHEL-27745]
- mm/hugetlb: have CONFIG_HUGETLB_PAGE select CONFIG_XARRAY_MULTI (Rafael Aquini) [RHEL-27745]
- mm: kmem: properly initialize local objcg variable in current_obj_cgroup() (Rafael Aquini) [RHEL-27745]
- mm/slub: optimize free fast path code layout (Rafael Aquini) [RHEL-27745]
- mm/slab: move kmalloc() functions from slab_common.c to slub.c (Rafael Aquini) [RHEL-27745]
- mm/slab: move kmalloc_slab() to mm/slab.h (Rafael Aquini) [RHEL-27745]
- mm/slab: move kfree() from slab_common.c to slub.c (Rafael Aquini) [RHEL-27745]
- mm/slab: move struct kmem_cache_node from slab.h to slub.c (Rafael Aquini) [RHEL-27745]
- mm/slab: move memcg related functions from slab.h to slub.c (Rafael Aquini) [RHEL-27745]
- mm/slab: move pre/post-alloc hooks from slab.h to slub.c (Rafael Aquini) [RHEL-27745]
- mm/slab: consolidate includes in the internal mm/slab.h (Rafael Aquini) [RHEL-27745]
- mm/slab: move the rest of slub_def.h to mm/slab.h (Rafael Aquini) [RHEL-27745]
- mm/slab: move struct kmem_cache_cpu declaration to slub.c (Rafael Aquini) [RHEL-27745]
- mm/slab: remove CONFIG_SLAB code from slab common code (Rafael Aquini) [RHEL-27745]
- mempolicy: alloc_pages_mpol() for NUMA policy without vma (Rafael Aquini) [RHEL-27745]
- mm: add page_rmappable_folio() wrapper (Rafael Aquini) [RHEL-27745]
- mempolicy: clean up minor dead code in queue_pages_test_walk() (Rafael Aquini) [RHEL-27745]
- mempolicy: remove confusing MPOL_MF_LAZY dead code (Rafael Aquini) [RHEL-27745]
- mempolicy: mpol_shared_policy_init() without pseudo-vma (Rafael Aquini) [RHEL-27745]
- mempolicy trivia: use pgoff_t in shared mempolicy tree (Rafael Aquini) [RHEL-27745]
- mempolicy trivia: slightly more consistent naming (Rafael Aquini) [RHEL-27745]
- mempolicy trivia: delete those ancient pr_debug()s (Rafael Aquini) [RHEL-27745]
- mempolicy: fix migrate_pages(2) syscall return nr_failed (Rafael Aquini) [RHEL-27745]
- kernfs: drop shared NUMA mempolicy hooks (Rafael Aquini) [RHEL-27745]
- hugetlbfs: drop shared NUMA mempolicy pretence (Rafael Aquini) [RHEL-27745]
- mm: migrate: record the mlocked page status to remove unnecessary lru drain (Rafael Aquini) [RHEL-27745]
- mm: page_alloc: check the order of compound page even when the order is zero (Rafael Aquini) [RHEL-27745]
- mm/khugepaged: convert collapse_pte_mapped_thp() to use folios (Rafael Aquini) [RHEL-27745]
- mm/khugepaged: convert alloc_charge_hpage() to use folios (Rafael Aquini) [RHEL-27745]
- mm/khugepaged: convert is_refcount_suitable() to use folios (Rafael Aquini) [RHEL-27745]
- mm/khugepaged: convert hpage_collapse_scan_pmd() to use folios (Rafael Aquini) [RHEL-27745]
- mm/khugepaged: convert __collapse_huge_page_isolate() to use folios (Rafael Aquini) [RHEL-27745]
- mm/migrate: add nr_split to trace_mm_migrate_pages stats. (Rafael Aquini) [RHEL-27745]
- mm/migrate: correct nr_failed in migrate_pages_sync() (Rafael Aquini) [RHEL-27745]
- bootmem: use kmemleak_free_part_phys in free_bootmem_page (Rafael Aquini) [RHEL-27745]
- bootmem: use kmemleak_free_part_phys in put_page_bootmem (Rafael Aquini) [RHEL-27745]
- mm: kmem: reimplement get_obj_cgroup_from_current() (Rafael Aquini) [RHEL-27745]
- percpu: scoped objcg protection (Rafael Aquini) [RHEL-27745]
- mm: kmem: scoped objcg protection (Rafael Aquini) [RHEL-27745]
- mm: kmem: make memcg keep a reference to the original objcg (Rafael Aquini) [RHEL-27745]
- mm: kmem: add direct objcg pointer to task_struct (Rafael Aquini) [RHEL-27745]
- mm: kmem: optimize get_obj_cgroup_from_current() (Rafael Aquini) [RHEL-27745]
- mm: abstract VMA merge and extend into vma_merge_extend() helper (Rafael Aquini) [RHEL-27745]
- mm: abstract merge for new VMAs into vma_merge_new_vma() (Rafael Aquini) [RHEL-27745]
- mm: make vma_merge() and split_vma() internal (Rafael Aquini) [RHEL-27745]
- mm: abstract the vma_merge()/split_vma() pattern for mprotect() et al. (Rafael Aquini) [RHEL-27745]
- mm: move vma_policy() and anon_vma_name() decls to mm_types.h (Rafael Aquini) [RHEL-27745]
- mm/mprotect: allow unfaulted VMAs to be unaccounted on mprotect() (Rafael Aquini) [RHEL-27745]
- mm/thp: fix "mm: thp: kill __transhuge_page_enabled()" (Rafael Aquini) [RHEL-27745]
- mm/gup: adapt get_user_page_vma_remote() to never return NULL (Rafael Aquini) [RHEL-27745]
- mm/gup: make failure to pin an error if FOLL_NOWAIT not specified (Rafael Aquini) [RHEL-27745]
- mm/gup: explicitly define and check internal GUP flags, disallow FOLL_TOUCH (Rafael Aquini) [RHEL-27745]
- mm: make __access_remote_vm() static (Rafael Aquini) [RHEL-27745]
- shmem: _add_to_page_cache() before shmem_inode_acct_blocks() (Rafael Aquini) [RHEL-27745]
- shmem: move memcg charge out of shmem_add_to_page_cache() (Rafael Aquini) [RHEL-27745]
- shmem: shmem_acct_blocks() and shmem_inode_acct_blocks() (Rafael Aquini) [RHEL-27745]
- shmem: factor shmem_falloc_wait() out of shmem_fault() (Rafael Aquini) [RHEL-27745]
- shmem: remove vma arg from shmem_get_folio_gfp() (Rafael Aquini) [RHEL-27745]
- shmem: shrink shmem_inode_info: dir_offsets in a union (Rafael Aquini) [RHEL-27745]
- mm: memcg: normalize the value passed into memcg_rstat_updated() (Rafael Aquini) [RHEL-27745]
- mm: memcg: refactor page state unit helpers (Rafael Aquini) [RHEL-27745]
- maple_tree: add GFP_KERNEL to allocations in mas_expected_entries() (Rafael Aquini) [RHEL-27745]
- mm/filemap: remove hugetlb special casing in filemap.c (Rafael Aquini) [RHEL-27745]
- sched/numa, mm: make numa migrate functions to take a folio (Rafael Aquini) [RHEL-27745]
- mm: mempolicy: make mpol_misplaced() to take a folio (Rafael Aquini) [RHEL-27745]
- mm: memory: make numa_migrate_prep() to take a folio (Rafael Aquini) [RHEL-27745]
- mm: memory: use a folio in do_numa_page() (Rafael Aquini) [RHEL-27745]
- mm: huge_memory: use a folio in do_huge_pmd_numa_page() (Rafael Aquini) [RHEL-27745]
- mm: memory: add vm_normal_folio_pmd() (Rafael Aquini) [RHEL-27745]
- memcg: remove unused do_memsw_account in memcg1_stat_format (Rafael Aquini) [RHEL-27745]
- memcg: expose swapcache stat for memcg v1 (Rafael Aquini) [RHEL-27745]
- mm/writeback: update filemap_dirty_folio() comment (Rafael Aquini) [RHEL-27745]
- mm/hugetlb: use nth_page() in place of direct struct page manipulation (Rafael Aquini) [RHEL-27745]
- mm: migrate: remove isolated variable in add_page_for_migration() (Rafael Aquini) [RHEL-27745]
- mm: migrate: remove PageHead() check for HugeTLB in add_page_for_migration() (Rafael Aquini) [RHEL-27745]
- mm: migrate: use a folio in add_page_for_migration() (Rafael Aquini) [RHEL-27745]
- mm: migrate: use __folio_test_movable() (Rafael Aquini) [RHEL-27745]
- mm: migrate: convert migrate_misplaced_page() to migrate_misplaced_folio() (Rafael Aquini) [RHEL-27745]
- mm: migrate: convert numamigrate_isolate_page() to numamigrate_isolate_folio() (Rafael Aquini) [RHEL-27745]
- mm: migrate: remove THP mapcount check in numamigrate_isolate_page() (Rafael Aquini) [RHEL-27745]
- mm: migrate: remove PageTransHuge check in numamigrate_isolate_page() (Rafael Aquini) [RHEL-27745]
- mm/rmap: pass folio to hugepage_add_anon_rmap() (Rafael Aquini) [RHEL-27745]
- mm/rmap: simplify PageAnonExclusive sanity checks when adding anon rmap (Rafael Aquini) [RHEL-27745]
- mm/rmap: warn on new PTE-mapped folios in page_add_anon_rmap() (Rafael Aquini) [RHEL-27745]
- mm/rmap: move folio_test_anon() check out of __folio_set_anon() (Rafael Aquini) [RHEL-27745]
- mm/rmap: move SetPageAnonExclusive out of __page_set_anon_rmap() (Rafael Aquini) [RHEL-27745]
- mm/rmap: drop stale comment in page_add_anon_rmap and hugepage_add_anon_rmap() (Rafael Aquini) [RHEL-27745]
- mm: memcg: add THP swap out info for anonymous reclaim (Rafael Aquini) [RHEL-27745]
- kmsan: introduce test_memcpy_initialized_gap() (Rafael Aquini) [RHEL-27745]
- kmsan: merge test_memcpy_aligned_to_unaligned{,2}() together (Rafael Aquini) [RHEL-27745]
- kmsan: prevent optimizations in memcpy tests (Rafael Aquini) [RHEL-27745]
- kmsan: simplify kmsan_internal_memmove_metadata() (Rafael Aquini) [RHEL-27745]
- mm: remove duplicated vma->vm_flags check when expanding stack (Rafael Aquini) [RHEL-27745]
- mm: convert DAX lock/unlock page to lock/unlock folio (Rafael Aquini) [RHEL-27745]
- mm/vmscan: use folio_migratetype() instead of get_pageblock_migratetype() (Rafael Aquini) [RHEL-27745]
- mm/mremap: fix unaccount of memory on vma_merge() failure (Rafael Aquini) [RHEL-27745]
- mm/compaction: factor out code to test if we should run compaction for target order (Rafael Aquini) [RHEL-27745]
- mm/compaction: improve comment of is_via_compact_memory (Rafael Aquini) [RHEL-27745]
- mm/compaction: remove repeat compact_blockskip_flush check in reset_isolation_suitable (Rafael Aquini) [RHEL-27745]
- mm/compaction: correctly return failure with bogus compound_order in strict mode (Rafael Aquini) [RHEL-27745]
- mm/compaction: call list_is_{first}/{last} more intuitively in move_freelist_{head}/{tail} (Rafael Aquini) [RHEL-27745]
- mm/compaction: use correct list in move_freelist_{head}/{tail} (Rafael Aquini) [RHEL-27745]
- mm/slub: simplify the last resort slab order calculation (Rafael Aquini) [RHEL-27745]
- mm/slub: add sanity check for slub_min/max_order cmdline setup (Rafael Aquini) [RHEL-27745]
- maple_tree: add MAS_UNDERFLOW and MAS_OVERFLOW states (Rafael Aquini) [RHEL-27745]
- maple_tree: add mas_is_active() to detect in-tree walks (Rafael Aquini) [RHEL-27745]
- arm/xen: remove lazy mode related definitions (Rafael Aquini) [RHEL-27745]
- mm: Remove kmem_valid_obj() (Rafael Aquini) [RHEL-27745]
- maple_tree: clean up mas_wr_append() (Rafael Aquini) [RHEL-27745]
- maple_tree: replace data before marking dead in split and spanning store (Rafael Aquini) [RHEL-27745]
- maple_tree: change mas_adopt_children() parent usage (Rafael Aquini) [RHEL-27745]
- maple_tree: introduce mas_tree_parent() definition (Rafael Aquini) [RHEL-27745]
- maple_tree: introduce mas_put_in_tree() (Rafael Aquini) [RHEL-27745]
- maple_tree: reorder replacement of nodes to avoid live lock (Rafael Aquini) [RHEL-27745]
- maple_tree: add hex output to maple_arange64 dump (Rafael Aquini) [RHEL-27745]
- maple_tree: Be more strict about locking (Rafael Aquini) [RHEL-27745]
- fs/address_space: add alignment padding for i_map and i_mmap_rwsem to mitigate a false sharing. (Rafael Aquini) [RHEL-15601 RHEL-27745]
- maple_tree: drop mas_first_entry() (Rafael Aquini) [RHEL-27745]
- maple_tree: replace mas_logical_pivot() with mas_safe_pivot() (Rafael Aquini) [RHEL-27745]
- maple_tree: update mt_validate() (Rafael Aquini) [RHEL-27745]
- maple_tree: make mas_validate_limits() check root node and node limit (Rafael Aquini) [RHEL-27745]
- maple_tree: fix mas_validate_child_slot() to check last missed slot (Rafael Aquini) [RHEL-27745]
- maple_tree: make mas_validate_gaps() to check metadata (Rafael Aquini) [RHEL-27745]
- maple_tree: don't use MAPLE_ARANGE64_META_MAX to indicate no gap (Rafael Aquini) [RHEL-27745]
- maple_tree: add a fast path case in mas_wr_slot_store() (Rafael Aquini) [RHEL-27745]
- maple_tree: optimize mas_wr_append(), also improve duplicating VMAs (Rafael Aquini) [RHEL-27745]
- maple_tree: add test for expanding range in RCU mode (Rafael Aquini) [RHEL-27745]
- maple_tree: add test for mas_wr_modify() fast path (Rafael Aquini) [RHEL-27745]
- shmem: Refactor shmem_symlink() (Rafael Aquini) [RHEL-27745]
- XArray: Do not return sibling entries from xa_load() (Rafael Aquini) [RHEL-27745]
- bootmem: remove the vmemmap pages from kmemleak in free_bootmem_page (Rafael Aquini) [RHEL-27745]
- kasan, doc: note kasan.fault=panic_on_write behaviour for async modes (Rafael Aquini) [RHEL-27745]
- fs: hugetlbfs: set vma policy only when needed for allocating folio (Rafael Aquini) [RHEL-27745]
- afs: fix the afs_dir_get_folio return value (Rafael Aquini) [RHEL-27745]
- of: reserved_mem: Have kmemleak ignore dynamically allocated reserved mem (Rafael Aquini) [RHEL-27745]
- powerpc/64s: Fix local irq disable when PMIs are disabled (Rafael Aquini) [RHEL-27745]
- powerpc/book3e: remove #include <generated/utsrelease.h> (Rafael Aquini) [RHEL-27745]
- s390: avoid using global register for current_stack_pointer (Rafael Aquini) [RHEL-27745]
- s390/virtio_ccw: Fix dma_parm pointer not set up (Thomas Huth) [RHEL-70246]
- fs/mnt_idmapping.c: Return -EINVAL when no map is written (Ian Kent) [RHEL-62007]
- fs: reformat idmapped mounts entry (Ian Kent) [RHEL-62007]
- mnt_idmapping: decouple from namespaces (Ian Kent) [RHEL-62007]
- mnt_idmapping: remove nop check (Ian Kent) [RHEL-62007]
- mnt_idmapping: remove check_fsmapping() (Ian Kent) [RHEL-62007]
- fs: export mnt_idmap_get/mnt_idmap_put (Ian Kent) [RHEL-62007]
- USB: serial: qcserial: add support for Sierra Wireless EM86xx (Desnes Nunes) [RHEL-59052]
- thunderbolt: Fix connection issue with Pluggable UD-4VPD dock (Desnes Nunes) [RHEL-59052]
- usb: typec: fix potential out of bounds in ucsi_ccg_update_set_new_cam_cmd() (Desnes Nunes) [RHEL-59052] {CVE-2024-50268}
- usb: dwc3: fix fault at system suspend if device was already runtime suspended (Desnes Nunes) [RHEL-59052 RHEL-68268] {CVE-2024-53070}
- USB: serial: io_edgeport: fix use after free in debug printk (Desnes Nunes) [RHEL-59052] {CVE-2024-50267}
- USB: serial: option: add Quectel RG650V (Desnes Nunes) [RHEL-59052]
- USB: serial: option: add Fibocom FG132 0x0112 composition (Desnes Nunes) [RHEL-59052]
- thunderbolt: Add only on-board retimers when !CONFIG_USB4_DEBUGFS_MARGINING (Desnes Nunes) [RHEL-59052]
- usb: phy: Fix API devm_usb_put_phy() can not release the phy (Desnes Nunes) [RHEL-59052]
- usb: typec: use cleanup facility for 'altmodes_node' (Desnes Nunes) [RHEL-59052]
- usb: typec: fix unreleased fwnode_handle in typec_port_register_altmodes() (Desnes Nunes) [RHEL-59052]
- usb: acpi: fix boot hang due to early incorrect 'tunneled' USB3 device links (Desnes Nunes) [RHEL-59052]
- xhci: Fix Link TRB DMA in command ring stopped completion event (Desnes Nunes) [RHEL-59052]
- xhci: Use pm_runtime_get to prevent RPM on unsupported systems (Desnes Nunes) [RHEL-59052]
- phy: tegra: xusb: Add error pointer check in xusb.c (Desnes Nunes) [RHEL-59052]
- phy: freescale: imx8m-pcie: Do CMN_RST just before PHY PLL lock check (Desnes Nunes) [RHEL-59052]
- thunderbolt: Honor TMU requirements in the domain when setting TMU mode (Desnes Nunes) [RHEL-59052]
- misc: rtsx: list supported models in Kconfig help (Desnes Nunes) [RHEL-59052]
- media: pulse8-cec: fix data timestamp at pulse8_setup() (Desnes Nunes) [RHEL-59052]
- redhat/configs: Adding CONFIG_USB_ONBOARD_DEV_USB5744 (Desnes Nunes) [RHEL-59052]
- USB: serial: option: add Telit FN920C04 MBIM compositions (Desnes Nunes) [RHEL-59052]
- USB: serial: option: add support for Quectel EG916Q-GL (Desnes Nunes) [RHEL-59052]
- xhci: dbc: honor usb transfer size boundaries. (Desnes Nunes) [RHEL-59052]
- usb: xhci: Fix handling errors mid TD followed by other errors (Desnes Nunes) [RHEL-59052]
- xhci: Mitigate failed set dequeue pointer commands (Desnes Nunes) [RHEL-59052]
- xhci: Fix incorrect stream context type macro (Desnes Nunes) [RHEL-59052]
- usb: dwc3: core: Fix system suspend on TI AM62 platforms (Desnes Nunes) [RHEL-59052]
- xhci: tegra: fix checked USB2 port number (Desnes Nunes) [RHEL-59052 RHEL-65123] {CVE-2024-50075}
- usb: dwc3: Wait for EndXfer completion before restoring GUSB2PHYCFG (Desnes Nunes) [RHEL-59052]
- usb: typec: altmode should keep reference to parent (Desnes Nunes) [RHEL-59052 RHEL-66511] {CVE-2024-50150}
- usb: xhci: Fix problem with xhci resume from suspend (Desnes Nunes) [RHEL-59052]
- usb: misc: onboard_usb_dev: introduce new config symbol for usb5744 SMBus support (Desnes Nunes) [RHEL-59052]
- usb: dwc3: core: Stop processing of pending events if controller is halted (Desnes Nunes) [RHEL-59052]
- usb: dwc3: re-enable runtime PM after failed resume (Desnes Nunes) [RHEL-59052]
- usb: storage: ignore bogus device raised by JieLi BR21 USB sound chip (Desnes Nunes) [RHEL-59052]
- usb: gadget: core: force synchronous registration (Desnes Nunes) [RHEL-59052]
- usbnet: fix cyclical race on disconnect with work queue (Desnes Nunes) [RHEL-59052]
- usbnet: Fix linkwatch use-after-free on disconnect (Desnes Nunes) [RHEL-59052]
- usbnet: Run unregister_netdev() before unbind() again (Desnes Nunes) [RHEL-59052]
- USB: appledisplay: close race between probe and completion handler (Desnes Nunes) [RHEL-59052]
- USB: class: CDC-ACM: fix race between get_serial and set_serial (Desnes Nunes) [RHEL-59052]
- usb: storage: ene_ub6250: Fix right shift warnings (Desnes Nunes) [RHEL-59052]
- usb: roles: Improve the fix for a false positive recursive locking complaint (Desnes Nunes) [RHEL-59052]
- locking/mutex: Introduce mutex_init_with_key() (Desnes Nunes) [RHEL-59052]
- locking/mutex: Define mutex_init() once (Desnes Nunes) [RHEL-59052]
- leds: mlxreg: Use devm_mutex_init() for mutex initialization (Desnes Nunes) [RHEL-59052] {CVE-2024-42129}
- locking/mutex: Introduce devm_mutex_init() (Desnes Nunes) [RHEL-59052]
- locking/rwsem: Make DEBUG_RWSEMS and PREEMPT_RT mutually exclusive (Desnes Nunes) [RHEL-59052]
- locking/rwsem: Clarify that RWSEM_READER_OWNED is just a hint (Desnes Nunes) [RHEL-59052]
- locking/qspinlock: Fix 'wait_early' set but not used warning (Desnes Nunes) [RHEL-59052]
- locking/mutex: Simplify <linux/mutex.h> (Desnes Nunes) [RHEL-59052]
- locking/mutex: split out mutex_types.h (Desnes Nunes) [RHEL-59052]
- usb: xhci: fix loss of data on Cadence xHC (Desnes Nunes) [RHEL-59052]
- usb: xHCI: add XHCI_RESET_ON_RESUME quirk for Phytium xHCI host (Desnes Nunes) [RHEL-59052]
- usb: dwc3: qcom: simplify with devm_platform_ioremap_resource (Desnes Nunes) [RHEL-59052]
- usb: dwc3: qcom: use scoped device node handling to simplify error paths (Desnes Nunes) [RHEL-59052]
- usb: dwc3: imx8mp: disable SS_CON and U3 wakeup for system sleep (Desnes Nunes) [RHEL-59052]
- usb: dwc3: imx8mp: add 2 software managed quirk properties for host mode (Desnes Nunes) [RHEL-59052]
- usb: host: xhci-plat: Parse xhci-missing_cas_quirk and apply quirk (Desnes Nunes) [RHEL-59052]
- usb: misc: onboard_usb_dev: add Microchip usb5744 SMBus programming support (Desnes Nunes) [RHEL-59052]
- usb: misc: onboard_dev: extend platform data to add power on delay field (Desnes Nunes) [RHEL-59052]
- usb: cdnsp: Fix incorrect usb_request status (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci: support edge irq (Desnes Nunes) [RHEL-59052]
- usb: chipidea: npcm: Fix coding style with clarification of data type (Desnes Nunes) [RHEL-59052]
- usb: common: Switch to device_property_match_property_string() (Desnes Nunes) [RHEL-59052]
- device property: Add fwnode_property_match_property_string() (Desnes Nunes) [RHEL-59052]
- device property: Use fwnode_property_string_array_count() (Desnes Nunes) [RHEL-59052]
- USB: usbtmc: prevent kernel-usb-infoleak (Desnes Nunes) [RHEL-59052] {CVE-2024-47671}
- USB: serial: pl2303: add device id for Macrosilicon MS3020 (Desnes Nunes) [RHEL-59052]
- redhat/configs: Adding CONFIG_USB_EXTRON_DA_HD_4K_PLUS_CEC (Desnes Nunes) [RHEL-59052]
- media: cec: extron-da-hd-4k-plus: add the Extron DA HD 4K Plus CEC driver (Desnes Nunes) [RHEL-59052]
- media: cec: move cec_get/put_device to header (Desnes Nunes) [RHEL-59052]
- media: input: serio.h: add SERIO_EXTRON_DA_HD_PLUS (Desnes Nunes) [RHEL-59052]
- media: admin-guide: cec.rst (Desnes Nunes) [RHEL-59052]
- xhci: support setting interrupt moderation IMOD for secondary interrupters (Desnes Nunes) [RHEL-59052]
- xhci: Set quirky xHC PCI hosts to D3 _after_ stopping and freeing them. (Desnes Nunes) [RHEL-59052]
- usb: xhci: adjust empty TD list handling in handle_tx_event() (Desnes Nunes) [RHEL-59052]
- usb: xhci: remove 'retval' from xhci_pci_resume() (Desnes Nunes) [RHEL-59052]
- usb: xhci: add comments explaining specific interrupt behaviour (Desnes Nunes) [RHEL-59052]
- usb: xhci: make 'sbrn' a local variable (Desnes Nunes) [RHEL-59052]
- usb: xhci: remove unused variables from struct 'xhci_hcd' (Desnes Nunes) [RHEL-59052]
- usb: xhci: remove excessive Bulk short packet debug message (Desnes Nunes) [RHEL-59052]
- usb: xhci: remove excessive isoc frame debug message spam (Desnes Nunes) [RHEL-59052]
- xhci: Remove unused function declarations (Desnes Nunes) [RHEL-59052]
- xhci: dbc: add dbgtty request to end of list once it completes (Desnes Nunes) [RHEL-59052]
- xhci: dbc: Fix STALL transfer event handling (Desnes Nunes) [RHEL-59052]
- dt-bindings: extcon: convert extcon-usb-gpio.txt to yaml format (Desnes Nunes) [RHEL-59052]
- redhat/configs: Adding CONFIG_EXTCON_LC824206XA (Desnes Nunes) [RHEL-59052]
- extcon: Add LC824206XA microUSB switch driver (Desnes Nunes) [RHEL-59052]
- power: supply: Change usb_types from an array into a bitmask (Desnes Nunes) [RHEL-59052]
- power: supply: sysfs: Move power_supply_show_enum_with_available() up (Desnes Nunes) [RHEL-59052]
- power: supply: sysfs: Add power_supply_show_enum_with_available() helper (Desnes Nunes) [RHEL-59052]
- power: supply: "usb_type" property may be written to (Desnes Nunes) [RHEL-59052]
- power: supply: core: simplify charge_behaviour formatting (Desnes Nunes) [RHEL-59052]
- power: supply: core: fix charge_behaviour formatting (Desnes Nunes) [RHEL-59052]
- power: supply: core: ease special formatting implementations (Desnes Nunes) [RHEL-59052]
- dt-bindings: phy: mxs-usb-phy: add nxp,sim property (Desnes Nunes) [RHEL-59052]
- thunderbolt: Don't create device link from USB4 Host Interface to USB3 xHC host (Desnes Nunes) [RHEL-59052]
- usb: acpi: add device link between tunneled USB3 device and USB4 Host Interface (Desnes Nunes) [RHEL-59052]
- device property: Move fwnode_handle_put() into property.h (Desnes Nunes) [RHEL-59052]
- usb: Add tunnel_mode parameter to usb device structure (Desnes Nunes) [RHEL-59052]
- xhci: Add USB4 tunnel detection for USB3 devices on Intel hosts (Desnes Nunes) [RHEL-59052]
- usb: chipidea: npcm: Fix coding style with missing space (Desnes Nunes) [RHEL-59052]
- usb: dwc3: imx8mp: use scoped device node handling to simplify error paths (Desnes Nunes) [RHEL-59052]
- usb: dwc3: imx8mp: simplify with dev_err_probe (Desnes Nunes) [RHEL-59052]
- usb: dwc3: imx8mp: simplify with devm_clk_get_enabled (Desnes Nunes) [RHEL-59052]
- usb-storage: Constify struct usb_device_id and us_unusual_dev (Desnes Nunes) [RHEL-59052]
- phy: broadcom: brcm-sata: Simplify with scoped for each OF child loop (Desnes Nunes) [RHEL-59052]
- USB: serial: kobil_sct: restore initial terminal settings (Desnes Nunes) [RHEL-59052]
- USB: serial: drop driver owner initialization (Desnes Nunes) [RHEL-59052]
- USB: serial: set driver owner when registering drivers (Desnes Nunes) [RHEL-59052]
- usb: roles: add lockdep class key to struct usb_role_switch (Desnes Nunes) [RHEL-59052]
- usb: typec: tipd: Free IRQ only if it was requested before (Desnes Nunes) [RHEL-59052 RHEL-63862] {CVE-2024-50057}
- Documentation: msm-hsusb.txt: remove (Desnes Nunes) [RHEL-59052]
- usb: typec: ucsi: Add DATA_RESET option of Connector Reset command (Desnes Nunes) [RHEL-59052]
- dt-bindings: usb: qcom,dwc3: Document X1E80100 MP controller (Desnes Nunes) [RHEL-59052]
- thunderbolt: Improve software receiver lane margining (Desnes Nunes) [RHEL-59052]
- thunderbolt: Add optional voltage offset range for receiver lane margining (Desnes Nunes) [RHEL-59052]
- thunderbolt: Consolidate margining parameters into a structure (Desnes Nunes) [RHEL-59052]
- thunderbolt: Add missing usb4_port_sb_read() to usb4_port_sw_margin() (Desnes Nunes) [RHEL-59052]
- xhci: dbgtty: use kfifo from tty_port struct (Desnes Nunes) [RHEL-59052]
- xhci: dbgtty: remove kfifo_out() wrapper (Desnes Nunes) [RHEL-59052]
- usb: common: Use helper function for_each_node_with_property() (Desnes Nunes) [RHEL-59052]
- usb: phy: mxs: enable weak 1p1 regulator for imx6ul during suspend (Desnes Nunes) [RHEL-59052]
- usb: phy: mxs: add wakeup enable for imx7ulp (Desnes Nunes) [RHEL-59052]
- usb: phy: mxs: keep USBPHY2's clk always on (Desnes Nunes) [RHEL-59052]
- usb: phy: mxs: enable regulator phy-3p0 to improve signal qualilty (Desnes Nunes) [RHEL-59052]
- xhci-pci: Make xhci-pci-renesas a proper modular driver (Desnes Nunes) [RHEL-59052]
- usb: dwc3: imx8mp: Switch to RUNTIME/SYSTEM_SLEEP_PM_OPS() (Desnes Nunes) [RHEL-59052]
- usb: chipidea: Use of_property_present() (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci: use GENMASK() for TCPC_TRANSMIT register fields (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci: use GENMASK() for TCPC_MSG_HDR_INFO_REV (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci: use GENMASK() for TCPC_ROLE_CTRL_RP_VAL (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci: use GENMASK() for TCPC_ROLE_CTRL_CC[12] (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci: use GENMASK() for TCPC_CC_STATUS_CC[12] (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci_rt1711h: Drop CONFIG_OF ifdeffery (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci_rt1711h: Convert enum->pointer for data in the match tables (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci_rt1711h: Remove trailing comma in the terminator entry for OF table (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpm/tcpci_maxim: clarify a comment (Desnes Nunes) [RHEL-59052]
- usb: typec: tcpci: fix a comment typo (Desnes Nunes) [RHEL-59052]
- dt-bindings: usb: qcom,dwc3: Update ipq5332 clock details (Desnes Nunes) [RHEL-59052]
- USB: ohci-ppc-of: Drop ohci-littledian compatible (Desnes Nunes) [RHEL-59052]
- usb: ohci-ppc-of: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-59052]
- fsnotify: fix sending inotify event with unexpected filename (Ian Kent) [RHEL-37493]
- block, bfq: fix possible UAF for bfqq->bic with merge chain (CKI Backport Bot) [RHEL-63388] {CVE-2024-47706}

* Fri Dec 13 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-544.el9]
- x86/apic: Always explicitly disarm TSC-deadline timer (David Arcari) [RHEL-65750]
- netfilter: ipset: Hold module reference while requesting a module (Phil Sutter) [RHEL-35819]
- CVE-2024-53122 mptcp: cope racing subflow creation in mptcp_rcv_space_adjust (Patrick Talbert) [RHEL-69670] {CVE-2024-53122}
- x86/tdx: mark TDX guest as fully supported (Vitaly Kuznetsov) [RHEL-70465]
- net: usb: cdc_ether: don't spew notifications (Jose Ignacio Tornos Martinez) [RHEL-52777]
- USB: zaurus: Add ID for A-300/B-500/C-700 (Jose Ignacio Tornos Martinez) [RHEL-52777]
- net: usb: cdc_ether: add u-blox 0x1313 composition. (Jose Ignacio Tornos Martinez) [RHEL-52777]
- USB: serial: xr: add TIOCGRS485 and TIOCSRS485 ioctls (Desnes Nunes) [RHEL-67057]
- USB: serial: xr: avoid requesting zero DTE rate (Desnes Nunes) [RHEL-67057]
- redhat: configs: enable xr_serial on rhel (Desnes Nunes) [RHEL-67057]
- smb: client: Fix use-after-free of network namespace. (Paulo Alcantara) [RHEL-68558] {CVE-2024-53095}
- dlm: fix recovery of middle conversions (Alexander Aring) [RHEL-67852]

* Thu Dec 12 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-543.el9]
- scsi: lpfc: Fix a possible null pointer dereference (Ewan D. Milne) [RHEL-64869] {CVE-2024-43821}
- smb: client: fix NULL ptr deref in crypto_aead_setkey() (Paulo Alcantara) [RHEL-63909]
- smb: client: fix UAF in async decryption (Paulo Alcantara) [RHEL-63909] {CVE-2024-50047}
- macsec: Fix use-after-free while sending the offloading packet (CKI Backport Bot) [RHEL-66910] {CVE-2024-50261}
- xfs: fix sparse inode limits on runt AG (Pavel Reichl) [RHEL-68541]
- ASoC: SOF: ipc4-topology: Preserve the DMA Link ID for ChainDMA on unprepare (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: Only handle dai_config with HW_PARAMS for ChainDMA (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: Use single token list for the copiers (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: Use correct queue_id for requesting input pin format (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: Adjust the params based on DAI formats (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: Improve readability of sof_ipc4_prepare_dai_copier() (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology/pcm: Rename sof_ipc4_copier_is_single_format() (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: Print out the channel count in sof_ipc4_dbg_audio_format (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: support tdm slot number query (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc3-topology: support tdm slot number query (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: sof-audio: add sof_dai_get_tdm_slots function (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: sof-audio: rename dai clock setting query function (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: Add support for NHLT with 16-bit only DMIC blob (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: Correct DAI copier config and NHLT blob request (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: Allow selective update in sof_ipc4_update_hw_params (Jaroslav Kysela) [RHEL-54539]
- ASoC: SOF: ipc4-topology: remove shadowed variable (Jaroslav Kysela) [RHEL-54539]
- redhat/configs: Move GPIO configs under rhel (Rupinderjit Singh) [RHEL-69941]
- platform/x86/intel/tpmi/plr: Fix output in plr_print_bits() (David Arcari) [RHEL-46074]
- doc: TPMI: Add entry for Performance Limit Reasons (David Arcari) [RHEL-46074]
- platform/x86/intel/tpmi/plr: Add support for the plr mailbox (David Arcari) [RHEL-46074]
- platform/x86/intel/tpmi: Add new auxiliary driver for performance limits (David Arcari) [RHEL-46074]
- redhat: configs: enable INTEL_PLR_TPMI for RHEL (David Arcari) [RHEL-46074]
- platform/x86/intel: TPMI domain id and CPU mapping (David Arcari) [RHEL-46074]
- platform/x86/intel/tpmi: Add API to get debugfs root (David Arcari) [RHEL-46074]
- platform/x86/intel/tpmi: Add support for performance limit reasons (David Arcari) [RHEL-46074]
- doc: TPMI: Add debugfs documentation (David Arcari) [RHEL-46074]
- MAINTAINERS: Add entry for TPMI driver (David Arcari) [RHEL-46074]
- gso: fix dodgy bit handling for GSO_UDP_L4 (Guillaume Nault) [RHEL-69903]
- udp: allow header check for dodgy GSO_UDP_L4 packets. (Guillaume Nault) [RHEL-69903]
- redhat: configs: Disable DVB settings (Kate Hsuan) [RHEL-65104]
- cache: add __cacheline_group_{begin, end}_aligned() (+ couple more) (CKI Backport Bot) [RHEL-68652]
- uapi: stddef.h: Provide UAPI macros for __counted_by_{le, be} (Michal Schmidt) [RHEL-68653]
- compiler_types: add Endianness-dependent __counted_by_{le,be} (Michal Schmidt) [RHEL-68653]
- docs: ignore __counted_by attribute in structure definitions (Michal Schmidt) [RHEL-68653]
- Documentation: conf.py: Add __force to c_id_attributes (Michal Schmidt) [RHEL-68653]

* Wed Dec 11 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-542.el9]
- bpf: Get better reg range with ldsx and 32bit compare (Viktor Malik) [RHEL-30774]
- selftests/bpf: Use -4095 as the bad address for bits iterator (Viktor Malik) [RHEL-30774]
- selftests/bpf: update send_signal to lower perf evemts frequency (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add three test cases for bits_iter (Viktor Malik) [RHEL-30774]
- bpf: Use __u64 to save the bits in bits iterator (Viktor Malik) [RHEL-30774]
- bpf: Check the validity of nr_words in bpf_iter_bits_new() (Viktor Malik) [RHEL-30774]
- bpf: Add bpf_mem_alloc_check_size() helper (Viktor Malik) [RHEL-30774]
- bpf: Free dynamically allocated bits in bpf_iter_bits_destroy() (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add test case for delta propagation (Viktor Malik) [RHEL-30774]
- bpf: Fix print_reg_state's constant scalar dump (Viktor Malik) [RHEL-30774]
- bpf: Fix incorrect delta propagation between linked registers (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add more test case for field flattening (Viktor Malik) [RHEL-30774]
- bpf: Check the remaining info_cnt before repeating btf fields (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add a selftest to check for incorrect names (Viktor Malik) [RHEL-30774]
- bpftool: Fix handling enum64 in btf dump sorting (Viktor Malik) [RHEL-30774]
- libbpf: Ensure new BTF objects inherit input endianness (Viktor Malik) [RHEL-30774]
- bpf: Fix a crash when btf_parse_base() returns an error pointer (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add a test to verify previous stacksafe() fix (Viktor Malik) [RHEL-30774]
- bpf: Fix updating attached freplace prog in prog_array map (Viktor Malik) [RHEL-30774]
- libbpf: Fix license for btf_relocate.c (Viktor Malik) [RHEL-30774]
- selftests/bpf: Filter out _GNU_SOURCE when compiling test_cpp (Viktor Malik) [RHEL-30774]
- tools/resolve_btfids: Fix comparison of distinct pointer types warning in resolve_btfids (Viktor Malik) [RHEL-30774]
- bpf, events: Use prog to emit ksymbol event for main program (Viktor Malik) [RHEL-30774]
- bpftool: Fix typo in usage help (Viktor Malik) [RHEL-30774]
- libbpf: Fix no-args func prototype BTF dumping syntax (Viktor Malik) [RHEL-30774]
- selftests/bpf: fexit_sleep: Fix stack allocation for arm64 (Viktor Malik) [RHEL-30774]
- test_bpf: convert comma to semicolon (Viktor Malik) [RHEL-30774]
- selftests/bpf: Test for null-pointer-deref bugfix in resolve_prog_type() (Viktor Malik) [RHEL-30774]
- bpf: Fix null pointer dereference in resolve_prog_type() for BPF_PROG_TYPE_EXT (Viktor Malik) [RHEL-30774]
- selftests/bpf: DENYLIST.aarch64: Skip fexit_sleep again (Viktor Malik) [RHEL-30774]
- bpf: Eliminate remaining "make W=1" warnings in kernel/bpf/btf.o (Viktor Malik) [RHEL-30774]
- bpf: annotate BTF show functions with __printf (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add ASSERT_OK_FD macro (Viktor Malik) [RHEL-30774]
- bpf: relax zero fixed offset constraint on KF_TRUSTED_ARGS/KF_RCU (Viktor Malik) [RHEL-30774]
- libbpf: improve old BPF skeleton handling for map auto-attach (Viktor Malik) [RHEL-30774]
- libbpf: fix BPF skeleton forward/backward compat handling (Viktor Malik) [RHEL-30774]
- bpftool: improve skeleton backwards compat with old buggy libbpfs (Viktor Malik) [RHEL-30774]
- selftests/bpf: DENYLIST.aarch64: Remove fexit_sleep (Viktor Malik) [RHEL-30774]
- libbpf: Add NULL checks to bpf_object__{prev_map,next_map} (Viktor Malik) [RHEL-30774]
- selftests/bpf: Remove exceptions tests from DENYLIST.s390x (Viktor Malik) [RHEL-30774]
- s390/bpf: Implement exceptions (Viktor Malik) [RHEL-30774]
- s390/bpf: Change seen_reg to a mask (Viktor Malik) [RHEL-30774]
- selftests/bpf: Remove arena tests from DENYLIST.s390x (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add UAF tests for arena atomics (Viktor Malik) [RHEL-30774]
- selftests/bpf: Introduce __arena_global (Viktor Malik) [RHEL-30774]
- s390/bpf: Support arena atomics (Viktor Malik) [RHEL-30774]
- s390/bpf: Enable arena (Viktor Malik) [RHEL-30774]
- s390/bpf: Support address space cast instruction (Viktor Malik) [RHEL-30774]
- s390/bpf: Support BPF_PROBE_MEM32 (Viktor Malik) [RHEL-30774]
- s390/bpf: Land on the next JITed instruction after exception (Viktor Malik) [RHEL-30774]
- s390/bpf: Introduce pre- and post- probe functions (Viktor Malik) [RHEL-30774]
- s390/bpf: Get rid of get_probe_mem_regno() (Viktor Malik) [RHEL-30774]
- s390/bpf: Factor out emitting probe nops (Viktor Malik) [RHEL-30774]
- bpftool: Mount bpffs when pinmaps path not under the bpffs (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add testcase where 7th argment is struct (Viktor Malik) [RHEL-30774]
- selftests/bpf: Factor out many args tests from tracing_struct (Viktor Malik) [RHEL-30774]
- bpf: Use precise image size for struct_ops trampoline (Viktor Malik) [RHEL-30774]
- libbpf: Fix error handling in btf__distill_base() (Viktor Malik) [RHEL-30774]
- selftests/bpf: Move ARRAY_SIZE to bpf_misc.h (Viktor Malik) [RHEL-30774]
- libbpf: Fix clang compilation error in btf_relocate.c (Viktor Malik) [RHEL-30774]
- selftests/bpf: Don't close(-1) in serial_test_fexit_stress() (Viktor Malik) [RHEL-30774]
- bpf: add new negative selftests to cover missing check_func_arg_reg_off() and reg->type check (Viktor Malik) [RHEL-30774]
- bpf: add missing check_func_arg_reg_off() to prevent out-of-bounds memory accesses (Viktor Malik) [RHEL-30774]
- bpf: Fix tailcall cases in test_bpf (Viktor Malik) [RHEL-30774]
- libbpf: Skip base btf sanity checks (Viktor Malik) [RHEL-30774]
- selftests/bpf: add test validating uprobe/uretprobe stack traces (Viktor Malik) [RHEL-30774]
- bpf: fix build when CONFIG_DEBUG_INFO_BTF[_MODULES] is undefined (Viktor Malik) [RHEL-30774]
- bpf, docs: Address comments from IETF Area Directors (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add kfunc_call test for simple dtor in bpf_testmod (Viktor Malik) [RHEL-30774]
- kbuild,bpf: Add module-specific pahole flags for distilled base BTF (Viktor Malik) [RHEL-30774]
- libbpf,bpf: Share BTF relocate-related code with kernel (Viktor Malik) [RHEL-30774]
- libbpf: Split field iter code into its own file kernel (Viktor Malik) [RHEL-30774]
- module, bpf: Store BTF base pointer in struct module (Viktor Malik) [RHEL-30774]
- libbpf: BTF relocation followup fixing naming, loop logic (Viktor Malik) [RHEL-30774]
- selftests/bpf: Match tests against regular expression (Viktor Malik) [RHEL-30774]
- selftests/bpf: Support checks against a regular expression (Viktor Malik) [RHEL-30774]
- libbpf: Checking the btf_type kind when fixing variable offsets (Viktor Malik) [RHEL-30774]
- bpf: Add security_file_post_open() LSM hook to sleepable_lsm_hooks (Viktor Malik) [RHEL-30774]
- bpftool: Allow compile-time checks of BPF map auto-attach support in skeleton (Viktor Malik) [RHEL-30774]
- bpf: remove redeclaration of new_n in bpf_verifier_vlog (Viktor Malik) [RHEL-30774]
- bpf: remove unused parameter in __bpf_free_used_btfs (Viktor Malik) [RHEL-30774]
- bpf: remove unused parameter in bpf_jit_binary_pack_finalize (Viktor Malik) [RHEL-30774]
- bpf, x64: Remove tail call detection (Viktor Malik) [RHEL-30774]
- bpf, verifier: Correct tail_call_reachable for bpf prog (Viktor Malik) [RHEL-30774]
- resolve_btfids: Handle presence of .BTF.base section (Viktor Malik) [RHEL-30774]
- libbpf: Make btf_parse_elf process .BTF.base transparently (Viktor Malik) [RHEL-30774]
- selftests/bpf: Extend distilled BTF tests to cover BTF relocation (Viktor Malik) [RHEL-30774]
- libbpf: Split BTF relocation (Viktor Malik) [RHEL-30774]
- selftests/bpf: Test distilled base, split BTF generation (Viktor Malik) [RHEL-30774]
- libbpf: Add btf__distill_base() creating split BTF with distilled base BTF (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add tests for add_const (Viktor Malik) [RHEL-30774]
- bpf: Support can_loop/cond_break on big endian (Viktor Malik) [RHEL-30774]
- bpf: Track delta between "linked" registers. (Viktor Malik) [RHEL-30774]
- selftests: bpf: add testmod kfunc for nullable params (Viktor Malik) [RHEL-30774]
- bpf: verifier: make kfuncs args nullalble (Viktor Malik) [RHEL-30774]
- bpf: selftests: Do not use generated kfunc prototypes for arena progs (Viktor Malik) [RHEL-30774]
- bpf: Fix bpf_dynptr documentation comments (Viktor Malik) [RHEL-30774]
- bpftool: Support dumping kfunc prototypes from BTF (Viktor Malik) [RHEL-30774]
- bpf: selftests: xfrm: Opt out of using generated kfunc prototypes (Viktor Malik) [RHEL-30774]
- bpf: selftests: nf: Opt out of using generated kfunc prototypes (Viktor Malik) [RHEL-30774]
- bpf: treewide: Align kfunc signatures to prog point-of-view (Viktor Malik) [RHEL-30774]
- bpf: verifier: Relax caller requirements for kfunc projection type args (Viktor Malik) [RHEL-30774]
- bpf: selftests: Fix bpf_map_sum_elem_count() kfunc prototype (Viktor Malik) [RHEL-30774]
- bpf: selftests: Fix bpf_cpumask_first_zero() kfunc prototype (Viktor Malik) [RHEL-30774]
- bpf: selftests: Fix fentry test kfunc prototypes (Viktor Malik) [RHEL-30774]
- bpf: selftests: Fix bpf_iter_task_vma_new() prototype (Viktor Malik) [RHEL-30774]
- kbuild: bpf: Tell pahole to DECL_TAG kfuncs (Viktor Malik) [RHEL-30774]
- bpftool: Query only cgroup-related attach types (Viktor Malik) [RHEL-30774]
- libbpf: Auto-attach struct_ops BPF maps in BPF skeleton (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add btf_field_iter selftests (Viktor Malik) [RHEL-30774]
- selftests/bpf: Fix send_signal test with nested CONFIG_PARAVIRT (Viktor Malik) [RHEL-30774]
- libbpf: Remove callback-based type/string BTF field visitor helpers (Viktor Malik) [RHEL-30774]
- bpftool: Use BTF field iterator in btfgen (Viktor Malik) [RHEL-30774]
- libbpf: Make use of BTF field iterator in BTF handling code (Viktor Malik) [RHEL-30774]
- libbpf: Make use of BTF field iterator in BPF linker code (Viktor Malik) [RHEL-30774]
- libbpf: Add BTF field iterator (Viktor Malik) [RHEL-30774]
- selftests/bpf: Ignore .llvm.<hash> suffix in kallsyms_find() (Viktor Malik) [RHEL-30774]
- selftests/bpf: Fix bpf_cookie and find_vma in nested VM (Viktor Malik) [RHEL-30774]
- selftests/bpf: Test global bpf_list_head arrays. (Viktor Malik) [RHEL-30774]
- selftests/bpf: Test global bpf_rb_root arrays and fields in nested struct types. (Viktor Malik) [RHEL-30774]
- selftests/bpf: Test kptr arrays and kptrs in nested struct fields. (Viktor Malik) [RHEL-30774]
- bpf: limit the number of levels of a nested struct type. (Viktor Malik) [RHEL-30774]
- bpf: look into the types of the fields of a struct type recursively. (Viktor Malik) [RHEL-30774]
- bpf: create repeated fields for arrays. (Viktor Malik) [RHEL-30774]
- bpf: refactor btf_find_struct_field() and btf_find_datasec_var(). (Viktor Malik) [RHEL-30774]
- bpf: Remove unnecessary call to btf_field_type_size(). (Viktor Malik) [RHEL-30774]
- bpf: Remove unnecessary checks on the offset of btf_field. (Viktor Malik) [RHEL-30774]
- test_bpf: Add missing MODULE_DESCRIPTION() (Viktor Malik) [RHEL-30774]
- bpftool: Fix typo in MAX_NUM_METRICS macro name (Viktor Malik) [RHEL-30774]
- selftests/bpf: Remove unused struct 'libcap' (Viktor Malik) [RHEL-30774]
- selftests/bpf: Remove unused 'key_t' structs (Viktor Malik) [RHEL-30774]
- selftests/bpf: Remove unused struct 'scale_test_def' (Viktor Malik) [RHEL-30774]
- bpftool: Change pid_iter.bpf.c to comply with the change of bpf_link_fops. (Viktor Malik) [RHEL-30774]
- selftests/bpf: test struct_ops with epoll (Viktor Malik) [RHEL-30774]
- bpf: export bpf_link_inc_not_zero. (Viktor Malik) [RHEL-30774]
- bpf: support epoll from bpf struct_ops links. (Viktor Malik) [RHEL-30774]
- bpf: enable detaching links of struct_ops objects. (Viktor Malik) [RHEL-30774]
- bpf: pass bpf_struct_ops_link to callbacks in bpf_struct_ops. (Viktor Malik) [RHEL-30774]
- selftests/bpf: Add selftest for bits iter (Viktor Malik) [RHEL-30774]
- bpf: Add bits iterator (Viktor Malik) [RHEL-30774]
- bitops: make BYTES_TO_BITS() treewide-available (Viktor Malik) [RHEL-30774]
- libbpf: Configure log verbosity with env variable (Viktor Malik) [RHEL-30774]
- bpf, docs: Fix instruction.rst indentation (Viktor Malik) [RHEL-30774]
- bpf, docs: Clarify call local offset (Viktor Malik) [RHEL-30774]
- bpf, docs: Add table captions (Viktor Malik) [RHEL-30774]
- bpf, docs: clarify sign extension of 64-bit use of 32-bit imm (Viktor Malik) [RHEL-30774]
- bpf, docs: Use RFC 2119 language for ISA requirements (Viktor Malik) [RHEL-30774]
- bpf, docs: Move sentence about returning R0 to abi.rst (Viktor Malik) [RHEL-30774]
- bpf: constify member bpf_sysctl_kern:: Table (Viktor Malik) [RHEL-30774]
- selftests/bpf: Fix prog numbers in test_sockmap (Viktor Malik) [RHEL-30774]
- bpf: Remove unused variable "prev_state" (Viktor Malik) [RHEL-30774]
- bpftool: Un-const bpf_func_info to fix it for llvm 17 and newer (Viktor Malik) [RHEL-30774]
- kbuild, bpf: Use test-ge check for v1.25-only pahole (Viktor Malik) [RHEL-30774]
- bpftool: Introduce btf c dump sorting (Viktor Malik) [RHEL-30774]
- bpftool: Fix make dependencies for vmlinux.h (Viktor Malik) [RHEL-30774]
- redhat: Add protected XTS and HMAC config files (Mete Durlu) [RHEL-50772]
- s390/pkey: Add AES xts and HMAC clear key token support (Mete Durlu) [RHEL-50772]
- s390/cpacf: Add MSA 10 and 11 new PCKMO functions (Mete Durlu) [RHEL-50772]
- s390/pkey_pckmo: Return with success for valid protected key types (Mete Durlu) [RHEL-50772]
- s390/pkey: Add function to enforce pkey handler modules load (Mete Durlu) [RHEL-50772]
- s390/pkey: Add slowpath function to CCA and EP11 handler (Mete Durlu) [RHEL-50772]
- s390/pkey: Introduce pkey base with handler registry and handler modules (Mete Durlu) [RHEL-50772]
- s390/pkey: Unify pkey cca, ep11 and pckmo functions signatures (Mete Durlu) [RHEL-50772]
- s390/pkey: Rework and split PKEY kernel module code (Mete Durlu) [RHEL-50772]
- s390/pkey: Split pkey_unlocked_ioctl function (Mete Durlu) [RHEL-50772]
- s390/pkey: Wipe copies of protected- and secure-keys (Mete Durlu) [RHEL-50772]
- s390/pkey: Wipe copies of clear-key structures on failure (Mete Durlu) [RHEL-50772]
- s390/pkey: Wipe sensitive data on failure (Mete Durlu) [RHEL-50772]
- s390/pkey: Use kfree_sensitive() to fix Coccinelle warnings (Mete Durlu) [RHEL-50772]
- scsi: aacraid: Fix double-free on probe failure (Tomas Henzl) [RHEL-64334] {CVE-2024-46673}
- selftests/landlock: Build without static libraries (Mamatha Inamdar) [RHEL-59644]
- selftests/landlock: Fix out-of-tree builds (Mamatha Inamdar) [RHEL-59644]
- selftests/landlock: fix broken include of linux/landlock.h (Mamatha Inamdar) [RHEL-59644]
- selftests/landlock: drop deprecated headers dependency (Mamatha Inamdar) [RHEL-59644]
- fscache: Fix oops due to race with cookie_lru and use_cookie (CKI Backport Bot) [RHEL-63701] {CVE-2022-48989}
- block: sed-opal: add ioctl IOC_OPAL_SET_SID_PW (Ming Lei) [RHEL-56730]
- uprobes: fix kernel info leak via "[uprobes]" vma (Oleg Nesterov) [RHEL-63997] {CVE-2024-49975}
- selftests: forwarding: Add IPv6 GRE remote change tests (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_ipip: Fix memory leak when changing remote IPv6 address (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Sync Rx buffers for device (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Sync Rx buffers for CPU (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_ptp: Add missing verification before pushing Tx header (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: fix xa_store() error checking (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Fix -Wformat-truncation warning (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Remove unnecessary assignments (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Remove unnecessary checks (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Simplify rollback (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Make mlxsw_thermal_module_{init, fini} symmetric (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Remove unused arguments (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Fold two loops into one (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Remove another unnecessary check (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Remove unnecessary check (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Call thermal_zone_device_unregister() unconditionally (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Lock configuration space of upstream bridge during reset (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Report valid current state during cooling device registration (Ivan Vecera) [RHEL-67125]
- mlxsw: Warn about invalid accesses to array fields (Ivan Vecera) [RHEL-67125]
- selftests: mlxsw: mirror_gre: Obey TESTS (Ivan Vecera) [RHEL-67125]
- selftests: mlxsw: mirror_gre: Simplify (Ivan Vecera) [RHEL-67125]
- mlxsw: Implement ethtool operation to write to a transceiver module EEPROM (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Use fragmented buffers (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Store number of scatter/gather entries for maximum packet size (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_buffers: Fix memory corruptions on Spectrum-4 systems (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Fix driver initialization with Spectrum-4 (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Use napi_consume_skb() to free SKB as part of Tx completion (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Do not store SKB for RDQ elements (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Optimize data buffer access (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Use page pool for Rx buffers allocation (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Initialize page pool per CQ (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Store CQ pointer as part of RDQ structure (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Split NAPI setup/teardown into two steps (Ivan Vecera) [RHEL-67125]
- mlxsw: Use the same maximum MTU value throughout the driver (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Set more accurate values for netdevice min/max MTU (Ivan Vecera) [RHEL-67125]
- mlxsw: Adjust MTU value to hardware check (Ivan Vecera) [RHEL-67125]
- mlxsw: port: Edit maximum MTU value (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Apply user-defined multipath hash seed (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_acl: Fix ACL scale regression and firmware errors (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_acl_erp: Fix object nesting warning (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_acl_atcam: Fix wrong comment (Ivan Vecera) [RHEL-67125]
- lib: test_objagg: Fix spelling (Ivan Vecera) [RHEL-67125]
- lib: objagg: Fix spelling (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Constify struct devlink_dpipe_table_ops (Ivan Vecera) [RHEL-67125]
- devlink: Constify the 'table_ops' parameter of devl_dpipe_table_register() (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Use NAPI for event processing (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Reorganize 'mlxsw_pci_queue' structure (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Initialize dummy net devices for NAPI (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Ring RDQ and CQ doorbells once per several completions (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Handle up to 64 Rx completions in tasklet (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_acl_tcam: Fix warning during rehash (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_acl_tcam: Rate limit error message (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_acl_tcam: Fix race during rehash delayed work (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_acl_tcam: Fix race in region ID allocation (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Fix driver initialization with old firmware (Ivan Vecera) [RHEL-67125]
- mlxsw: core: Unregister EMAD trap using FORWARD action (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_flower: validate control flags (Ivan Vecera) [RHEL-67125]
- selftests: mlxsw: ethtool_lanes: Wait for lanes parameter dump explicitly (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_ethtool: Add support for 100Gb/s per lane link modes (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Store DQ pointer as part of CQ structure (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Remove mlxsw_pci_cq_count() (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Remove mlxsw_pci_sdq_count() (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Break mlxsw_pci_cq_tasklet() into tasklets per queue type (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Make style change in mlxsw_pci_cq_tasklet() (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Remove unused wait queue (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Use only one event queue (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Rename MLXSW_PCI_EQS_COUNT (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Poll command interface for each cmd_exec() (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Make style changes in mlxsw_pci_eq_tasklet() (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Remove unused counters (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Arm CQ doorbell regardless of number of completions (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Do not setup tasklet from operation (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Move mlxsw_pci_cq_{init, fini}() (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Move mlxsw_pci_eq_{init, fini}() (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Share nexthop counters in resilient groups (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Support nexthop group hardware statistics (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Track NH ID's of group members (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Add helpers for nexthop counters (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Avoid allocating NH counters twice (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Allow fetch-and-clear of flow counters (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Have mlxsw_sp_nexthop_counter_enable() return int (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Rename two functions (Ivan Vecera) [RHEL-67125]
- mlxsw: core_thermal: Set THERMAL_TRIP_FLAG_RW_TEMP directly (Ivan Vecera) [RHEL-67125]
- mlxsw: remove I2C_CLASS_HWMON from drivers w/o detect and address_list (Ivan Vecera) [RHEL-67125]
- mlxsw: Use refcount_t for reference counting (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Refactor LAG create and destroy code (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Search for free LAD ID once (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Query max_lag once (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Remove mlxsw_sp_lag_get() (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Change mlxsw_sp_upper to LAG structure (Ivan Vecera) [RHEL-67125]
- selftests: mlxsw: qos_pfc: Adjust the test to support 8 lanes (Ivan Vecera) [RHEL-67125]
- selftests: mlxsw: qos_pfc: Remove wrong description (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_acl_tcam: Fix NULL pointer dereference in error path (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_acl_erp: Fix error flow of pool allocation failure (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Set NVE flood profile as part of FID configuration (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add an "any" packet type (Ivan Vecera) [RHEL-67125]
- mlxsw: reg: Add nve_flood_prf_id field to SFMR (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Use CFF mode where available (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add support for rFID family in CFF flood mode (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add a family for bridge FIDs in CFF flood mode (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Initialize flood profiles in CFF mode (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add profile_id to flood profile (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add an object to keep flood profiles (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add hooks for RSP table maintenance (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add a not-UC packet type (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add an op for packing SFMR (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add an op to get PGT address of a FID (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add an op to get PGT allocation size (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Add an op for flood table initialization (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Move mlxsw_sp_fid_flood_table_init() up (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Make mlxsw_sp_fid_ops.setup return an int (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Split a helper out of mlxsw_sp_fid_flood_table_mid() (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Rename FID ops, families, arrays (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Privatize FID families (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Fix missing error checking (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Call RIF setup before obtaining FID (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_router: Add a helper to get subport number from a RIF (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Extract SFMR packing into a helper (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Drop unnecessary conditions (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Permit enabling CFF mode (Ivan Vecera) [RHEL-67125]
- mlxsw: core, pci: Add plumbing related to CFF mode (Ivan Vecera) [RHEL-67125]
- mlxsw: reg: Add to SFMR register the fields related to CFF flood mode (Ivan Vecera) [RHEL-67125]
- mlxsw: reg: Extract flood-mode specific part of mlxsw_reg_sfmr_pack() (Ivan Vecera) [RHEL-67125]
- mlxsw: reg: Drop unnecessary writes from mlxsw_reg_sfmr_pack() (Ivan Vecera) [RHEL-67125]
- mlxsw: reg: Mark SFGC & some SFMR fields as reserved in CFF mode (Ivan Vecera) [RHEL-67125]
- mlxsw: reg: Add Switch FID Flooding Profiles Register (Ivan Vecera) [RHEL-67125]
- mlxsw: resources: Add max_cap_nve_flood_prf (Ivan Vecera) [RHEL-67125]
- mlxsw: cmd: Add MLXSW_CMD_MBOX_CONFIG_PROFILE_FLOOD_MODE_CFF (Ivan Vecera) [RHEL-67125]
- mlxsw: cmd: Add cmd_mbox.query_fw.cff_support (Ivan Vecera) [RHEL-67125]
- selftests: mlxsw: Add PCI reset test (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Implement PCI reset handlers (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Add support for new reset flow (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Move software reset code to a separate function (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Rename mlxsw_pci_sw_reset() (Ivan Vecera) [RHEL-67125]
- mlxsw: Extend MRSR pack() function to support new commands (Ivan Vecera) [RHEL-67125]
- PCI: Add no PM reset quirk for NVIDIA Spectrum devices (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Set SW LAG mode on Spectrum>1 (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum: Allocate LAG table when in SW LAG mode (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_pgt: Generalize PGT allocation (Ivan Vecera) [RHEL-67125]
- mlxsw: spectrum_fid: Allocate PGT for the whole FID family in one go (Ivan Vecera) [RHEL-67125]
- mlxsw: pci: Permit toggling LAG mode (Ivan Vecera) [RHEL-67125]
- mlxsw: core, pci: Add plumbing related to LAG mode (Ivan Vecera) [RHEL-67125]
- mlxsw: cmd: Add QUERY_FW.lag_mode_support (Ivan Vecera) [RHEL-67125]
- mlxsw: cmd: Add CONFIG_PROFILE.{set_, }lag_mode (Ivan Vecera) [RHEL-67125]
- mlxsw: cmd: Fix omissions in CONFIG_PROFILE field names in comments (Ivan Vecera) [RHEL-67125]
- mlxsw: reg: Add SGCR.lag_lookup_pgt_base (Ivan Vecera) [RHEL-67125]
- mlxsw: reg: Drop SGCR.llb (Ivan Vecera) [RHEL-67125]
- cachefiles: fix dentry leak in cachefiles_open_file() (CKI Backport Bot) [RHEL-63602] {CVE-2024-49870}
- nfsd: fix race between laundromat and free_stateid (Olga Kornievskaia) [RHEL-65915] {CVE-2024-50106}
- dm cache: fix potential out-of-bounds access on the first resume (Benjamin Marzinski) [RHEL-69092]
- dm cache: optimize dirty bit checking with find_next_bit when resizing (Benjamin Marzinski) [RHEL-69092]
- dm cache: fix out-of-bounds access to the dirty bitset when resizing (Benjamin Marzinski) [RHEL-69092]
- dm cache: fix flushing uninitialized delayed_work on cache_ctr error (Benjamin Marzinski) [RHEL-69092]
- dm cache: correct the number of origin blocks to match the target length (Benjamin Marzinski) [RHEL-69092]
- dm-verity: don't crash if panic_on_corruption is not selected (Benjamin Marzinski) [RHEL-69092]
- dm-unstriped: cast an operand to sector_t to prevent potential uint32_t overflow (Benjamin Marzinski) [RHEL-69092]
- dm: fix a crash if blk_alloc_disk fails (Benjamin Marzinski) [RHEL-69092]
- nfsd: cancel nfsd_shrinker_work using sync mode in nfs4_state_shutdown_net (Olga Kornievskaia) [RHEL-66036] {CVE-2024-50121}
- md/raid10: fix null ptr dereference in raid10_size() (Nigel Croxon) [RHEL-66030] {CVE-2024-50109}
- netfilter: nf_reject_ipv6: fix potential crash in nf_send_reset6() (CKI Backport Bot) [RHEL-66865] {CVE-2024-50256}
- netfilter: nf_reject: Fix build warning when CONFIG_BRIDGE_NETFILTER=n (CKI Backport Bot) [RHEL-66865] {CVE-2024-50256}
- NFSv4: Prevent NULL-pointer dereference in nfs42_complete_copies() (Olga Kornievskaia) [RHEL-63854] {CVE-2024-50046}
- scsi: storvsc: Do not flag MAINTENANCE_IN return of SRB_STATUS_DATA_OVERRUN as an error (Cathy Avery) [RHEL-9848]
- scsi: storvsc: Handle additional SRB status values (Cathy Avery) [RHEL-9848]
- media: Convert from tasklet to BH workqueue (Kate Hsuan) [RHEL-67885]
- media: videobuf2: add missing MODULE_DESCRIPTION() macro (Kate Hsuan) [RHEL-67885]
- usb: uvc: add missing MODULE_DESCRIPTION() macro (Kate Hsuan) [RHEL-67885]
- media: uapi: Add PiSP Compressed RAW Bayer formats (Kate Hsuan) [RHEL-67885]
- media: uapi: Add a pixel format for BGR48 and RGB48 (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Fix typo in documentation (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Drop unreacheable warning (Kate Hsuan) [RHEL-67885]
- media: videobuf2: core: Drop unneeded forward declaration (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Add average QP control (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Provide const-aware subdev state accessors (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Fix v4l2_subdev_state_get_format() documentation (Kate Hsuan) [RHEL-67885]
- media: subdev: Improve s_stream documentation (Kate Hsuan) [RHEL-67885]
- media: subdev: Support non-routing subdevs in v4l2_subdev_s_stream_helper() (Kate Hsuan) [RHEL-67885]
- media: subdev: Support single-stream case in v4l2_subdev_enable/disable_streams() (Kate Hsuan) [RHEL-67885]
- media: subdev: Refactor v4l2_subdev_enable/disable_streams() (Kate Hsuan) [RHEL-67885]
- media: subdev: Add v4l2_subdev_is_streaming() (Kate Hsuan) [RHEL-67885]
- media: subdev: Improve v4l2_subdev_enable/disable_streams_fallback (Kate Hsuan) [RHEL-67885]
- media: subdev: Fix use of sd->enabled_streams in call_s_stream() (Kate Hsuan) [RHEL-67885]
- media: subdev: Add checks for subdev features (Kate Hsuan) [RHEL-67885]
- media: subdev: Use v4l2_subdev_has_op() in v4l2_subdev_enable/disable_streams() (Kate Hsuan) [RHEL-67885]
- Revert "media: v4l2-ctrls: show all owned controls in log_status" (Kate Hsuan) [RHEL-67885]
- media: cec: cec.h: 2.1 ms -> 2100 ms (Kate Hsuan) [RHEL-67885]
- media: uapi: v4l: Don't expose generic metadata formats to userspace (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Add trivial set_routing support (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Return routes set using S_ROUTING (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Add len_routes field to struct v4l2_subdev_routing (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Copy argument back to user also for S_ROUTING (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Add a function to lock two sub-device states, use it (Kate Hsuan) [RHEL-67885]
- media: v4l: Set line based metadata flag in V4L2 core (Kate Hsuan) [RHEL-67885]
- media: v4l: Support line-based metadata capture (Kate Hsuan) [RHEL-67885]
- media: uapi: v4l: Add generic 8-bit metadata format definitions (Kate Hsuan) [RHEL-67885]
- media: Documentation: Rename meta format files (Kate Hsuan) [RHEL-67885]
- media: uapi: Document which mbus format fields are valid for metadata (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Clearly document that the crop API won't be extended (Kate Hsuan) [RHEL-67885]
- media: v4l: async: Set owner for async sub-devices (Kate Hsuan) [RHEL-67885]
- media: v4l: Set sub-device's owner field to the caller's module (Kate Hsuan) [RHEL-67885]
- media: videobuf2: improve max_num_buffers sanity checks (Kate Hsuan) [RHEL-67885]
- media: cec: return -ENODEV instead of -ENXIO if unregistered (Kate Hsuan) [RHEL-67885]
- media: v4l2-core: hold videodev_lock until dev reg, finishes (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Return handler error in creating new fwnode properties (Kate Hsuan) [RHEL-67885]
- media: mc: mark the media devnode as registered from the, start (Kate Hsuan) [RHEL-67885]
- media: videodev2: Fix v4l2_ext_control packing. (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Fix stream handling for crop API (Kate Hsuan) [RHEL-67885]
- media: mc: Fix graph walk in media_pipeline_start (Kate Hsuan) [RHEL-67885]
- media: mc: Add nop implementations of media_device_{init,cleanup} (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Remove non-pad dv timing callbacks (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Add pad versions of dv timing subdev calls (Kate Hsuan) [RHEL-67885]
- media: v4l2-common: Add Y210 and Y216 format info (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: add support for area type logging (Kate Hsuan) [RHEL-67885]
- media: v4l2: Add REMOVE_BUFS ioctl (Kate Hsuan) [RHEL-67885]
- media: core: Free range of buffers (Kate Hsuan) [RHEL-67885]
- media: core: Add bitmap manage bufs array entries (Kate Hsuan) [RHEL-67885]
- media: core: Rework how create_buf index returned value is computed (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Add min_reqbufs_allocation field to vb2_queue structure (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Update vb2_is_busy() logic (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Add missing doc comment for waiting_in_dqbuf (Kate Hsuan) [RHEL-67885]
- media: core: v4l2-ioctl.c: use is_valid_ioctl() (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls-core.c: check min/max for menu, controls (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Follow renaming of SPI "master" to "controller" (Kate Hsuan) [RHEL-67885]
- media: mc: Expand MUST_CONNECT flag to always require an enabled link (Kate Hsuan) [RHEL-67885]
- media: mc: Rename pad variable to clarify intent (Kate Hsuan) [RHEL-67885]
- media: mc: Add num_links flag to media_pad (Kate Hsuan) [RHEL-67885]
- media: mc: Fix flags handling when creating pad links (Kate Hsuan) [RHEL-67885]
- media: mc: Add local pad to pipeline regardless of the link state (Kate Hsuan) [RHEL-67885]
- media: media-devnode: make media_bus_type const (Kate Hsuan) [RHEL-67885]
- media: cec: make cec_bus_type const (Kate Hsuan) [RHEL-67885]
- media: v4l2-common.h: kerneldoc: correctly format return values (Kate Hsuan) [RHEL-67885]
- media: cec.h: Fix kerneldoc (Kate Hsuan) [RHEL-67885]
- media: videodev2.h: Fix kerneldoc (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: show all owned controls in log_status (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Fix doc comment (Kate Hsuan) [RHEL-67885]
- media: v4l: Add a helper for setting up link-frequencies control (Kate Hsuan) [RHEL-67885]
- media: vb2: refactor setting flags and caps, fix missing cap (Kate Hsuan) [RHEL-67885]
- media: media videobuf2: Stop direct calls to queue num_buffers field (Kate Hsuan) [RHEL-67885]
- media: mc: Drop useless debug print on file handle release (Kate Hsuan) [RHEL-67885]
- media: v4l2-mc: Add debug prints for v4l2_fwnode_create_links_for_pad() (Kate Hsuan) [RHEL-67885]
- media: media-entity.h: fix Excess kernel-doc description warnings (Kate Hsuan) [RHEL-67885]
- media: videobuf2: core: Rename min_buffers_needed field in vb2_queue (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Store frame interval in subdev state (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Move out subdev state lock macros outside CONFIG_MEDIA_CONTROLLER (Kate Hsuan) [RHEL-67885]
- media: videobuf2: request more buffers for vb2_read (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Fix indentation in v4l2-subdev.h (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Rename .init_cfg() operation to .init_state() (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Return NULL from pad access functions on error (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Remove stream-unaware sub-device state access (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Always compile sub-device state access functions (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Make stream argument optional in state access functions (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: v4l2_subdev_state_get_format always returns format now (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Rename sub-device state information access functions (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Also return pads array information on stream functions (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Store the sub-device in the sub-device state (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Drop outdated comment for v4l2_subdev_pad_config (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Rename pad config 'try_*' fields (Kate Hsuan) [RHEL-67885]
- media: videodev2.h: add missing __user to p_h264_pps (Kate Hsuan) [RHEL-67885]
- media: drop CONFIG_MEDIA_CONTROLLER_REQUEST_API (Kate Hsuan) [RHEL-67885]
- media: v4l2-mem2mem.h: fix typo in comment (Kate Hsuan) [RHEL-67885]
- media: v4l2-dev: Check that g/s_selection are valid before selecting crop (Kate Hsuan) [RHEL-67885]
- media: v4l2-common: Add 10bpp RGB formats info (Kate Hsuan) [RHEL-67885]
- media: core: v4l2-ioctl: check if ioctl is known to avoid NULL name (Kate Hsuan) [RHEL-67885]
- media: core: Report the maximum possible number of buffers for the queue (Kate Hsuan) [RHEL-67885]
- media: media videobuf2: Be more flexible on the number of queue stored buffers (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Use vb2_get_num_buffers() helper (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Add helper to get queue number of buffers (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Remove duplicated index vs q->num_buffers check (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Access vb2_queue bufs array through helper functions (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Use vb2_buffer instead of index (Kate Hsuan) [RHEL-67885]
- media: dvb_vb2: fix possible out of bound access (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Stop spamming kernel log with all queue counter (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Rework offset 'cookie' encoding pattern (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Rename offset parameter (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Fix a 64bit bug (Kate Hsuan) [RHEL-67885]
- media: v4l2: Add ignore_streaming flag (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Fix IS_ERR checking in vb2_vmalloc_put_userptr() (Kate Hsuan) [RHEL-67885]
- media: subdev: Don't report V4L2_SUBDEV_CAP_STREAMS when the streams API is disabled (Kate Hsuan) [RHEL-67885]
- media: mc: Check pad flag validity (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Print debug information on frame descriptor (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Clear frame descriptor before get_frame_desc (Kate Hsuan) [RHEL-67885]
- media: v4l2-event: Annotate struct v4l2_subscribed_event with __counted_by (Kate Hsuan) [RHEL-67885]
- media: v4l2-device.h: drop V4L2_DEVICE_NAME_SIZE (Kate Hsuan) [RHEL-67885]
- media: use sizeof() instead of V4L2_SUBDEV_NAME_SIZE (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev.h: increase struct v4l2_subdev name size (Kate Hsuan) [RHEL-67885]
- media: v4l2-dev.h: increase struct video_device name size (Kate Hsuan) [RHEL-67885]
- media: cec.h: increase input_phys buffer (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Add user control base for Nuvoton NPCM controls (Kate Hsuan) [RHEL-67885]
- media: v4l: Add HEXTILE compressed format (Kate Hsuan) [RHEL-67885]
- media: use struct_size() helper (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Document and enforce .s_stream() requirements (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Document that routing support depends on streams (Kate Hsuan) [RHEL-67885]
- media: v4l2-mc: Make v4l2_pipeline_pm_{get,put} deprecated (Kate Hsuan) [RHEL-67885]
- media: videobuf2: fix typo: vb2_dbuf -> vb2_qbuf (Kate Hsuan) [RHEL-67885]
- media: vb2: frame_vector.c: replace WARN_ONCE with a comment (Kate Hsuan) [RHEL-67885]
- media: subdev: Add debug prints to enable/disable_streams (Kate Hsuan) [RHEL-67885]
- media: subdev: Constify v4l2_subdev_set_routing_with_fmt() param (Kate Hsuan) [RHEL-67885]
- media: subdev: Drop implicit zeroing of stream field (Kate Hsuan) [RHEL-67885]
- media: cec-pin: only enable interrupts when monitoring the CEC pin (Kate Hsuan) [RHEL-67885]
- media: cec-pin: improve interrupt handling (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Don't assert held reservation lock for dma-buf mmapping (Kate Hsuan) [RHEL-67885]
- media: Add NV15_4L4 pixel format (Kate Hsuan) [RHEL-67885]
- media: v4l2-common: Add support for fractional bpp (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Fix missing kerneldoc for client_caps (Kate Hsuan) [RHEL-67885]
- media: v4l2-mc: Drop subdev check in v4l2_create_fwnode_links_to_pad() (Kate Hsuan) [RHEL-67885]
- media: uapi: Use unsigned int values for assigning bits in u32 fields (Kate Hsuan) [RHEL-67885]
- media: mc: Make media_entity_get_fwnode_pad() fwnode argument const (Kate Hsuan) [RHEL-67885]
- media: videodev2.h: Fix struct v4l2_input tuner index comment (Kate Hsuan) [RHEL-67885]
- media: Adjust column width for pdfdocs (Kate Hsuan) [RHEL-67885]
- media: videodev2.h: Fix p_s32 and p_s64 pointer types (Kate Hsuan) [RHEL-67885]
- media: v4l2-mem2mem: add lock to protect parameter num_rdy (Kate Hsuan) [RHEL-67885]
- media: Add ABGR64_12 video format (Kate Hsuan) [RHEL-67885]
- media: Add BGR48_12 video format (Kate Hsuan) [RHEL-67885]
- media: Add YUV48_12 video format (Kate Hsuan) [RHEL-67885]
- media: Add Y212 v4l2 format info (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Add new ioctl for client capabilities (Kate Hsuan) [RHEL-67885]
- media: Accept non-subdev sinks in v4l2_create_fwnode_links_to_pad() (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Fix doc for v4l2_ctrl_request_hdl_find (Kate Hsuan) [RHEL-67885]
- media: subdev: Add V4L2_SUBDEV_ROUTING_NO_MULTIPLEXING (Kate Hsuan) [RHEL-67885]
- media: subdev: Split V4L2_SUBDEV_ROUTING_NO_STREAM_MIX (Kate Hsuan) [RHEL-67885]
- media: subdev: Use 'shall' instead of 'may' in route validation (Kate Hsuan) [RHEL-67885]
- media: v4l2-core: zero field base in struct v4l2_framebuffer (Kate Hsuan) [RHEL-67885]
- media: videodev.h: drop V4L2_FBUF_CAP_LIST/BITMAP_CLIPPING (Kate Hsuan) [RHEL-67885]
- media: v4l2-core: drop v4l2_window clipping and bitmap support (Kate Hsuan) [RHEL-67885]
- media: drop unnecessary networking includes (Kate Hsuan) [RHEL-67885]
- media: rc: add common keymap for Dreambox RC10/RC0 and RC20/RC-BT remotes (Kate Hsuan) [RHEL-67885]
- media: v4l2-dev.c: check for V4L2_CAP_STREAMING to enable streaming ioctls (Kate Hsuan) [RHEL-67885]
- media: vb2: set owner before calling vb2_read (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Make link validation safer (Kate Hsuan) [RHEL-67885]
- media: subdev: Fix validation state lockdep issue (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev.c: clear stream field (Kate Hsuan) [RHEL-67885]
- media: videobuf2-core: drop obsolete sanity check in __vb2_queue_free() (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Fix minor issues in comments and documentation (Kate Hsuan) [RHEL-67885]
- media: mc: Get media_device directly from pad (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Add entity iterator for media_pipeline (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Add pad iterator for media_pipeline (Kate Hsuan) [RHEL-67885]
- media: Add stream to frame descriptor (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Add v4l2_subdev_s_stream_helper() function (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Add subdev .(enable|disable)_streams() operations (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Add v4l2_subdev_state_xlate_streams() helper (Kate Hsuan) [RHEL-67885]
- media: subdev: add v4l2_subdev_routing_validate() helper (Kate Hsuan) [RHEL-67885]
- media: subdev: add v4l2_subdev_set_routing_with_fmt() helper (Kate Hsuan) [RHEL-67885]
- media: subdev: add streams to v4l2_subdev_get_fmt() helper function (Kate Hsuan) [RHEL-67885]
- media: subdev: add "opposite" stream helper funcs (Kate Hsuan) [RHEL-67885]
- media: subdev: use streams in v4l2_subdev_link_validate() (Kate Hsuan) [RHEL-67885]
- media: subdev: add stream based configuration (Kate Hsuan) [RHEL-67885]
- media: subdev: Add for_each_active_route() macro (Kate Hsuan) [RHEL-67885]
- media: subdev: add v4l2_subdev_set_routing helper() (Kate Hsuan) [RHEL-67885]
- media: subdev: add v4l2_subdev_has_pad_interdep() (Kate Hsuan) [RHEL-67885]
- media: subdev: Require code change to enable [GS]_ROUTING (Kate Hsuan) [RHEL-67885]
- media: subdev: Add [GS]_ROUTING subdev ioctls and operations (Kate Hsuan) [RHEL-67885]
- media: add V4L2_SUBDEV_CAP_STREAMS (Kate Hsuan) [RHEL-67885]
- media: add V4L2_SUBDEV_FL_STREAMS (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Sort includes (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Fix doc for media_graph_walk_init (Kate Hsuan) [RHEL-67885]
- media: mc: Improve the media_entity_has_pad_interdep() documentation (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls-api.c: move ctrl->is_new = 1 to the correct line (Kate Hsuan) [RHEL-67885]
- media: Add Y210, Y212 and Y216 formats (Kate Hsuan) [RHEL-67885]
- media: Add 2-10-10-10 RGB formats (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls-api.c: add back dropped ctrl->is_new = 1 (Kate Hsuan) [RHEL-67885]
- media: videobuf2-core: take mmap_lock in vb2_get_unmapped_area() (Kate Hsuan) [RHEL-67885]
- headers: Remove some left-over license text in include/uapi/linux/v4l2-* (Kate Hsuan) [RHEL-67885]
- media: videobuf2: revert "get_userptr: buffers are always writable" (Kate Hsuan) [RHEL-67885]
- media: videobuf2-dma-sg: Fix buf->vb NULL pointer dereference (Kate Hsuan) [RHEL-67885]
- v4l2: don't fall back to follow_pfn() if pin_user_pages_fast() fails (Kate Hsuan) [RHEL-67885]
- media: add nv12_8l128 and nv12_10be_8l128 video format. (Kate Hsuan) [RHEL-67885]
- media: v4l: Use memset_after() helper (Kate Hsuan) [RHEL-67885]
- media: dvb_ringbuffer: Fix typo in dvb_ringbuffer_pkt_write() kerneldoc (Kate Hsuan) [RHEL-67885]
- media: subdev: Replace custom implementation of device_match_fwnode() (Kate Hsuan) [RHEL-67885]
- media: v4l2-dv-timings.c: fix too strict blanking sanity checks (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Reserve controls for ASPEED (Kate Hsuan) [RHEL-67885]
- media: v4l: Add definition for the Aspeed JPEG format (Kate Hsuan) [RHEL-67885]
- v4l: subdev: Warn if disabling streaming failed, return success (Kate Hsuan) [RHEL-67885]
- media: videodev2.h: V4L2_DV_BT_BLANKING_HEIGHT should check 'interlaced' (Kate Hsuan) [RHEL-67885]
- media: v4l2-dv-timings: add sanity checks for blanking values (Kate Hsuan) [RHEL-67885]
- media: v4l: ctrls: Add a control for HDR mode (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Document s_power() callback is deprecated (Kate Hsuan) [RHEL-67885]
- media: Fix documentation typos in media-entity.h (Kate Hsuan) [RHEL-67885]
- media: v4l2-ioctl.c: Unify YCbCr/YUV terms in format descriptions (Kate Hsuan) [RHEL-67885]
- videodev2.h: add p_s32 and p_s64 pointers (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Fix off-by-one error in integer menu control check (Kate Hsuan) [RHEL-67885]
- media: v4l2-ioctl.c: fix incorrect error path (Kate Hsuan) [RHEL-67885]
- media: v4l2-compat-ioctl32.c: zero buffer passed to v4l2_compat_get_array_args() (Kate Hsuan) [RHEL-67885]
- media: mc: convert pipeline funcs to take media_pad (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Add has_pad_interdep entity operation (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Rewrite media_pipeline_start() (Kate Hsuan) [RHEL-67885]
- media: mc: entity: add alloc variant of pipeline_start (Kate Hsuan) [RHEL-67885]
- media: v4l2-dev: Add videodev wrappers for media pipelines (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Add media_entity_pipeline() to access the media pipeline (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Move media_entity_get_fwnode_pad() out of graph walk section (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Merge media_entity_enum_init and __media_entity_enum_init (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Add iterator helper for entity pads (Kate Hsuan) [RHEL-67885]
- media: mc: entity: Rename streaming_count -> start_count (Kate Hsuan) [RHEL-67885]
- media: subdev: increase V4L2_FRAME_DESC_ENTRY_MAX to 8 (Kate Hsuan) [RHEL-67885]
- media: media-entity.h: add include for min() (Kate Hsuan) [RHEL-67885]
- media: Remove incorrect comment from struct v4l2_fwnode_endpoint (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Fail graciously when getting try data for NULL state (Kate Hsuan) [RHEL-67885]
- media: v4l2: Fix v4l2_i2c_subdev_set_name function documentation (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: drop 'elems' argument from control type ops. (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Remove vb2_find_timestamp() (Kate Hsuan) [RHEL-67885]
- media: videodev2.h: drop V4L2_CAP_ASYNCIO (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Fix typo in VP8 comment (Kate Hsuan) [RHEL-67885]
- media: vb2: videobuf -> videobuf2 (Kate Hsuan) [RHEL-67885]
- media: v4l2-ioctl: Fix typo 'the the' in comment (Kate Hsuan) [RHEL-67885]
- media: v4l: uapi: Add user control base for DW100 controls (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Export default v4l2_ctrl_type_ops callbacks (Kate Hsuan) [RHEL-67885]
- media: Documentation: mc-core: Fix typo (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: optimize type_ops for arrays (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: add change flag for when dimensions change (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: add v4l2_ctrl_modify_dimensions (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: alloc arrays in ctrl_ref (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: allocate space for arrays (Kate Hsuan) [RHEL-67885]
- media: mc-entity: Add a new helper function to get a remote pad for a pad (Kate Hsuan) [RHEL-67885]
- media: mc-entity: Add a new helper function to get a remote pad (Kate Hsuan) [RHEL-67885]
- media: mc-entity: Rename media_entity_remote_pad() to media_pad_remote_pad_first() (Kate Hsuan) [RHEL-67885]
- media: videobuf2: Introduce vb2_find_buffer() (Kate Hsuan) [RHEL-67885]
- media: Add P010 tiled format (Kate Hsuan) [RHEL-67885]
- media: uapi: HEVC: Add SEI pic struct flags (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: add support for dynamically allocated arrays. (Kate Hsuan) [RHEL-67885]
- media: videodev2.h: add V4L2_CTRL_FLAG_DYNAMIC_ARRAY (Kate Hsuan) [RHEL-67885]
- media: entity: Use dedicated data link iterator (Kate Hsuan) [RHEL-67885]
- media: entity: Add iterator for entity data links (Kate Hsuan) [RHEL-67885]
- media: subdev: Add v4l2_subdev_call_state_try() macro (Kate Hsuan) [RHEL-67885]
- media: v4l2: Sanitize colorspace values in the framework (Kate Hsuan) [RHEL-67885]
- media: pixfmt-yuv-planar.rst: fix PIX_FMT labels (Kate Hsuan) [RHEL-67885]
- media: v4l2: Make colorspace validity checks more future-proof (Kate Hsuan) [RHEL-67885]
- media: v4l: Add packed YUV 4:4:4 YUVA and YUVX pixel formats (Kate Hsuan) [RHEL-67885]
- media: Fix incorrect P010 chroma order description (Kate Hsuan) [RHEL-67885]
- media: Add P010 video format (Kate Hsuan) [RHEL-67885]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_168.RULE (part 2) (Kate Hsuan) [RHEL-67885]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_30.RULE (part 2) (Kate Hsuan) [RHEL-67885]
- media: Add CSI-2 bus configuration to frame descriptors (Kate Hsuan) [RHEL-67885]
- media: Add bus type to frame descriptors (Kate Hsuan) [RHEL-67885]
- media: cec-pin.c: don't zero work_pin_num_events in adap_enable (Kate Hsuan) [RHEL-67885]
- media: cec-pin.c: disabling the adapter cannot call kthread_stop (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctls-core.c: kvmalloc_array -> kvcalloc (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev.c: kvmalloc_array -> kvcalloc (Kate Hsuan) [RHEL-67885]
- media: videobuf2-v4l2: Expose vb2_queue_is_busy() to drivers (Kate Hsuan) [RHEL-67885]
- media: v4l2: fix uninitialized value tuner_status(CWE-457) (Kate Hsuan) [RHEL-67885]
- media: ext-ctrls-codec.rst: fix indentation (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Add intra-refresh type control (Kate Hsuan) [RHEL-67885]
- media: v4l: Add Qualcomm custom compressed pixel formats (Kate Hsuan) [RHEL-67885]
- media: media-entity.h: Fix documentation for media_create_intf_link (Kate Hsuan) [RHEL-67885]
- media: media.h: remove unneeded <stdint.h> inclusion (Kate Hsuan) [RHEL-67885]
- media: subdev: add v4l2_subdev_get_fmt() helper function (Kate Hsuan) [RHEL-67885]
- media: subdev: add locking wrappers to subdev op wrappers (Kate Hsuan) [RHEL-67885]
- media: subdev: add subdev state locking (Kate Hsuan) [RHEL-67885]
- media: subdev: pass also the active state to subdevs from ioctls (Kate Hsuan) [RHEL-67885]
- media: subdev: rename v4l2_subdev_get_pad_* helpers (Kate Hsuan) [RHEL-67885]
- media: subdev: add active state to struct v4l2_subdev (Kate Hsuan) [RHEL-67885]
- media: subdev: rename subdev-state alloc & free (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: drop extra #ifdef (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: fix #endif comments (Kate Hsuan) [RHEL-67885]
- media: mc: delete redundant code in __media_device_unregister_entity (Kate Hsuan) [RHEL-67885]
- media: v4l: ioctl: Set bus_info in v4l_querycap() (Kate Hsuan) [RHEL-67885]
- media: mc: Set bus_info in media_device_init() (Kate Hsuan) [RHEL-67885]
- media: mc: Provide a helper for setting bus_info field (Kate Hsuan) [RHEL-67885]
- media: mc: media_device_init() initialises a media_device, not media_entity (Kate Hsuan) [RHEL-67885]
- media: mc: Remove redundant documentation (Kate Hsuan) [RHEL-67885]
- media: entity: Add support for ancillary links (Kate Hsuan) [RHEL-67885]
- media: entity: Add link_type_name() helper (Kate Hsuan) [RHEL-67885]
- media: media.h: Add new media link type (Kate Hsuan) [RHEL-67885]
- media: entity: Skip non-data links in graph iteration (Kate Hsuan) [RHEL-67885]
- media: entity: skip non-data link when removing reverse links (Kate Hsuan) [RHEL-67885]
- media: add nv12m_8l128 and nv12m_10be_8l128 video format. (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Add new V4L2_H264_DECODE_PARAM_FLAG_P/BFRAME flags (Kate Hsuan) [RHEL-67885]
- media: media-entity: Clarify media_entity_cleanup() usage (Kate Hsuan) [RHEL-67885]
- media: media-entity: Simplify media_pipeline_start() (Kate Hsuan) [RHEL-67885]
- media: media-entity: Add media_pad_is_streaming() helper function (Kate Hsuan) [RHEL-67885]
- media: v4l2-core: Initialize h264 scaling matrix (Kate Hsuan) [RHEL-67885]
- media: uapi: Init VP9 stateless decode params (Kate Hsuan) [RHEL-67885]
- media: v4l2-mediabus: Drop legacy V4L2_MBUS_CSI2_*_LANE flags (Kate Hsuan) [RHEL-67885]
- media: v4l: Avoid unaligned access warnings when printing 4cc modifiers (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Drop .set_mbus_config() operation (Kate Hsuan) [RHEL-67885]
- media: v4l2-dev: Use non-atomic bitmap API when applicable (Kate Hsuan) [RHEL-67885]
- media: hevc: Remove RPS named flags (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: make array range static (Kate Hsuan) [RHEL-67885]
- media: dmxdev: drop unneeded <linux/kernel.h> inclusion from other headers (Kate Hsuan) [RHEL-67885]
- media: mc: mc-entity.c: Use bitmap_zalloc() when applicable (Kate Hsuan) [RHEL-67885]
- media: videobuf2: add WARN_ON_ONCE if bytesused is bigger than buffer length (Kate Hsuan) [RHEL-67885]
- media: vb2: frame_vector.c: don't overwrite error code (Kate Hsuan) [RHEL-67885]
- media: mc: drop an unused debug function (Kate Hsuan) [RHEL-67885]
- media: uapi: Add VP9 stateless decoder controls (Kate Hsuan) [RHEL-67885]
- media: v4l2-ioctl.c: readbuffers depends on V4L2_CAP_READWRITE (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Add RGB color effects control (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Add V4L2_CID_COLORFX_CBCR max setting (Kate Hsuan) [RHEL-67885]
- media: v4l2-mem2mem: add v4l2_m2m_get_unmapped_area for no-mmu platform (Kate Hsuan) [RHEL-67885]
- media: v4l2-core: fix VIDIOC_DQEVENT handling on non-x86 (Kate Hsuan) [RHEL-67885]
- include/media/media-entity.h: replace kernel.h with the necessary inclusions (Kate Hsuan) [RHEL-67885]
- media: v4l2-dev.h: move open brace after struct video_device (Kate Hsuan) [RHEL-67885]
- media: videobuf2: handle V4L2_MEMORY_FLAG_NON_COHERENT flag (Kate Hsuan) [RHEL-67885]
- media: videobuf2: add queue memory coherency parameter (Kate Hsuan) [RHEL-67885]
- media: videobuf2: add V4L2_MEMORY_FLAG_NON_COHERENT flag (Kate Hsuan) [RHEL-67885]
- media: videobuf2: split buffer cache_hints initialisation (Kate Hsuan) [RHEL-67885]
- media: videobuf2: inverse buffer cache_hints flags (Kate Hsuan) [RHEL-67885]
- media: videobuf2: rework vb2_mem_ops API (Kate Hsuan) [RHEL-67885]
- media: Request API is no longer experimental (Kate Hsuan) [RHEL-67885]
- media: v4l2-ioctl: S_CTRL output the right value (Kate Hsuan) [RHEL-67885]
- media: v4l2-ioctl: Fix check_ext_ctrls (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Add V4L2_CID_NOTIFY_GAINS control (Kate Hsuan) [RHEL-67885]
- media: add Mediatek's MM21 format (Kate Hsuan) [RHEL-67885]
- media: Clean V4L2_PIX_FMT_NV12MT documentation (Kate Hsuan) [RHEL-67885]
- media: Add NV12_4L4 tiled format (Kate Hsuan) [RHEL-67885]
- media: Rename V4L2_PIX_FMT_HM12 to V4L2_PIX_FMT_NV12_16L16 (Kate Hsuan) [RHEL-67885]
- media: Rename V4L2_PIX_FMT_SUNXI_TILED_NV12 to V4L2_PIX_FMT_NV12_32L32 (Kate Hsuan) [RHEL-67885]
- media: videobuf2-core: sanity checks for requests and qbuf (Kate Hsuan) [RHEL-67885]
- media: hevc: Add scaling matrix control (Kate Hsuan) [RHEL-67885]
- media: v4l2-ctrls: Add intra-refresh period control (Kate Hsuan) [RHEL-67885]
- media: docs: ext-ctrls-codec: Document cyclic intra-refresh zero control value (Kate Hsuan) [RHEL-67885]
- media: v4l2-dv-timings.c: fix wrong condition in two for-loops (Kate Hsuan) [RHEL-67885]
- media: v4l: subdev: Add pre_streamon and post_streamoff callbacks (Kate Hsuan) [RHEL-67885]
- media: mc-device.c: use DEVICE_ATTR_RO() helper macro (Kate Hsuan) [RHEL-67885]
- media: v4l2-subdev: Fix documentation of the subdev_notifier member (Kate Hsuan) [RHEL-67885]

* Tue Dec 10 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-541.el9]
- platform/x86/amd/pmc: Detect when STB is not available (CKI Backport Bot) [RHEL-68176] {CVE-2024-53072}
- fs: dlm: avoid false-positive checker warning (Alexander Aring) [RHEL-60001]
- ice: change q_index variable type to s16 to store -1 value (Petr Oros) [RHEL-49816]
- ice: Fix use after free during unload with ports in bridge (Petr Oros) [RHEL-49816]
- ice: fix crash on probe for DPLL enabled E810 LOM (Petr Oros) [RHEL-49816]
- ice: block SF port creation in legacy mode (Petr Oros) [RHEL-49816]
- ice: Fix increasing MSI-X on VF (Petr Oros) [RHEL-49816]
- ice: Flush FDB entries before reset (Petr Oros) [RHEL-49816]
- ice: Fix netif_is_ice() in Safe Mode (Petr Oros) [RHEL-49816]
- ice: Fix entering Safe Mode (Petr Oros) [RHEL-49816]
- ice: fix VLAN replay after reset (Petr Oros) [RHEL-49816]
- ice: disallow DPLL_PIN_STATE_SELECTABLE for dpll output pins (Petr Oros) [RHEL-49816]
- ice: fix memleak in ice_init_tx_topology() (Petr Oros) [RHEL-49816]
- ice: clear port vlan config during reset (Petr Oros) [RHEL-49816]
- ice: Fix improper handling of refcount in ice_sriov_set_msix_vec_count() (Petr Oros) [RHEL-49816]
- ice: Fix improper handling of refcount in ice_dpll_init_rclk_pins() (Petr Oros) [RHEL-49816]
- ice: set correct dst VSI in only LAN filters (Petr Oros) [RHEL-49816]
- ice: Fix a NULL vs IS_ERR() check in probe() (Petr Oros) [RHEL-49816]
- ice: Fix a couple NULL vs IS_ERR() bugs (Petr Oros) [RHEL-49816]
- ice: Fix lldp packets dropping after changing the number of channels (Petr Oros) [RHEL-49816]
- ice: subfunction activation and base devlink ops (Petr Oros) [RHEL-49816]
- ice: basic support for VLAN in subfunctions (Petr Oros) [RHEL-49816]
- ice: support subfunction devlink Tx topology (Petr Oros) [RHEL-49816]
- ice: implement netdevice ops for SF representor (Petr Oros) [RHEL-49816]
- ice: check if SF is ready in ethtool ops (Petr Oros) [RHEL-49816]
- ice: don't set target VSI for subfunction (Petr Oros) [RHEL-49816]
- ice: create port representor for SF (Petr Oros) [RHEL-49816]
- ice: make representor code generic (Petr Oros) [RHEL-49816]
- ice: implement netdev for subfunction (Petr Oros) [RHEL-49816]
- ice: base subfunction aux driver (Petr Oros) [RHEL-49816]
- ice: allocate devlink for subfunction (Petr Oros) [RHEL-49816]
- ice: treat subfunction VSI the same as PF VSI (Petr Oros) [RHEL-49816]
- ice: add basic devlink subfunctions support (Petr Oros) [RHEL-49816]
- ice: export ice ndo_ops functions (Petr Oros) [RHEL-49816]
- ice: add new VSI type for subfunctions (Petr Oros) [RHEL-49816]
- ice: do not bring the VSI up, if it was down before the XDP setup (Petr Oros) [RHEL-49816]
- ice: remove ICE_CFG_BUSY locking from AF_XDP code (Petr Oros) [RHEL-49816]
- ice: check ICE_VSI_DOWN under rtnl_lock when preparing for reset (Petr Oros) [RHEL-49816]
- ice: check for XDP rings instead of bpf program when unconfiguring (Petr Oros) [RHEL-49816]
- ice: protect XDP configuration with a mutex (Petr Oros) [RHEL-49816]
- ice: move netif_queue_set_napi to rtnl-protected sections (Petr Oros) [RHEL-49816]
- ice: Adjust over allocation of memory in ice_sched_add_root_node() and ice_sched_add_node() (Petr Oros) [RHEL-49816]
- ice: Report NVM version numbers on mismatch during load (Petr Oros) [RHEL-49816]
- ice: remove unnecessary control queue cmd_buf arrays (Petr Oros) [RHEL-49816]
- ice: reword comments referring to control queues (Petr Oros) [RHEL-49816]
- ice: stop intermixing AQ commands/responses debug dumps (Petr Oros) [RHEL-49816]
- ice: do not clutter debug logs with unused data (Petr Oros) [RHEL-49816]
- ice: improve debug print for control queue messages (Petr Oros) [RHEL-49816]
- ice: implement and use rd32_poll_timeout for ice_sq_done timeout (Petr Oros) [RHEL-49816]
- ice: add callbacks for Embedded SYNC enablement on dpll pins (Petr Oros) [RHEL-49816]
- ice: use internal pf id instead of function number (Petr Oros) [RHEL-49816]
- ice: Fix a 32bit bug (Petr Oros) [RHEL-49816]
- ice: enable FDIR filters from raw binary patterns for VFs (Petr Oros) [RHEL-49816]
- ice: add method to disable FDIR SWAP option (Petr Oros) [RHEL-49816]
- virtchnl: support raw packet in protocol header (Petr Oros) [RHEL-49816]
- ice: add API for parser profile initialization (Petr Oros) [RHEL-49816]
- ice: add UDP tunnels support to the parser (Petr Oros) [RHEL-49816]
- ice: support turning on/off the parser's double vlan mode (Petr Oros) [RHEL-49816]
- ice: add parser execution main loop (Petr Oros) [RHEL-49816]
- ice: add parser internal helper functions (Petr Oros) [RHEL-49816]
- ice: add debugging functions for the parser sections (Petr Oros) [RHEL-49816]
- ice: parse and init various DDP parser sections (Petr Oros) [RHEL-49816]
- ice: add parser create and destroy skeleton (Petr Oros) [RHEL-49816]
- ice: Fix incorrect assigns of FEC counts (Petr Oros) [RHEL-49816]
- ice: Skip PTP HW writes during PTP reset procedure (Petr Oros) [RHEL-49816]
- ice: Fix reset handler (Petr Oros) [RHEL-49816]
- ice: Fix recipe read procedure (Petr Oros) [RHEL-49816]
- ice: Add tracepoint for adding and removing switch rules (Petr Oros) [RHEL-49816]
- ice: Remove unused members from switch API (Petr Oros) [RHEL-49816]
- ice: Optimize switch recipe creation (Petr Oros) [RHEL-49816]
- ice: remove unused recipe bookkeeping data (Petr Oros) [RHEL-49816]
- ice: Simplify bitmap setting in adding recipe (Petr Oros) [RHEL-49816]
- ice: Remove reading all recipes before adding a new one (Petr Oros) [RHEL-49816]
- ice: Remove unused struct ice_prot_lkup_ext members (Petr Oros) [RHEL-49816]
- ice: remove eswitch rebuild (Petr Oros) [RHEL-49816]
- ice: Add support for devlink local_forwarding param (Petr Oros) [RHEL-49816]
- ice: Implement driver functionality to dump serdes equalizer values (Petr Oros) [RHEL-49816]
- ice: Implement driver functionality to dump fec statistics (Petr Oros) [RHEL-49816]
- ice: Extend Sideband Queue command to support flags (Petr Oros) [RHEL-49816]
- ice: do not init struct ice_adapter more times than needed (Petr Oros) [RHEL-49816]
- ice: Distinguish driver reset and removal for AQ shutdown (Petr Oros) [RHEL-49816]
- ice: Allow different FW API versions based on MAC type (Petr Oros) [RHEL-49816]
- ice: Check all ice_vsi_rebuild() errors in function (Petr Oros) [RHEL-49816]
- ice: Add get/set hw address for VFs using devlink commands (Petr Oros) [RHEL-49816]
- ice: update representor when VSI is ready (Petr Oros) [RHEL-49816]
- ice: move VSI configuration outside repr setup (Petr Oros) [RHEL-49816]
- ice: move devlink locking outside the port creation (Petr Oros) [RHEL-49816]
- ice: store representor ID in bridge port (Petr Oros) [RHEL-49816]
- ice: add and use roundup_u64 instead of open coding equivalent (Petr Oros) [RHEL-49816]
- ice: check for unregistering correct number of devlink params (Petr Oros) [RHEL-49816]
- ice: flower: validate control flags (Petr Oros) [RHEL-49816]
- ice: Document tx_scheduling_layers parameter (Petr Oros) [RHEL-49816]
- ice: Add tx_scheduling_layers devlink param (Petr Oros) [RHEL-49816]
- ice: Enable switching default Tx scheduler topology (Petr Oros) [RHEL-49816]
- ice: Adjust the VSI/Aggregator layers (Petr Oros) [RHEL-49816]
- ice: Support 5 layer topology (Petr Oros) [RHEL-49816]
- net: intel: implement modern PM ops declarations (ice) (Petr Oros) [RHEL-49816]
- overflow: Change DEFINE_FLEX to take __counted_by member (Petr Oros) [RHEL-49816]
- ice: Implement RSS settings for GTP using ethtool (Petr Oros) [RHEL-49816]
- net: intel: fix old compiler regressions (ice) (Petr Oros) [RHEL-49816]
- intel: fix string truncation warnings (ice) (Petr Oros) [RHEL-49816]
- net: Tree wide: Replace xdp_do_flush_map() with xdp_do_flush(). (ice) (Petr Oros) [RHEL-49816]
- Documentation: networking: correct spelling (ice) (Petr Oros) [RHEL-49816]
- cpufreq: intel_pstate: Update asym capacity for CPUs that were offline initially (Steve Best) [RHEL-68120]
- x86/sev: Ensure that RMP table fixups are reserved (Bandan Das) [RHEL-68360]
- redhat/configs: aarch64: compile cpufreq-dt-platdev as built-in (Radu Rendec) [RHEL-68851]
- iommu/tegra241-cmdqv: Fix alignment failure at max_n_shift (Jerry Snitselaar) [RHEL-67994]
- iommu/vt-d: Fix incorrect pci_for_each_dma_alias() for non-PCI devices (CKI Backport Bot) [RHEL-65892] {CVE-2024-50101}
- s390/pci: Allow allocation of more than 1 MSI interrupt (Mete Durlu) [RHEL-69123]
- s390/pci: Refactor arch_setup_msi_irqs() (Mete Durlu) [RHEL-69123]
- sfc: Don't invoke xdp_do_flush() from netpoll. (Michal Schmidt) [RHEL-52776]
- sfc: Add X4 PF support (Michal Schmidt) [RHEL-52776]
- sfc: siena: rip out rss-context dead code (Michal Schmidt) [RHEL-52776]
- sfc: convert comma to semicolon (Michal Schmidt) [RHEL-52776]
- sfc/siena: Convert comma to semicolon (Michal Schmidt) [RHEL-52776]
- sfc: Convert to use ERR_CAST() (Michal Schmidt) [RHEL-52776]
- sfc: remove .cap_rss_ctx_supported from updated drivers (Michal Schmidt) [RHEL-52776]
- sfc: falcon: Make I2C terminology more inclusive (Michal Schmidt) [RHEL-52776]
- sfc: remove get_rxfh_context dead code (Michal Schmidt) [RHEL-52776]
- sfc: use new rxfh_context API (Michal Schmidt) [RHEL-52776]
- sfc: use flow_rule_is_supp_control_flags() (Michal Schmidt) [RHEL-52776]
- sfc: adopt skb_network_offset() and similar helpers (Michal Schmidt) [RHEL-52776]
- sfc: fix a double-free bug in efx_probe_filters (Michal Schmidt) [RHEL-52776]
- sfc-siena: Implement ndo_hwtstamp_(get|set) (Michal Schmidt) [RHEL-52776]
- sfc: Implement ndo_hwtstamp_(get|set) (Michal Schmidt) [RHEL-52776]
- sfc: cleanup and reduce netlink error messages (Michal Schmidt) [RHEL-52776]
- sfc: support offloading ct(nat) action in RHS rules (Michal Schmidt) [RHEL-52776]
- sfc: parse mangle actions (NAT) in conntrack entries (Michal Schmidt) [RHEL-52776]
- sfc: replace deprecated strncpy with strscpy (Michal Schmidt) [RHEL-52776]
- sfc: support TC rules which require OR-AR-CT-AR flow (Michal Schmidt) [RHEL-52776]
- sfc: ensure an extack msg from efx_tc_flower_replace_foreign EOPNOTSUPPs (Michal Schmidt) [RHEL-52776]
- sfc: offload foreign RHS rules without an encap match (Michal Schmidt) [RHEL-52776]
- sfc: support TC left-hand-side rules on foreign netdevs (Michal Schmidt) [RHEL-52776]
- sfc: Replace xdp_do_flush_map() with xdp_do_flush(). (Michal Schmidt) [RHEL-52776]
- sfc: handle error pointers returned by rhashtable_lookup_get_insert_fast() (Michal Schmidt) [RHEL-52776]
- sfc: make coding style of PTP addresses consistent with core (Michal Schmidt) [RHEL-52776]
- sfc: check for zero length in EF10 RX prefix (Michal Schmidt) [RHEL-52776]
- sfc: extend pedit add action to handle decrement ipv6 hop limit (Michal Schmidt) [RHEL-52776]
- sfc: introduce pedit add actions on the ipv4 ttl field (Michal Schmidt) [RHEL-52776]
- sfc: add decrement ipv6 hop limit by offloading set hop limit actions (Michal Schmidt) [RHEL-52776]
- sfc: add decrement ttl by offloading set ipv4 ttl actions (Michal Schmidt) [RHEL-52776]
- sfc: add mac source and destination pedit action offload (Michal Schmidt) [RHEL-52776]
- sfc: introduce ethernet pedit set action infrastructure (Michal Schmidt) [RHEL-52776]
- sfc: Remove unneeded semicolon (Michal Schmidt) [RHEL-52776]
- sfc: don't fail probe if MAE/TC setup fails (Michal Schmidt) [RHEL-52776]
- sfc: don't unregister flow_indr if it was never registered (Michal Schmidt) [RHEL-52776]
- sfc: offload left-hand side rules for conntrack (Michal Schmidt) [RHEL-52776]
- sfc: conntrack state matches in TC rules (Michal Schmidt) [RHEL-52776]
- sfc: handle non-zero chain_index on TC rules (Michal Schmidt) [RHEL-52776]
- sfc: offload conntrack flow entries (match only) from CT zones (Michal Schmidt) [RHEL-52776]
- sfc: functions to insert/remove conntrack entries to MAE hardware (Michal Schmidt) [RHEL-52776]
- sfc: functions to register for conntrack zone offload (Michal Schmidt) [RHEL-52776]
- sfc: add MAE table machinery for conntrack table (Michal Schmidt) [RHEL-52776]
- sfc: fix use-after-free in efx_tc_flower_record_encap_match() (Michal Schmidt) [RHEL-52776]
- sfc: support TC decap rules matching on enc_src_port (Michal Schmidt) [RHEL-52776]
- sfc: support TC decap rules matching on enc_ip_tos (Michal Schmidt) [RHEL-52776]
- sfc/falcon: fix repeated words in comments (Michal Schmidt) [RHEL-52776]
- sfc: falcon: Use the bitmap API to allocate bitmaps (Michal Schmidt) [RHEL-52776]
- sfc:falcon: fix repeated words in comments (Michal Schmidt) [RHEL-52776]
- sfc: Stop using iommu_present() (Michal Schmidt) [RHEL-52776]
- sfc: falcon: Check null pointer of rx_queue->page_ring (Michal Schmidt) [RHEL-52776]
- sfc: use swap() to make code cleaner (Michal Schmidt) [RHEL-52776]
- s390/cio: Externalize full CMG characteristics (Mete Durlu) [RHEL-50790]
- s390/cio: export CHPID operating speed (Mete Durlu) [RHEL-50790]
- s390/cio: export measurement data for all CMGs (Mete Durlu) [RHEL-50790]
- s390/cio: export extended channel-path-measurement data (Mete Durlu) [RHEL-50790]
- s390/cio: simplify measurement attribute registration (Mete Durlu) [RHEL-50790]
- s390/cio: rework channel-utilization-block handling (Mete Durlu) [RHEL-50790]
- vfio/mlx5: Fix unwind flows in mlx5vf_pci_save/resume_device_data() (Alex Williamson) [RHEL-69746]
- vfio/mlx5: Fix an unwind issue in mlx5vf_add_migration_pages() (Alex Williamson) [RHEL-69746]
- bpf: Do not alloc arena on unsupported arches (Viktor Malik) [RHEL-66263]
- cpufreq: intel_pstate: Update Balance-performance EPP for Granite Rapids (Steve Best) [RHEL-70007]
- netfilter: br_netfilter: fix panic with metadata_dst skb (Ivan Vecera) [RHEL-59418]
- bridge: mcast: Fail MDB get request on empty entry (Ivan Vecera) [RHEL-59418]
- mptcp: error out earlier on disconnect (CKI Backport Bot) [RHEL-69692] {CVE-2024-53123}

* Mon Dec 09 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-540.el9]
- selftest/lkdtm: Skip stack-entropy test if lkdtm is not available (Mamatha Inamdar) [RHEL-52232]
- PCI: Extend ACS configurability (Myron Stowe) [RHEL-48601]
- PCI: Add ACS quirk for Broadcom BCM5760X NIC (Myron Stowe) [RHEL-48601]
- net: add softirq safety to netdev_rename_lock (Ivan Vecera) [RHEL-68117]
- arp: Convert ioctl(SIOCGARP) to RCU. (Ivan Vecera) [RHEL-68117]
- net: Protect dev->name by seqlock. (Ivan Vecera) [RHEL-68117]
- net: Remove unused declaration dev_restart() (Ivan Vecera) [RHEL-68117]
- arp: Get dev after calling arp_req_(delete|set|get)(). (Ivan Vecera) [RHEL-68117]
- arp: Remove a nest in arp_req_get(). (Ivan Vecera) [RHEL-68117]
- arp: Factorise ip_route_output() call in arp_req_set() and arp_req_delete(). (Ivan Vecera) [RHEL-68117]
- arp: Validate netmask earlier for SIOCDARP and SIOCSARP in arp_ioctl(). (Ivan Vecera) [RHEL-68117]
- arp: Move ATF_COM setting in arp_req_set(). (Ivan Vecera) [RHEL-68117]
- x86: fix user address masking non-canonical speculation issue (Waiman Long) [RHEL-65965] {CVE-2024-50102}
- runtime constants: move list of constants to vmlinux.lds.h (Waiman Long) [RHEL-65965]
- x86: make the masked_user_access_begin() macro use its argument only once (Waiman Long) [RHEL-65965]
- x86: do the user address masking outside the user access area (Waiman Long) [RHEL-65965]
- x86: support user address masking instead of non-speculative conditional (Waiman Long) [RHEL-65965]
- dcache: keep dentry_hashtable or d_hash_shift even when not used (Waiman Long) [RHEL-65965]
- runtime constants: deal with old decrepit linkers (Waiman Long) [RHEL-65965]
- s390: Add runtime constant support (Waiman Long) [RHEL-65965]
- um: Use generic runtime constant implementation (Waiman Long) [RHEL-65965]
- arm64: add 'runtime constant' support (Waiman Long) [RHEL-65965]
- runtime constants: add x86 architecture support (Waiman Long) [RHEL-65965]
- runtime constants: add default dummy infrastructure (Waiman Long) [RHEL-65965]
- vfs: dcache: move hashlen_hash() from callers into d_hash() (Waiman Long) [RHEL-65965]
- x86/uaccess: Add missing __force to casts in __access_ok() and valid_user_address() (Waiman Long) [RHEL-65965]
- dcache: move the DCACHE_OP_COMPARE case out of the __d_lookup_rcu loop (Waiman Long) [RHEL-65965]
- net/sched: sch_api: fix xa_insert() error path in tcf_block_get_ext() (CKI Backport Bot) [RHEL-68161] {CVE-2024-53044}
- vdpa/mlx5: Allow CVQ size changes (Laurent Vivier) [RHEL-21861]
- crypto: qat - Fix missing destroy_workqueue in adf_init_aer() (Vladis Dronov) [RHEL-69543]
- crypto: qat - Fix typo "accelaration" (Vladis Dronov) [RHEL-69543]
- crypto: qat - Constify struct pm_status_row (Vladis Dronov) [RHEL-69543]
- crypto: qat - remove faulty arbiter config reset (Vladis Dronov) [RHEL-69543]
- net/sched: stop qdisc_tree_reduce_backlog on TC_H_ROOT (CKI Backport Bot) [RHEL-68244] {CVE-2024-53057}
- net: avoid potential underflow in qdisc_pkt_len_init() with UFO (CKI Backport Bot) [RHEL-65404] {CVE-2024-49949}
- arm64/sve: Remove unused declaration read_smcr_features() (Mark Salter) [RHEL-40604]
- arm64/mm: Define dummy pud_user_exec() when using 2-level page-table (Mark Salter) [RHEL-40604]
- arm64: smp: smp_send_stop() and crash_smp_send_stop() should try non-NMI first (Mark Salter) [RHEL-40604]
- arm64/cpufeatures/kvm: Add ARMv8.9 FEAT_ECBHB bits in ID_AA64MMFR1 register (Mark Salter) [RHEL-40604]
- arm64: errata: Expand speculative SSBS workaround (Mark Salter) [RHEL-40604]
- arm64: errata: Unify speculative SSBS errata logic (Mark Salter) [RHEL-40604]
- arm64: cputype: Add Cortex-X925 definitions (Mark Salter) [RHEL-40604]
- arm64: cputype: Add Cortex-A720 definitions (Mark Salter) [RHEL-40604]
- arm64: cputype: Add Cortex-X3 definitions (Mark Salter) [RHEL-40604]
- arm64: mte: Make mte_check_tfsr_*() conditional on KASAN instead of MTE (Mark Salter) [RHEL-40604]
- scripts/gdb: change the layout of vmemmap (Mark Salter) [RHEL-40604]
- scripts/gdb: change VA_BITS_MIN when we use 16K page (Mark Salter) [RHEL-40604]
- scripts/gdb: set vabits_actual based on TCR_EL1 (Mark Salter) [RHEL-40604]
- arm64: mm: Fix lockless walks with static and dynamic page-table folding (Mark Salter) [RHEL-40604]
- arm64: remove redundant 'if HAVE_ARCH_KASAN' in Kconfig (Mark Salter) [RHEL-40604]
- arm64: smp: Fix missing IPI statistics (Mark Salter) [RHEL-40604]
- arm64: Clear the initial ID map correctly before remapping (Mark Salter) [RHEL-40604]
- arm64: armv8_deprecated: Fix warning in isndep cpuhp starting process (Mark Salter) [RHEL-40604]
- arm64: Add the arm64.no32bit_el0 command line option (Mark Salter) [RHEL-40604]
- arm64: defer clearing DAIF.D (Mark Salter) [RHEL-40604]
- arm64: assembler: update stale comment for disable_step_tsk (Mark Salter) [RHEL-40604]
- arm64/sysreg: Update PIE permission encodings (Mark Salter) [RHEL-40604]
- arm64: Add Neoverse-V2 part (Mark Salter) [RHEL-40604]
- redhat/configs: Enable ARM64_ERRATUM_3194386 (Mark Salter) [RHEL-40604]
- arm64: errata: Add workaround for Arm errata 3194386 and 3312417 (Mark Salter) [RHEL-40604]
- arm64: cputype: Add Neoverse-V3 definitions (Mark Salter) [RHEL-40604]
- arm64: cputype: Add Cortex-X4 definitions (Mark Salter) [RHEL-40604]
- arm64: barrier: Restore spec_bar() macro (Mark Salter) [RHEL-40604]
- arm64: tlb: Allow range operation for MAX_TLBI_RANGE_PAGES (Mark Salter) [RHEL-40604]
- arm64: tlb: Improve __TLBI_VADDR_RANGE() (Mark Salter) [RHEL-40604]
- arm64/fpsimd: Avoid erroneous elide of user state reload (Mark Salter) [RHEL-40604]
- arm64: Remove unnecessary irqflags alternative.h include (Mark Salter) [RHEL-40604]
- tools/include: Sync arm64 asm/cputype.h with the kernel sources (Mark Salter) [RHEL-40604]
- arm64/head: Disable MMU at EL2 before clearing HCR_EL2.E2H (Mark Salter) [RHEL-40604]
- arm64/head: Drop unnecessary pre-disable-MMU workaround (Mark Salter) [RHEL-40604]
- arm64/hugetlb: Fix page table walk in huge_pte_alloc() (Mark Salter) [RHEL-40604]
- arm64/ptrace: Use saved floating point state type to determine SVE layout (Mark Salter) [RHEL-40604]
- arm64: errata: Don't enable workarounds for "rare" errata by default (Mark Salter) [RHEL-40604]
- arm64: Unmask Debug + SError in do_notify_resume() (Mark Salter) [RHEL-40604]
- arm64: Move do_notify_resume() to entry-common.c (Mark Salter) [RHEL-40604]
- arm64: Simplify do_notify_resume() DAIF masking (Mark Salter) [RHEL-40604]
- arm64: Remove enable_daif macro (Mark Salter) [RHEL-40604]
- arm64/hw_breakpoint: Directly use ESR_ELx_WNR for an watchpoint exception (Mark Salter) [RHEL-40604]
- arm64: cpufeatures: Clean up temporary variable to simplify code (Mark Salter) [RHEL-40604]
- arm64: Update setup_arch() comment on interrupt masking (Mark Salter) [RHEL-40604]
- arm64: remove unnecessary ifdefs around is_compat_task() (Mark Salter) [RHEL-40604]
- arm64/sme: Ensure that all fields in SMCR_EL1 are set to known values (Mark Salter) [RHEL-40604]
- arm64/sve: Ensure that all fields in ZCR_EL1 are set to known values (Mark Salter) [RHEL-40604]
- arm64/sve: Document that __SVE_VQ_MAX is much larger than needed (Mark Salter) [RHEL-40604]
- arm64: make member of struct pt_regs and it's offset macro in the same order (Mark Salter) [RHEL-40604]
- arm64: io: permit offset addressing (Mark Salter) [RHEL-40604]
- arm64/hwcap: Define hwcaps for 2023 DPISA features (Mark Salter) [RHEL-40604]
- arm64/ptrace: Expose FPMR via ptrace (Mark Salter) [RHEL-40604]
- arm64/signal: Add FPMR signal handling (Mark Salter) [RHEL-40604]
- arm64/fpsimd: Support FEAT_FPMR (Mark Salter) [RHEL-40604]
- arm64/fpsimd: Enable host kernel access to FPMR (Mark Salter) [RHEL-40604]
- arm64/cpufeature: Hook new identification registers up to cpufeature (Mark Salter) [RHEL-40604]
- arm64/mm: Avoid ID mapping of kpti flag if it is no longer needed (Mark Salter) [RHEL-40604]
- arm64/mm: Use generic __pud_free() helper in pud_free() implementation (Mark Salter) [RHEL-40604]
- arm64: gitignore: ignore relacheck (Mark Salter) [RHEL-40604]
- arm64: Use Signed/Unsigned enums for TGRAN{4,16,64} and VARange (Mark Salter) [RHEL-40604]
- arm64: mm: Make PUD folding check in set_pud() a runtime check (Mark Salter) [RHEL-40604]
- arm64: defconfig: Enable LPA2 support (Mark Salter) [RHEL-40604]
- arm64: Enable 52-bit virtual addressing for 4k and 16k granule configs (Mark Salter) [RHEL-40604]
- arm64: ptdump: Deal with translation levels folded at runtime (Mark Salter) [RHEL-40604]
- arm64: ptdump: Disregard unaddressable VA space (Mark Salter) [RHEL-40604]
- arm64: mm: Add support for folding PUDs at runtime (Mark Salter) [RHEL-40604]
- arm64: kasan: Reduce minimum shadow alignment and enable 5 level paging (Mark Salter) [RHEL-40604]
- arm64: mm: Add 5 level paging support to fixmap and swapper handling (Mark Salter) [RHEL-40604]
- arm64: Enable LPA2 at boot if supported by the system (Mark Salter) [RHEL-40604]
- arm64: mm: add LPA2 and 5 level paging support to G-to-nG conversion (Mark Salter) [RHEL-40604]
- arm64: mm: Add definitions to support 5 levels of paging (Mark Salter) [RHEL-40604]
- arm64: mm: Add LPA2 support to phys<->pte conversion routines (Mark Salter) [RHEL-40604]
- arm64: mm: Wire up TCR.DS bit to PTE shareability fields (Mark Salter) [RHEL-40604]
- arm64: Add ESR decoding for exceptions involving translation level -1 (Mark Salter) [RHEL-40604]
- arm64: Avoid #define'ing PTE_MAYBE_NG to 0x0 for asm use (Mark Salter) [RHEL-40604]
- arm64: mm: Add feature override support for LVA (Mark Salter) [RHEL-40604]
- arm64: mm: Handle LVA support as a CPU feature (Mark Salter) [RHEL-40604]
- redhat/configs: move ARM64_VA_BITS_52 to common place (Mark Salter) [RHEL-40604]
- arm64: Revert "mm: provide idmap pointer to cpu_replace_ttbr1()" (Mark Salter) [RHEL-40604]
- arm64: mm: omit redundant remap of kernel image (Mark Salter) [RHEL-40604]
- arm64: mm: avoid fixmap for early swapper_pg_dir updates (Mark Salter) [RHEL-40604]
- arm64: kernel: Create initial ID map from C code (Mark Salter) [RHEL-40604]
- arm64: pgtable: Decouple PGDIR size macros from PGD/PUD/PMD levels (Mark Salter) [RHEL-40604]
- arm64: mm: Use 48-bit virtual addressing for the permanent ID map (Mark Salter) [RHEL-40604]
- arm64: head: Move early kernel mapping routines into C code (Mark Salter) [RHEL-40604]
- arm64: mmu: Make __cpu_replace_ttbr1() out of line (Mark Salter) [RHEL-40604]
- arm64: mm: Make kaslr_requires_kpti() a static inline (Mark Salter) [RHEL-40604]
- arm64: head: move memstart_offset_seed handling to C code (Mark Salter) [RHEL-40604]
- arm64: head: allocate more pages for the kernel mapping (Mark Salter) [RHEL-40604]
- arm64: Add helpers to probe local CPU for PAC and BTI support (Mark Salter) [RHEL-40604]
- arm64: idreg-override: Create a pseudo feature for rodata=off (Mark Salter) [RHEL-40604]
- arm64: kaslr: Use feature override instead of parsing the cmdline again (Mark Salter) [RHEL-40604]
- arm64: cpufeature: Add helper to test for CPU feature overrides (Mark Salter) [RHEL-40604]
- arm64: head: Run feature override detection before mapping the kernel (Mark Salter) [RHEL-40604]
- arm64: Move feature overrides into the BSS section (Mark Salter) [RHEL-40604]
- arm64: head: Clear BSS and the kernel page tables in one go (Mark Salter) [RHEL-40604]
- arm64: kernel: Remove early fdt remap code (Mark Salter) [RHEL-40604]
- arm64: idreg-override: Move to early mini C runtime (Mark Salter) [RHEL-40604]
- arm64: head: move relocation handling to C code (Mark Salter) [RHEL-40604]
- arm64: kernel: Don't rely on objcopy to make code under pi/ __init (Mark Salter) [RHEL-40604]
- arm64: kernel: Manage absolute relocations in code built under pi/ (Mark Salter) [RHEL-40604]
- arm64: kaslr: Adjust randomization range dynamically (Mark Salter) [RHEL-40604]
- arm64: mm: Reclaim unused vmemmap region for vmalloc use (Mark Salter) [RHEL-40604]
- arm64: vmemmap: Avoid base2 order of struct page size to dimension region (Mark Salter) [RHEL-40604]
- arm64: ptdump: Discover start of vmemmap region at runtime (Mark Salter) [RHEL-40604]
- arm64: ptdump: Allow all region boundaries to be defined at boot time (Mark Salter) [RHEL-40604]
- arm64: mm: Move fixmap region above vmemmap region (Mark Salter) [RHEL-40604]
- arm64: mm: Move PCI I/O emulation region above the vmemmap region (Mark Salter) [RHEL-40604]
- arm64/sysreg: Update ID_AA64DFR0_EL1 register (Mark Salter) [RHEL-40604]
- arm64/sysreg: Update ID_DFR0_EL1 register fields (Mark Salter) [RHEL-40604]
- arm64/sysreg: Add register fields for ID_AA64DFR1_EL1 (Mark Salter) [RHEL-40604]
- arm64/sme: Restore SMCR_EL1.EZT0 on exit from suspend (Mark Salter) [RHEL-40604]
- arm64/sme: Restore SME registers on exit from suspend (Mark Salter) [RHEL-40604]
- arm64/sve: Lower the maximum allocation for the SVE ptrace regset (Mark Salter) [RHEL-40604]
- arm64: Subscribe Microsoft Azure Cobalt 100 to ARM Neoverse N2 errata (Mark Salter) [RHEL-40604]
- arm64: fix typo in comments (Mark Salter) [RHEL-40604]
- arm64/signal: Don't assume that TIF_SVE means we saved SVE state (Mark Salter) [RHEL-40604]
- arm64: Fix circular header dependency (Mark Salter) [RHEL-40604]
- kasan/arm64: improve comments for KASAN_SHADOW_START/END (Mark Salter) [RHEL-40604]
- arm64: mm: get rid of kimage_vaddr global variable (Mark Salter) [RHEL-40604]
- arm64: mm: Take potential load offset into account when KASLR is off (Mark Salter) [RHEL-40604]
- arm64: Fix silcon-errata.rst formatting (Mark Salter) [RHEL-40604]
- arm64/fpsimd: Remove spurious check for SVE support (Mark Salter) [RHEL-40604]
- arm64/ptrace: Don't flush ZA/ZT storage when writing ZA via ptrace (Mark Salter) [RHEL-40604]
- arm64: entry: simplify kernel_exit logic (Mark Salter) [RHEL-40604]
- arm64: errata: Add Cortex-A510 speculative unprivileged load workaround (Mark Salter) [RHEL-40604]
- redhat/configs: enable ARM64_ERRATUM_3117295 (Mark Salter) [RHEL-40604]
- arm64: fpsimd: Bring cond_yield asm macro in line with new rules (Mark Salter) [RHEL-40604]
- arm64: irq: include <linux/cpumask.h> (Mark Salter) [RHEL-40604]
- arm64: Delete the zero_za macro (Mark Salter) [RHEL-40604]
- arm64: Align boot cpucap handling with system cpucap handling (Mark Salter) [RHEL-40604]
- arm64: Cleanup system cpucap handling (Mark Salter) [RHEL-40604]
- arm64: Kconfig: drop KAISER reference from KPTI option description (Mark Salter) [RHEL-40604]
- arm64: mm: Only map KPTI trampoline if it is going to be used (Mark Salter) [RHEL-40604]
- arm64: Get rid of ARM64_HAS_NO_HW_PREFETCH (Mark Salter) [RHEL-40604]
- arm64: irq: set the correct node for shadow call stack (Mark Salter) [RHEL-40604]
- arm64: irq: set the correct node for VMAP stack (Mark Salter) [RHEL-40604]
- arm64: fpsimd: Implement lazy restore for kernel mode FPSIMD (Mark Salter) [RHEL-40604]
- arm64: fpsimd: Preserve/restore kernel mode NEON at context switch (Mark Salter) [RHEL-40604]
- arm64: fpsimd: Drop unneeded 'busy' flag (Mark Salter) [RHEL-40604]
- arm64/kernel: Move 'nokaslr' parsing out of early idreg code (Mark Salter) [RHEL-40604]
- arm64: idreg-override: Avoid kstrtou64() to parse a single hex digit (Mark Salter) [RHEL-40604]
- arm64: idreg-override: Avoid sprintf() for simple string concatenation (Mark Salter) [RHEL-40604]
- arm64: idreg-override: avoid strlen() to check for empty strings (Mark Salter) [RHEL-40604]
- arm64: idreg-override: Avoid parameq() and parameqn() (Mark Salter) [RHEL-40604]
- arm64: idreg-override: Prepare for place relative reloc patching (Mark Salter) [RHEL-40604]
- arm64: idreg-override: Omit non-NULL checks for override pointer (Mark Salter) [RHEL-40604]
- arm64: Rename reserved values for CTR_EL0.L1Ip (Mark Salter) [RHEL-40604]
- arm64: Kill detection of VPIPT i-cache policy (Mark Salter) [RHEL-40604]
- arm64: mm: Always make sw-dirty PTEs hw-dirty in pte_modify (Mark Salter) [RHEL-40604]
- arm64: Avoid enabling KPTI unnecessarily (Mark Salter) [RHEL-40604]
- arm64: Remove system_uses_lse_atomics() (Mark Salter) [RHEL-40604]
- arm64: swiotlb: Reduce the default size if no ZONE_DMA bouncing needed (Mark Salter) [RHEL-40604]
- arm64: Move MediaTek GIC quirk handling from irqchip to core (Mark Salter) [RHEL-40604]
- sbsa_gwdt: Calculate timeout with 64-bit math (Mark Salter) [RHEL-40604]
- arm64: cpufeature: Change DBM to display enabled cores (Mark Salter) [RHEL-40604]
- arm64: cpufeature: Display the set of cores with a feature (Mark Salter) [RHEL-40604]
- arm64/sve: Remove SMCR pseudo register from cpufeature code (Mark Salter) [RHEL-40604]
- arm64/sve: Remove ZCR pseudo register from cpufeature code (Mark Salter) [RHEL-40604]
- arm64: Remove cpus_have_const_cap() (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_WORKAROUND_REPEAT_TLBI (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_WORKAROUND_NVIDIA_CARMEL_CNP (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_WORKAROUND_CAVIUM_23154 (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_WORKAROUND_2645198 (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_WORKAROUND_1742098 (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_WORKAROUND_1542419 (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_WORKAROUND_843419 (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_UNMAP_KERNEL_AT_EL0 (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_{SVE,SME,SME2,FA64} (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_SPECTRE_V2 (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_SSBS (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_MTE (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_TLB_RANGE (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_WFXT (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_RNG (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_EPAN (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_PAN (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_GIC_PRIO_MASKING (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_DIT (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_CNP (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_CACHE_DIC (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_BTI (Mark Salter) [RHEL-40604]
- arm64: Avoid cpus_have_const_cap() for ARM64_HAS_{ADDRESS,GENERIC}_AUTH (Mark Salter) [RHEL-40604]
- arm64: Use a positive cpucap for FP/SIMD (Mark Salter) [RHEL-40604]
- arm64: Rename SVE/SME cpu_enable functions (Mark Salter) [RHEL-40604]
- arm64: Use build-time assertions for cpucap ordering (Mark Salter) [RHEL-40604]
- arm64: Explicitly save/restore CPACR when probing SVE and SME (Mark Salter) [RHEL-40604]
- arm64: Split kpti_install_ng_mappings() (Mark Salter) [RHEL-40604]
- arm64: Fixup user features at boot time (Mark Salter) [RHEL-40604]
- arm64: Rework setup_cpu_features() (Mark Salter) [RHEL-40604]
- arm64: Add cpus_have_final_boot_cap() (Mark Salter) [RHEL-40604]
- arm64: Add cpucap_is_possible() (Mark Salter) [RHEL-40604]
- arm64: Factor out cpucap definitions (Mark Salter) [RHEL-40604]
- clocksource/drivers/arm_arch_timer: Initialize evtstrm after finalizing cpucaps (Mark Salter) [RHEL-40604]
- arm64: add FEAT_LSE128 HWCAP (Mark Salter) [RHEL-40604]
- arm64: add FEAT_LRCPC3 HWCAP (Mark Salter) [RHEL-40604]
- arm64/sve: Report FEAT_SVE_B16B16 to userspace (Mark Salter) [RHEL-40604]
- arm64: smp: Don't directly call arch_smp_send_reschedule() for wakeup (Mark Salter) [RHEL-40604]
- arm64: smp: Mark IPI globals as __ro_after_init (Mark Salter) [RHEL-40604]
- arm64: kgdb: Implement kgdb_roundup_cpus() to enable pseudo-NMI roundup (Mark Salter) [RHEL-40604]
- arm64: smp: IPI_CPU_STOP and IPI_CPU_CRASH_STOP should try for NMI (Mark Salter) [RHEL-40604]
- arm64: smp: Add arch support for backtrace using pseudo-NMI (Mark Salter) [RHEL-40604]
- arm64: smp: Remove dedicated wakeup IPI (Mark Salter) [RHEL-40604]
- arm64: idle: Tag the arm64 idle functions as __cpuidle (Mark Salter) [RHEL-40604]
- irqchip/gic-v3: Enable support for SGIs to act as NMIs (Mark Salter) [RHEL-40604]
- efi/arm64: Move EFI runtime call setup/teardown helpers out of line (Mark Salter) [RHEL-40604]
- arm64: tlbflush: add some comments for TLB batched flushing (Mark Salter) [RHEL-40604]
- arm64: support batched/deferred tlb shootdown during page reclamation/migration (Mark Salter) [RHEL-40604]
- scripts/gdb/aarch64: add aarch64 page operation helper commands and configs (Mark Salter) [RHEL-40604]
- arm64: fix build warning for ARM64_MEMSTART_SHIFT (Mark Salter) [RHEL-40604]
- arm64: Remove unsued extern declaration init_mem_pgprot() (Mark Salter) [RHEL-40604]
- arm64/mm: Set only the PTE_DIRTY bit while preserving the HW dirty state (Mark Salter) [RHEL-40604]
- arm64/mm: Add pte_rdonly() helper (Mark Salter) [RHEL-40604]
- arm64/mm: Replace an open coding with ID_AA64MMFR1_EL1_HAFDBS_MASK (Mark Salter) [RHEL-40604]
- arm64: mm: use ptep_clear() instead of pte_clear() in clear_flush() (Mark Salter) [RHEL-40604]
- arm64/mm: Directly use ID_AA64MMFR2_EL1_VARange_MASK (Mark Salter) [RHEL-40604]
- arm64: module: Use module_init_layout_section() to spot init sections (Mark Salter) [RHEL-40604]
- arm64/fpsimd: Don't flush SME register hardware state along with thread (Mark Salter) [RHEL-40604]
- kgdb: Provide a stub kgdb_nmicallback() if !CONFIG_KGDB (Mark Salter) [RHEL-40604]
- arm64: add hw_nmi_get_sample_period for preparation of lockup detector (Mark Salter) [RHEL-40604]
- arm64: alternatives: make clean_dcache_range_nopatch() noinstr-safe (Mark Salter) [RHEL-40604]
- arm64: hibernate: remove WARN_ON in save_processor_state (Mark Salter) [RHEL-40604]
- arm64/fpsimd: Exit streaming mode when flushing tasks (Mark Salter) [RHEL-40604]
- arm64: mm: fix VA-range sanity check (Mark Salter) [RHEL-40604]
- arm64/mm: remove now-superfluous ISBs from TTBR writes (Mark Salter) [RHEL-40604]
- arm64: consolidate rox page protection logic (Mark Salter) [RHEL-40604]
- arm64: set __exception_irq_entry with __irq_entry as a default (Mark Salter) [RHEL-40604]
- arm64: mm: always map fixmap at page granularity (Mark Salter) [RHEL-40604]
- arm64: mm: move fixmap code to its own file (Mark Salter) [RHEL-40604]
- arm64: add FIXADDR_TOT_{START,SIZE} (Mark Salter) [RHEL-40604]
- arm: uaccess: Remove memcpy_page_flushcache() (Mark Salter) [RHEL-40604]
- scripts/gdb: add mm introspection utils (Mark Salter) [RHEL-40604]
- arm/mm: fix swp type masking in __swp_entry() (Mark Salter) [RHEL-40604]
- arm64, smp: Remove trace_.*_rcuidle() usage (Mark Salter) [RHEL-40604]
- arm64: mte: Avoid the racy walk of the vma list during core dump (Mark Salter) [RHEL-40604]
- arm64: mte: Fix double-freeing of the temporary tag storage during coredump (Mark Salter) [RHEL-40604]
- arm64/mm: add pud_user_exec() check in pud_user_accessible_page() (Mark Salter) [RHEL-40604]
- arm64/mm: fix incorrect file_map_count for invalid pmd (Mark Salter) [RHEL-40604]
- arm64/mm: fix incorrect file_map_count for non-leaf pmd/pud (Mark Salter) [RHEL-40604]
- arm64/asm: Remove unused assembler DAIF save/restore macros (Mark Salter) [RHEL-40604]
- arm64/mm: Drop idmap_pg_end[] declaration (Mark Salter) [RHEL-40604]
- arm64/mm: fix page table check compile error for CONFIG_PGTABLE_LEVELS=2 (Mark Salter) [RHEL-40604]
- arm64/mm: Compute PTRS_PER_[PMD|PUD] independently of PTRS_PER_PTE (Mark Salter) [RHEL-40604]
- arm64: Add support for user sub-page fault probing (Mark Salter) [RHEL-40604]
- arm64: clean up tools Makefile (Mark Salter) [RHEL-40604]
- clocksource/drivers/arm_arch_timer: Use event stream scaling when available (Mark Salter) [RHEL-40604]
- workqueue: Improve scalability of workqueue watchdog touch (Waiman Long) [RHEL-60747] {CVE-2024-46839}
- workqueue: wq_watchdog_touch is always called with valid CPU (Waiman Long) [RHEL-60747] {CVE-2024-46839}

* Thu Dec 05 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-539.el9]
- smb: client: fix use-after-free of signing key (Paulo Alcantara) [RHEL-66206]
- Bluetooth: MGMT: Fix possible deadlocks (Bastien Nocera) [RHEL-64476] {CVE-2024-49951}
- Bluetooth: MGMT: Fix possible crash on mgmt_index_removed (CKI Backport Bot) [RHEL-64476] {CVE-2024-49951}
- HID: hyperv: streamline driver probe to avoid devres issues (Vitaly Kuznetsov) [RHEL-29299]
- filter-modules.sh.rhel: Move squashfs to kernel-modules-core (Vitaly Kuznetsov) [RHEL-68817]
- net: qede: flower: validate control flags (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_parse_actions() (Michal Schmidt) [RHEL-52263]
- net: qede: propagate extack through qede_flow_spec_validate() (Michal Schmidt) [RHEL-52263]
- net: qede: use faked extack in qede_flow_spec_to_rule() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_parse_flow_attr() (Michal Schmidt) [RHEL-52263]
- net: qede: add extack in qede_add_tc_flower_fltr() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_flow_parse_udp_v4() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_flow_parse_udp_v6() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_flow_parse_tcp_v4() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_flow_parse_tcp_v6() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_flow_parse_v4_common() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_flow_parse_v6_common() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_set_v4_tuple_to_profile() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_set_v6_tuple_to_profile() (Michal Schmidt) [RHEL-52263]
- net: qede: use extack in qede_flow_parse_ports() (Michal Schmidt) [RHEL-52263]
- net: qede: use return from qede_flow_parse_ports() (Michal Schmidt) [RHEL-52263]
- net: qede: use return from qede_flow_spec_validate_unused() (Michal Schmidt) [RHEL-52263]
- net: qede: use return from qede_parse_actions() for flow_spec (Michal Schmidt) [RHEL-52263]
- net: qede: use return from qede_parse_actions() (Michal Schmidt) [RHEL-52263]
- net: qede: use return from qede_parse_flow_attr() for flow_spec (Michal Schmidt) [RHEL-52263]
- net: qede: use return from qede_parse_flow_attr() for flower (Michal Schmidt) [RHEL-52263]
- net: qede: sanitize 'rc' in qede_add_tc_flower_fltr() (Michal Schmidt) [RHEL-52263]
- qed: avoid truncating work queue length (Michal Schmidt) [RHEL-52263]
- qed: Drop useless pci_params.pm_cap (Michal Schmidt) [RHEL-52263]
- scsi: qedf: Replace deprecated strncpy() with strscpy() (Michal Schmidt) [RHEL-52263]
- qede: adopt skb_network_offset() and similar helpers (Michal Schmidt) [RHEL-52263]
- qed: remove duplicated assignment to variable opaque_fid (Michal Schmidt) [RHEL-52263]
- qed: Fix a potential use-after-free in qed_cxt_tables_alloc (Michal Schmidt) [RHEL-52263]
- qede: Refactor qede_forced_speed_maps_init() (Michal Schmidt) [RHEL-52263]
- qed: replace uses of strncpy (Michal Schmidt) [RHEL-52263]
- qed/red_ll2: Fix undefined behavior bug in struct qed_ll2_info (Michal Schmidt) [RHEL-52263]
- qed/qede: Remove unused declarations (Michal Schmidt) [RHEL-52263]
- qed: remove unused 'resp_size' calculation (Michal Schmidt) [RHEL-52263]
- qed: Fix scheduling in a tasklet while getting stats (Michal Schmidt) [RHEL-52263]
- qed: remove unused num_ooo_add_to_peninsula variable (Michal Schmidt) [RHEL-52263]
- qed/qed_sriov: guard against NULL derefs from qed_iov_get_vf_info (Michal Schmidt) [RHEL-52263]
- qed/qed_mng_tlv: correctly zero out ->min instead of ->hour (Michal Schmidt) [RHEL-52263]
- qed/qed_dev: guard against a possible division by zero (Michal Schmidt) [RHEL-52263]
- qede: remove linux/version.h and linux/compiler.h (Michal Schmidt) [RHEL-52263]
- qede: execute xdp_do_flush() before napi_complete_done() (Michal Schmidt) [RHEL-52263]
- qed: fix a typo in comment (Michal Schmidt) [RHEL-52263]
- qed: Introduce slab_build_skb() (Michal Schmidt) [RHEL-52263]
- qed: avoid defines prefixed with CONFIG (Michal Schmidt) [RHEL-52263]
- qed (gcc13): use u16 for fid to be big enough (Michal Schmidt) [RHEL-52263]
- qed, qede: constify references to netdev->dev_addr in drivers (Michal Schmidt) [RHEL-52263]
- qed: Remove redundant 'flush_workqueue()' calls (Michal Schmidt) [RHEL-52263]
- ntb: intel: Fix the NULL vs IS_ERR() bug for debugfs_create_dir() (CKI Backport Bot) [RHEL-63229] {CVE-2023-52917}
- netdevice: add netdev_tx_reset_subqueue() shorthand (CKI Backport Bot) [RHEL-68651]
- drivers: net: ionic: add missed debugfs cleanup to ionic_probe() error path (Mohammad Heib) [RHEL-64963]
- ionic: Allow XDP program to be hot swapped (Mohammad Heib) [RHEL-64963]
- ionic: convert Rx queue buffers to use page_pool (Mohammad Heib) [RHEL-64963]
- ionic: Fully reconfigure queues when going to/from a NULL XDP program (Mohammad Heib) [RHEL-64963]
- ionic: always use rxq_info (Mohammad Heib) [RHEL-64963]
- ionic: use per-queue xdp_prog (Mohammad Heib) [RHEL-64963]
- ionic: rename ionic_xdp_rx_put_bufs (Mohammad Heib) [RHEL-64963]
- ionic: debug line for Tx completion errors (Mohammad Heib) [RHEL-64963]
- ionic: Convert comma to semicolon (Mohammad Heib) [RHEL-64963]
- ionic: Remove redundant null pointer checks in ionic_debugfs_add_qcq() (Mohammad Heib) [RHEL-64963]
- ionic: Prevent tx_timeout due to frequent doorbell ringing (Mohammad Heib) [RHEL-64963]
- ionic: use dev_consume_skb_any outside of napi (Mohammad Heib) [RHEL-64963]
- ionic: fix kernel panic due to multi-buffer handling (Mohammad Heib) [RHEL-64963]
- ionic: Only run the doorbell workaround for certain asic_type (Mohammad Heib) [RHEL-64963]
- ionic: Use an u16 for rx_copybreak (Mohammad Heib) [RHEL-64963]
- ionic: check for queue deadline in doorbell_napi_work (Mohammad Heib) [RHEL-64963]
- ionic: add per-queue napi_schedule for doorbell check (Mohammad Heib) [RHEL-64963]
- ionic: add work item for missed-doorbell check (Mohammad Heib) [RHEL-64963]
- ionic: add private workqueue per-device (Mohammad Heib) [RHEL-64963]
- ionic: Keep interrupt affinity up to date (Mohammad Heib) [RHEL-64963]
- ionic: remove missed doorbell per-queue timer (Mohammad Heib) [RHEL-64963]
- ionic: advertise 52-bit addressing limitation for MSI-X (Mohammad Heib) [RHEL-64963]
- ionic: fix up ionic_if.h kernel-doc issues (Mohammad Heib) [RHEL-64963]
- ionic: only sync frag_len in first buffer of xdp (Mohammad Heib) [RHEL-64963]
- ionic: Use netdev_name() function instead of netdev->name (Mohammad Heib) [RHEL-64963]
- ionic: Mark error paths in the data path as unlikely (Mohammad Heib) [RHEL-64963]
- ionic: Pass ionic_txq_desc to ionic_tx_tso_post (Mohammad Heib) [RHEL-64963]
- ionic: Reset LIF device while restarting LIF (Mohammad Heib) [RHEL-64963]
- ionic: fix potential irq name truncation (Mohammad Heib) [RHEL-64963]
- fbdev: efifb: Register sysfs groups through driver core (Jocelyn Falempe) [RHEL-53899]
- fbdev: efifb: Use driver-private screen_info for sysfs (Jocelyn Falempe) [RHEL-53899]
- firmware/sysfb: Disable sysfb for firmware buffers with unknown parent (Jocelyn Falempe) [RHEL-53899]
- fbdev: xen-fbfront: Assign fb_info->device (Jocelyn Falempe) [RHEL-53899]
- fbdev: hpfb: Fix an error handling path in hpfb_dio_probe() (Jocelyn Falempe) [RHEL-53899]
- video/aperture: optionally match the device in sysfb_disable() (Jocelyn Falempe) [RHEL-53899]
- firmware: sysfb: Fix reference count of sysfb parent device (Jocelyn Falempe) [RHEL-53899]
- fbdev: viafb: Make I2C terminology more inclusive (Jocelyn Falempe) [RHEL-53899]
- fbdev: smscufx: Make I2C terminology more inclusive (Jocelyn Falempe) [RHEL-53899]
- fb_defio: use a folio in fb_deferred_io_work() (Jocelyn Falempe) [RHEL-53899]
- fbdev: omap2: Return clk_prepare_enable to transfer the error (Jocelyn Falempe) [RHEL-53899]
- fbdev: mmp: Constify struct mmp_overlay_ops (Jocelyn Falempe) [RHEL-53899]
- fbdev: Drop explicit initialization of struct i2c_device_id::driver_data to 0 (Jocelyn Falempe) [RHEL-53899]
- video: console: add missing MODULE_DESCRIPTION() macros (Jocelyn Falempe) [RHEL-53899]
- fbdev: amifb: add missing MODULE_DESCRIPTION() macro (Jocelyn Falempe) [RHEL-53899]
- fbdev: c2p_planar: add missing MODULE_DESCRIPTION() macro (Jocelyn Falempe) [RHEL-53899]
- fbdev: vesafb: Detect VGA compatibility from screen info's VESA attributes (Jocelyn Falempe) [RHEL-53899]
- fbdev: omapfb: use of_graph_get_remote_port() (Jocelyn Falempe) [RHEL-53899]
- fbdev: omapdss: use for_each_endpoint_of_node() (Jocelyn Falempe) [RHEL-53899]
- fbdev: offb: add missing MODULE_DESCRIPTION() macro (Jocelyn Falempe) [RHEL-53899]
- fbdev: vfb: add missing MODULE_DESCRIPTION() macro (Jocelyn Falempe) [RHEL-53899]
- fbdev: macmodes: add missing MODULE_DESCRIPTION() macro (Jocelyn Falempe) [RHEL-53899]
- fbdev: goldfishfb: add missing MODULE_DESCRIPTION() macro (Jocelyn Falempe) [RHEL-53899]
- fbdev: kyro: add missing MODULE_DESCRIPTION() macro (Jocelyn Falempe) [RHEL-53899]
- fbdev: viafb: add missing MODULE_DESCRIPTION() macro (Jocelyn Falempe) [RHEL-53899]
- fbdev: matroxfb: add missing MODULE_DESCRIPTION() macros (Jocelyn Falempe) [RHEL-53899]
- video/logo: Make logo data const again (Jocelyn Falempe) [RHEL-53899]
- arch: Remove struct fb_info from video helpers (Jocelyn Falempe) [RHEL-53899]
- arch: Select fbdev helpers with CONFIG_VIDEO (Jocelyn Falempe) [RHEL-53899]
- fbdev: omap: lcd_ams_delta: Constify lcd_ops (Jocelyn Falempe) [RHEL-53899]
- fbdev: imx: Constify lcd_ops (Jocelyn Falempe) [RHEL-53899]
- fbdev: clps711x: Constify lcd_ops (Jocelyn Falempe) [RHEL-53899]
- fbdev/deferred-io: Provide get_page hook in struct fb_deferred_io (Jocelyn Falempe) [RHEL-53899]
- fbdev/deferred-io: Always call get_page() for framebuffer pages (Jocelyn Falempe) [RHEL-53899]
- fbdev/deferred-io: Test smem_start for I/O memory (Jocelyn Falempe) [RHEL-53899]
- fbdev/deferred-io: Test screen_buffer for vmalloc'ed memory (Jocelyn Falempe) [RHEL-53899]
- fbdev/deferred-io: Clean up pageref on lastclose (Jocelyn Falempe) [RHEL-53899]
- fbdev/deferred-io: Move pageref setup into separate helper (Jocelyn Falempe) [RHEL-53899]
- fbdev: savage: Handle err return when savagefb_check_var failed (Jocelyn Falempe) [RHEL-53899]
- fbdev: uvesafb: replace deprecated strncpy with strscpy_pad (Jocelyn Falempe) [RHEL-53899]
- fbdev: au1200fb: replace deprecated strncpy with strscpy (Jocelyn Falempe) [RHEL-53899]
- fbdev: fsl-diu-fb: replace deprecated strncpy with strscpy_pad (Jocelyn Falempe) [RHEL-53899]
- fbdev: fix incorrect address computation in deferred IO (Jocelyn Falempe) [RHEL-53899]
- video: logo: Drop full path of the input filename in generated file (Jocelyn Falempe) [RHEL-53899]
- fbdev: add HAS_IOPORT dependencies (Jocelyn Falempe) [RHEL-53899]
- fbdev: sh7760fb: allow modular build (Jocelyn Falempe) [RHEL-53899]
- fbdev: sisfb: hide unused variables (Jocelyn Falempe) [RHEL-53899]
- fbdev: omap2/omapfb: Replace use of fb_blank with backlight helpers (Jocelyn Falempe) [RHEL-53899]
- fbdev: ssd1307fb: Remove struct backlight_ops.check_fb (Jocelyn Falempe) [RHEL-53899]
- fbdev: ssd1307fb: Init backlight before registering framebuffer (Jocelyn Falempe) [RHEL-53899]
- fbdev: sh_mobile_lcdc_fb: Remove struct backlight_ops.check_fb (Jocelyn Falempe) [RHEL-53899]
- backlight: pwm-backlight: Remove struct backlight_ops.check_fb (Jocelyn Falempe) [RHEL-53899]
- backlight: aat2870-backlight: Remove struct backlight.check_fb (Jocelyn Falempe) [RHEL-53899]
- backlight: Match backlight device against struct fb_info.bl_dev (Jocelyn Falempe) [RHEL-53899]
- fbdev: shmobile: fix snprintf truncation (Jocelyn Falempe) [RHEL-53899]
- fbdev: Select I/O-memory framebuffer ops for SBus (Jocelyn Falempe) [RHEL-53899]
- fbdev: omap2: replace of_graph_get_next_endpoint() (Jocelyn Falempe) [RHEL-53899]
- firmware/sysfb: fix an error code in sysfb_init() (Jocelyn Falempe) [RHEL-53899]
- firmware/sysfb: Create firmware device only for enabled PCI devices (Jocelyn Falempe) [RHEL-53899]
- firmware/sysfb: Set firmware-framebuffer parent device (Jocelyn Falempe) [RHEL-53899]
- fbdev: panel-tpo-td043mtea1: Convert sprintf() to sysfs_emit() (Jocelyn Falempe) [RHEL-53899]
- fbmon: prevent division by zero in fb_videomode_from_videomode() (Jocelyn Falempe) [RHEL-53899]
- fbcon: Increase maximum font width x height to 64 x 128 (Jocelyn Falempe) [RHEL-53899]
- fbdev: viafb: fix typo in hw_bitblt_1 and hw_bitblt_2 (Jocelyn Falempe) [RHEL-53899]
- fbdev: mb862xxfb: Fix defined but not used error (Jocelyn Falempe) [RHEL-53899]
- fbdev: uvesafb: Convert sprintf/snprintf to sysfs_emit (Jocelyn Falempe) [RHEL-53899]
- fbdev/chipsfb: Include <linux/backlight.h> (Jocelyn Falempe) [RHEL-53899]
- backlight/corgi-lcd: Include <linux/backlight.h> (Jocelyn Falempe) [RHEL-53899]
- fbdev/efifb: Remove framebuffer relocation tracking (Jocelyn Falempe) [RHEL-53899]
- firmware/sysfb: Update screen_info for relocated EFI framebuffers (Jocelyn Falempe) [RHEL-53899]
- fbdev/efifb: Do not track parent device status (Jocelyn Falempe) [RHEL-53899]
- fbdev/efifb: Remove PM for parent device (Jocelyn Falempe) [RHEL-53899]
- video: Provide screen_info_get_pci_dev() to find screen_info's PCI device (Jocelyn Falempe) [RHEL-53899]
- video: Add helpers for decoding screen_info (Jocelyn Falempe) [RHEL-53899]
- video: fbdev: mmp: Follow renaming of SPI "master" to "controller" (Jocelyn Falempe) [RHEL-53899]
- fbdev: Restrict FB_SH_MOBILE_LCDC to SuperH (Jocelyn Falempe) [RHEL-53899]
- vt: remove superfluous CONFIG_HW_CONSOLE (Jocelyn Falempe) [RHEL-53899]
- fbcon: remove fbcon_getxy() (Jocelyn Falempe) [RHEL-53899]
- fbcon: remove consw::con_screen_pos() (Jocelyn Falempe) [RHEL-53899]
- tty: vt: change consw::con_set_origin() return type (Jocelyn Falempe) [RHEL-53899]
- tty: vt: make consw::con_font_default()'s name const (Jocelyn Falempe) [RHEL-53899]
- tty: vt: make font of consw::con_font_set() const (Jocelyn Falempe) [RHEL-53899]
- tty: vt: stop using -1 for blank mode in consw::con_blank() (Jocelyn Falempe) [RHEL-53899]
- tty: vt: make consw::con_switch() return a bool (Jocelyn Falempe) [RHEL-53899]
- tty: vt: remove CM_* constants (Jocelyn Falempe) [RHEL-53899]
- fbdev/core: simplify cursor_state setting in fbcon_ops::cursor() (Jocelyn Falempe) [RHEL-53899]
- consoles: use if instead of switch-case in consw::con_cursor() (Jocelyn Falempe) [RHEL-53899]
- tty: vt: sanitize consw::con_putcs() parameters (Jocelyn Falempe) [RHEL-53899]
- tty: vt: sanitize consw::con_putc() parameters (Jocelyn Falempe) [RHEL-53899]
- tty: vt: eliminate unneeded consw::con_putc() implementations (Jocelyn Falempe) [RHEL-53899]
- tty: vt: add con_putc() helper (Jocelyn Falempe) [RHEL-53899]
- tty: vt: remove checks for count in consw::con_clear() implementations (Jocelyn Falempe) [RHEL-53899]
- tty: vt: sanitize arguments of consw::con_clear() (Jocelyn Falempe) [RHEL-53899]
- tty: vt: make init parameter of consw::con_init() a bool (Jocelyn Falempe) [RHEL-53899]
- tty: vt: make consw::con_debug_*() return void (Jocelyn Falempe) [RHEL-53899]
- tty: vt: pass vc_resize_user as a parameter (Jocelyn Falempe) [RHEL-53899]
- fbcon: make display_desc a static array in fbcon_startup() (Jocelyn Falempe) [RHEL-53899]
- vgacon: inline vc_scrolldelta_helper() into vgacon_scrolldelta() (Jocelyn Falempe) [RHEL-53899]
- of/platform: Disable sysfb if a simple-framebuffer node is found (Jocelyn Falempe) [RHEL-53899]
- video/nomodeset: Select nomodeset= parameter with CONFIG_VIDEO (Jocelyn Falempe) [RHEL-53899]
- video/cmdline: Hide __video_get_options() behind CONFIG_FB_CORE (Jocelyn Falempe) [RHEL-53899]
- video/cmdline: Introduce CONFIG_VIDEO for video= parameter (Jocelyn Falempe) [RHEL-53899]
- fbdev/vesafb: Use screen_info pointer from device (Jocelyn Falempe) [RHEL-53899]
- fbdev/vesafb: Replace references to global screen_info by local pointer (Jocelyn Falempe) [RHEL-53899]
- fbdev/efifb: Use screen_info pointer from device (Jocelyn Falempe) [RHEL-53899]
- fbdev/efifb: Replace references to global screen_info by local pointer (Jocelyn Falempe) [RHEL-53899]
- lib/fonts: fix undefined behavior in bit shift for get_default_font (Jocelyn Falempe) [RHEL-53899]
- scsi: qla2xxx: Convert comma to semicolon (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Remove the unused 'del_list_entry' field in struct fc_port (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Update version to 10.02.09.300-k (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Use QP lock to search for bsg (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Reduce fabric scan duplicate code (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Fix optrom version displayed in FDMI (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: During vport delete send async logout explicitly (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Complete command early within lock (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Fix flash read failure (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Return ENOBUFS if sg_cnt is more than one for ELS cmds (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Fix for possible memory corruption (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: validate nvme_local_port correctly (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Unable to act on RSCN for port online (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Remove unused struct 'scsi_dif_tuple' (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Fix debugfs output for fw_resource_count (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Avoid possible run-time warning with long model_num (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Indent help text (Nilesh Javali) [RHEL-58013]
- scsi: qla2xxx: Drop driver owner assignment (Nilesh Javali) [RHEL-58013]
- powercap: intel_rapl_tpmi: Ignore minor version change (David Arcari) [RHEL-33313]
- powercap: intel_rapl_tpmi: Fix bogus register reading (David Arcari) [RHEL-33313]
- powercap: intel_rapl_msr: Add PL4 support for ArrowLake-H (David Arcari) [RHEL-33313]
- powercap: intel_rapl_msr: Add PL4 support for Arrowlake-U (David Arcari) [RHEL-33313]
- powercap: intel_rapl: Change an error pointer to NULL (David Arcari) [RHEL-33313]
- powercap: intel_rapl: Add support for ArrowLake-U platform (David Arcari) [RHEL-33313]
- powercap/intel_rapl: Fix the energy-pkg event for AMD CPUs (David Arcari) [RHEL-33313]
- powercap/intel_rapl: Add support for AMD family 1Ah (David Arcari) [RHEL-33313]
- sctp: properly validate chunk size in sctp_sf_ootb() (CKI Backport Bot) [RHEL-68005] {CVE-2024-50299}
- net/sched: act_api: deny mismatched skip_sw/skip_hw flags for actions created by classifiers (Ivan Vecera) [RHEL-57768]
- net: fix races in netdev_tx_sent_queue()/dev_watchdog() (Ivan Vecera) [RHEL-57768]
- sch_cake: constify inverse square root cache (Ivan Vecera) [RHEL-57768]
- net: sched: consistently use rcu_replace_pointer() in taprio_change() (Ivan Vecera) [RHEL-57768]
- net_sched: sch_fq: fix incorrect behavior for small weights (Ivan Vecera) [RHEL-57768]
- selftests: tc_actions: test egress 2nd vlan push (Ivan Vecera) [RHEL-57768]
- selftests: tc_actions: test ingress 2nd vlan push (Ivan Vecera) [RHEL-57768]
- tc: adjust network header after 2nd vlan push (Ivan Vecera) [RHEL-57768]
- net: sched: Correct spelling in headers (Ivan Vecera) [RHEL-57768]
- tc-testing: don't access non-existent variable on exception (Ivan Vecera) [RHEL-57768]
- UAPI: net/sched: Use __struct_group() in flex struct tc_u32_sel (Ivan Vecera) [RHEL-57768]
- sched: act_ct: avoid -Wflex-array-member-not-at-end warning (Ivan Vecera) [RHEL-57768]
- net/sched: act_skbmod: convert comma to semicolon (Ivan Vecera) [RHEL-57768]
- act_ct: prepare for stolen verdict coming from conntrack and nat engine (Ivan Vecera) [RHEL-57768]
- tracing/net_sched: NULL pointer dereference in perf_trace_qdisc_reset() (Ivan Vecera) [RHEL-57768]
- net: count drops due to missing qdisc as dev->tx_drops (Ivan Vecera) [RHEL-57768]
- redhat/configs: enable TMP421 hardware monitoring sensors on aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable TMP401 hardware monitoring sensors on aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable TMP102 hardware monitoring sensors on aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable LM93 hardware monitoring sensors on aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable LM92 hardware monitoring sensors on aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable LM90 hardare monitoring sensors for aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable LM78 hardware monitoring sensors for aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable LM77 hardware monitoring sensors for aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable LM75 hardware monitoring sensors for aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable LM73 hardware monitoring sensors for aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable INA2XX hardware monitoring sensors for aarch64 (Nirmala Dalvi) [RHEL-21097]
- redhat/configs: enable F71882FG hardware monitoring sensors for aarch64 (Nirmala Dalvi) [RHEL-21097]
- RDMA/mlx4: Simplify an alloc_ordered_workqueue() invocation (Benjamin Poirier) [RHEL-52873]
- RDMA/mlx4: Simplify an alloc_ordered_workqueue() invocation (Benjamin Poirier) [RHEL-52873]
- net/mlx4: Add support for EEPROM high pages query for QSFP/QSFP+/QSFP28 (Benjamin Poirier) [RHEL-52873]
- RDMA/mlx4: Fix truncated output warning in alias_GUID.c (Benjamin Poirier) [RHEL-52873]
- RDMA/mlx4: Fix truncated output warning in mad.c (Benjamin Poirier) [RHEL-52873]
- net/mlx4_en: Use ethtool_puts/sprintf to fill stats strings (Benjamin Poirier) [RHEL-52873]
- net/mlx4_en: Use ethtool_puts to fill selftest strings (Benjamin Poirier) [RHEL-52873]
- net/mlx4_en: Use ethtool_puts to fill priv flags strings (Benjamin Poirier) [RHEL-52873]
- net/mlx4: support per-queue statistics via netlink (Benjamin Poirier) [RHEL-52873]
- net/mlx4: link NAPI instances to queues and IRQs (Benjamin Poirier) [RHEL-52873]
- net/mlx4: Track RX allocation failures in a stat (Benjamin Poirier) [RHEL-52873]
- net: ethernet: mlx4: remove unused struct 'mlx4_port_config' (Benjamin Poirier) [RHEL-52873]
- mlx4: Address spelling errors (Benjamin Poirier) [RHEL-52873]
- i40e: Fix handling changed priv flags (Kamal Heib) [RHEL-30524]
- PCI: qcom: Use OPP only if the platform supports it (Myron Stowe) [RHEL-65598]
- PCI: qcom-ep: Disable MHI RAM data parity error interrupt for SA8775P SoC (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Do not enable watermark interrupts for HDMA (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Fix unmasking STOP and ABORT interrupts for HDMA (Myron Stowe) [RHEL-65598]
- PCI: qcom: Prevent use of uninitialized data in qcom_pcie_suspend_noirq() (Myron Stowe) [RHEL-65598]
- PCI: qcom: Prevent potential error pointer dereference (Myron Stowe) [RHEL-65598]
- PCI: qcom: Fix missing error code in qcom_pcie_probe() (Myron Stowe) [RHEL-65598]
- PCI: qcom: Add OPP support to scale performance (Myron Stowe) [RHEL-65598]
- PCI: Bring the PCIe speed to MBps logic to new pcie_dev_speed_mbps() (Myron Stowe) [RHEL-65598]
- PCI: qcom: Add ICC bandwidth vote for CPU to PCIe path (Myron Stowe) [RHEL-65598]
- PCI: qcom-ep: Disable resources unconditionally during PERST# assert (Myron Stowe) [RHEL-65598]
- PCI: qcom-ep: Override NO_SNOOP attribute for SA8775P EP (Myron Stowe) [RHEL-65598]
- PCI: qcom: Override NO_SNOOP attribute for SA8775P RC (Myron Stowe) [RHEL-65598]
- PCI: epf-mhi: Enable HDMA for SA8775P SoC (Myron Stowe) [RHEL-65598]
- PCI: qcom-ep: Add HDMA support for SA8775P SoC (Myron Stowe) [RHEL-65598]
- PCI: dwc: Pass the eDMA mapping format flag directly from glue drivers (Myron Stowe) [RHEL-65598]
- PCI: dwc: Skip finding eDMA channels count for HDMA platforms (Myron Stowe) [RHEL-65598]
- PCI: dwc: Refactor dw_pcie_edma_find_chip() API (Myron Stowe) [RHEL-65598]
- PCI: qcom-ep: Add support for SA8775P SOC (Myron Stowe) [RHEL-65598]
- dt-bindings: PCI: qcom-ep: Add support for SA8775P SoC (Myron Stowe) [RHEL-65598]
- PCI: qcom: Use devm_clk_bulk_get_all() API (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: eDMA: Add sync read before starting the DMA transfer in remote setup (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: HDMA: Add sync read before starting the DMA transfer in remote setup (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Add HDMA remote interrupt configuration (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: HDMA_V0_REMOTEL_STOP_INT_EN typo fix (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Fix wrong interrupt bit set for HDMA (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Fix the ch_count hdma callback (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: increase size of 'name' in debugfs code (Myron Stowe) [RHEL-65598]
- dmaengine: shdma: increase size of 'dev_id' (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Add HDMA DebugFS support (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Add support for native HDMA (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Create a new dw_edma_core_ops structure to abstract controller operation (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Rename dw_edma_core_ops structure to dw_edma_plat_ops (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Fix to enable to issue dma request on DMA processing (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Fix to change for continuous transfer (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: remove unused readq_ch and writeq_ch functions (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Remove runtime PM support (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: remove a macro conditional with similar branches (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Fix inconsistent indenting (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Fix unaligned 64bit access (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Fix return value check for dma_set_mask_and_coherent() (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma-pcie: switch from 'pci_' to 'dma_' API (Myron Stowe) [RHEL-65598]
- dmaengine: dw-edma: Remove an unused variable (Myron Stowe) [RHEL-65598]
- autofs: fix thinko in validate_dev_ioctl() (Ian Kent) [RHEL-67294]
- autofs: add per dentry expire timeout (Ian Kent) [RHEL-67294]
- idpf: fix idpf_vc_core_init error path (CKI Backport Bot) [RHEL-67141]
- idpf: avoid vport access in idpf_get_link_ksettings (CKI Backport Bot) [RHEL-67141]

* Tue Dec 03 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-538.el9]
- perf dwarf-aux: Fix build with !HAVE_DWARF_GETLOCATIONS_SUPPORT (Michael Petlan) [RHEL-29796]
- kernel.spec: Remove tools/build/Build (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync linux/stat.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync linux/prctl.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync linux/fs.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync linux/fcntl.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync linux/socket.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync asm/prctl.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync asm/irq_vectors.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync arch/mips/kernel/syscalls/syscall_n64.tbl with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync arch/s390/kernel/syscalls/syscall.tbl with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync arch/powerpc/kernel/syscalls/syscall.tbl with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync arch/x86/entry/syscalls/syscall_64.tbl with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync arch/x86/entry/syscalls/syscall_32.tbl with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync asm-generic/unistd.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync asm/svm.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync asm/kvm.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync asm/msr-index.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync asm/cpufeatures.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync asm/disabled-features.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync linux/stat.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync linux/in.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync linux/kvm.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync linux/fscrypt.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync drm/i915_drm.h with kernel (Michael Petlan) [RHEL-29796]
- tools headers UAPI: sync drm/drm.h with kernel (Michael Petlan) [RHEL-29796]
- perf cap: Add __NR_capget to arch/x86 unistd (Michael Petlan) [RHEL-29796]
- perf python: Fix up the build on architectures without HAVE_KVM_STAT_SUPPORT (Michael Petlan) [RHEL-29796]
- perf test: Handle perftool-testsuite_probe failure due to broken DWARF (Michael Petlan) [RHEL-29796]
- perf trace: Fix non-listed archs in the syscalltbl routines (Michael Petlan) [RHEL-29796]
- perf build: Change the clang check back to 12.0.1 (Michael Petlan) [RHEL-29796]
- perf trace augmented_raw_syscalls: Add more checks to pass the verifier (Michael Petlan) [RHEL-29796]
- perf trace augmented_raw_syscalls: Add extra array index bounds checking to satisfy some BPF verifiers (Michael Petlan) [RHEL-29796]
- perf trace: The return from 'write' isn't a pid (Michael Petlan) [RHEL-29796]
- perf tools: Update copy of libbpf's hashmap.c (Michael Petlan) [RHEL-29796]
- perf cs-etm: Fix the assert() to handle captured and unprocessed cpu trace (Michael Petlan) [RHEL-29796]
- perf build: Fix build feature-dwarf_getlocations fail for old libdw (Michael Petlan) [RHEL-29796]
- perf build: Fix static compilation error when libdw is not installed (Michael Petlan) [RHEL-29796]
- perf tools: Cope with differences for lib/list_sort.c copy from the kernel (Michael Petlan) [RHEL-29796]
- tools check_headers.sh: Add check variant that excludes some hunks (Michael Petlan) [RHEL-29796]
- tools headers UAPI: Sync the linux/in.h with the kernel sources (Michael Petlan) [RHEL-29796]
- perf vdso: Missed put on 32-bit dsos (Michael Petlan) [RHEL-29796]
- perf symbol: Set binary_type of dso when loading (Michael Petlan) [RHEL-29796]
- perf trace: Mark the 'head' arg in the set_robust_list syscall as coming from user space (Michael Petlan) [RHEL-29796]
- perf trace: Mark the 'rseq' arg in the rseq syscall as coming from user space (Michael Petlan) [RHEL-29796]
- perf env: Find correct branch counter info on hybrid (Michael Petlan) [RHEL-29796]
- perf evlist: Print hint for group (Michael Petlan) [RHEL-29796]
- tools: Drop nonsensical -O6 (Michael Petlan) [RHEL-29796]
- perf evsel: Add accessor for tool_event (Michael Petlan) [RHEL-29796]
- perf pmus: Fake PMU clean up (Michael Petlan) [RHEL-29796]
- perf list: Avoid potential out of bounds memory read (Michael Petlan) [RHEL-29796]
- perf help: Fix a typo ("bellow") (Michael Petlan) [RHEL-29796]
- perf ftrace: Detect whether ftrace is enabled on system (Michael Petlan) [RHEL-29796]
- perf test shell probe_vfs_getname: Remove extraneous '=' from probe line number regex (Michael Petlan) [RHEL-29796]
- perf build: Require at least clang 16.0.6 to build BPF skeletons (Michael Petlan) [RHEL-29796]
- perf trace: If a syscall arg is marked as 'const', assume it is coming _from_ userspace (Michael Petlan) [RHEL-29796]
- perf parse-events: Remove duplicated include in parse-events.c (Michael Petlan) [RHEL-29796]
- perf callchain: Allow symbols to be optional when resolving a callchain (Michael Petlan) [RHEL-29796]
- perf inject: Lazy build-id mmap2 event insertion (Michael Petlan) [RHEL-29796]
- perf inject: Add new mmap2-buildid-all option (Michael Petlan) [RHEL-29796]
- perf inject: Fix build ID injection (Michael Petlan) [RHEL-29796]
- perf annotate-data: Add pr_debug_scope() (Michael Petlan) [RHEL-29796]
- perf annotate: Treat 'call' instruction as stack operation (Michael Petlan) [RHEL-29796]
- perf build: Remove unused feature test target (Michael Petlan) [RHEL-29796]
- perf build: Autodetect minimum required llvm-dev version (Michael Petlan) [RHEL-29796]
- perf trace: Mark the rlim arg in the prlimit64 and setrlimit syscalls as coming from user space (Michael Petlan) [RHEL-29796]
- perf trace: Support collecting 'union's with the BPF augmenter (Michael Petlan) [RHEL-29796]
- perf trace: Add --force-btf for debugging (Michael Petlan) [RHEL-29796]
- perf trace: Collect augmented data using BPF (Michael Petlan) [RHEL-29796]
- perf trace: Pretty print buffer data (Michael Petlan) [RHEL-29796]
- perf trace: Pretty print struct data (Michael Petlan) [RHEL-29796]
- perf trace: Add trace__bpf_sys_enter_beauty_map() to prepare for fetching data in BPF (Michael Petlan) [RHEL-29796]
- perf trace: Mark bpf's attr as from_user (Michael Petlan) [RHEL-29796]
- perf trace: Introduce SCA_TIMESPEC_FROM_USER() to set .from_user = true (Michael Petlan) [RHEL-29796]
- perf trace: Introduce SCA_SOCKADDR_FROM_USER() to set .from_user = true (Michael Petlan) [RHEL-29796]
- perf trace: Introduce SCA_PERF_ATTR_FROM_USER() to set .from_user = true (Michael Petlan) [RHEL-29796]
- perf trace: Mark which syscall arguments go from user space to kernel space (Michael Petlan) [RHEL-29796]
- perf trace: Use a common encoding for augmented arguments, with size + error + payload (Michael Petlan) [RHEL-29796]
- perf trace augmented_syscalls.bpf: Move the renameat aumenter to renameat2, temporarily (Michael Petlan) [RHEL-29796]
- perf mem: Fix the wrong reference in parse_record_events() (Michael Petlan) [RHEL-29796]
- perf mem: Fix missed p-core mem events on ADL and RPL (Michael Petlan) [RHEL-29796]
- perf mem: Check mem_events for all eligible PMUs (Michael Petlan) [RHEL-29796]
- perf script python: Avoid buffer overflow in python PEBS register interface (Michael Petlan) [RHEL-29796]
- perf jevents: Ignore sys when determining a model directory (Michael Petlan) [RHEL-29796]
- perf check: Fix inconsistencies in feature names (Michael Petlan) [RHEL-29796]
- perf tests probe_vfs_getname.sh: Update to use 'perf check feature' (Michael Petlan) [RHEL-29796]
- perf tools test_task_analyzer.sh: Update to use 'perf check feature' (Michael Petlan) [RHEL-29796]
- perf version: Update --build-options to use 'supported_features' array (Michael Petlan) [RHEL-29796]
- perf jevents: Add cpuid to model lookup command (Michael Petlan) [RHEL-29796]
- perf check: Introduce 'check' subcommand (Michael Petlan) [RHEL-29796]
- libsubcmd: Don't free the usage string (Michael Petlan) [RHEL-29796]
- perf parse-events: Vary default_breakpoint_len on i386 and arm64 (Michael Petlan) [RHEL-29796]
- perf parse-events: Add default_breakpoint_len helper (Michael Petlan) [RHEL-29796]
- perf parse-events: Pass cpu_list as a perf_cpu_map in __add_event() (Michael Petlan) [RHEL-29796]
- perf pmu: Merge boolean sysfs event option parsing (Michael Petlan) [RHEL-29796]
- perf sched timehist: Add --prio option (Michael Petlan) [RHEL-29796]
- perf sched timehist: Add --show-prio option (Michael Petlan) [RHEL-29796]
- perf sched timehist: Remove redundant BUG_ON in timehist_sched_change_event() (Michael Petlan) [RHEL-29796]
- perf sched timehist: Skip print non-idle task samples when only show idle events (Michael Petlan) [RHEL-29796]
- perf record offcpu: Constify control data for BPF (Michael Petlan) [RHEL-29796]
- perf lock contention: Constify control data for BPF (Michael Petlan) [RHEL-29796]
- perf kwork: Constify control data for BPF (Michael Petlan) [RHEL-29796]
- perf ftrace latency: Constify control data for BPF (Michael Petlan) [RHEL-29796]
- perf stat: Constify control data for BPF (Michael Petlan) [RHEL-29796]
- perf test: Make watchpoint data 32-bits on i386 (Michael Petlan) [RHEL-29796]
- perf test: Skip uprobe test if probe command isn't present (Michael Petlan) [RHEL-29796]
- perf time-utils: Fix 32-bit nsec parsing (Michael Petlan) [RHEL-29796]
- perf pmus: Fix name comparisons on 32-bit systems (Michael Petlan) [RHEL-29796]
- perf annotate: LLVM-based disassembler (Michael Petlan) [RHEL-29796]
- perf annotate: Split out read_symbol() (Michael Petlan) [RHEL-29796]
- perf report: Support LLVM for addr2line() (Michael Petlan) [RHEL-29796]
- perf tools: Build x86 32-bit syscall table from arch/x86/entry/syscalls/syscall_32.tbl (Michael Petlan) [RHEL-29796]
- perf sched timehist: Fixed timestamp error when unable to confirm event sched_in time (Michael Petlan) [RHEL-29796]
- perf lock contention: Do not fail EEXIST for update (Michael Petlan) [RHEL-29796]
- perf lock contention: Simplify spinlock check (Michael Petlan) [RHEL-29796]
- perf lock contention: Handle error in a single place (Michael Petlan) [RHEL-29796]
- perf test: Additional pipe tests with pipe output written to a file (Michael Petlan) [RHEL-29796]
- perf header: Remove repipe option (Michael Petlan) [RHEL-29796]
- perf inject: Overhaul handling of pipe files (Michael Petlan) [RHEL-29796]
- perf header: Allow attributes to be written after data (Michael Petlan) [RHEL-29796]
- perf header: Fail read if header sections overlap (Michael Petlan) [RHEL-29796]
- perf header: Add kerneldoc to 'struct perf_file_header' (Michael Petlan) [RHEL-29796]
- perf session: Document 'struct perf_session' and constify its 'auxtrace' member (Michael Petlan) [RHEL-29796]
- perf: cs-etm: Print queue number in raw trace dump (Michael Petlan) [RHEL-29796]
- perf: cs-etm: Support version 0.1 of HW_ID packets (Michael Petlan) [RHEL-29796]
- perf: cs-etm: Only save valid trace IDs into files (Michael Petlan) [RHEL-29796]
- perf: cs-etm: Create decoders based on the trace ID mappings (Michael Petlan) [RHEL-29796]
- perf: cs-etm: Move traceid_list to each queue (Michael Petlan) [RHEL-29796]
- perf: cs-etm: Allocate queues for all CPUs (Michael Petlan) [RHEL-29796]
- perf cs-etm: Create decoders after both AUX and HW_ID search passes (Michael Petlan) [RHEL-29796]
- perf test: Add 'perf record cgroup' filtering test (Michael Petlan) [RHEL-29796]
- perf bpf-filter: Support filtering on cgroups (Michael Petlan) [RHEL-29796]
- perf bpf-filter: Add build dependency to header files (Michael Petlan) [RHEL-29796]
- perf report: Fix segfault when 'sym' sort key is not used (Michael Petlan) [RHEL-29796]
- perf test trace_btf_enum: Fix shellcheck warning (Michael Petlan) [RHEL-29796]
- perf auxtrace: Remove unused 'pmu' pointer from struct auxtrace_record (Michael Petlan) [RHEL-29796]
- perf auxtrace: Use evsel__is_aux_event() for checking AUX event (Michael Petlan) [RHEL-29796]
- perf vendor events arm64: Move Yitian 710 DDR PMU into T-Head directory (Michael Petlan) [RHEL-29796]
- perf vendor events: Move PM_BR_MPRED_CMPL event for power10 platform (Michael Petlan) [RHEL-29796]
- perf vendor events power10: Move the JSON/events (Michael Petlan) [RHEL-29796]
- perf vendor events power10: Update JSON/events (Michael Petlan) [RHEL-29796]
- perf trace: Pass the richer 'struct syscall_arg' pointer to trace__btf_scnprintf() (Michael Petlan) [RHEL-29796]
- perf trace: Fix perf trace -p <PID> (Michael Petlan) [RHEL-29796]
- perf evlist: Introduce method to find if there is a bpf-output event (Michael Petlan) [RHEL-29796]
- perf report: Name events in stats for pipe mode (Michael Petlan) [RHEL-29796]
- perf testsuite: Install perf-report tests in the 'make install-tests -C tools/perf' target (Michael Petlan) [RHEL-29796]
- perf testsuite report: Add test case for perf report (Michael Petlan) [RHEL-29796]
- perf testsuite report: Add test for perf-report basic functionality (Michael Petlan) [RHEL-29796]
- perf testsuite: Add common output checking helper (Michael Petlan) [RHEL-29796]
- perf testsuite probe: Add test for line semantics (Michael Petlan) [RHEL-29796]
- perf testsuite probe: Add test for invalid options (Michael Petlan) [RHEL-29796]
- perf testsuite probe: Add test for basic perf-probe options (Michael Petlan) [RHEL-29796]
- perf testsuite probe: Add test for blacklisted kprobes handling (Michael Petlan) [RHEL-29796]
- perf testsuite: Fix shellcheck warnings (Michael Petlan) [RHEL-29796]
- perf testsuite: Merge settings files for shell tests (Michael Petlan) [RHEL-29796]
- perf tests shell: Skip base_* dirs in test script search (Michael Petlan) [RHEL-29796]
- perf test vfs_getname: Look for alternative line where to collect the pathname (Michael Petlan) [RHEL-29796]
- perf test: Update sample filtering tests with multiple events (Michael Petlan) [RHEL-29796]
- perf tools: Print lost samples due to BPF filter (Michael Petlan) [RHEL-29796]
- perf bpf-filter: Support multiple events properly (Michael Petlan) [RHEL-29796]
- perf hist: Don't set hpp_fmt_value for members in --no-group (Michael Petlan) [RHEL-29796]
- perf test: Support external tests for separate objdir (Michael Petlan) [RHEL-29796]
- perf python: Disable -Wno-cast-function-type-mismatch if present on clang (Michael Petlan) [RHEL-29796]
- perf python: Allow checking for the existence of warning options in clang (Michael Petlan) [RHEL-29796]
- perf annotate-data: Copy back variable types after move (Michael Petlan) [RHEL-29796]
- perf annotate-data: Update stack slot for the store (Michael Petlan) [RHEL-29796]
- perf annotate-data: Update debug messages (Michael Petlan) [RHEL-29796]
- perf dwarf-aux: Handle bitfield members from pointer access (Michael Petlan) [RHEL-29796]
- perf annotate-data: Add 'typecln' sort key (Michael Petlan) [RHEL-29796]
- perf annotate-data: Show offset and size in hex (Michael Petlan) [RHEL-29796]
- perf bpf: Remove redundant check that map is NULL (Michael Petlan) [RHEL-29796]
- perf annotate-data: Fix percpu pointer check (Michael Petlan) [RHEL-29796]
- perf annotate-data: Prefer struct/union over base type (Michael Petlan) [RHEL-29796]
- perf annotate-data: Fix missing constant copy (Michael Petlan) [RHEL-29796]
- perf cap: Tidy up and improve capability testing (Michael Petlan) [RHEL-29796]
- perf annotate-data: Set bitfield member offset and size properly (Michael Petlan) [RHEL-29796]
- perf test: Add cgroup sampling test (Michael Petlan) [RHEL-29796]
- perf record: Fix sample cgroup & namespace tracking (Michael Petlan) [RHEL-29796]
- perf inject: Combine mmap and mmap2 handling (Michael Petlan) [RHEL-29796]
- perf inject: Combine different mmap and mmap2 functions (Michael Petlan) [RHEL-29796]
- perf inject: Combine build_ids and build_id_all into enum (Michael Petlan) [RHEL-29796]
- perf test: Expand pipe/inject test (Michael Petlan) [RHEL-29796]
- perf evsel: Constify evsel__id_hdr_size() argument (Michael Petlan) [RHEL-29796]
- perf dso: Constify dso_id (Michael Petlan) [RHEL-29796]
- perf jit: Constify filename argument (Michael Petlan) [RHEL-29796]
- perf map: API clean up (Michael Petlan) [RHEL-29796]
- perf synthetic-events: Avoid unnecessary memset (Michael Petlan) [RHEL-29796]
- perf annotate-data: Update type stat at the end of find_data_type_die() (Michael Petlan) [RHEL-29796]
- perf annotate-data: Check variables in every scope (Michael Petlan) [RHEL-29796]
- perf annotate-data: Add is_better_type() helper (Michael Petlan) [RHEL-29796]
- perf annotate-data: Add is_pointer_type() helper (Michael Petlan) [RHEL-29796]
- perf annotate-data: Change return type of find_data_type_block() (Michael Petlan) [RHEL-29796]
- perf annotate-data: Add variable_state_str() (Michael Petlan) [RHEL-29796]
- perf annotate-data: Add 'enum type_match_result' (Michael Petlan) [RHEL-29796]
- perf annotate-data: Fix off-by-one in location range check (Michael Petlan) [RHEL-29796]
- perf dwarf-aux: Check allowed location expressions when collecting variables (Michael Petlan) [RHEL-29796]
- perf stat: Display iostat headers correctly (Michael Petlan) [RHEL-29796]
- perf sched timehist: Fix missing free of session in perf_sched__timehist() (Michael Petlan) [RHEL-29796]
- tools build: Provide consistent build options for fixdep (Michael Petlan) [RHEL-29796]
- perf hist: Update hist symbol when updating maps (Michael Petlan) [RHEL-29796]
- perf build: Fix up broken capstone feature detection fast path (Michael Petlan) [RHEL-29796]
- perf test: Add new test cases for the branch counter feature (Michael Petlan) [RHEL-29796]
- perf script: Add branch counters (Michael Petlan) [RHEL-29796]
- perf annotate: Display the branch counter histogram (Michael Petlan) [RHEL-29796]
- perf report: Display the branch counter histogram (Michael Petlan) [RHEL-29796]
- perf evsel: Assign abbr name for the branch counter events (Michael Petlan) [RHEL-29796]
- perf annotate: Save branch counters for each block (Michael Petlan) [RHEL-29796]
- perf evlist: Save branch counters information (Michael Petlan) [RHEL-29796]
- perf report: Remove the first overflow check for branch counters (Michael Petlan) [RHEL-29796]
- perf report: Fix --total-cycles --stdio output error (Michael Petlan) [RHEL-29796]
- perf test annotate: Dump trapping test in trap handler (Michael Petlan) [RHEL-29796]
- perf disasm: Fix memory leak for locked operations (Michael Petlan) [RHEL-29796]
- perf inject: Inject build ids for entire call chain (Michael Petlan) [RHEL-29796]
- perf callchain: Add a for_each callback style API (Michael Petlan) [RHEL-29796]
- perf test: Add test for Intel TPEBS counting mode (Michael Petlan) [RHEL-29796]
- perf Document: Add TPEBS (Timed PEBS(Precise Event-Based Sampling)) to Documents (Michael Petlan) [RHEL-29796]
- perf stat: Add command line option for enabling TPEBS recording (Michael Petlan) [RHEL-29796]
- perf vendor events intel: Add MTL metric JSON files (Michael Petlan) [RHEL-29796]
- perf stat: Fork and launch 'perf record' when 'perf stat' needs to get retire latency value for a metric. (Michael Petlan) [RHEL-29796]
- perf data: Allow to use given fd in data->file.fd (Michael Petlan) [RHEL-29796]
- perf parse-events: Add a retirement latency modifier (Michael Petlan) [RHEL-29796]
- perf session: Constify tool (Michael Petlan) [RHEL-29796]
- perf tool: Remove perf_tool__fill_defaults() (Michael Petlan) [RHEL-29796]
- perf kwork: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf test event_update: Ensure tools is initialized (Michael Petlan) [RHEL-29796]
- perf data convert ctf: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf data convert json: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf diff: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf timechart: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf mem: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf sched: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf annotate: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf stat: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf report: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf inject: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf script: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf c2c: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf record: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf evlist: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf lock: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf kvm: Use perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf buildid-list: Use perf_tool__init (Michael Petlan) [RHEL-29796]
- perf kmem: Use perf_tool__init (Michael Petlan) [RHEL-29796]
- perf tool: Add perf_tool__init() (Michael Petlan) [RHEL-29796]
- perf tool: Move fill defaults into tool.c (Michael Petlan) [RHEL-29796]
- perf tool: Constify tool pointers (Michael Petlan) [RHEL-29796]
- perf s390-cpumsf: Remove unused struct (Michael Petlan) [RHEL-29796]
- perf auxtrace: Remove dummy tools (Michael Petlan) [RHEL-29796]
- perf inject: Fix leader sampling inserting additional samples (Michael Petlan) [RHEL-29796]
- perf annotate-data: Show first-level children by default in TUI (Michael Petlan) [RHEL-29796]
- perf annotate-data: Implement folding in TUI browser (Michael Petlan) [RHEL-29796]
- perf annotate-data: Support folding in TUI browser (Michael Petlan) [RHEL-29796]
- perf vendor events: SKX, CLX, SNR uncore cache event fixes (Michael Petlan) [RHEL-29796]
- perf lock contention: Change stack_id type to s32 (Michael Petlan) [RHEL-29796]
- perf annotate-data: Fix a buffer overflow in TUI browser (Michael Petlan) [RHEL-29796]
- perf docs: Refine the description for the buffer size (Michael Petlan) [RHEL-29796]
- perf script: add --addr2line option (Michael Petlan) [RHEL-29796]
- perf tests pmu: Initialize all fields of test_pmu variable (Michael Petlan) [RHEL-29796]
- perf annotate-data: Support --skip-empty option (Michael Petlan) [RHEL-29796]
- perf annotate: Fix --group behavior when leader has no samples (Michael Petlan) [RHEL-29796]
- perf tools: Create source symlink in perf object dir (Michael Petlan) [RHEL-29796]
- perf debuginfo: Fix the build with !HAVE_DWARF_SUPPORT (Michael Petlan) [RHEL-29796]
- perf script python: Add the 'ins_lat' field to event handler (Michael Petlan) [RHEL-29796]
- perf test shell lbr: Support hybrid x86 systems too (Michael Petlan) [RHEL-29796]
- perf test: Add set of perf record LBR tests (Michael Petlan) [RHEL-29796]
- perf callchain: Fix stitch LBR memory leaks (Michael Petlan) [RHEL-29796]
- perf tests ftrace: Add pattern check for time, count (Michael Petlan) [RHEL-29796]
- perf test: Add a new shell test for perf ftrace (Michael Petlan) [RHEL-29796]
- perf annotate-data: Show typedef names properly (Michael Petlan) [RHEL-29796]
- perf annotate: Cache debuginfo for data type profiling (Michael Petlan) [RHEL-29796]
- perf hist: Fix reference counting of branch_info (Michael Petlan) [RHEL-29796]
- perf jevents.py: Ensure event names aren't duplicated (Michael Petlan) [RHEL-29796]
- perf pmu-events: Remove duplicated ampereone event (Michael Petlan) [RHEL-29796]
- perf pmu-events: Change dependencies for empty-pmu-events.c test (Michael Petlan) [RHEL-29796]
- perf test: Add build test for JEVENTS_ARCH=all (Michael Petlan) [RHEL-29796]
- perf annotate: Add --skip-empty option (Michael Petlan) [RHEL-29796]
- perf annotate: Set al->data_nr using the notes->src->nr_events (Michael Petlan) [RHEL-29796]
- perf annotate: Use annotation__pcnt_width() consistently (Michael Petlan) [RHEL-29796]
- perf annotate: Set notes->src->nr_events early (Michael Petlan) [RHEL-29796]
- perf annotate: Use al->data_nr if possible (Michael Petlan) [RHEL-29796]
- tools build: Correct bpf fixdep dependencies (Michael Petlan) [RHEL-29796]
- tools build: Avoid circular .fixdep-in.o.cmd issues (Michael Petlan) [RHEL-29796]
- tools build: Correct libsubcmd fixdep dependencies (Michael Petlan) [RHEL-29796]
- perf mem: Update documentation for new options (Michael Petlan) [RHEL-29796]
- perf mem: Add -T/--data-type option to report subcommand (Michael Petlan) [RHEL-29796]
- perf mem: Add -s/--sort option (Michael Petlan) [RHEL-29796]
- perf tools: Add mode argument to sort_help() (Michael Petlan) [RHEL-29796]
- perf mem: Rework command option handling (Michael Petlan) [RHEL-29796]
- perf mem: Free the allocated sort string, fixing a leak (Michael Petlan) [RHEL-29796]
- perf hist: Correct hist_entry->mem_info refcounts (Michael Petlan) [RHEL-29796]
- perf python: Remove PYTHON_PERF ifdefs (Michael Petlan) [RHEL-29796]
- perf jevents: Autogenerate empty-pmu-events.c (Michael Petlan) [RHEL-29796]
- perf bpf: Move BPF disassembly routines to separate file to avoid clash with capstone bpf headers (Michael Petlan) [RHEL-29796]
- perf test: Update sample filtering test (Michael Petlan) [RHEL-29796]
- perf record: Add --setup-filter option (Michael Petlan) [RHEL-29796]
- perf record: Fix a potential error handling issue (Michael Petlan) [RHEL-29796]
- perf bpf-filter: Support separate lost counts for each filter (Michael Petlan) [RHEL-29796]
- perf bpf-filter: Support pin/unpin BPF object (Michael Petlan) [RHEL-29796]
- perf bpf-filter: Split per-task filter use case (Michael Petlan) [RHEL-29796]
- perf bpf-filter: Pass 'target' to perf_bpf_filter__prepare() (Michael Petlan) [RHEL-29796]
- perf bpf-filter: Make filters map a single entry hashmap (Michael Petlan) [RHEL-29796]
- perf jevents: Use name for special find value (PMU_EVENTS__NOT_FOUND) (Michael Petlan) [RHEL-29796]
- perf list: Give clues if failed to open tracing events directory (Michael Petlan) [RHEL-29796]
- perf tools: Fix wrong message when running "make JOBS=1" (Michael Petlan) [RHEL-29796]
- libperf: Add gitignore (Michael Petlan) [RHEL-29796]
- perf arm-spe: Support multiple Arm SPE events (Michael Petlan) [RHEL-29796]
- perf arm-spe: Extract evsel setting up (Michael Petlan) [RHEL-29796]
- perf test: make metric validation test return early when there is no metric supported on the test system (Michael Petlan) [RHEL-29796]
- perf ftrace profile: Add -s/--sort option (Michael Petlan) [RHEL-29796]
- perf ftrace: Add 'profile' command (Michael Petlan) [RHEL-29796]
- perf ftrace: Factor out check_ftrace_capable() (Michael Petlan) [RHEL-29796]
- perf ftrace: Add 'tail' option to --graph-opts (Michael Petlan) [RHEL-29796]
- perf test pmu: Remove unused test_pmus (Michael Petlan) [RHEL-29796]
- perf tools: Enable evsel__is_aux_event() to work for S390_CPUMSF (Michael Petlan) [RHEL-29796]
- perf tools: Enable evsel__is_aux_event() to work for ARM/ARM64 (Michael Petlan) [RHEL-29796]
- perf scripts python cs-etm: Restore first sample log in verbose mode (Michael Petlan) [RHEL-29796]
- perf cs-etm: Output 0 instead of 0xdeadbeef when exception packets are flushed (Michael Petlan) [RHEL-29796]
- perf inject: Convert comma to semicolon (Michael Petlan) [RHEL-29796]
- perf daemon: Convert comma to semicolon (Michael Petlan) [RHEL-29796]
- perf annotate: Convert comma to semicolon (Michael Petlan) [RHEL-29796]
- perf vendor events power10: Update JSON/events (Michael Petlan) [RHEL-29796]
- perf annotate: Set instruction name to be used with insn-stat when using raw instruction (Michael Petlan) [RHEL-29796]
- perf annotate: Add support to use libcapstone in powerpc (Michael Petlan) [RHEL-29796]
- perf annotate: Use capstone_init and remove open_capstone_handle from disasm.c (Michael Petlan) [RHEL-29796]
- perf annotate: Make capstone_init non-static so that it can be used during symbol disassemble (Michael Petlan) [RHEL-29796]
- perf annotate: Update instruction tracking for powerpc (Michael Petlan) [RHEL-29796]
- perf annotate: Add more instructions for instruction tracking (Michael Petlan) [RHEL-29796]
- perf annotate: Add some of the arithmetic instructions to support instruction tracking in powerpc (Michael Petlan) [RHEL-29796]
- perf annotate: Add support to identify memory instructions of opcode 31 in powerpc (Michael Petlan) [RHEL-29796]
- perf annotate: Add parse function for memory instructions in powerpc (Michael Petlan) [RHEL-29796]
- perf annotate: Update parameters for reg extract functions to use raw instruction on powerpc (Michael Petlan) [RHEL-29796]
- perf annotate: Add support to capture and parse raw instruction in powerpc using dso__data_read_offset utility (Michael Petlan) [RHEL-29796]
- perf annotate: Add disasm_line__parse() to parse raw instruction for powerpc (Michael Petlan) [RHEL-29796]
- perf annotate: Update TYPE_STATE_MAX_REGS to include max of regs in powerpc (Michael Petlan) [RHEL-29796]
- perf annotate: Add "update_insn_state" callback function to handle arch specific instruction tracking (Michael Petlan) [RHEL-29796]
- perf annotate: Move the data structures related to register type to header file (Michael Petlan) [RHEL-29796]
- perf test: Avoid python leak sanitizer test failures (Michael Petlan) [RHEL-29796]
- perf trace: Remove arg_fmt->is_enum, we can get that from the BTF type (Michael Petlan) [RHEL-29796]
- perf trace: Introduce trace__btf_scnprintf() (Michael Petlan) [RHEL-29796]
- perf test trace_btf_enum: Add regression test for the BTF augmentation of enums in 'perf trace' (Michael Petlan) [RHEL-29796]
- perf test: Add landlock workload (Michael Petlan) [RHEL-29796]
- perf trace: Filter enum arguments with enum names (Michael Petlan) [RHEL-29796]
- perf trace: Augment non-syscall tracepoints with enum arguments with BTF (Michael Petlan) [RHEL-29796]
- perf trace: BTF-based enum pretty printing for syscall args (Michael Petlan) [RHEL-29796]
- perf: Fix missing RCU reader protection in perf_event_clear_cpumask() (Michael Petlan) [RHEL-29796]
- perf: Fix topology_sibling_cpumask check warning on ARM (Michael Petlan) [RHEL-29796]
- dmaengine: idxd: Clean up cpumask and hotplug for perfmon (Michael Petlan) [RHEL-29796]
- iommu/vt-d: Clean up cpumask and hotplug for perfmon (Michael Petlan) [RHEL-29796]
- perf/x86/intel/cstate: Clean up cpumask and hotplug (Michael Petlan) [RHEL-29796]
- perf: Add PERF_EV_CAP_READ_SCOPE (Michael Petlan) [RHEL-29796]
- perf: Generic hotplug support for a PMU with a scope (Michael Petlan) [RHEL-29796]
- perf/core: Fix small negative period being ignored (Michael Petlan) [RHEL-29796]
- perf: Really fix event_function_call() locking (Michael Petlan) [RHEL-29796]
- perf: Optimize __pmu_ctx_sched_out() (Michael Petlan) [RHEL-29796]
- perf: Add context time freeze (Michael Petlan) [RHEL-29796]
- perf: Fix event_function_call() locking (Michael Petlan) [RHEL-29796]
- perf: Extract a few helpers (Michael Petlan) [RHEL-29796]
- perf: Optimize context reschedule for single PMU cases (Michael Petlan) [RHEL-29796]
- perf/x86/intel/bts: Fix comment about default perf_event_paranoid setting (Michael Petlan) [RHEL-29796]
- perf,x86: avoid missing caller address in stack traces captured in uprobe (Michael Petlan) [RHEL-29796]
- perf/x86/intel/pt: Fix sampling synchronization (Michael Petlan) [RHEL-29796]
- perf/x86/intel: Allow to setup LBR for counting event for BPF (Michael Petlan) [RHEL-29796]
- drivers/perf: arm_spe: Use perf_allow_kernel() for permissions (Michael Petlan) [RHEL-29796]
- perf: Support PERF_SAMPLE_READ with inherit (Michael Petlan) [RHEL-29796]
- perf: Rename perf_event_context.nr_pending to nr_no_switch_fast. (Michael Petlan) [RHEL-29796]
- perf/x86: Add hw_perf_event::aux_config (Michael Petlan) [RHEL-29796]

* Mon Dec 02 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-537.el9]
- smb: client: Handle kstrdup failures for passwords (Paulo Alcantara) [RHEL-65939] {CVE-2024-50120}
- fs/inode: Prevent dump_mapping() accessing invalid dentry.d_name.name (CKI Backport Bot) [RHEL-64530] {CVE-2024-49934}
- mptcp: init: protect sched with rcu_read_lock (CKI Backport Bot) [RHEL-68179] {CVE-2024-53047}
- ARM: 9361/1: amba: store owner from modules with amba_driver_register() (Mark Salter) [RHEL-56484]
- amba: bus: balance firmware node reference counting (Mark Salter) [RHEL-56484]
- of/platform: increase refcount of fwnode (Mark Salter) [RHEL-56484]
- of/platform: Propagate firmware node by calling device_set_node() (Mark Salter) [RHEL-56484]
- amba: bus: fix refcount leak (Mark Salter) [RHEL-56484]
- amba: move to_amba_device() to use container_of_const (Mark Salter) [RHEL-56484]
- ARM: tegra: Remove MODULE_LICENSE in non-modules (Mark Salter) [RHEL-56484]
- ARM: 9261/1: amba: Drop redundant assignments of the system PM callbacks (Mark Salter) [RHEL-56484]
- ARM: 9229/1: amba: Fix use-after-free in amba_read_periphid() (Mark Salter) [RHEL-56484]
- ARM: 9220/1: amba: Remove deferred device addition (Mark Salter) [RHEL-56484]
- ARM: 9207/1: amba: fix refcount underflow if amba_device_add() fails (Mark Salter) [RHEL-56484]
- ARM: 9192/1: amba: fix memory leak in amba_device_try_add() (Mark Salter) [RHEL-56484]
- ARM: 9193/1: amba: Add amba_read_periphid() helper (Mark Salter) [RHEL-56484]
- amba: Use driver_set_override() instead of open-coding (Mark Salter) [RHEL-56484]
- ARM: 9174/1: amba: Move EXPORT_SYMBOL() closer to definition (Mark Salter) [RHEL-56484]
- ARM: 9173/1: amba: kill amba_find_match() (Mark Salter) [RHEL-56484]
- ARM: 9172/1: amba: Cleanup amba pclk operation (Mark Salter) [RHEL-56484]
- ARM: 9163/1: amba: Move of_amba_device_decode_irq() into amba_probe() (Mark Salter) [RHEL-56484]
- ARM: 9162/1: amba: Kill sysfs attribute file of irq (Mark Salter) [RHEL-56484]
- ARM: 9121/1: amba: Drop unused functions about APB/AHB devices add (Mark Salter) [RHEL-56484]
- KVM: selftests: Allow skipping the KVM_RUN sanity check in rseq_test (Vitaly Kuznetsov) [RHEL-28186]
- smb: client: fix OOBs when building SMB2_IOCTL request (Paulo Alcantara) [RHEL-66476] {CVE-2024-50151}
- smb: client: fix possible double free in smb2_set_ea() (Paulo Alcantara) [RHEL-66493] {CVE-2024-50152}
- libeth: add Tx buffer completion helpers (Petr Oros) [RHEL-59099]
- net: intel: Remove MODULE_AUTHORs (Petr Oros) [RHEL-59099]
- libeth: support different types of buffers for Rx (Petr Oros) [RHEL-59099]
- libeth: add cacheline / struct layout assertion helpers (Petr Oros) [RHEL-59099]
- net: intel: Use *-y instead of *-objs in Makefile (Petr Oros) [RHEL-59099]
- libeth: add Rx buffer management (Petr Oros) [RHEL-59099]
- net: intel: introduce {, Intel} Ethernet common library (Petr Oros) [RHEL-59099]
- e1000e: Remove Meteor Lake SMBUS workarounds (Ivan Vecera) [RHEL-49812]
- e1000e: change I219 (19) devices to ADP (Ivan Vecera) [RHEL-49812]
- e1000e: avoid failing the system during pm_suspend (Ivan Vecera) [RHEL-49812]
- net: intel: Remove MODULE_AUTHORs (Ivan Vecera) [RHEL-49812]
- e1000e: fix force smbus during suspend flow (Ivan Vecera) [RHEL-49812]
- e1000e: Fix S0ix residency on corporate systems (Ivan Vecera) [RHEL-49812]
- net: intel: Use *-y instead of *-objs in Makefile (Ivan Vecera) [RHEL-49812]
- e1000e: move force SMBUS near the end of enable_ulp function (Ivan Vecera) [RHEL-49812]
- net: e1000e & ixgbe: Remove PCI_HEADER_TYPE_MFD duplicates (Ivan Vecera) [RHEL-49812]
- e1000e: change usleep_range to udelay in PHY mdic access (Ivan Vecera) [RHEL-49812]
- e1000e: Remove redundant runtime resume for ethtool_ops (Ivan Vecera) [RHEL-49812]
- net: intel: implement modern PM ops declarations (Ivan Vecera) [RHEL-49812]
- e1000e: move force SMBUS from enable ulp function to avoid PHY loss issue (Ivan Vecera) [RHEL-49812]
- e1000e: Workaround for sporadic MDI error on Meteor Lake systems (Ivan Vecera) [RHEL-49812]
- intel: legacy: Partial revert of field get conversion (Ivan Vecera) [RHEL-49812]
- e1000e: Minor flow correction in e1000_shutdown function (Ivan Vecera) [RHEL-49812]
- e1000e: correct maximum frequency adjustment values (Ivan Vecera) [RHEL-49812]
- intel: legacy: field get conversion (Ivan Vecera) [RHEL-49812]
- intel: legacy: field prep conversion (Ivan Vecera) [RHEL-49812]
- e1000e: make lost bits explicit (Ivan Vecera) [RHEL-49812]
- e1000e: Use pcie_capability_read_word() for reading LNKSTA (Ivan Vecera) [RHEL-49812]
- e1000e: Use PCI_EXP_LNKSTA_NLW & FIELD_GET() instead of custom defines/code (Ivan Vecera) [RHEL-49812]
- ipv4: ip_tunnel: Fix suspicious RCU usage warning in ip_tunnel_find() (Guillaume Nault) [RHEL-68205] {CVE-2024-50304}
- ipv4: ip_tunnel: Fix suspicious RCU usage warning in ip_tunnel_init_flow() (Guillaume Nault) [RHEL-68250] {CVE-2024-53042}
- Bluetooth: ISO: Fix UAF on iso_sock_timeout (CKI Backport Bot) [RHEL-66320] {CVE-2024-50124}

* Thu Nov 28 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-536.el9]
- gfs2: Get rid of demote_ok checks (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Remove freeze_go_demote_ok (Andreas Gruenbacher) [RHEL-67675]
- Revert "GFS2: Don't add all glocks to the lru" (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Revise glock reference counting model (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Add GL_NOBLOCK flag (Andreas Gruenbacher) [RHEL-67675]
- gfs2: fix double destroy_workqueue error (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Switch to a per-filesystem glock workqueue (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Report when glocks cannot be freed for a long time (Andreas Gruenbacher) [RHEL-67675]
- gfs2: gfs2_glock_get cleanup (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Invert the GLF_INITIAL flag (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Remove outdated comment in glock_work_func (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Update glocks documentation (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Rename handle_callback to request_demote (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Rename GLF_FROZEN to GLF_HAVE_FROZEN_REPLY (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Rename GLF_REPLY_PENDING to GLF_HAVE_REPLY (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Rename GLF_FREEING to GLF_UNLOCKED (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Remove useless return statement in run_queue (Andreas Gruenbacher) [RHEL-67675]
- gfs2: Remove unnecessary function prototype (Andreas Gruenbacher) [RHEL-67675]
- gfs2: dynamically allocate the gfs2-qd shrinker (Andreas Gruenbacher) [RHEL-67675]
- gfs2: dynamically allocate the gfs2-glock shrinker (Andreas Gruenbacher) [RHEL-67675]
- Bluetooth: RFCOMM: FIX possible deadlock in rfcomm_sk_state_change (CKI Backport Bot) [RHEL-63971] {CVE-2024-50044}
- selftests/mm: relax test to fail after 100 migration failures (Radostin Stoyanov) [RHEL-62703]
- perf dso: Fix symtab_type for kmod compression (Michael Petlan) [RHEL-62198]
- Bluetooth: HCI: Fix potential null-ptr-deref (CKI Backport Bot) [RHEL-38466] {CVE-2024-36011}
- RDMA/bnxt_re: Check cqe flags to know imm_data vs inv_irkey (Mohammad Heib) [RHEL-67317]
- RDMA/bnxt_re: Remove some dead code (Mohammad Heib) [RHEL-67317]
- RDMA/bnxt_re: Fix some error handling paths in bnxt_re_probe() (Mohammad Heib) [RHEL-67317]
- RDMA/bnxt_re: synchronize the qp-handle table array (Mohammad Heib) [RHEL-67317]
- RDMA/bnxt_re: Fix the usage of control path spin locks (Mohammad Heib) [RHEL-67317]
- bnxt_re: Fix imm_data endianness (Mohammad Heib) [RHEL-67317]
- Bluetooth: hci: fix null-ptr-deref in hci_read_supported_codecs (CKI Backport Bot) [RHEL-66803] {CVE-2024-50255}
- Revert "ixgbe: Manual AN-37 for troublesome link partners for X550 SFI" (Ivan Vecera) [RHEL-44950]
- Bluetooth: hci_core: Fix calling mgmt_device_connected (Bastien Nocera) [RHEL-63624] {CVE-2024-49950}
- Bluetooth: L2CAP: Fix uaf in l2cap_connect (CKI Backport Bot) [RHEL-63624] {CVE-2024-49950}
- Bluetooth: SCO: Fix UAF on sco_sock_timeout (CKI Backport Bot) [RHEL-65927] {CVE-2024-50125}
- Bluetooth: hci_sync: Fix UAF in hci_acl_create_conn_sync (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: hci_sync: Fix UAF on create_le_conn_complete (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: hci_sync: Fix UAF on hci_abort_conn_sync (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: hci_sync: Attempt to dequeue connection attempt (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: hci_sync: Add helper functions to manipulate cmd_sync queue (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: hci_conn: Fix UAF Write in __hci_acl_create_connection_sync (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: hci_conn: Always use sk_timeo as conn_timeout (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: Remove pending ACL connection attempts (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: hci_conn: Only do ACL connections sequentially (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: hci_event: Use HCI error defines instead of magic values (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: Remove superfluous call to hci_conn_check_pending() (Bastien Nocera) [RHEL-63875] {CVE-2024-50029}
- Bluetooth: Call iso_exit() on module unload (CKI Backport Bot) [RHEL-65144] {CVE-2024-50078}
- Bluetooth: ISO: Fix multiple init when debugfs is disabled (CKI Backport Bot) [RHEL-65135] {CVE-2024-50077}
- Bluetooth: bnep: fix wild-memory-access in proto_unregister (CKI Backport Bot) [RHEL-66364] {CVE-2024-50148}
- fsdax: dax_unshare_iter needs to copy entire blocks (Brian Foster) [RHEL-64959]
- fsdax: remove zeroing code from dax_unshare_iter (Brian Foster) [RHEL-64959]
- iomap: turn iomap_want_unshare_iter into an inline function (Brian Foster) [RHEL-64959]
- iomap: share iomap_unshare_iter predicate code with fsdax (Brian Foster) [RHEL-64959]
- iomap: constrain the file range passed to iomap_file_unshare (Brian Foster) [RHEL-64959]
- iomap: don't bother unsharing delalloc extents (Brian Foster) [RHEL-64959]
- iomap: improve shared block detection in iomap_unshare_iter (Brian Foster) [RHEL-64959]
- iomap: convert iomap_unshare_iter to use large folios (Brian Foster) [RHEL-64959]
- xfs: don't allocate COW extents when unsharing a hole (Brian Foster) [RHEL-64959]
- xfs: don't free cowblocks from under dirty pagecache on unshare (Brian Foster) [RHEL-64959]
- xfs: skip background cowblock trims on inodes open for write (Brian Foster) [RHEL-64959]
- uprobe: avoid out-of-bounds memory access of fetching args (Oleg Nesterov) [RHEL-64995] {CVE-2024-50067}
- uprobes: encapsulate preparation of uprobe args buffer (Oleg Nesterov) [RHEL-64995] {CVE-2024-50067}

* Wed Nov 27 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-535.el9]
- redhat: create 'crashkernel=' addons for UKI (Vitaly Kuznetsov) [RHEL-33051]
- redhat: avoid superfluous quotes in UKI cmdline addones (Vitaly Kuznetsov) [RHEL-33051]
- x86/mm: Fix a kdump kernel failure on SME system when CONFIG_IMA_KEXEC=y (Baoquan He) [RHEL-39727]
- netfilter: nft_payload: sanitize offset and length before calling skb_checksum() (CKI Backport Bot) [RHEL-66855] {CVE-2024-50251}
- cxl/port: Fix use-after-free, permit out-of-order decoder shutdown (CKI Backport Bot) [RHEL-66836] {CVE-2024-50226}
- fs/netfs/fscache_cookie: add missing "n_accesses" check (CKI Backport Bot) [RHEL-57214] {CVE-2024-45000}
- ACPI: sysfs: validate return type of _STR method (CKI Backport Bot) [RHEL-63262] {CVE-2024-49860}
- tty: n_gsm: Fix use-after-free in gsm_cleanup_mux (CKI Backport Bot) [RHEL-65117] {CVE-2024-50073}
- ACPI: PAD: fix crash in exit_round_robin() (Mark Langsdorf) [RHEL-64453] {CVE-2024-49935}
- ext4: avoid use-after-free in ext4_ext_show_leaf() (CKI Backport Bot) [RHEL-64591] {CVE-2024-49889}
- kthread: unpark only parked kthread (Radostin Stoyanov) [RHEL-63788] {CVE-2024-50019}
- irqchip/gic-v4: Correctly deal with set_affinity on lazily-mapped VPEs (Charles Mirabile) [RHEL-66968] {CVE-2024-50192}
- irqchip/gic-v4: Don't allow a VMOVP on a dying VPE (Charles Mirabile) [RHEL-66968] {CVE-2024-50192}
- selftests: fib_nexthops: Test 16-bit next hop weights (Ivan Vecera) [RHEL-68365]
- selftests: router_mpath_nh_res: Test 16-bit next hop weights (Ivan Vecera) [RHEL-68365]
- selftests: router_mpath_nh: Test 16-bit next hop weights (Ivan Vecera) [RHEL-68365]
- selftests: router_mpath: Sleep after MZ (Ivan Vecera) [RHEL-68365]
- net: nexthop: Increase weight to u16 (Ivan Vecera) [RHEL-68365]
- net: nexthop: Add flag to assert that NHGRP reserved fields are zero (Ivan Vecera) [RHEL-68365]
- mm, slub: avoid zeroing kmalloc redzone (Waiman Long) [RHEL-64035] {CVE-2024-49885}
- mm/slub: avoid zeroing outside-object freepointer for single free (Waiman Long) [RHEL-64035]
- slub, kasan: improve interaction of KASAN and slub_debug poisoning (Waiman Long) [RHEL-64035]
- jbd2: stop waiting for space when jbd2_cleanup_journal_tail() returns error (CKI Backport Bot) [RHEL-64518] {CVE-2024-49959}
- page_pool: export page_pool_disable_direct_recycling() (Felix Maurer) [RHEL-57765]
- page_pool: fix &page_pool_params kdoc issues (Felix Maurer) [RHEL-57765]
- xsk: use generic DMA sync shortcut instead of a custom one (Felix Maurer) [RHEL-57765]
- page_pool: check for DMA sync shortcut earlier (Felix Maurer) [RHEL-57765]
- page_pool: don't use driver-set flags field directly (Felix Maurer) [RHEL-57765]
- page_pool: make sure frag API fields don't span between cachelines (Felix Maurer) [RHEL-57765]
- page_pool: add DMA-sync-for-CPU inline helper (Felix Maurer) [RHEL-57765]
- page_pool: constify some read-only function arguments (Felix Maurer) [RHEL-57765]
- page_pool: try direct bulk recycling (Felix Maurer) [RHEL-57765]
- page_pool: check for PP direct cache locality later (Felix Maurer) [RHEL-57765]
- net: page_pool: factor out page_pool recycle check (Felix Maurer) [RHEL-57765]
- net: page_pool: fix recycle stats for system page_pool allocator (Felix Maurer) [RHEL-57765]
- page_pool: disable direct recycling based on pool->cpuid on destroy (Felix Maurer) [RHEL-57765]
- scsi: lpfc: Update lpfc version to 14.4.0.5 (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Support loopback tests with VMID enabled (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Revise TRACE_EVENT log flag severities from KERN_ERR to KERN_WARNING (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Ensure DA_ID handling completion before deleting an NPIV instance (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Fix kref imbalance on fabric ndlps from dev_loss_tmo handler (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Restrict support for 32 byte CDBs to specific HBAs (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Update phba link state conditional before sending CMF_SYNC_WQE (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Add ELS_RSP cmd to the list of WQEs to flush in lpfc_els_flush_cmd() (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Remove trailing space after \n newline (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Update lpfc version to 14.4.0.4 (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Update PRLO handling in direct attached topology (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Fix unsolicited FLOGI kref imbalance when in direct attached topology (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Fix unintentional double clearing of vmid_flag (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Validate hdwq pointers before dereferencing in reset/errata paths (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Remove redundant vport assignment when building an abort request (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Change diagnostic log flag during receipt of unknown ELS cmds (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Update lpfc version to 14.4.0.3 (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Revise lpfc_prep_embed_io routine with proper endian macro usages (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Fix incorrect request len mbox field when setting trunking via sysfs (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Handle mailbox timeouts in lpfc_get_sfp_info (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Fix handling of fully recovered fabric node in dev_loss callbk (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Relax PRLI issue conditions after GID_FT response (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Allow DEVICE_RECOVERY mode after RSCN receipt if in PRLI_ISSUE state (Dick Kennedy) [RHEL-53595]
- scsi: lpfc: Cancel ELS WQE instead of issuing abort when SLI port is inactive (Dick Kennedy) [RHEL-53595]
- dm-raid: Fix WARN_ON_ONCE check for sync_thread in raid_resume (CKI Backport Bot) [RHEL-54875] {CVE-2024-43820}
- ACPI: PRM: Clean up guid type in struct prm_handler_info (Mark Langsdorf) [RHEL-66520] {CVE-2024-50141}
- ACPI: PRM: Find EFI_MEMORY_RUNTIME block for PRM handler and context (CKI Backport Bot) [RHEL-66520] {CVE-2024-50141}
- ext4: force disable fscrypt feature (Brian Foster) [RHEL-41061]
- exfat: fix memory leak in exfat_load_bitmap() (CKI Backport Bot) [RHEL-63633] {CVE-2024-50013}
- nbd: fix race between timeout and normal completion (Ming Lei) [RHEL-55992]
- nfsd: map the EBADMSG to nfserr_io to avoid warning (Olga Kornievskaia) [RHEL-63586] {CVE-2024-49875}
- bpf: Use nla_ok() instead of checking nla_len directly (Petr Oros) [RHEL-57755]
- devlink: use kvzalloc() to allocate devlink instance resources (Petr Oros) [RHEL-57755]
- Documentation: Add documentation for eswitch attribute (Petr Oros) [RHEL-57755]
- devlink: fix port new reply cmd type (Petr Oros) [RHEL-57755]
- tools: ynl: add header guards for nlctrl (Petr Oros) [RHEL-57755]
- devlink: Add comments to use netlink gen tool (Petr Oros) [RHEL-57755]
- net/netlink: Add getsockopt support for NETLINK_LISTEN_ALL_NSID (Petr Oros) [RHEL-57755]
- netlink: specs: support generating code for genl socket priv (Petr Oros) [RHEL-57755]
- tools: ynl: remove trailing semicolon (Petr Oros) [RHEL-57755]
- netlink: specs: support unterminated-ok (Petr Oros) [RHEL-57755]
- tools: ynl-gen: support using pre-defined values in attr checks (Petr Oros) [RHEL-57755]
- ynl: samples: fix recycling rate calculation (Petr Oros) [RHEL-57755]
- tools: ynl: Fix spelling mistake "Constructred" -> "Constructed" (Petr Oros) [RHEL-57755]
- doc/netlink/specs: Add spec for nlctrl netlink family (Petr Oros) [RHEL-57755]
- doc/netlink: Allow empty enum-name in ynl specs (Petr Oros) [RHEL-57755]
- tools/net/ynl: Add nest-type-value decoding (Petr Oros) [RHEL-57755]
- tools/net/ynl: Fix c codegen for array-nest (Petr Oros) [RHEL-57755]
- tools/net/ynl: Fix extack decoding for netlink-raw (Petr Oros) [RHEL-57755]
- tools: ynl: check for overflow of constructed messages (Petr Oros) [RHEL-57755]
- tools: ynl: add --dbg-small-recv for easier kernel testing (Petr Oros) [RHEL-57755]
- tools: ynl: support debug printing messages (Petr Oros) [RHEL-57755]
- tools: ynl: allow setting recv() size (Petr Oros) [RHEL-57755]
- tools: ynl: move the new line in NlMsg __repr__ (Petr Oros) [RHEL-57755]
- tools: ynl: remove __pycache__ during clean (Petr Oros) [RHEL-57755]
- tools: ynl: add distclean to .PHONY in all makefiles (Petr Oros) [RHEL-57755]
- tools: ynl: rename make hardclean -> distclean (Petr Oros) [RHEL-57755]
- genetlink: fit NLMSG_DONE into same read() as families (Petr Oros) [RHEL-57755]
- netdev: let netlink core handle -EMSGSIZE errors (Petr Oros) [RHEL-57755]
- netlink: handle EMSGSIZE errors in the core (Petr Oros) [RHEL-57755]
- tools: ynl: use MSG_DONTWAIT for getting notifications (Petr Oros) [RHEL-57755]
- tools: ynl: remove the libmnl dependency (Petr Oros) [RHEL-57755]
- tools: ynl: stop using mnl socket helpers (Petr Oros) [RHEL-57755]
- tools: ynl: switch away from MNL_CB_* (Petr Oros) [RHEL-57755]
- tools: ynl: switch away from mnl_cb_t (Petr Oros) [RHEL-57755]
- tools: ynl: stop using mnl_cb_run2() (Petr Oros) [RHEL-57755]
- tools: ynl: use ynl_sock_read_msgs() for ACK handling (Petr Oros) [RHEL-57755]
- tools: ynl: wrap recv() + mnl_cb_run2() into a single helper (Petr Oros) [RHEL-57755]
- tools: ynl-gen: remove unused parse code (Petr Oros) [RHEL-57755]
- tools: ynl: make yarg the first member of struct ynl_dump_state (Petr Oros) [RHEL-57755]
- tools: ynl: create local ARRAY_SIZE() helper (Petr Oros) [RHEL-57755]
- tools: ynl: create local nlmsg access helpers (Petr Oros) [RHEL-57755]
- tools: ynl: create local for_each helpers (Petr Oros) [RHEL-57755]
- tools: ynl: create local attribute helpers (Petr Oros) [RHEL-57755]
- tools: ynl: give up on libmnl for auto-ints (Petr Oros) [RHEL-57755]
- tools: ynl: protect from old OvS headers (Petr Oros) [RHEL-57755]
- tools: ynl: fix header guards (Petr Oros) [RHEL-57755]
- genetlink: make info in GENL_REQ_ATTR_CHECK() const (Petr Oros) [RHEL-57755]
- tools: ynl: allow user to pass enum string instead of scalar value (Petr Oros) [RHEL-57755]
- tools: ynl: process all scalar types encoding in single elif statement (Petr Oros) [RHEL-57755]
- tools: ynl: allow user to specify flag attr with bool values (Petr Oros) [RHEL-57755]
- tools: ynl: don't access uninitialized attr_space variable (Petr Oros) [RHEL-57755]
- tools: ynl: add support for encoding multi-attr (Petr Oros) [RHEL-57755]
- doc: netlink: specs: tc: add multi-attr to tc-taprio-sched-entry (Petr Oros) [RHEL-57755]
- tools: ynl: correct typo and docstring (Petr Oros) [RHEL-57755]
- Documentation: Fix counter name of mlx5 vnic reporter (Petr Oros) [RHEL-57755]
- net: make dev_unreg_count global (Petr Oros) [RHEL-57755]
- tools: ynl: auto-gen for all genetlink families (Petr Oros) [RHEL-57755]
- tools: ynl: generate code for ovs families (Petr Oros) [RHEL-57755]
- tools: ynl: include dpll and mptcp_pm in C codegen (Petr Oros) [RHEL-57755]
- tools/net/ynl: Add type info to struct members in generated docs (Petr Oros) [RHEL-57755]
- doc/netlink: Describe nested structs in netlink raw docs (Petr Oros) [RHEL-57755]
- tools/net/ynl: Add support for nested structs (Petr Oros) [RHEL-57755]
- tools/net/ynl: Move formatted_string method out of NlAttr (Petr Oros) [RHEL-57755]
- tools/net/ynl: Rename _fixed_header_size() to _struct_size() (Petr Oros) [RHEL-57755]
- tools/net/ynl: Combine struct decoding logic in ynl (Petr Oros) [RHEL-57755]
- tools/net/ynl: Encode default values for binary blobs (Petr Oros) [RHEL-57755]
- tools/net/ynl: Add support for encoding sub-messages (Petr Oros) [RHEL-57755]
- tools/net/ynl: Refactor fixed header encoding into separate method (Petr Oros) [RHEL-57755]
- doc/netlink: Describe sub-message selector resolution (Petr Oros) [RHEL-57755]
- tools/net/ynl: Support sub-messages in nested attribute spaces (Petr Oros) [RHEL-57755]
- netlink: Return unsigned value for nla_len() (Petr Oros) [RHEL-57755]
- tools: ynl: move private definitions to a separate header (Petr Oros) [RHEL-57755]
- tools: ynl: remove generated user space code from git (Petr Oros) [RHEL-57755]
- ice: document RDMA devlink parameters (Petr Oros) [RHEL-57755]
- tracing: devlink: Use static array for string in devlink_trap_report event (Petr Oros) [RHEL-57755]
- net: get rid of rtnl_lock_unregistering() (Petr Oros) [RHEL-57755]
- netfilter: br_netfilter: Use nested-BH locking for brnf_frag_data_storage. (Michal Schmidt) [RHEL-59089]
- locking/local_lock: Add local nested BH locking infrastructure. (Michal Schmidt) [RHEL-59089]
- locking/local_lock: Introduce guard definition for local_lock. (Michal Schmidt) [RHEL-59089]
- vhost_vdpa: assign irq bypass producer token correctly (Cindy Lu) [RHEL-63364] {CVE-2024-47748}
- nfsd: call cache_put if xdr_reserve_space returns NULL (Olga Kornievskaia) [RHEL-63382] {CVE-2024-47737}

* Mon Nov 25 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-534.el9]
- block: fix integer overflow in BLKSECDISCARD (Ming Lei) [RHEL-64512] {CVE-2024-49994}
- fsnotify: clear PARENT_WATCHED flags lazily (CKI Backport Bot) [RHEL-62134] {CVE-2024-47660}
- thunderbolt: Fix KASAN reported stack out-of-bounds read in tb_retimer_scan() (Desnes Nunes) [RHEL-59051]
- usb: typec: tcpm: restrict SNK_WAIT_CAPABILITIES_TIMEOUT transitions to non self-powered devices (Desnes Nunes) [RHEL-59051]
- drm/test: fix the gem shmem test to map the sg table. (Desnes Nunes) [RHEL-59051]
- dt-bindings: usb: qcom,dwc3: Update ipq5332 interrupt info (Desnes Nunes) [RHEL-59051]
- minmax: improve macro expansion and type checking (Desnes Nunes) [RHEL-59051]
- minmax: simplify min()/max()/clamp() implementation (Desnes Nunes) [RHEL-59051]
- minmax: don't use max() in situations that want a C constant expression (Desnes Nunes) [RHEL-59051]
- minmax: make generic MIN() and MAX() macros available everywhere (Desnes Nunes) [RHEL-59051]
- minmax: simplify and clarify min_t()/max_t() implementation (Desnes Nunes) [RHEL-59051]
- minmax: add a few more MIN_T/MAX_T users (Desnes Nunes) [RHEL-59051]
- minmax: avoid overly complicated constant expressions in VM code (Desnes Nunes) [RHEL-59051]
- mm: set pageblock_order to HPAGE_PMD_ORDER in case with !CONFIG_HUGETLB_PAGE but THP enabled (Desnes Nunes) [RHEL-59051]
- minmax: fix indentation of __cmp_once() and __clamp_once() (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Fix busy loop on ASUS VivoBooks (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Remove useless error check from ucsi_read_error() (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Call CANCEL from single location (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Common function for the GET_PD_MESSAGE command (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Only assign the identity structure if the PPM supports it (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Don't truncate the reads (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Remove unused fields from struct ucsi_connector_status (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Fix cable registration (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Fix the partner PD revision (Desnes Nunes) [RHEL-59051]
- usb: dwc3: core: update LC timer as per USB Spec V3.2 (Desnes Nunes) [RHEL-59051]
- usb: dwc3: Avoid waking up gadget during startxfer (Desnes Nunes) [RHEL-59051]
- USB: serial: option: add MeiG Smart SRM825L (Desnes Nunes) [RHEL-59051]
- usb: cdnsp: fix for Link TRB with TC (Desnes Nunes) [RHEL-59051]
- usb: dwc3: ep0: Don't reset resource alloc flag (including ep0) (Desnes Nunes) [RHEL-59051]
- usb: core: sysfs: Unmerge @usb3_hardware_lpm_attr_group in remove_power_attributes() (Desnes Nunes) [RHEL-59051]
- usb: typec: fsa4480: Relax CHIP_ID check (Desnes Nunes) [RHEL-59051]
- dt-bindings: usb: microchip,usb2514: Fix reference USB device schema (Desnes Nunes) [RHEL-59051]
- cdc-acm: Add DISABLE_ECHO quirk for GE HealthCare UI Controller (Desnes Nunes) [RHEL-59051]
- usb: cdnsp: fix incorrect index in cdnsp_get_hw_deq function (Desnes Nunes) [RHEL-59051]
- usb: dwc3: core: Prevent USB core invalid event buffer address access (Desnes Nunes) [RHEL-59051] {CVE-2024-46675}
- xhci: Fix Panther point NULL pointer deref at full-speed re-enumeration (Desnes Nunes) [RHEL-59051]
- Revert "usb: typec: tcpm: clear pd_event queue in PORT_RESET" (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Fix the return value of ucsi_run_command() (Desnes Nunes) [RHEL-59051]
- usb: xhci: fix duplicate stall handling in handle_tx_event() (Desnes Nunes) [RHEL-59051]
- usb: xhci: Check for xhci->interrupters being allocated in xhci_mem_clearup() (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Fix a deadlock in ucsi_send_command_common() (Desnes Nunes) [RHEL-59051]
- usb: typec: tcpm: avoid sink goto SNK_UNATTACHED state if not received source capability message (Desnes Nunes) [RHEL-59051]
- thunderbolt: Mark XDomain as unplugged when router is removed (Desnes Nunes) [RHEL-59051]
- phy: fsl-imx8mq-usb: fix tuning parameter name (Desnes Nunes) [RHEL-59051]
- thunderbolt: Fix memory leaks in {port|retimer}_sb_regs_write() (Desnes Nunes) [RHEL-59051]
- USB: serial: debug: do not echo input by default (Desnes Nunes) [RHEL-59051]
- usb: typec: tipd: Delete extra semi-colon (Desnes Nunes) [RHEL-59051]
- usb: typec: tipd: Fix dereferencing freeing memory in tps6598x_apply_patch() (Desnes Nunes) [RHEL-59051]
- usb: typec: tcpci: Fix error code in tcpci_check_std_output_cap() (Desnes Nunes) [RHEL-59051]
- usb: typec: fsa4480: Check if the chip is really there (Desnes Nunes) [RHEL-59051]
- usb: gadget: core: Check for unset descriptor (Desnes Nunes) [RHEL-59051] {CVE-2024-44960}
- dt-bindings: usb: microchip,usb2514: Add USB2517 compatible (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Fix custom control mapping probing (Desnes Nunes) [RHEL-59051]
- USB: uas: Implement the new shutdown callback (Desnes Nunes) [RHEL-59051]
- USB: core: add 'shutdown' callback to usb_driver (Desnes Nunes) [RHEL-59051]
- usb: typec: Drop explicit initialization of struct i2c_device_id::driver_data to 0 (Desnes Nunes) [RHEL-59051]
- usb: dwc3: enable CCI support for AMD-xilinx DWC3 controller (Desnes Nunes) [RHEL-59051]
- usb: gadget: Use u16 types for 16-bit fields (Desnes Nunes) [RHEL-59051]
- pinctrl: tegra: Use scope based of_node_put() cleanups (Desnes Nunes) [RHEL-59051]
- of: Introduce for_each_*_child_of_node_scoped() to automate of_node_put() handling (Desnes Nunes) [RHEL-59051]
- of: Add cleanup.h based auto release via __free(device_node) markings (Desnes Nunes) [RHEL-59051]
- writing_musb_glue_layer.rst: Fix broken URL (Desnes Nunes) [RHEL-59051]
- redhat: configs: Drop CONFIG_MEMSTICK_REALTEK_PCI config option (Desnes Nunes) [RHEL-59051]
- memstick: rtsx_pci_ms: Remove Realtek PCI memstick driver (Desnes Nunes) [RHEL-59051]
- USB: serial: garmin_gps: use struct_size() to allocate pkt (Desnes Nunes) [RHEL-59051]
- USB: serial: garmin_gps: annotate struct garmin_packet with __counted_by (Desnes Nunes) [RHEL-59051]
- USB: serial: add missing MODULE_DESCRIPTION() macros (Desnes Nunes) [RHEL-59051]
- USB: serial: spcp8x5: remove unused struct 'spcp8x5_usb_ctrl_arg' (Desnes Nunes) [RHEL-59051]
- usb: dwc3: core: Check all ports when set phy suspend (Desnes Nunes) [RHEL-59051]
- usb: typec: tcpci: add support to set connector orientation (Desnes Nunes) [RHEL-59051]
- dt-bindings: usb: Convert fsl-usb to yaml (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: reorder operations in ucsi_run_command() (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: extract common code for command handling (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: inline ucsi_read_message_in (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: rework command execution functions (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: split read operation (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: simplify command sending API (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: move ucsi_acknowledge() from ucsi_read_error() (Desnes Nunes) [RHEL-59051]
- phy: core: Fix documentation of of_phy_get (Desnes Nunes) [RHEL-59051]
- redhat/configs: Adding CONFIG_UCSI_LENOVO_YOGA_C630 (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: add Lenovo Yoga C630 glue driver (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: UCSI2.0 Get Error Status changes (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: UCSI2.0 Get Error Status data structure changes (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Only set number of plug altmodes after registration (Desnes Nunes) [RHEL-59051]
- xhci: sort out TRB Endpoint ID bitfield macros (Desnes Nunes) [RHEL-59051]
- xhci: Apply XHCI_RESET_TO_DEFAULT quirk to TGL (Desnes Nunes) [RHEL-59051]
- usb: xhci: add 'goto' for halted endpoint check in handle_tx_event() (Desnes Nunes) [RHEL-59051]
- usb: xhci: move process TD code out of the while loop (Desnes Nunes) [RHEL-59051]
- usb: xhci: remove infinite loop prevention (Desnes Nunes) [RHEL-59051]
- usb: xhci: remove false xhci_giveback_urb_in_irq() header comment (Desnes Nunes) [RHEL-59051]
- usb: xhci: ensure skipped isoc TDs are returned when isoc ring is stopped (Desnes Nunes) [RHEL-59051]
- xhci: rework xhci internal endpoint halt state detection. (Desnes Nunes) [RHEL-59051]
- usb: xhci: remove obsolete sanity check debug messages (Desnes Nunes) [RHEL-59051]
- usb: xhci: improve error message for targetless transfer event (Desnes Nunes) [RHEL-59051]
- usb: xhci: move untargeted transfer event handling to a separate function (Desnes Nunes) [RHEL-59051]
- usb: xhci: move all segment re-numbering to xhci_link_rings() (Desnes Nunes) [RHEL-59051]
- usb: xhci: move link chain bit quirk checks into one helper function. (Desnes Nunes) [RHEL-59051]
- usb: xhci: remove unused argument from handle_port_status() (Desnes Nunes) [RHEL-59051]
- usb: xhci: remove unused argument from xhci_handle_cmd_config_ep() (Desnes Nunes) [RHEL-59051]
- usb: xhci: remove unused 'xhci' argument (Desnes Nunes) [RHEL-59051]
- usb: xhci: remove 'num_trbs' from struct 'xhci_td' (Desnes Nunes) [RHEL-59051]
- xhci: dbc: Allow users to modify DbC poll interval via sysfs (Desnes Nunes) [RHEL-59051]
- xhci: Set correct transferred length for cancelled isoc transfers (Desnes Nunes) [RHEL-59051]
- xhci: show usb device name in xhci urb tracing (Desnes Nunes) [RHEL-59051]
- xhci: Remove dead code in xhci_move_dequeue_past_td() (Desnes Nunes) [RHEL-59051]
- usb: chipidea: ci_hdrc_imx: Switch to RUNTIME/SYSTEM_SLEEP_PM_OPS() (Desnes Nunes) [RHEL-59051]
- usb: misc: onboard_usb_dev: Add match function (Desnes Nunes) [RHEL-59051]
- usb: uas: set host status byte on data completion error (Desnes Nunes) [RHEL-59051]
- media: b2c2: flexcop-usb: fix flexcop_usb_memory_req (Desnes Nunes) [RHEL-59051]
- media: flexcop-usb: Use min macro (Desnes Nunes) [RHEL-59051]
- media: cx231xx: Constify struct vb2_ops (Desnes Nunes) [RHEL-59051]
- dt-bindings: usb: Add the binding example for the Genesys Logic GL3523 hub (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: psy: Add support for the charge type property (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Changing the driver data type to void (Desnes Nunes) [RHEL-59051]
- dt-bindings: usb: qcom,dwc3: Add SC8180X compatibles (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: don't retrieve PDOs if not supported (Desnes Nunes) [RHEL-59051]
- usb: host: xhci-plat: Add support for XHCI_WRITE_64_HI_LO (Desnes Nunes) [RHEL-59051]
- xhci: Add a quirk for writing ERST in high-low order (Desnes Nunes) [RHEL-59051]
- usb: dwc3: Support quirk for writing high-low order (Desnes Nunes) [RHEL-59051]
- usb: typec: tipd: use min() to set tps6598x firmware packet size (Desnes Nunes) [RHEL-59051]
- usb: typec: tipd: add error log to provide firmware name and size (Desnes Nunes) [RHEL-59051]
- usb: typec: tipd: drop second firmware name read (Desnes Nunes) [RHEL-59051]
- usb: typec: tcpm: use 'time_left' variable with wait_for_completion_timeout() (Desnes Nunes) [RHEL-59051]
- usb: misc: Drop explicit initialization of struct i2c_device_id::driver_data to 0 (Desnes Nunes) [RHEL-59051]
- usb: add missing MODULE_DESCRIPTION() macros (Desnes Nunes) [RHEL-59051]
- usb: common: add missing MODULE_DESCRIPTION() macros (Desnes Nunes) [RHEL-59051]
- usb: host: add missing MODULE_DESCRIPTION() macros (Desnes Nunes) [RHEL-59051]
- usb: misc: add missing MODULE_DESCRIPTION() macros (Desnes Nunes) [RHEL-59051]
- dt-bindings: usb: cdns,usb3: use common usb-drd yaml (Desnes Nunes) [RHEL-59051]
- thunderbolt: debugfs: Use FIELD_GET() (Desnes Nunes) [RHEL-59051]
- thunderbolt: Add receiver lane margining support for retimers (Desnes Nunes) [RHEL-59051]
- thunderbolt: Make margining functions accept target and retimer index (Desnes Nunes) [RHEL-59051]
- thunderbolt: Split out margining from USB4 port (Desnes Nunes) [RHEL-59051]
- thunderbolt: Add sideband register access to debugfs (Desnes Nunes) [RHEL-59051]
- thunderbolt: Make usb4_port_sb_read/write() available outside of usb4.c (Desnes Nunes) [RHEL-59051]
- thunderbolt: Move usb4_port_margining_caps() declaration into correct place (Desnes Nunes) [RHEL-59051]
- thunderbolt: Mention Thunderbolt/USB4 debugging tools in Kconfig (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Remove mappings form uvc_device_info (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Remove PLF device quirking (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Cleanup version-specific mapping (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Probe the PLF characteristics (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Refactor Power Line Frequency limit selection (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Allow custom control mapping (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Fix the bandwdith quirk on USB 3.x (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Force UVC version to 1.0a for 0408:4035 (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Override default flags (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Enforce alignment of frame and interval (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Add quirk for invalid dev_sof in Logitech C920 (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Fix integer overflow calculating timestamp (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Fix hw timestamp handling for slow FPS (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Refactor clock circular buffer (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Allow hw clock updates with buffers not full (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Quirk for invalid dev_sof in Logitech C922 (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Ignore empty TS packets (Desnes Nunes) [RHEL-59051]
- media: uvcvideo: Support timestamp lists of any size (Desnes Nunes) [RHEL-59051]
- redhat/configs: Adding CONFIG_PHY_FSL_IMX8QM_HSIO (Desnes Nunes) [RHEL-59051]
- phy: freescale: imx8qm-hsio: Add i.MX8QM HSIO PHY driver support (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Enable UCSI v2.0 notifications (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Add new capability bits (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Always set number of alternate modes (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Delay alternate mode discovery (Desnes Nunes) [RHEL-59051]
- usb: typec: Update sysfs when setting ops (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Fix null pointer dereference in trace (Desnes Nunes) [RHEL-59051]
- usb: typec: tcpm: print error on hard reset (Desnes Nunes) [RHEL-59051]
- usb: typec: tcpm: avoid resets for missing source capability messages (Desnes Nunes) [RHEL-59051]
- usb: typec: ucsi: Add new notification bits (Desnes Nunes) [RHEL-59051]
- usb: cdns3-ti: Add workaround for Errata i2409 (Desnes Nunes) [RHEL-59051]
- usb: cdns3: Add quirk flag to enable suspend residency (Desnes Nunes) [RHEL-59051]
- usb-storage: Optimize scan delay more precisely (Desnes Nunes) [RHEL-59051]
- gnss: add USB support (Desnes Nunes) [RHEL-59051]
- xfs: fix finding a last resort AG in xfs_filestream_pick_ag (CKI Backport Bot) [RHEL-66904] {CVE-2024-50216}
- ACPICA: check null return of ACPI_ALLOCATE_ZEROED() in acpi_db_convert_to_package() (Mark Langsdorf) [RHEL-64502] {CVE-2024-49962}
- parport: Proper fix for array out-of-bounds access (CKI Backport Bot) [RHEL-65181] {CVE-2024-50074}
- scsi: target: core: Fix null-ptr-deref in target_alloc_device() (CKI Backport Bot) [RHEL-66470] {CVE-2024-50153}
- blk-mq: setup queue ->tag_set before initializing hctx (CKI Backport Bot) [RHEL-65152] {CVE-2024-50081}
- udf: fix uninit-value use in udf_get_fileshortad (CKI Backport Bot) [RHEL-66420] {CVE-2024-50143}
- block: fix potential invalid pointer dereference in blk_add_partition (Ming Lei) [RHEL-63267] {CVE-2024-47705}
- xfs: dquot recovery does not validate the recovered dquot (Bill O'Donnell) [RHEL-62760]
- block: update the stable_writes flag in bdev_add (Bill O'Donnell) [RHEL-62760]
- xfs: clean up dqblk extraction (Bill O'Donnell) [RHEL-62760]
- xfs: respect the stable writes flag on the RT device (Bill O'Donnell) [RHEL-62760]
- filemap: add a per-mapping stable writes flag (Bill O'Donnell) [RHEL-62760]
- xfs: clean up FS_XFLAG_REALTIME handling in xfs_ioctl_setattr_xflags (Bill O'Donnell) [RHEL-62760]
- xfs: inode recovery does not validate the recovered inode (Bill O'Donnell) [RHEL-62760]
- xfs: up(ic_sema) if flushing data device fails (Bill O'Donnell) [RHEL-62760]
- xfs: only remap the written blocks in xfs_reflink_end_cow_extent (Bill O'Donnell) [RHEL-62760]
- xfs: abort intent items when recovery intents fail (Bill O'Donnell) [RHEL-62760]
- xfs: factor out xfs_defer_pending_abort (Bill O'Donnell) [RHEL-62760]
- xfs: allow read IO and FICLONE to run concurrently (Bill O'Donnell) [RHEL-62760]
- xfs: handle nimaps=0 from xfs_bmapi_write in xfs_alloc_file_space (Bill O'Donnell) [RHEL-62760]
- xfs: introduce protection for drop nlink (Bill O'Donnell) [RHEL-62760]
- xfs: don't look for end of extent further than necessary in xfs_rtallocate_extent_near() (Bill O'Donnell) [RHEL-62760]
- xfs: don't try redundant allocations in xfs_rtallocate_extent_near() (Bill O'Donnell) [RHEL-62760]
- xfs: limit maxlen based on available space in xfs_rtallocate_extent_near() (Bill O'Donnell) [RHEL-62760]
- xfs: return maximum free size from xfs_rtany_summary() (Bill O'Donnell) [RHEL-62760]
- xfs: invert the realtime summary cache (Bill O'Donnell) [RHEL-62760]
- xfs: simplify rt bitmap/summary block accessor functions (Bill O'Donnell) [RHEL-62760]
- xfs: simplify xfs_rtbuf_get calling conventions (Bill O'Donnell) [RHEL-62760]
- xfs: cache last bitmap block in realtime allocator (Bill O'Donnell) [RHEL-62760]
- xfs: consolidate realtime allocation arguments (Bill O'Donnell) [RHEL-62760]
- xfs: use accessor functions for summary info words (Bill O'Donnell) [RHEL-62760]
- xfs: create helpers for rtsummary block/wordcount computations (Bill O'Donnell) [RHEL-62760]
- xfs: use accessor functions for bitmap words (Bill O'Donnell) [RHEL-62760]
- xfs: create a helper to handle logging parts of rt bitmap/summary blocks (Bill O'Donnell) [RHEL-62760]
- xfs: create helpers for rtbitmap block/wordcount computations (Bill O'Donnell) [RHEL-62760]
- xfs: convert rt summary macros to helpers (Bill O'Donnell) [RHEL-62760]
- xfs: convert open-coded xfs_rtword_t pointer accesses to helper (Bill O'Donnell) [RHEL-62760]
- xfs: remove XFS_BLOCKWSIZE and XFS_BLOCKWMASK macros (Bill O'Donnell) [RHEL-62760]
- xfs: convert the rtbitmap block and bit macros to static inline functions (Bill O'Donnell) [RHEL-62760]
- xfs: use shifting and masking when converting rt extents, if possible (Bill O'Donnell) [RHEL-62760]
- xfs: create rt extent rounding helpers for realtime extent blocks (Bill O'Donnell) [RHEL-62760]
- xfs: convert do_div calls to xfs_rtb_to_rtx helper calls (Bill O'Donnell) [RHEL-62760]
- xfs: create helpers to convert rt block numbers to rt extent numbers (Bill O'Donnell) [RHEL-62760]
- xfs: create a helper to convert extlen to rtextlen (Bill O'Donnell) [RHEL-62760]
- xfs: create a helper to compute leftovers of realtime extents (Bill O'Donnell) [RHEL-62760]
- xfs: create a helper to convert rtextents to rtblocks (Bill O'Donnell) [RHEL-62760]
- xfs: convert rt extent numbers to xfs_rtxnum_t (Bill O'Donnell) [RHEL-62760]
- xfs: rename xfs_verify_rtext to xfs_verify_rtbext (Bill O'Donnell) [RHEL-62760]
- xfs: convert rt bitmap extent lengths to xfs_rtbxlen_t (Bill O'Donnell) [RHEL-62760]
- xfs: convert rt bitmap/summary block numbers to xfs_fileoff_t (Bill O'Donnell) [RHEL-62760]
- xfs: convert xfs_extlen_t to xfs_rtxlen_t in the rt allocator (Bill O'Donnell) [RHEL-62760]
- xfs: move the xfs_rtbitmap.c declarations to xfs_rtbitmap.h (Bill O'Donnell) [RHEL-62760]
- xfs: make sure maxlen is still congruent with prod when rounding down (Bill O'Donnell) [RHEL-62760]
- xfs: rt stubs should return negative errnos when rt disabled (Bill O'Donnell) [RHEL-62760]
- xfs: prevent rt growfs when quota is enabled (Bill O'Donnell) [RHEL-62760]
- xfs: hoist freeing of rt data fork extent mappings (Bill O'Donnell) [RHEL-62760]
- xfs: bump max fsgeom struct version (Bill O'Donnell) [RHEL-62760]
- xfs: move xfs_xattr_handlers to .rodata (Bill O'Donnell) [RHEL-62760]
- cgroup/cpuset: Correct invalid remote parition prs (Waiman Long) [RHEL-36267]
- cgroup: Fix incorrect WARN_ON_ONCE() in css_release_work_fn() (Waiman Long) [RHEL-36267]
- cgroup: Show # of subsystem CSSes in cgroup.stat (Waiman Long) [RHEL-36267]

* Fri Nov 22 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-533.el9]
- ext4: sanity check for NULL pointer after ext4_force_shutdown (Brian Foster) [RHEL-64967] {CVE-2024-43898}
- ext4: dax: fix overflowing extents beyond inode size when partially writing (Brian Foster) [RHEL-64575] {CVE-2024-50015}
- ext4: fix access to uninitialised lock in fc replay path (Brian Foster) [RHEL-63918] {CVE-2024-50014}
- ext4: fix error message when rejecting the default hash (Brian Foster) [RHEL-63899]
- ext4: factor out ext4_hash_info_init() (Brian Foster) [RHEL-63899]
- ext4: filesystems without casefold feature cannot be mounted with siphash (Brian Foster) [RHEL-63899] {CVE-2024-49968}
- ext4: check stripe size compatibility on remount as well (Brian Foster) [RHEL-63289] {CVE-2024-47700}
- ata: libata: avoid superfluous disk spin down + spin up during hibernation (Tomas Henzl) [RHEL-52820]
- ata: libata-scsi: Fix ata_msense_control() CDL page reporting (Tomas Henzl) [RHEL-52820]
- ata: libata: Fix W=1 compilation warning (Tomas Henzl) [RHEL-52820]
- ata: libata: Move sector_buf from struct ata_port to struct ata_device (Tomas Henzl) [RHEL-52820]
- ata: libata: Rename ata_eh_read_sense_success_ncq_log() (Tomas Henzl) [RHEL-52820]
- ata: libata: Move sata_std_hardreset() definition to libata-sata.c (Tomas Henzl) [RHEL-52820]
- ata: libata: Move sata_down_spd_limit() to libata-sata.c (Tomas Henzl) [RHEL-52820]
- ata: libata: Improve __ata_qc_complete() (Tomas Henzl) [RHEL-52820]
- ata: libata-scsi: Improve ata_scsi_handle_link_detach() (Tomas Henzl) [RHEL-52820]
- ata: libata: Cleanup libata-transport (Tomas Henzl) [RHEL-52820]
- ata: libata: Add helper ata_eh_decide_disposition() (Tomas Henzl) [RHEL-52820]
- ata: libata: Remove ata_noop_qc_prep() (Tomas Henzl) [RHEL-52820]
- ata: libata: Change ata_dev_knobble() to return a bool (Tomas Henzl) [RHEL-52820]
- perf test: Restore sample rate for perf_event_attr (Michael Petlan) [RHEL-22716]
- perf test attr: Add back missing topdown events (Michael Petlan) [RHEL-15967]
- gfs2: Prevent inode creation race (Andreas Gruenbacher) [RHEL-68102]
- gfs2: Only defer deletes when we have an iopen glock (Andreas Gruenbacher) [RHEL-68102]
- thermal: intel: int340x: processor: Fix warning during module unload (David Arcari) [RHEL-65903] {CVE-2024-50093}
- x86/resctrl: Avoid overflow in MB settings in bw_validate() (David Arcari) [RHEL-59825]
- KVM: SVM: Propagate error from snp_guest_req_init() to userspace (Bandan Das) [RHEL-65840]
- KVM: SEV: Provide support for SNP_EXTENDED_GUEST_REQUEST NAE event (Bandan Das) [RHEL-65840]
- x86/sev: Move sev_guest.h into common SEV header (Bandan Das) [RHEL-65840]
- KVM: SEV: Provide support for SNP_GUEST_REQUEST NAE event (Bandan Das) [RHEL-65840]
- perf vendor events: Move PM_BR_MPRED_CMPL event for power10 platform (Mamatha Inamdar) [RHEL-52736]
- perf vendor events power10: Move the JSON/events (Mamatha Inamdar) [RHEL-52736]
- perf vendor events power10: Update JSON/events (Mamatha Inamdar) [RHEL-52736]
- perf vendor events power10: Update JSON/events (Mamatha Inamdar) [RHEL-52736]
- tcp/dccp: Don't use timer_pending() in reqsk_queue_unlink(). (Guillaume Nault) [RHEL-66328] {CVE-2024-50154}
- net: explicitly clear the sk pointer, when pf->create fails (Andrea Claudi) [RHEL-66687] {CVE-2024-50186}
- scsi: libcxgbi: Remove an unused field in struct cxgbi_device (Chris Leech) [RHEL-66745]
- scsi: bnx2i: Remove unused declarations (Chris Leech) [RHEL-66745]
- scsi: iscsi: Remove unused list 'connlist_err' (Chris Leech) [RHEL-66745]
- scsi: qla4xxx: Replace deprecated strncpy() with strscpy() (Chris Leech) [RHEL-66745]
- scsi: be2iscsi: Make some variables static (Chris Leech) [RHEL-66745]
- net: sched: fix use-after-free in taprio_change() (Xin Long) [RHEL-65971] {CVE-2024-50127}
- selftests: net: no_forwarding: fix VID for $swp2 in one_bridge_two_pvids() test (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: local_termination: Down ports on cleanup (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: no_forwarding: Down ports on cleanup (Ivan Vecera) [RHEL-66601]
- selftests: net/forwarding: spawn sh inside vrf to speed up ping loop (Ivan Vecera) [RHEL-66601]
- selftests: net: local_termination: add PTP frames to the mix (Ivan Vecera) [RHEL-66601]
- selftests: net: local_termination: don't use xfail_on_veth() (Ivan Vecera) [RHEL-66601]
- selftests: net: local_termination: introduce new tests which capture VLAN behavior (Ivan Vecera) [RHEL-66601]
- selftests: net: local_termination: add one more test for VLAN-aware bridges (Ivan Vecera) [RHEL-66601]
- selftests: net: local_termination: parameterize test name (Ivan Vecera) [RHEL-66601]
- selftests: net: local_termination: parameterize sending interface (Ivan Vecera) [RHEL-66601]
- selftests: net: local_termination: refactor macvlan creation/deletion (Ivan Vecera) [RHEL-66601]
- selftests: net: lib: kill PIDs before del netns (Ivan Vecera) [RHEL-66601]
- selftests: libs: Drop unused functions (Ivan Vecera) [RHEL-66601]
- selftests: libs: Drop slow_path_trap_install()/_uninstall() (Ivan Vecera) [RHEL-66601]
- selftests: mirror_gre_lag_lacp: Drop unnecessary code (Ivan Vecera) [RHEL-66601]
- selftests: mirror: Drop dual SW/HW testing (Ivan Vecera) [RHEL-66601]
- selftests: mirror: mirror_test(): Allow exact count of packets (Ivan Vecera) [RHEL-66601]
- selftests: mirror: do_test_span_dir_ips(): Install accurate taps (Ivan Vecera) [RHEL-66601]
- selftests: mirror_gre_lag_lacp: Check counters at tunnel (Ivan Vecera) [RHEL-66601]
- selftests: lib: tc_rule_stats_get(): Move default to argument definition (Ivan Vecera) [RHEL-66601]
- selftests: mirror: Drop direction argument from several functions (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: Add test for minimum and maximum MTU (Ivan Vecera) [RHEL-66601]
- selftests: net: lib: remove 'ns' var in setup_ns (Ivan Vecera) [RHEL-66601]
- selftests: net: lib: do not set ns var as readonly (Ivan Vecera) [RHEL-66601]
- selftests: net: lib: remove ns from list after clean-up (Ivan Vecera) [RHEL-66601]
- selftests: net: lib: ignore possible errors (Ivan Vecera) [RHEL-66601]
- selftests: net: lib: avoid error removing empty netns name (Ivan Vecera) [RHEL-66601]
- selftests: net: lib: support errexit with busywait (Ivan Vecera) [RHEL-66601]
- selftests: net: local_termination: annotate the expected failures (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: add wait_for_dev() helper (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: add check_driver() helper (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: router_nh: Add a diagram (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: router_mpath_nh_res: Add a diagram (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: router_mpath_nh: Add a diagram (Ivan Vecera) [RHEL-66601]
- selftests: drivers: hw: Include tc_common.sh in hw_stats_l3 (Ivan Vecera) [RHEL-66601]
- selftests: drivers: hw: ethtool.sh: Adjust output (Ivan Vecera) [RHEL-66601]
- selftests: drivers: hw: Fix ethtool_rmon (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: Add a test for testing lib.sh functionality (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: router_mpath_nh_lib: Don't skip, xfail on veth (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: Mark performance-sensitive tests (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: Change inappropriate log_test_skip() calls (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: Ditch skip_on_veth() (Ivan Vecera) [RHEL-66601]
- selftests: mlxsw: ethtool_lanes: Source ethtool lib from correct path (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: Move several selftests (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: ipip_lib: Do not import lib.sh (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: Make {, ip6}gre-inner-v6-multipath tests more robust (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: Remove IPv6 L3 multipath hash tests (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: ethtool_mm: fall back to aggregate if device does not report pMAC stats (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: ethtool_mm: support devices with higher rx-min-frag-size (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: ethtool_rmon: Add histogram counter test (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: ethtool_mm: Skip when MAC Merge is not supported (Ivan Vecera) [RHEL-66601]
- selftests: forwarding: add a test for MAC Merge layer (Ivan Vecera) [RHEL-66601]
- bpf: Fix a sdiv overflow issue (CKI Backport Bot) [RHEL-64597] {CVE-2024-49888}
- xfrm: validate new SA's prefixlen using SA family when sel.family is unset (Sabrina Dubroca) [RHEL-66461] {CVE-2024-50142}
- selinux,smack: don't bypass permissions check in inode_setsecctx hook (CKI Backport Bot) [RHEL-66109] {CVE-2024-46695}
- ext4: don't set SB_RDONLY after filesystem errors (CKI Backport Bot) [RHEL-66718] {CVE-2024-50191}
- netfilter: nf_reject_ipv6: fix nf_reject_ip6_tcphdr_put() (CKI Backport Bot) [RHEL-63300] {CVE-2024-47685}
- netfilter: bpf: must hold reference on net namespace (Florian Westphal) [RHEL-65877] {CVE-2024-50130}
- bpf: fix order of args in call to bpf_map_kvcalloc (Viktor Malik) [RHEL-30773]
- bpf: Allow return values 0 and 1 for kprobe session (Viktor Malik) [RHEL-30773]
- selftests/bpf: skip the timer_lockup test for single-CPU nodes (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add tests for tail calls with locks and refs (Viktor Malik) [RHEL-30773]
- bpf: Unify resource leak checks (Viktor Malik) [RHEL-30773]
- bpf: Tighten tail call checks for lingering locks, RCU, preempt_disable (Viktor Malik) [RHEL-30773]
- bpf: fix do_misc_fixups() for bpf_get_branch_snapshot() (Viktor Malik) [RHEL-30773]
- bpf: use type_may_be_null() helper for nullable-param check (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add timer lockup selftest (Viktor Malik) [RHEL-30773]
- bpf: Defer work in bpf_timer_cancel_and_free (Viktor Malik) [RHEL-30773]
- bpf: Fail bpf_timer_cancel when callback is being cancelled (Viktor Malik) [RHEL-30773]
- selftests/bpf: amend for wrong bpf_wq_set_callback_impl signature (Viktor Malik) [RHEL-30773]
- bpf: helpers: fix bpf_wq_set_callback_impl signature (Viktor Malik) [RHEL-30773]
- bpf: Fix atomic probe zero-extension (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add more ring buffer test coverage (Viktor Malik) [RHEL-30773]
- bpf: Change bpf_session_cookie return value to __u64 * (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add a few tests to cover (Viktor Malik) [RHEL-30773]
- bpf: Add missed var_off setting in coerce_subreg_to_size_sx() (Viktor Malik) [RHEL-30773]
- bpf: Add missed var_off setting in set_sext32_default_val() (Viktor Malik) [RHEL-30773]
- bpf: Harden __bpf_kfunc tag against linker kfunc removal (Viktor Malik) [RHEL-30773]
- compiler_types.h: Define __retain for __attribute__((__retain__)) (Viktor Malik) [RHEL-30773]
- bpf: fix UML x86_64 compile failure (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add test coverage for reg_set_min_max handling (Viktor Malik) [RHEL-30773]
- bpf: Reduce stack consumption in check_stack_write_fixed_off (Viktor Malik) [RHEL-30773]
- bpf: Fix reg_set_min_max corruption of fake_reg (Viktor Malik) [RHEL-30773]
- bpf: Make bpf_session_cookie() kfunc return long * (Viktor Malik) [RHEL-30773]
- bpf: Set run context for rawtp test_run callback (Viktor Malik) [RHEL-30773]
- bpf, devmap: Remove unnecessary if check in for loop (Viktor Malik) [RHEL-30773]
- libbpf: don't close(-1) in multi-uprobe feature detector (Viktor Malik) [RHEL-30773]
- bpf: Fix bpf_session_cookie BTF_ID in special_kfunc_set list (Viktor Malik) [RHEL-30773]
- powerpc/bpf: enforce full ordering for ATOMIC operations with BPF_FETCH (Viktor Malik) [RHEL-30773]
- selftests/bpf: extend multi-uprobe tests with USDTs (Viktor Malik) [RHEL-30773]
- selftests/bpf: extend multi-uprobe tests with child thread case (Viktor Malik) [RHEL-30773]
- libbpf: detect broken PID filtering logic for multi-uprobe (Viktor Malik) [RHEL-30773]
- bpf: remove unnecessary rcu_read_{lock,unlock}() in multi-uprobe attach logic (Viktor Malik) [RHEL-30773]
- bpf: fix multi-uprobe PID filtering logic (Viktor Malik) [RHEL-30773]
- bpf: Fix potential integer overflow in resolve_btfids (Viktor Malik) [RHEL-30773]
- selftests/bpf: add more variations of map-in-map situations (Viktor Malik) [RHEL-30773]
- bpf: save extended inner map info for percpu array maps as well (Viktor Malik) [RHEL-30773]
- bpf, docs: Fix the description of 'src' in ALU instructions (Viktor Malik) [RHEL-30773]
- bpf: make list_for_each_entry portable (Viktor Malik) [RHEL-30773]
- bpf: ignore expected GCC warning in test_global_func10.c (Viktor Malik) [RHEL-30773]
- bpf: disable strict aliasing in test_global_func9.c (Viktor Malik) [RHEL-30773]
- selftests/bpf: Fix a few tests for GCC related warnings. (Viktor Malik) [RHEL-30773]
- s390/bpf: Emit a barrier for BPF_FETCH instructions (Viktor Malik) [RHEL-30773]
- kbuild,bpf: Switch to using --btf_features for pahole v1.26 and later (Viktor Malik) [RHEL-30773]
- kbuild: avoid too many execution of scripts/pahole-flags.sh (Viktor Malik) [RHEL-30773]
- bpf: Avoid uninitialized value in BPF_CORE_READ_BITFIELD (Viktor Malik) [RHEL-30773]
- bpf: guard BPF_NO_PRESERVE_ACCESS_INDEX in skb_pkt_end.c (Viktor Malik) [RHEL-30773]
- bpf: avoid UB in usages of the __imm_insn macro (Viktor Malik) [RHEL-30773]
- bpf: avoid uninitialized warnings in verifier_global_subprogs.c (Viktor Malik) [RHEL-30773]
- bpf, arm64: Add support for lse atomics in bpf_arena (Viktor Malik) [RHEL-30773]
- selftests/bpf: shorten subtest names for struct_ops_module test (Viktor Malik) [RHEL-30773]
- selftests/bpf: validate struct_ops early failure detection logic (Viktor Malik) [RHEL-30773]
- libbpf: improve early detection of doomed-to-fail BPF program loading (Viktor Malik) [RHEL-30773]
- libbpf: fix libbpf_strerror_r() handling unknown errors (Viktor Malik) [RHEL-30773]
- selftests/bpf: add another struct_ops callback use case test (Viktor Malik) [RHEL-30773]
- libbpf: handle yet another corner case of nulling out struct_ops program (Viktor Malik) [RHEL-30773]
- libbpf: remove unnecessary struct_ops prog validity check (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add CFLAGS per source file and runner (Viktor Malik) [RHEL-30773]
- bpf: Temporarily define BPF_NO_PRESEVE_ACCESS_INDEX for GCC (Viktor Malik) [RHEL-30773]
- bpf: Disable some `attribute ignored' warnings in GCC (Viktor Malik) [RHEL-30773]
- bpf: Avoid __hidden__ attribute in static object (Viktor Malik) [RHEL-30773]
- bpf: Remove redundant page mask of vmf->address (Viktor Malik) [RHEL-30773]
- selftests/bpf: MUL range computation tests. (Viktor Malik) [RHEL-30773]
- bpf/verifier: relax MUL range computation check (Viktor Malik) [RHEL-30773]
- selftests/bpf: XOR and OR range computation tests. (Viktor Malik) [RHEL-30773]
- bpf/verifier: improve XOR and OR range computation (Viktor Malik) [RHEL-30773]
- bpf/verifier: refactor checks for range computation (Viktor Malik) [RHEL-30773]
- bpf/verifier: replace calls to mark_reg_unknown. (Viktor Malik) [RHEL-30773]
- bpftool, selftests/hid/bpf: Fix 29 clang warnings (Viktor Malik) [RHEL-30773]
- selftests/bpf: Use bpf_tracing.h instead of bpf_tcp_helpers.h (Viktor Malik) [RHEL-30773]
- powerpc/bpf: enable kfunc call (Viktor Malik) [RHEL-30773]
- libbpf: Avoid casts from pointers to enums in bpf_tracing.h (Viktor Malik) [RHEL-30773]
- libbpf: Fix bpf_ksym_exists() in GCC (Viktor Malik) [RHEL-30773]
- libbpf: fix ring_buffer__consume_n() return result logic (Viktor Malik) [RHEL-30773]
- libbpf: fix potential overflow in ring__consume_n() (Viktor Malik) [RHEL-30773]
- bpf: Missing trailing slash in tools/testing/selftests/bpf/Makefile (Viktor Malik) [RHEL-30773]
- libbpf: Fix error message in attach_kprobe_multi (Viktor Malik) [RHEL-30773]
- libbpf: Fix error message in attach_kprobe_session (Viktor Malik) [RHEL-30773]
- libbpf: better fix for handling nulled-out struct_ops program (Viktor Malik) [RHEL-30773]
- selftests/bpf: add tests for the "module: Function" syntax (Viktor Malik) [RHEL-30773]
- libbpf: support "module: Function" syntax for tracing programs (Viktor Malik) [RHEL-30773]
- bpf: Add BPF_PROG_TYPE_CGROUP_SKB attach type enforcement in BPF_LINK_CREATE (Viktor Malik) [RHEL-30773 RHEL-64874] {CVE-2024-38564}
- selftests/bpf: Add kprobe session cookie test (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add kprobe session test (Viktor Malik) [RHEL-30773]
- libbpf: Add kprobe session attach type name to attach_type_name (Viktor Malik) [RHEL-30773]
- libbpf: Add support for kprobe session attach (Viktor Malik) [RHEL-30773]
- bpf: Add support for kprobe session cookie (Viktor Malik) [RHEL-30773]
- bpf: Add support for kprobe session context (Viktor Malik) [RHEL-30773]
- bpf: Add support for kprobe session attach (Viktor Malik) [RHEL-30773]
- selftests/bpf: Drop an unused local variable (Viktor Malik) [RHEL-30773]
- bpf: Do not walk twice the hash map on free (Viktor Malik) [RHEL-30773]
- bpf: Do not walk twice the map on free (Viktor Malik) [RHEL-30773]
- selftests/bpf: validate nulled-out struct_ops program is handled properly (Viktor Malik) [RHEL-30773]
- libbpf: handle nulled-out program in struct_ops correctly (Viktor Malik) [RHEL-30773]
- bpf: Include linux/types.h for u32 (Viktor Malik) [RHEL-30773]
- selftests/bpf: Free strdup memory in veristat (Viktor Malik) [RHEL-30773]
- bpf: Switch to krealloc_array() (Viktor Malik) [RHEL-30773]
- bpf: Use struct_size() (Viktor Malik) [RHEL-30773]
- samples/bpf: Add valid info for VMLINUX_BTF (Viktor Malik) [RHEL-30773]
- bpf: Fix verifier assumptions about socket->sk (Viktor Malik) [RHEL-30773]
- bpf, docs: Clarify PC use in instruction-set.rst (Viktor Malik) [RHEL-30773]
- bpf_helpers.h: Define bpf_tail_call_static when building with GCC (Viktor Malik) [RHEL-30773]
- bpf, docs: Add introduction for use in the ISA Internet Draft (Viktor Malik) [RHEL-30773]
- selftests/bpf: dummy_st_ops should reject 0 for non-nullable params (Viktor Malik) [RHEL-30773]
- bpf: check bpf_dummy_struct_ops program params for test runs (Viktor Malik) [RHEL-30773]
- selftests/bpf: do not pass NULL for non-nullable params in dummy_st_ops (Viktor Malik) [RHEL-30773]
- selftests/bpf: adjust dummy_st_ops_success to detect additional error (Viktor Malik) [RHEL-30773]
- bpf: mark bpf_dummy_struct_ops.test_1 parameter as nullable (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add ring_buffer__consume_n test. (Viktor Malik) [RHEL-30773]
- bpf: Add bpf_guard_preempt() convenience macro (Viktor Malik) [RHEL-30773]
- bpf: update the comment for BTF_FIELDS_MAX (Viktor Malik) [RHEL-30773]
- selftests/bpf: Fix wq test. (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add tests for preempt kfuncs (Viktor Malik) [RHEL-30773]
- bpf: Introduce bpf_preempt_[disable,enable] kfuncs (Viktor Malik) [RHEL-30773]
- bpf: Don't check for recursion in bpf_wq_work. (Viktor Malik) [RHEL-30773]
- selftests/bpf: wq: add bpf_wq_start() checks (Viktor Malik) [RHEL-30773]
- bpf: add bpf_wq_start (Viktor Malik) [RHEL-30773]
- selftests/bpf: add checks for bpf_wq_set_callback() (Viktor Malik) [RHEL-30773]
- bpf: wq: add bpf_wq_set_callback_impl (Viktor Malik) [RHEL-30773]
- selftests/bpf: wq: add bpf_wq_init() checks (Viktor Malik) [RHEL-30773]
- bpf: wq: add bpf_wq_init (Viktor Malik) [RHEL-30773]
- selftests/bpf: add bpf_wq tests (Viktor Malik) [RHEL-30773]
- bpf: allow struct bpf_wq to be embedded in arraymaps and hashmaps (Viktor Malik) [RHEL-30773]
- bpf: add support for KF_ARG_PTR_TO_WORKQUEUE (Viktor Malik) [RHEL-30773]
- bpf: verifier: bail out if the argument is not a map (Viktor Malik) [RHEL-30773]
- tools: sync include/uapi/linux/bpf.h (Viktor Malik) [RHEL-30773]
- bpf: add support for bpf_wq user type (Viktor Malik) [RHEL-30773]
- bpf: replace bpf_timer_cancel_and_free with a generic helper (Viktor Malik) [RHEL-30773]
- bpf: replace bpf_timer_set_callback with a generic helper (Viktor Malik) [RHEL-30773]
- bpf: replace bpf_timer_init with a generic helper (Viktor Malik) [RHEL-30773]
- bpf: make timer data struct more generic (Viktor Malik) [RHEL-30773]
- bpf: Fix typos in comments (Viktor Malik) [RHEL-30773]
- bpf: Fix typo in function save_aux_ptr_type (Viktor Malik) [RHEL-30773]
- bpf, docs: Fix formatting nit in instruction-set.rst (Viktor Malik) [RHEL-30773]
- bpf, docs: Clarify helper ID and pointer terms in instruction-set.rst (Viktor Malik) [RHEL-30773]
- bpf: Fix JIT of is_mov_percpu_addr instruction. (Viktor Malik) [RHEL-30773]
- libbpf: Fix dump of subsequent char arrays (Viktor Malik) [RHEL-30773]
- libbpf: Fix misaligned array closing bracket (Viktor Malik) [RHEL-30773]
- bpftool: Address minor issues in bash completion (Viktor Malik) [RHEL-30773]
- bpftool: Update documentation where progs/maps can be passed by name (Viktor Malik) [RHEL-30773]
- bpf: Harden and/or/xor value tracking in verifier (Viktor Malik) [RHEL-30773]
- bpf, tests: Fix typos in comments (Viktor Malik) [RHEL-30773]
- btf: Avoid weak external references (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add read_trace_pipe_iter function (Viktor Malik) [RHEL-30773]
- bpftool: Fix typo in error message (Viktor Malik) [RHEL-30773]
- selftest/bpf: Test a perf BPF program that suppresses side effects (Viktor Malik) [RHEL-30773]
- tools include: Add some common function attributes (Viktor Malik) [RHEL-30773]
- bpf: Choose RCU Tasks based on TASKS_RCU rather than PREEMPTION (Viktor Malik) [RHEL-30773]
- selftests/bpf: Enable tests for atomics with cpuv4 (Viktor Malik) [RHEL-30773]
- bpftool: Add link dump support for BPF_LINK_TYPE_SOCKMAP (Viktor Malik) [RHEL-30773]
- libbpf: Add bpf_link support for BPF_PROG_TYPE_SOCKMAP (Viktor Malik) [RHEL-30773]
- bpf: Add bpf_link support for sk_msg and sk_skb progs [UAPI headers only] (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add tests for atomics in bpf_arena. (Viktor Malik) [RHEL-30773]
- bpf: Add support for certain atomics in bpf_arena to x86 JIT (Viktor Malik) [RHEL-30773]
- selftests/bpf: eliminate warning of get_cgroup_id_from_path() (Viktor Malik) [RHEL-30773]
- libbpf: Add ring__consume_n / ring_buffer__consume_n (Viktor Malik) [RHEL-30773]
- libbpf: ringbuf: Allow to consume up to a certain amount of items (Viktor Malik) [RHEL-30773]
- libbpf: Start v1.5 development cycle (Viktor Malik) [RHEL-30773]
- selftests/bpf: Verify calling core kfuncs from BPF_PROG_TYPE_SYCALL (Viktor Malik) [RHEL-30773]
- bpf: Allow invoking kfuncs from BPF_PROG_TYPE_SYSCALL progs (Viktor Malik) [RHEL-30773]
- bpf, docs: Editorial nits in instruction-set.rst (Viktor Malik) [RHEL-30773]
- selftests/bpf: Make sure libbpf doesn't enforce the signature of a func pointer. (Viktor Malik) [RHEL-30773]
- selftests/bpf: add test for bpf_for_each_map_elem() with different maps (Viktor Malik) [RHEL-30773]
- bpf: allow invoking bpf_for_each_map_elem with different maps (Viktor Malik) [RHEL-30773]
- bpf: store both map ptr and state in bpf_insn_aux_data (Viktor Malik) [RHEL-30773]
- bpf: fix perf_snapshot_branch_stack link failure (Viktor Malik) [RHEL-30773]
- selftests/bpf: add fp-leaking precise subprog result tests (Viktor Malik) [RHEL-30773]
- bpf: prevent r10 register from being marked as precise (Viktor Malik) [RHEL-30773]
- bpftool: Mount bpffs on provided dir instead of parent dir (Viktor Malik) [RHEL-30773]
- bpf: inline bpf_get_branch_snapshot() helper (Viktor Malik) [RHEL-30773]
- bpf: make bpf_get_branch_snapshot() architecture-agnostic (Viktor Malik) [RHEL-30773]
- bpf: Optimize emit_mov_imm64(). (Viktor Malik) [RHEL-30773]
- bpf: handle CONFIG_SMP=n configuration in x86 BPF JIT (Viktor Malik) [RHEL-30773]
- bpf: inline bpf_map_lookup_elem() helper for PERCPU_HASH map (Viktor Malik) [RHEL-30773]
- bpf: inline bpf_map_lookup_elem() for PERCPU_ARRAY maps (Viktor Malik) [RHEL-30773]
- bpf: inline bpf_get_smp_processor_id() helper (Viktor Malik) [RHEL-30773]
- bpf: add special internal-only MOV instruction to resolve per-CPU addrs (Viktor Malik) [RHEL-30773]
- bpf: Replace deprecated strncpy with strscpy (Viktor Malik) [RHEL-30773]
- bpf: Add arm64 JIT support for bpf_addr_space_cast instruction. (Viktor Malik) [RHEL-30773]
- bpf: Add arm64 JIT support for PROBE_MEM32 pseudo instructions. (Viktor Malik) [RHEL-30773]
- libbpf: Use local bpf_helpers.h include (Viktor Malik) [RHEL-30773]
- bpf: Improve program stats run-time calculation (Viktor Malik) [RHEL-30773]
- selftests/bpf: Skip test when perf_event_open returns EOPNOTSUPP (Viktor Malik) [RHEL-30773]
- bpftool: Use __typeof__() instead of typeof() in BPF skeleton (Viktor Malik) [RHEL-30773]
- selftests/bpf: Using llvm may_goto inline asm for cond_break macro (Viktor Malik) [RHEL-30773]
- bpf: Add a verbose message if map limit is reached (Viktor Malik) [RHEL-30773]
- bpf: Fix typo in uapi doc comments (Viktor Malik) [RHEL-30773]
- bpftool: Clean-up typos, punctuation, list formatting in docs (Viktor Malik) [RHEL-30773]
- bpftool: Remove useless emphasis on command description in man pages (Viktor Malik) [RHEL-30773]
- bpftool: Use simpler indentation in source rST for documentation (Viktor Malik) [RHEL-30773]
- selftests/bpf: make multi-uprobe tests work in RELEASE=1 mode (Viktor Malik) [RHEL-30773]
- bpf: Avoid kfree_rcu() under lock in bpf_lpm_trie. (Viktor Malik) [RHEL-30773]
- bpf: Mark bpf prog stack with kmsan_unposion_memory in interpreter mode (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add a kprobe_multi subtest to use addrs instead of syms (Viktor Malik) [RHEL-30773]
- selftests/bpf: Fix kprobe_multi_bench_attach test failure with LTO kernel (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add {load,search}_kallsyms_custom_local() (Viktor Malik) [RHEL-30773]
- selftests/bpf: Refactor trace helper func load_kallsyms_local() (Viktor Malik) [RHEL-30773]
- selftests/bpf: Refactor some functions for kprobe_multi_test (Viktor Malik) [RHEL-30773]
- libbpf: Handle <orig_name>.llvm.<hash> symbol properly (Viktor Malik) [RHEL-30773]
- libbpf: Mark libbpf_kallsyms_parse static function (Viktor Malik) [RHEL-30773]
- selftests/bpf: Replace CHECK with ASSERT macros for ksyms test (Viktor Malik) [RHEL-30773]
- selftests/bpf: add batched tp/raw_tp/fmodret tests (Viktor Malik) [RHEL-30773]
- bpf: add bpf_modify_return_test_tp() kfunc triggering tracepoint (Viktor Malik) [RHEL-30773]
- selftests/bpf: lazy-load trigger bench BPF programs (Viktor Malik) [RHEL-30773]
- selftests/bpf: remove syscall-driven benchs, keep syscall-count only (Viktor Malik) [RHEL-30773]
- selftests/bpf: add batched, mostly in-kernel BPF triggering benchmarks (Viktor Malik) [RHEL-30773]
- bpf: Mitigate latency spikes associated with freeing non-preallocated htab (Viktor Malik) [RHEL-30773]
- selftests/bpf: rename and clean up userspace-triggered benchmarks (Viktor Malik) [RHEL-30773]
- bpf,arena: Use helper sizeof_field in struct accessors (Viktor Malik) [RHEL-30773]
- bpf: implement insn_is_cast_user() helper for JITs (Viktor Malik) [RHEL-30773]
- bpf: Avoid get_kernel_nofault() to fetch kprobe entry IP (Viktor Malik) [RHEL-30773]
- bpf: Sync uapi bpf.h to tools directory (Viktor Malik) [RHEL-30773]
- libbpf: Add new sec_def "sk_skb/verdict" (Viktor Malik) [RHEL-30773]
- selftests/bpf: Mark uprobe trigger functions with nocf_check attribute (Viktor Malik) [RHEL-30773]
- selftests/bpf: Use syscall(SYS_gettid) instead of gettid() wrapper in bench (Viktor Malik) [RHEL-30773]
- bpf-next: Avoid goto in regs_refine_cond_op() (Viktor Malik) [RHEL-30773]
- bpftool: Clean up HOST_CFLAGS, HOST_LDFLAGS for bootstrap bpftool (Viktor Malik) [RHEL-30773]
- selftests/bpf: scale benchmark counting by using per-CPU counters (Viktor Malik) [RHEL-30773]
- bpftool: Remove unnecessary source files from bootstrap version (Viktor Malik) [RHEL-30773]
- bpftool: Enable libbpf logs when loading pid_iter in debug mode (Viktor Malik) [RHEL-30773]
- selftests/bpf: add raw_tp/tp_btf BPF cookie subtests (Viktor Malik) [RHEL-30773]
- libbpf: add support for BPF cookie for raw_tp/tp_btf programs (Viktor Malik) [RHEL-30773]
- bpf: support BPF cookie in raw tracepoint (raw_tp, tp_btf) programs (Viktor Malik) [RHEL-30773]
- bpf: pass whole link instead of prog when triggering raw tracepoint (Viktor Malik) [RHEL-30773]
- bpf: flatten bpf_probe_register call chain (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add a sk_msg prog bpf_get_ns_current_pid_tgid() test (Viktor Malik) [RHEL-30773]
- selftests/bpf: Add a cgroup prog bpf_get_ns_current_pid_tgid() test (Viktor Malik) [RHEL-30773]
- selftests/bpf: Refactor out some functions in ns_current_pid_tgid test (Viktor Malik) [RHEL-30773]
- selftests/bpf: Replace CHECK with ASSERT_* in ns_current_pid_tgid test (Viktor Malik) [RHEL-30773]
- bpf: Allow helper bpf_get_[ns_]current_pid_tgid() for all prog types (Viktor Malik) [RHEL-30773]
- bpf/lpm_trie: Inline longest_prefix_match for fastpath (Viktor Malik) [RHEL-30773]
- bpf: Check return from set_memory_rox() (Viktor Malik) [RHEL-30773]
- libbpbpf: Check bpf_map/bpf_program fd validity (Viktor Malik) [RHEL-30773]
- selftests/bpf: Remove second semicolon (Viktor Malik) [RHEL-30773]
- bpf: Take return from set_memory_rox() into account with bpf_jit_binary_lock_ro() (Viktor Malik) [RHEL-30773]
- bpf: Take return from set_memory_ro() into account with bpf_prog_lock_ro() (Viktor Malik) [RHEL-30773]
- bpf: preserve sleepable bit in subprog info (Viktor Malik) [RHEL-30773]
- selftests/bpf: Ensure libbpf skip all-zeros fields of struct_ops maps. (Viktor Malik) [RHEL-30773]
- libbpf: Skip zeroed or null fields if not found in the kernel type. (Viktor Malik) [RHEL-30773]
- bpftool: Fix missing pids during link show (Viktor Malik) [RHEL-30773]
- bpftool: Cast pointers for shadow types explicitly. (Viktor Malik) [RHEL-30773]
- arm64: probes: Remove broken LDR (literal) uprobe support (CKI Backport Bot) [RHEL-66045] {CVE-2024-50099}
- xfrm: fix one more kernel-infoleak in algo dumping (CKI Backport Bot) [RHEL-65959] {CVE-2024-50110}
- net: napi: Prevent overflow of napi_defer_hard_irqs (Antoine Tenart) [RHEL-63914] {CVE-2024-50018}
- net: tighten bad gso csum offset check in virtio_net_hdr (Guillaume Nault) [RHEL-62411]
- udp: fix receiving fraglist GSO packets (Guillaume Nault) [RHEL-62411]
- redhat/configs: For aarch64/RT, default kstack randomization off (Gabriele Monaco) [RHEL-62390]
- wifi: ath11k: fix RCU documentation in ath11k_mac_op_ipv6_changed() (Antoine Tenart) [RHEL-62205]
- wifi: ath11k: use RCU when accessing struct inet6_dev::ac_list (Antoine Tenart) [RHEL-62205]
- ipv6: Fix address dump when IPv6 is disabled on an interface (Antoine Tenart) [RHEL-62205]
- ipv6: remove RTNL protection from inet6_dump_addr() (Antoine Tenart) [RHEL-62205]
- ipv6: use xa_array iterator to implement inet6_dump_addr() (Antoine Tenart) [RHEL-62205]
- ipv6: remove unnecessary local variable (Antoine Tenart) [RHEL-62205]
- ipv6: make in6_dump_addrs() lockless (Antoine Tenart) [RHEL-62205]
- ipv6: make inet6_fill_ifaddr() lockless (Antoine Tenart) [RHEL-62205]
- ipv6: anycast: complete RCU handling of struct ifacaddr6 (Antoine Tenart) [RHEL-62205]
- inet: fix inet_fill_ifaddr() flags truncation (Antoine Tenart) [RHEL-62204]
- inet6: expand rcu_read_lock() scope in inet6_dump_addr() (Antoine Tenart) [RHEL-62204]
- rtnetlink: make the "split" NLM_DONE handling generic (Antoine Tenart) [RHEL-62204]
- ipv4: correctly iterate over the target netns in inet_dump_ifaddr() (Antoine Tenart) [RHEL-62204]
- ipv4: Fix address dump when IPv4 is disabled on an interface (Antoine Tenart) [RHEL-62204]
- rtnetlink: use xarray iterator to implement rtnl_dump_ifinfo() (Antoine Tenart) [RHEL-62204]
- inet: use xa_array iterator to implement inet_dump_ifaddr() (Antoine Tenart) [RHEL-62204]
- inet: prepare inet_base_seq() to run without RTNL (Antoine Tenart) [RHEL-62204]
- inet: annotate data-races around ifa->ifa_flags (Antoine Tenart) [RHEL-62204]
- inet: annotate data-races around ifa->ifa_preferred_lft (Antoine Tenart) [RHEL-62204]
- inet: annotate data-races around ifa->ifa_valid_lft (Antoine Tenart) [RHEL-62204]
- inet: annotate data-races around ifa->ifa_tstamp and ifa->ifa_cstamp (Antoine Tenart) [RHEL-62204]
- ipv6: use xa_array iterator to implement inet6_netconf_dump_devconf() (Antoine Tenart) [RHEL-62203]
- ipv6/addrconf: annotate data-races around devconf fields (II) (Antoine Tenart) [RHEL-62203]
- ipv6: Remove duplicate statements (Antoine Tenart) [RHEL-62203]
- ipv6/addrconf: annotate data-races around devconf fields (I) (Antoine Tenart) [RHEL-62203]
- ipv6: addrconf_disable_policy() optimization (Antoine Tenart) [RHEL-62203]
- ipv6: annotate data-races around devconf->disable_policy (Antoine Tenart) [RHEL-62203]
- ipv6: annotate data-races around devconf->proxy_ndp (Antoine Tenart) [RHEL-62203]
- ipv6: annotate data-races in rt6_probe() (Antoine Tenart) [RHEL-62203]
- ipv6: annotate data-races around idev->cnf.ignore_routes_with_linkdown (Antoine Tenart) [RHEL-62203]
- ipv6: annotate data-races in ndisc_router_discovery() (Antoine Tenart) [RHEL-62203]
- ipv6: annotate data-races around cnf.forwarding (Antoine Tenart) [RHEL-62203]
- ipv6: annotate data-races around cnf.hop_limit (Antoine Tenart) [RHEL-62203]
- ipv6: annotate data-races around cnf.mtu6 (Antoine Tenart) [RHEL-62203]
- ipv6: addrconf_disable_ipv6() optimization (Antoine Tenart) [RHEL-62203]
- ipv6: annotate data-races around cnf.disable_ipv6 (Antoine Tenart) [RHEL-62203]
- ipv6: add ipv6_devconf_read_txrx cacheline_group (Antoine Tenart) [RHEL-62203]
- inet: use xa_array iterator to implement inet_netconf_dump_devconf() (Antoine Tenart) [RHEL-62202]
- inet: do not use RTNL in inet_netconf_get_devconf() (Antoine Tenart) [RHEL-62202]
- inet: annotate devconf data-races (Antoine Tenart) [RHEL-62202]
- slip: make slhc_remember() more robust against malicious packets (CKI Backport Bot) [RHEL-63892] {CVE-2024-50033}
- mm: split critical region in remap_file_pages() and invoke LSMs in between (Waiman Long) [RHEL-63349]
- mm: call the security_mmap_file() LSM hook in remap_file_pages() (Waiman Long) [RHEL-63349] {CVE-2024-47745}
- NFS: Further fixes to attribute delegation a/mtime changes (Scott Mayhew) [RHEL-59704]
- NFS: Fix attribute delegation behaviour on exclusive create (Scott Mayhew) [RHEL-59704]
- rpcrdma: Always release the rpcrdma_device's xa_array (Scott Mayhew) [RHEL-59704]
- nfsd: fix possible badness in FREE_STATEID (Scott Mayhew) [RHEL-59704]
- NFSv4.2: Fix detection of "Proxying of Times" server support (Scott Mayhew) [RHEL-59704]
- nfsd: fix initial getattr on write delegation (Scott Mayhew) [RHEL-59704]
- nfsd: untangle code in nfsd4_deleg_getattr_conflict() (Scott Mayhew) [RHEL-59704]
- NFSD: remove redundant assignment operation (Scott Mayhew) [RHEL-59704]
- nfsd/sunrpc: have svc tasks sleep in TASK_IDLE (Scott Mayhew) [RHEL-59704]
- nfsd: fix nfsd4_deleg_getattr_conflict in presence of third party lease (Scott Mayhew) [RHEL-59704]
- fs/nfsd: fix update of inode attrs in CB_GETATTR (Scott Mayhew) [RHEL-59704]
- nfsd: fix potential UAF in nfsd4_cb_getattr_release (Scott Mayhew) [RHEL-59704]
- nfsd: hold reference to delegation when updating it for cb_getattr (Scott Mayhew) [RHEL-59704]
- nfsd: prevent panic for nfsv4.0 closed files in nfs4_show_open (Scott Mayhew) [RHEL-59704]
- NFS: Avoid unnecessary rescanning of the per-server delegation list (Scott Mayhew) [RHEL-59704]
- NFSv4: Fix clearing of layout segments in layoutreturn (Scott Mayhew) [RHEL-59704]
- NFSv4: Add missing rescheduling points in nfs_client_return_marked_delegations (Scott Mayhew) [RHEL-59704]
- nfs: fix bitmap decoder to handle a 3rd word (Scott Mayhew) [RHEL-59704]
- nfs: fix the fetch of FATTR4_OPEN_ARGUMENTS (Scott Mayhew) [RHEL-59704]
- rpcrdma: Trace connection registration and unregistration (Scott Mayhew) [RHEL-59704]
- rpcrdma: Use XA_FLAGS_ALLOC instead of XA_FLAGS_ALLOC1 (Scott Mayhew) [RHEL-59704]
- rpcrdma: Device kref is over-incremented on error from xa_alloc (Scott Mayhew) [RHEL-59704]
- nfsd: don't set SVC_SOCK_ANONYMOUS when creating nfsd sockets (Scott Mayhew) [RHEL-59704]
- sunrpc: avoid -Wformat-security warning (Scott Mayhew) [RHEL-59704]
- SUNRPC: Fix a race to wake a sync task (Scott Mayhew) [RHEL-59704]
- nfs: split nfs_read_folio (Scott Mayhew) [RHEL-59704]
- nfs: do not extend writes to the entire folio (Scott Mayhew) [RHEL-59704]
- nfs/blocklayout: add support for NVMe (Scott Mayhew) [RHEL-59704]
- nfs: remove nfs_page_length (Scott Mayhew) [RHEL-59704]
- nfs: remove the unused max_deviceinfo_size field from struct pnfs_layoutdriver_type (Scott Mayhew) [RHEL-59704]
- nfsd: new netlink ops to get/set server pool_mode (Scott Mayhew) [RHEL-59704]
- sunrpc: refactor pool_mode setting code (Scott Mayhew) [RHEL-59704]
- nfsd: allow passing in array of thread counts via netlink (Scott Mayhew) [RHEL-59704]
- nfsd: make nfsd_svc take an array of thread counts (Scott Mayhew) [RHEL-59704]
- sunrpc: fix up the special handling of sv_nrpools == 1 (Scott Mayhew) [RHEL-59704]
- SUNRPC: Add a trace point in svc_xprt_deferred_close (Scott Mayhew) [RHEL-59704]
- lockd: Use *-y instead of *-objs in Makefile (Scott Mayhew) [RHEL-59704]
- svcrdma: Handle ADDR_CHANGE CM event properly (Scott Mayhew) [RHEL-59704]
- svcrdma: Refactor the creation of listener CMA ID (Scott Mayhew) [RHEL-59704]
- NFSD: remove unused structs 'nfsd3_voidargs' (Scott Mayhew) [RHEL-59704]
- NFSD: harden svcxdr_dupstr() and svcxdr_tmpalloc() against integer overflows (Scott Mayhew) [RHEL-59704]
- nfs: don't reuse partially completed requests in nfs_lock_and_join_requests (Scott Mayhew) [RHEL-59704]
- nfs: move nfs_wait_on_request to write.c (Scott Mayhew) [RHEL-59704]
- nfs: fold nfs_page_group_lock_subrequests into nfs_lock_and_join_requests (Scott Mayhew) [RHEL-59704]
- nfs: fold nfs_folio_find_and_lock_request into nfs_lock_and_join_requests (Scott Mayhew) [RHEL-59704]
- nfs: simplify nfs_folio_find_and_lock_request (Scott Mayhew) [RHEL-59704]
- nfs: remove nfs_folio_private_request (Scott Mayhew) [RHEL-59704]
- nfs: remove dead code for the old swap over NFS implementation (Scott Mayhew) [RHEL-59704]
- nfs: Block on write congestion (Scott Mayhew) [RHEL-59704]
- nfs: Properly initialize server->writeback (Scott Mayhew) [RHEL-59704]
- nfs: Drop pointless check from nfs_commit_release_pages() (Scott Mayhew) [RHEL-59704]
- nfs/blocklayout: SCSI layout trace points for reservation key reg/unreg (Scott Mayhew) [RHEL-59704]
- nfs/blocklayout: Report only when /no/ device is found (Scott Mayhew) [RHEL-59704]
- nfs/blocklayout: Fix premature PR key unregistration (Scott Mayhew) [RHEL-59704]
- NFSv4/pNFS: Do layout state recovery upon reboot (Scott Mayhew) [RHEL-59704]
- NFSv4/pNFS: Remove redundant call to unhash the layout (Scott Mayhew) [RHEL-59704]
- NFSv4/pnfs: Give nfs4_proc_layoutreturn() a flags argument (Scott Mayhew) [RHEL-59704]
- NFSv4/pNFS: Retry the layout return later in case of a timeout or reboot (Scott Mayhew) [RHEL-59704]
- NFSv4/pNFS: Handle server reboots in pnfs_poc_release() (Scott Mayhew) [RHEL-59704]
- NFSv4/pNFS: Add a helper to defer failed layoutreturn calls (Scott Mayhew) [RHEL-59704]
- NFSv4/pnfs: Add support for the PNFS_LAYOUT_FILE_BULK_RETURN flag (Scott Mayhew) [RHEL-59704]
- pNFS: Add a flag argument to pnfs_destroy_layouts_byclid() (Scott Mayhew) [RHEL-59704]
- NFSv4: Clean up encode_nfs4_stateid() (Scott Mayhew) [RHEL-59704]
- NFSv4.1: constify the stateid argument in nfs41_test_stateid() (Scott Mayhew) [RHEL-59704]
- NFSv4/pnfs: Remove redundant list check (Scott Mayhew) [RHEL-59704]
- NFSv4: Don't send delegation-related share access modes to CLOSE (Scott Mayhew) [RHEL-59704]
- Return the delegation when deleting sillyrenamed files (Scott Mayhew) [RHEL-59704]
- NFSv4: Ask for a delegation or an open stateid in OPEN (Scott Mayhew) [RHEL-59704]
- NFSv4: Add support for OPEN4_RESULT_NO_OPEN_STATEID (Scott Mayhew) [RHEL-59704]
- NFSv4: Detect support for OPEN4_SHARE_ACCESS_WANT_OPEN_XOR_DELEGATION (Scott Mayhew) [RHEL-59704]
- NFSv4: Add support for the FATTR4_OPEN_ARGUMENTS attribute (Scott Mayhew) [RHEL-59704]
- NFSv4: Don't request atime/mtime/size if they are delegated to us (Scott Mayhew) [RHEL-59704]
- NFSv4: Fix up delegated attributes in nfs_setattr (Scott Mayhew) [RHEL-59704]
- NFSv4: Delegreturn must set m/atime when they are delegated (Scott Mayhew) [RHEL-59704]
- NFSv4: Enable attribute delegations (Scott Mayhew) [RHEL-59704]
- NFSv4: Add a capability for delegated attributes (Scott Mayhew) [RHEL-59704]
- NFSv4: Add recovery of attribute delegations (Scott Mayhew) [RHEL-59704]
- NFSv4: Add support for delegated atime and mtime attributes (Scott Mayhew) [RHEL-59704]
- NFSv4: Add a flags argument to the 'have_delegation' callback (Scott Mayhew) [RHEL-59704]
- NFSv4: Add CB_GETATTR support for delegated attributes (Scott Mayhew) [RHEL-59704]
- NFSv4: Plumb in XDR support for the new delegation-only setattr op (Scott Mayhew) [RHEL-59704]
- NFSv4: Add new attribute delegation definitions (Scott Mayhew) [RHEL-59704]
- NFSv4: Refactor nfs4_opendata_check_deleg() (Scott Mayhew) [RHEL-59704]
- NFSv4: Clean up open delegation return structure (Scott Mayhew) [RHEL-59704]
- fs: nfs: add missing MODULE_DESCRIPTION() macros (Scott Mayhew) [RHEL-59704]
- NFS: remove unused struct 'mnt_fhstatus' (Scott Mayhew) [RHEL-59704]
- xprtrdma: Remove temp allocation of rpcrdma_rep objects (Scott Mayhew) [RHEL-59704]
- xprtrdma: Clean up synopsis of frwr_mr_unmap() (Scott Mayhew) [RHEL-59704]
- xprtrdma: Handle device removal outside of the CM event handler (Scott Mayhew) [RHEL-59704]
- rpcrdma: Implement generic device removal (Scott Mayhew) [RHEL-59704]
- xprtrdma: removed asm-generic headers from verbs.c (Scott Mayhew) [RHEL-59704]
- nfs: drop usage of folio_file_pos (Scott Mayhew) [RHEL-59704]
- nfs: Avoid flushing many pages with NFS_FILE_SYNC (Scott Mayhew) [RHEL-59704]
- nfs: propagate readlink errors in nfs_symlink_filler (Scott Mayhew) [RHEL-59704]
- pNFS: rework pnfs_generic_pg_check_layout to check IO range (Scott Mayhew) [RHEL-59704]
- pNFS/filelayout: check layout segment range (Scott Mayhew) [RHEL-59704]
- NFS: Don't enable NFS v2 by default (Scott Mayhew) [RHEL-59704]
- SUNRPC: fix handling expired GSS context (Scott Mayhew) [RHEL-59704]
- NFSv4: Fixup smatch warning for ambiguous return (Scott Mayhew) [RHEL-59704]
- NFS: make sure lock/nolock overriding local_lock mount option (Scott Mayhew) [RHEL-59704]
- pNFS/filelayout: Specify the layout segment range in LAYOUTGET (Scott Mayhew) [RHEL-59704]
- pNFS/filelayout: Remove the whole file layout requirement (Scott Mayhew) [RHEL-59704]
- NFS/knfsd: Remove the invalid NFS error 'NFSERR_OPNOTSUPP' (Scott Mayhew) [RHEL-59704]
- nfsd: set security label during create operations (Scott Mayhew) [RHEL-59704]
- NFSD: Add COPY status code to OFFLOAD_STATUS response (Scott Mayhew) [RHEL-59704]
- NFSD: Record status of async copy operation in struct nfsd4_copy (Scott Mayhew) [RHEL-59704]
- SUNRPC: Remove comment for sp_lock (Scott Mayhew) [RHEL-59704]
- NFSD: add listener-{set,get} netlink command (Scott Mayhew) [RHEL-59704]
- SUNRPC: add a new svc_find_listener helper (Scott Mayhew) [RHEL-59704]
- SUNRPC: introduce svc_xprt_create_from_sa utility routine (Scott Mayhew) [RHEL-59704]
- NFSD: add write_version to netlink command (Scott Mayhew) [RHEL-59704]
- NFSD: convert write_threads to netlink command (Scott Mayhew) [RHEL-59704]
- NFSD: allow callers to pass in scope string to nfsd_svc (Scott Mayhew) [RHEL-59704]
- NFSD: move nfsd_mutex handling into nfsd_svc callers (Scott Mayhew) [RHEL-59704]
- lockd: host: Remove unnecessary statements＇host = NULL;＇ (Scott Mayhew) [RHEL-59704]
- nfsd: optimise recalculate_deny_mode() for a common case (Scott Mayhew) [RHEL-59704]
- nfsd: add tracepoint in mark_client_expired_locked (Scott Mayhew) [RHEL-59704]
- nfsd: new tracepoint for check_slot_seqid (Scott Mayhew) [RHEL-59704]
- nfsd: drop extraneous newline from nfsd tracepoints (Scott Mayhew) [RHEL-59704]
- nfsd: trivial GET_DIR_DELEGATION support (Scott Mayhew) [RHEL-59704]
- NFSD: Move callback_wq into struct nfs4_client (Scott Mayhew) [RHEL-59704]
- nfsd: drop st_mutex before calling move_to_close_lru() (Scott Mayhew) [RHEL-59704]
- nfsd: replace rp_mutex to avoid deadlock in move_to_close_lru() (Scott Mayhew) [RHEL-59704]
- nfsd: move nfsd4_cstate_assign_replay() earlier in open handling. (Scott Mayhew) [RHEL-59704]
- nfsd: perform all find_openstateowner_str calls in the one place. (Scott Mayhew) [RHEL-59704]
- Revert "NFSD: Convert the callback workqueue to use delayed_work" (Scott Mayhew) [RHEL-59704]
- Revert "NFSD: Reschedule CB operations when backchannel rpc_clnt is shut down" (Scott Mayhew) [RHEL-59704]
- nfs: Handle error of rpc_proc_register() in nfs_net_init(). (Scott Mayhew) [RHEL-59704]
- SUNRPC: add a missing rpc_stat for TCP TLS (Scott Mayhew) [RHEL-59704]
- NFSD: Clean up nfsd4_encode_replay() (Scott Mayhew) [RHEL-59704]
- NFS: trace the uniquifier of fscache (Scott Mayhew) [RHEL-59704]
- NFS: remove unused variable nfs_rpcstat (Scott Mayhew) [RHEL-59704]
- nfs: properly protect nfs_direct_req fields (Scott Mayhew) [RHEL-59704]
- NFS: enable nconnect for RDMA (Scott Mayhew) [RHEL-59704]
- NFSv4: nfs4_do_open() is incorrectly triggering state recovery (Scott Mayhew) [RHEL-59704]
- NFS: avoid infinite loop in pnfs_update_layout. (Scott Mayhew) [RHEL-59704]
- nfs: make the rpc_stat per net namespace (Scott Mayhew) [RHEL-59704]
- nfs: expose /proc/net/sunrpc/nfs in net namespaces (Scott Mayhew) [RHEL-59704]
- sunrpc: add a struct rpc_stats arg to rpc_create_args (Scott Mayhew) [RHEL-59704]
- nfs: remove unused NFS_CALL macro (Scott Mayhew) [RHEL-59704]
- NFSv4.1: add tracepoint to trunked nfs4_exchange_id calls (Scott Mayhew) [RHEL-59704]
- NFSD: send OP_CB_RECALL_ANY to clients when number of delegations reaches its limit (Scott Mayhew) [RHEL-59704]
- NFSD: Document nfsd_setattr() fill-attributes behavior (Scott Mayhew) [RHEL-59704]
- nfsd: Fix NFSv3 atomicity bugs in nfsd_setattr() (Scott Mayhew) [RHEL-59704]
- NFSD: OP_CB_RECALL_ANY should recall both read and write delegations (Scott Mayhew) [RHEL-59704]
- NFSD: handle GETATTR conflict with write delegation (Scott Mayhew) [RHEL-59704]
- NFSD: add support for CB_GETATTR callback (Scott Mayhew) [RHEL-59704]
- nfsd: clean up comments over nfs4_client definition (Scott Mayhew) [RHEL-59704]
- svcrdma: Post WRs for Write chunks in svc_rdma_sendto() (Scott Mayhew) [RHEL-59704]
- svcrdma: Post the Reply chunk and Send WR together (Scott Mayhew) [RHEL-59704]
- svcrdma: Move write_info for Reply chunks into struct svc_rdma_send_ctxt (Scott Mayhew) [RHEL-59704]
- svcrdma: Post Send WR chain (Scott Mayhew) [RHEL-59704]
- svcrdma: Fix retry loop in svc_rdma_send() (Scott Mayhew) [RHEL-59704]
- svcrdma: Prevent a UAF in svc_rdma_send() (Scott Mayhew) [RHEL-59704]
- svcrdma: Fix SQ wake-ups (Scott Mayhew) [RHEL-59704]
- svcrdma: Increase the per-transport rw_ctx count (Scott Mayhew) [RHEL-59704]
- svcrdma: Update max_send_sges after QP is created (Scott Mayhew) [RHEL-59704]
- svcrdma: Report CQ depths in debugging output (Scott Mayhew) [RHEL-59704]
- svcrdma: Reserve an extra WQE for ib_drain_rq() (Scott Mayhew) [RHEL-59704]
- nfsd: allow layout state to be admin-revoked. (Scott Mayhew) [RHEL-59704]
- nfsd: allow delegation state ids to be revoked and then freed (Scott Mayhew) [RHEL-59704]
- nfsd: allow open state ids to be revoked and then freed (Scott Mayhew) [RHEL-59704]
- nfsd: allow lock state ids to be revoked and then freed (Scott Mayhew) [RHEL-59704]
- nfsd: allow admin-revoked NFSv4.0 state to be freed. (Scott Mayhew) [RHEL-59704]
- nfsd: report in /proc/fs/nfsd/clients/*/states when state is admin-revoke (Scott Mayhew) [RHEL-59704]
- nfsd: allow state with no file to appear in /proc/fs/nfsd/clients/*/states (Scott Mayhew) [RHEL-59704]
- nfsd: prepare for supporting admin-revocation of state (Scott Mayhew) [RHEL-59704]
- nfsd: split sc_status out of sc_type (Scott Mayhew) [RHEL-59704]
- nfsd: avoid race after unhash_delegation_locked() (Scott Mayhew) [RHEL-59704]
- nfsd: don't call functions with side-effecting inside WARN_ON() (Scott Mayhew) [RHEL-59704]
- nfsd: hold ->cl_lock for hash_delegation_locked() (Scott Mayhew) [RHEL-59704]
- nfsd: remove stale comment in nfs4_show_deleg() (Scott Mayhew) [RHEL-59704]
- NFSD: Remove redundant cb_seq_status initialization (Scott Mayhew) [RHEL-59704]
- SUNRPC: Remove EXPORT_SYMBOL_GPL for svc_process_bc() (Scott Mayhew) [RHEL-59704]
- nfsd: make svc_stat per-network namespace instead of global (Scott Mayhew) [RHEL-59704]
- nfsd: remove nfsd_stats, make th_cnt a global counter (Scott Mayhew) [RHEL-59704]
- nfsd: make all of the nfsd stats per-network namespace (Scott Mayhew) [RHEL-59704]
- nfsd: expose /proc/net/sunrpc/nfsd in net namespaces (Scott Mayhew) [RHEL-59704]
- nfsd: rename NFSD_NET_* to NFSD_STATS_* (Scott Mayhew) [RHEL-59704]
- sunrpc: use the struct net as the svc proc private (Scott Mayhew) [RHEL-59704]
- sunrpc: remove ->pg_stats from svc_program (Scott Mayhew) [RHEL-59704]
- sunrpc: pass in the sv_stats struct through svc_create_pooled (Scott Mayhew) [RHEL-59704]
- nfsd: stop setting ->pg_stats for unused stats (Scott Mayhew) [RHEL-59704]
- sunrpc: don't change ->sv_stats if it doesn't exist (Scott Mayhew) [RHEL-59704]
- nfsd: use __fput_sync() to avoid delayed closing of files. (Scott Mayhew) [RHEL-59704]
- nfsd: Don't leave work of closing files to a work queue (Scott Mayhew) [RHEL-59704]
- SUNRPC: increase size of rpc_wait_queue.qlen from unsigned short to unsigned int (Scott Mayhew) [RHEL-59704]
- nfs: fix regression in handling of fsc= option in NFSv4 (Scott Mayhew) [RHEL-59704]
- pnfs/filelayout: add tracepoint to getdeviceinfo (Scott Mayhew) [RHEL-59704]
- NFS: Display the "fsc=" mount option if it is set (Scott Mayhew) [RHEL-59704]
- SUNRPC: add xrpt id to rpc_stats_latency tracepoint (Scott Mayhew) [RHEL-59704]
- SUNRPC: Add a transport callback to handle dequeuing of an RPC request (Scott Mayhew) [RHEL-59704]
- SUNRPC: Don't try to send when the connection is shutting down (Scott Mayhew) [RHEL-59704]
- SUNRPC: Don't retry using the same source port if connection failed (Scott Mayhew) [RHEL-59704]
- SUNRPC: change the back-channel queue to lwq (Scott Mayhew) [RHEL-59704]
- SUNRPC: discard sp_lock (Scott Mayhew) [RHEL-59704]
- SUNRPC: change sp_nrthreads to atomic_t (Scott Mayhew) [RHEL-59704]
- SUNRPC: use lwq for sp_sockets - renamed to sp_xprts (Scott Mayhew) [RHEL-59704]
- SUNRPC: only have one thread waking up at a time (Scott Mayhew) [RHEL-59704]
- SUNRPC: rename some functions from rqst_ to svc_thread_ (Scott Mayhew) [RHEL-59704]
- lib: add light-weight queuing mechanism. (Scott Mayhew) [RHEL-59704]
- redhat/configs: add CONFIG_LWQ_TEST (Scott Mayhew) [RHEL-59704]
- llist: add llist_del_first_this() (Scott Mayhew) [RHEL-59704]
- SUNRPC: change service idle list to be an llist (Scott Mayhew) [RHEL-59704]
- llist: add interface to check if a node is on a list. (Scott Mayhew) [RHEL-59704]
- SUNRPC: discard SP_CONGESTED (Scott Mayhew) [RHEL-59704]
- SUNRPC: add list of idle threads (Scott Mayhew) [RHEL-59704]
- SUNRPC: change how svc threads are asked to exit. (Scott Mayhew) [RHEL-59704]
- nfsd: convert to ctime accessor functions (Scott Mayhew) [RHEL-59704]
- nfs: convert to ctime accessor functions (Scott Mayhew) [RHEL-59704]
- fs: drop the timespec64 arg from generic_update_time (Scott Mayhew) [RHEL-59704]
- fs: convert to ctime accessor functions (Scott Mayhew) [RHEL-59704]
- mptcp: pm: do not remove closing subflows (Davide Caratti) [RHEL-62871]
- mptcp: pm: fix ID 0 endp usage after multiple re-creations (Davide Caratti) [RHEL-58839 RHEL-62871] {CVE-2024-46711}
- mptcp: pm: do not remove already closed subflows (Davide Caratti) [RHEL-62871]
- mptcp: pm: reset MPC endp ID when re-added (Davide Caratti) [RHEL-62871]
- mptcp: pm: skip connecting to already established sf (Davide Caratti) [RHEL-62871]
- mptcp: pm: send ACK on an active subflow (Davide Caratti) [RHEL-62871]
- mptcp: pm: update add_addr counters after connect (Davide Caratti) [RHEL-62871]
- selftests: mptcp: join: cannot rm sf if closed (Davide Caratti) [RHEL-62871]
- selftests: mptcp: add evts_get_info helper (Davide Caratti) [RHEL-62871]
- selftests: mptcp: update userspace pm test helpers (Davide Caratti) [RHEL-62871]
- mptcp: pm: fix UaF read in mptcp_pm_nl_rm_addr_or_subflow (Davide Caratti) [RHEL-62871 RHEL-66074] {CVE-2024-45009}
- selftests: mptcp: join: restrict fullmesh endp on 1st sf (Davide Caratti) [RHEL-62871]
- mptcp: pm: ADD_ADDR 0 is not a new address (Davide Caratti) [RHEL-62871]
- mptcp: avoid duplicated SUB_CLOSED events (Davide Caratti) [RHEL-62871]
- selftests: mptcp: join: check removing ID 0 endpoint (Davide Caratti) [RHEL-62871]
- mptcp: pm: fix RM_ADDR ID for the initial subflow (Davide Caratti) [RHEL-62871]
- mptcp: pm: reuse ID 0 after delete and re-add (Davide Caratti) [RHEL-62871]
- mptcp: pr_debug: add missing \n at the end (Davide Caratti) [RHEL-62871]
- mptcp: sched: check both backup in retrans (Davide Caratti) [RHEL-62871]
- mptcp: close subflow when receiving TCP+FIN (Davide Caratti) [RHEL-62871]
- mptcp: pm: avoid possible UaF when selecting endp (Davide Caratti) [RHEL-62871]
- selftests: mptcp: join: validate fullmesh endp on 1st sf (Davide Caratti) [RHEL-62871]
- mptcp: pm: fullmesh: select the right ID later (Davide Caratti) [RHEL-62871]
- mptcp: pm: only in-kernel cannot have entries with ID 0 (Davide Caratti) [RHEL-62871]
- mptcp: pm: check add_addr_accept_max before accepting new ADD_ADDR (Davide Caratti) [RHEL-62871]
- mptcp: pm: only decrement add_addr_accepted for MPJ req (Davide Caratti) [RHEL-62871 RHEL-66074] {CVE-2024-45009}
- mptcp: pm: only mark 'subflow' endp as available (Davide Caratti) [RHEL-62871 RHEL-66083] {CVE-2024-45010}
- mptcp: pm: remove mptcp_pm_remove_subflow() (Davide Caratti) [RHEL-62871]
- mptcp: pm: re-using ID of unused flushed subflows (Davide Caratti) [RHEL-62871]
- selftests: mptcp: join: check re-using ID of closed subflow (Davide Caratti) [RHEL-62871]
- mptcp: pm: re-using ID of unused removed subflows (Davide Caratti) [RHEL-62871]
- mptcp: pm: re-using ID of unused removed ADD_ADDR (Davide Caratti) [RHEL-62871]
- mptcp: correct MPTCP_SUBFLOW_ATTR_SSN_OFFSET reserved size (Davide Caratti) [RHEL-62871]
- selftests: mptcp: join: test both signal & subflow (Davide Caratti) [RHEL-62871]
- selftests: mptcp: join: ability to invert ADD_ADDR check (Davide Caratti) [RHEL-62871]
- mptcp: pm: do not ignore 'subflow' if 'signal' flag is also set (Davide Caratti) [RHEL-62871]
- mptcp: pm: don't try to create sf if alloc failed (Davide Caratti) [RHEL-62871]
- mptcp: pm: reduce indentation blocks (Davide Caratti) [RHEL-62871]
- mptcp: pm: deny endp with signal + subflow + port (Davide Caratti) [RHEL-62871]
- mptcp: fully established after ADD_ADDR echo on MPJ (Davide Caratti) [RHEL-62871]
- mptcp: fix duplicate data handling (Davide Caratti) [RHEL-62871]
- mptcp: fix bad RCVPRUNED mib accounting (Davide Caratti) [RHEL-62871]
- selftests: mptcp: join: check backup support in signal endp (Davide Caratti) [RHEL-62871]
- mptcp: pm: fix backup support in signal endpoints (Davide Caratti) [RHEL-62871]
- selftests: mptcp: join: validate backup in MPJ (Davide Caratti) [RHEL-62871]
- mptcp: mib: count MPJ with backup flag (Davide Caratti) [RHEL-62871]
- mptcp: pm: only set request_bkup flag when sending MP_PRIO (Davide Caratti) [RHEL-62871]
- mptcp: distinguish rcv vs sent backup flag in requests (Davide Caratti) [RHEL-62871]
- mptcp: sched: check both directions for backup (Davide Caratti) [RHEL-62871]
- selftests: mptcp: always close input's FD if opened (Davide Caratti) [RHEL-62871]
- selftests: mptcp: fix error path (Davide Caratti) [RHEL-62871]
- mptcp: fix NL PM announced address accounting (Davide Caratti) [RHEL-62871]
- mptcp: fix user-space PM announced address accounting (Davide Caratti) [RHEL-62871]
- mptcp: add validity check for sending RM_ADDR (Davide Caratti) [RHEL-62871]
- mptcp: pm: inc RmAddr MIB counter once per RM_ADDR ID (Davide Caratti) [RHEL-62871]
- mptcp: include inet_common in mib.h (Davide Caratti) [RHEL-62871]
- mptcp: move mptcp_pm_gen.h's include (Davide Caratti) [RHEL-62871]
- mptcp: remove unnecessary else statements (Davide Caratti) [RHEL-62871]
- mptcp: prefer strscpy over strcpy (Davide Caratti) [RHEL-62871]
- mptcp: sockopt: info: stop early if no buffer (Davide Caratti) [RHEL-62871]
- mptcp: fix full TCP keep-alive support (Davide Caratti) [RHEL-62871]
- mptcp: SO_KEEPALIVE: fix getsockopt support (Davide Caratti) [RHEL-62871]
- tcp: set TCP_DEFER_ACCEPT locklessly (Davide Caratti) [RHEL-62871]
- tcp: set TCP_LINGER2 locklessly (Davide Caratti) [RHEL-62871]
- tcp: set TCP_KEEPCNT locklessly (Davide Caratti) [RHEL-62871]
- tcp: set TCP_KEEPINTVL locklessly (Davide Caratti) [RHEL-62871]
- tcp: set TCP_USER_TIMEOUT locklessly (Davide Caratti) [RHEL-62871]
- tcp: set TCP_SYNCNT locklessly (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around fastopenq.max_qlen (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around icsk->icsk_user_timeout (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around tp->notsent_lowat (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around rskq_defer_accept (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around tp->linger2 (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around icsk->icsk_syn_retries (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around tp->keepalive_probes (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around tp->keepalive_intvl (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around tp->keepalive_time (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around tp->tsoffset (Davide Caratti) [RHEL-62871]
- tcp: annotate data-races around tp->tcp_tx_delay (Davide Caratti) [RHEL-62871]
- net: do not delay dst_entries_add() in dst_release() (Paolo Abeni) [RHEL-62849]
- net: add more sanity checks to qdisc_pkt_len_init() (Paolo Abeni) [RHEL-62849 RHEL-64328] {CVE-2024-49948}
- net: Fix gso_features_check to check for both dev->gso_{ipv4_,}max_size (Paolo Abeni) [RHEL-62849]
- net: busy-poll: use ktime_get_ns() instead of local_clock() (Paolo Abeni) [RHEL-62849]
- pktgen: use cpus_read_lock() in pg_net_init() (Paolo Abeni) [RHEL-62849]
- net: linkwatch: use system_unbound_wq (Paolo Abeni) [RHEL-62849]
- rtnetlink: Don't ignore IFLA_TARGET_NETNSID when ifname is specified in rtnl_dellink(). (Paolo Abeni) [RHEL-62849]
- net: page_pool: fix warning code (Paolo Abeni) [RHEL-62849]
- net: give more chances to rcu in netdev_wait_allrefs_any() (Paolo Abeni) [RHEL-62849]
- bpf: Fix a kernel verifier crash in stacksafe() (CKI Backport Bot) [RHEL-66098] {CVE-2024-45020}
- bpf: Fix use-after-free in bpf_uprobe_multi_link_attach() (Viktor Malik) [RHEL-63330] {CVE-2024-47675}
- bpf: Fix out-of-bounds write in trie_get_next_key() (CKI Backport Bot) [RHEL-66876] {CVE-2024-50262}
- selftests/bpf: Add return value checks for failed tests (Viktor Malik) [RHEL-63343]
- selftests/bpf: Workaround strict bpf_lsm return value check. (Viktor Malik) [RHEL-63343]
- bpf: Fix compare error in function retval_range_within (Viktor Malik) [RHEL-63343]
- bpf, lsm: Add check for BPF LSM return value (CKI Backport Bot) [RHEL-63343] {CVE-2024-47703}
- scsi: sd: Fix off-by-one error in sd_read_block_characteristics() (Ewan D. Milne) [RHEL-62151]
- scsi: scsi_debug: Remove a useless memset() (Ewan D. Milne) [RHEL-62151]
- scsi: sd: Retry START STOP UNIT commands (Ewan D. Milne) [RHEL-62151]
- scsi: sd: Remove duplicate included header file linux/bio-integrity.h (Ewan D. Milne) [RHEL-62151]
- scsi: core: Remove obsoleted declaration for scsi_driverbyte_string() (Ewan D. Milne) [RHEL-62151]
- scsi: core: Simplify an alloc_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: ufs: Simplify alloc*_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: stex: Simplify an alloc_ordered_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: scsi_transport_fc: Simplify alloc_workqueue() invocations (Ewan D. Milne) [RHEL-62151]
- scsi: snic: Simplify alloc_workqueue() invocations (Ewan D. Milne) [RHEL-62151]
- scsi: qedi: Simplify an alloc_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: qedf: Simplify alloc_workqueue() invocations (Ewan D. Milne) [RHEL-62151]
- scsi: myrs: Simplify an alloc_ordered_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: myrb: Simplify an alloc_ordered_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: mpt3sas: Simplify an alloc_ordered_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: mpi3mr: Simplify an alloc_ordered_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: ibmvscsi_tgt: Simplify an alloc_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: fcoe: Simplify alloc_ordered_workqueue() invocations (Ewan D. Milne) [RHEL-62151]
- scsi: esas2r: Simplify an alloc_ordered_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: bfa: Simplify an alloc_ordered_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: be2iscsi: Simplify an alloc_workqueue() invocation (Ewan D. Milne) [RHEL-62151]
- scsi: mptfusion: Simplify the alloc*_workqueue() invocations (Ewan D. Milne) [RHEL-62151]
- scsi: Expand all create*_workqueue() invocations (Ewan D. Milne) [RHEL-62151]
- scsi: sd: Ignore command SYNCHRONIZE CACHE error if format in progress (Ewan D. Milne) [RHEL-62151]
- scsi: sd: Do not attempt to configure discard unless LBPME is set (Ewan D. Milne) [RHEL-62151]
- scsi: core: Fix the return value of scsi_logical_block_count() (Ewan D. Milne) [RHEL-62151]
- scsi: sd: Keep the discard mode stable (Ewan D. Milne) [RHEL-62151]
- minmax: scsi: fix mis-use of 'clamp()' in sr.c (Ewan D. Milne) [RHEL-62151]
- scsi: scsi_debug: Fix create target debugfs failure (Ewan D. Milne) [RHEL-62151]
- scsi: core: Fix an incorrect comment (Ewan D. Milne) [RHEL-62151]
- scsi: core: Disable CDL by default (Ewan D. Milne) [RHEL-62151]
- scsi: sd: Use READ(16) when reading block zero on large capacity disks (Ewan D. Milne) [RHEL-62151]
- scsi: core: Pass sdev to blk_mq_alloc_queue() (Ewan D. Milne) [RHEL-62151]
- scsi: sr: Fix unintentional arithmetic wraparound (Ewan D. Milne) [RHEL-62151]
- scsi: core: alua: I/O errors for ALUA state transitions (Ewan D. Milne) [RHEL-62151]
- scsi: core: Improve the code for showing commands in debugfs (Ewan D. Milne) [RHEL-62151]
- scsi: core: Introduce scsi_cmd_list_info() (Ewan D. Milne) [RHEL-62151]
- scsi: scsi_transport_srp: Fix a couple of kernel-doc warnings (Ewan D. Milne) [RHEL-62151]
- scsi: scsi_transport_fc: Add kernel-doc for function return (Ewan D. Milne) [RHEL-62151]
- scsi: core: Add function return kernel-doc for 2 functions (Ewan D. Milne) [RHEL-62151]
- scsi: libfcoe: Fix a slew of kernel-doc warnings (Ewan D. Milne) [RHEL-62151]
- scsi: iser: Fix @read_stag kernel-doc warning (Ewan D. Milne) [RHEL-62151]
- scsi: core: Add kernel-doc for scsi_msg_to_host_byte() (Ewan D. Milne) [RHEL-62151]
- scsi: st: Drop driver owner initialization (Ewan D. Milne) [RHEL-62151]
- scsi: sr: Drop driver owner initialization (Ewan D. Milne) [RHEL-62151]
- scsi: ses: Drop driver owner initialization (Ewan D. Milne) [RHEL-62151]
- scsi: sd: Drop driver owner initialization (Ewan D. Milne) [RHEL-62151]
- scsi: core: Store owner from modules with scsi_register_driver() (Ewan D. Milne) [RHEL-62151]
- scsi: devinfo: Replace strncpy() and manual pad (Ewan D. Milne) [RHEL-62151]
- scsi: sd: Have pr commands retry UAs (Ewan D. Milne) [RHEL-62151]
- scsi: Fix sshdr use in scsi_cdl_enable (Ewan D. Milne) [RHEL-62151]
- scsi: Add support for block PR read keys/reservation (Ewan D. Milne) [RHEL-62151]
- scsi: Move sd_pr_type to scsi_common (Ewan D. Milne) [RHEL-62151]
- scsi: Rename sd_pr_command (Ewan D. Milne) [RHEL-62151]
- scsi: core: Remove scsi_execute_req()/scsi_execute() functions (Ewan D. Milne) [RHEL-62151]
- scsi: Adjust recently added fields to SCSI and FC structures (Ewan D. Milne) [RHEL-62151]
- dpll: add Embedded SYNC feature for a pin (CKI Backport Bot) [RHEL-57743]
- dpll: fix return value check for kmemdup (CKI Backport Bot) [RHEL-57743]
- sched: sch_cake: fix bulk flow accounting logic for host fairness (CKI Backport Bot) [RHEL-60755] {CVE-2024-46828}
- mm/huge_memory: don't unpoison huge_zero_folio (Aristeu Rozanski) [RHEL-47802] {CVE-2024-40914}

* Tue Nov 19 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-532.el9]
- KVM: selftests: memslot_perf_test: increase guest sync timeout (Maxim Levitsky) [RHEL-66118]
- pinctrl: intel: platform: fix error path in device_for_each_child_node() (Steve Best) [RHEL-66957] {CVE-2024-50197}
- device property: Introduce device_for_each_child_node_scoped() (Steve Best) [RHEL-66957] {CVE-2024-50197}
- device property: Add cleanup.h based fwnode_handle_put() scope based cleanup. (Steve Best) [RHEL-66957] {CVE-2024-50197}
- kernel.spec: add bootconfig to kernel-tools package (Brian Masney) [RHEL-65546]
- bootconfig: Remove duplicate included header file linux/bootconfig.h (Brian Masney) [RHEL-65546]
- bootconfig: Fix the kerneldoc of _xbc_exit() (Brian Masney) [RHEL-65546]
- bootconfig: use memblock_free_late to free xbc memory to buddy (Brian Masney) [RHEL-65546]
- bootconfig: do not put quotes on cmdline items unless necessary (Brian Masney) [RHEL-65546]
- bootconfig: Fix testcase to increase max node (Brian Masney) [RHEL-65546]
- bootconfig: Change message if no bootconfig with CONFIG_BOOT_CONFIG_FORCE=y (Brian Masney) [RHEL-65546]
- tools/bootconfig: fix single & used for logical condition (Brian Masney) [RHEL-65546]
- bootconfig: Increase max nodes of bootconfig from 1024 to 8192 for DCC support (Brian Masney) [RHEL-65546]
- bootconfig: Default BOOT_CONFIG_FORCE to y if BOOT_CONFIG_EMBED (Brian Masney) [RHEL-65546]
- Allow forcing unconditional bootconfig processing (Brian Masney) [RHEL-65546]
- Documentation: Fixed a typo in bootconfig.rst (Brian Masney) [RHEL-65546]
- bootconfig: Support embedding a bootconfig file in kernel (Brian Masney) [RHEL-65546]
- bootconfig: Check the checksum before removing the bootconfig from initrd (Brian Masney) [RHEL-65546]
- docs: bootconfig: Add how to embed the bootconfig into kernel (Brian Masney) [RHEL-65546]
- bootconfig: Make the bootconfig.o as a normal object file (Brian Masney) [RHEL-65546]
- bootconfig: Initialize ret in xbc_parse_tree() (Brian Masney) [RHEL-65546]
- lib/bootconfig: Fix the xbc_get_info kerneldoc (Brian Masney) [RHEL-65546]
- lib/bootconfig: Make xbc_alloc_mem() and xbc_free_mem() as __init function (Brian Masney) [RHEL-65546]
- bootconfig: Cleanup dummy headers in tools/bootconfig (Brian Masney) [RHEL-65546]
- bootconfig: Replace u16 and u32 with uint16_t and uint32_t (Brian Masney) [RHEL-65546]
- bootconfig: Remove unused debug function (Brian Masney) [RHEL-65546]
- bootconfig: Split parse-tree part from xbc_init (Brian Masney) [RHEL-65546]
- bootconfig: Rename xbc_destroy_all() to xbc_exit() (Brian Masney) [RHEL-65546]
- tools/bootconfig: Run test script when build all (Brian Masney) [RHEL-65546]
- bootconfig: Add xbc_get_info() for the node information (Brian Masney) [RHEL-65546]
- bootconfig: Allocate xbc_data inside xbc_init() (Brian Masney) [RHEL-65546]
- init/bootconfig: Reorder init parameter from bootconfig and cmdline (Brian Masney) [RHEL-65546]
- init: bootconfig: Remove all bootconfig data when the init memory is removed (Brian Masney) [RHEL-65546]
- tools/bootconfig: Show whole test command for each test case (Brian Masney) [RHEL-65546]
- tools/bootconfig: Fix tracing_on option checking in ftrace2bconf.sh (Brian Masney) [RHEL-65546]
- docs: bootconfig: Add how to use bootconfig for kernel parameters (Brian Masney) [RHEL-65546]
- tracing/boot: Fix to check the histogram control param is a leaf node (Brian Masney) [RHEL-65546]
- tracing/boot: Fix trace_boot_hist_add_array() to check array is value (Brian Masney) [RHEL-65546]
- bootconfig: Rename xbc_node_find_child() to xbc_node_find_subkey() (Brian Masney) [RHEL-65546]
- bootconfig/tracing/ktest: Update ktest example for boot-time tracing (Brian Masney) [RHEL-65546]
- docs/trace: fix a label of boottime-trace (Brian Masney) [RHEL-65546]
- Documentation: tracing: Add histogram syntax to boot-time tracing (Brian Masney) [RHEL-65546]
- tracing: Fix missing trace_boot_init_histograms kstrdup NULL checks (Brian Masney) [RHEL-65546]
- tracing/boot: Show correct histogram error command (Brian Masney) [RHEL-65546]
- tracing/boot: Support multiple histograms for each event (Brian Masney) [RHEL-65546]
- tracing: Initialize integer variable to prevent garbage return value (Brian Masney) [RHEL-65546]
- tracing/boot: Support multiple handlers for per-event histogram (Brian Masney) [RHEL-65546]
- tracing/boot: Add per-event histogram action options (Brian Masney) [RHEL-65546]
- tracing/boot: Fix a hist trigger dependency for boot time tracing (Brian Masney) [RHEL-65546]
- tools/bootconfig: Use per-group/all enable option in ftrace2bconf script (Brian Masney) [RHEL-65546]
- tools/bootconfig: Add histogram syntax support to bconf2ftrace.sh (Brian Masney) [RHEL-65546]
- tools/bootconfig: Support per-group/all event enabling option (Brian Masney) [RHEL-65546]
- redhat/configs: set values for CONFIG_BOOT_CONFIG_{EMBED,FORCE} (Brian Masney) [RHEL-65546]
- tools/power/x86/intel-speed-select: v1.20 release (Steve Best) [RHEL-65196]
- tools/power/x86/intel-speed-select: Set TRL MSR in 100 MHz units (Steve Best) [RHEL-65196]
- platform/x86: ISST: Add Diamond Rapids to support list (Steve Best) [RHEL-65196]
- platform/x86: ISST: Fix return value on last invalid resource (Steve Best) [RHEL-65196]
- platform/x86: ISST: Simplify isst_misc_reg() and isst_misc_unreg() (Steve Best) [RHEL-65196]
- platform/x86: intel_speed_select_if: Switch to new Intel CPU model defines (Steve Best) [RHEL-65196]
- platform/x86: ISST: Use only TPMI interface when present (Steve Best) [RHEL-65196]
- platform/x86: ISST: Avoid some SkyLake server models (Steve Best) [RHEL-65196]
- platform/x86: ISST: Add model specific loading for common module (Steve Best) [RHEL-65196]
- x86/cpu: Add two Intel CPU model numbers (Steve Best) [RHEL-65196]
- ext4: fix i_data_sem unlock order in ext4_ind_migrate() (CKI Backport Bot) [RHEL-64540] {CVE-2024-50006}
- ext4: no need to continue when the number of entries is 1 (CKI Backport Bot) [RHEL-64524] {CVE-2024-49967}
- ext4: fix slab-use-after-free in ext4_split_extent_at() (CKI Backport Bot) [RHEL-64147] {CVE-2024-49884}
- ext4: drop ppath from ext4_ext_replay_update_ex() to avoid double-free (CKI Backport Bot) [RHEL-64010] {CVE-2024-49983}
- ext4: fix timer use-after-free on failed mount (CKI Backport Bot) [RHEL-64008] {CVE-2024-49960}
- ext4: aovid use-after-free in ext4_ext_insert_extent() (CKI Backport Bot) [RHEL-64001] {CVE-2024-49883}
- ext4: fix double brelse() the buffer of the extents path (CKI Backport Bot) [RHEL-63617] {CVE-2024-49882}
- driver core: Fix uevent_show() vs driver detach race (CKI Backport Bot) [RHEL-61583] {CVE-2024-44952}
- thermal: intel: hfi: Give HFI instances package scope (David Arcari) [RHEL-20130]
- thermal: intel: hfi: Increase the number of CPU capabilities per netlink event (David Arcari) [RHEL-20130]
- thermal: intel: hfi: Rename HFI_MAX_THERM_NOTIFY_COUNT (David Arcari) [RHEL-20130]
- thermal: intel: hfi: Shorten the thermal netlink event delay to 100ms (David Arcari) [RHEL-20130]
- thermal: intel: hfi: Rename HFI_UPDATE_INTERVAL (David Arcari) [RHEL-20130]
- thermal: intel: hfi: Enable HFI only when required (David Arcari) [RHEL-20130]
- thermal: netlink: Add genetlink bind/unbind notifications (David Arcari) [RHEL-20130]
- x86/cpu/topology: Rename topology_max_die_per_package() [partial] (David Arcari) [RHEL-20130]
- genetlink: Add per family bind/unbind callbacks (David Arcari) [RHEL-20130]
- thermal: netlink: Rework notify API for cooling devices (David Arcari) [RHEL-20130]
- thermal: netlink: Add thermal_group_has_listeners() helper (David Arcari) [RHEL-20130]
- thermal: netlink: Add enum for mutlicast groups indexes (David Arcari) [RHEL-20130]
- thermal: netlink: Drop thermal_notify_tz_trip_add/delete() (David Arcari) [RHEL-20130]
- thermal: netlink: Use for_each_trip() in thermal_genl_cmd_tz_get_trip() (David Arcari) [RHEL-20130]
- ext4: fix infinite loop when replaying fast_commit (CKI Backport Bot) [RHEL-54846] {CVE-2024-43828}

* Fri Nov 15 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-531.el9]
- bnx2x: Set ivi->vlan field as an integer (Michal Schmidt) [RHEL-52258 RHEL-52667]
- bnx2x: Provide declaration of dmae_reg_go_c in header (Michal Schmidt) [RHEL-52258 RHEL-52667]
- bnx2x: Fix multiple UBSAN array-index-out-of-bounds (Michal Schmidt) [RHEL-52258 RHEL-52667]
- bnx2x: adopt skb_network_header_len() more broadly (Michal Schmidt) [RHEL-52258 RHEL-52667]
- bnx2x: adopt skb_network_offset() and similar helpers (Michal Schmidt) [RHEL-52258 RHEL-52667]
- bnx2x: constify references to netdev->dev_addr in drivers (Michal Schmidt) [RHEL-52258 RHEL-52667]
- bnx2x: use eth_hw_addr_set() for dev->addr_len cases (Michal Schmidt) [RHEL-52258 RHEL-52667]
- tg3: Remove residual error handling in tg3_suspend (Michal Schmidt) [RHEL-52671 RHEL-52757]
- tg3: simplify tg3_phy_autoneg_cfg (Michal Schmidt) [RHEL-52671 RHEL-52757]
- powerpc/pseries/eeh: move pseries_eeh_err_inject() outside CONFIG_DEBUG_FS block (Mamatha Inamdar) [RHEL-61572]
- powerpc/pseries/eeh: Fix pseries_eeh_err_inject (Mamatha Inamdar) [RHEL-61572]
- nvmet-auth: assign dh_key to NULL after kfree_sensitive (CKI Backport Bot) [RHEL-66830] {CVE-2024-50215}
- perf/x86/rapl: Fix the energy-pkg event for AMD CPUs (David Arcari) [RHEL-66194]
- net: sched: use RCU read-side critical section in taprio_dump() (Xin Long) [RHEL-65978] {CVE-2024-50126}
- nfsd: enforce upper limit for namelen in __cld_pipe_inprogress_downcall() (Olga Kornievskaia) [RHEL-63198] {CVE-2024-47692}
- nfsd: return -EINVAL when namelen is 0 (Olga Kornievskaia) [RHEL-63198] {CVE-2024-47692}
- powerpc/qspinlock: Fix deadlock in MCS queue (Mamatha Inamdar) [RHEL-58127]
- net: ethtool: phy: Don't set the context dev pointer for unfiltered DUMP (Michal Schmidt) [RHEL-57751]
- net: ethtool: Enhance error messages sent to user space (Michal Schmidt) [RHEL-57751]
- Documentation: networking: Fix missing PSE documentation and grammar issues (Michal Schmidt) [RHEL-57751]
- net: ethtool: phy: Check the req_info.pdn field for GET commands (Michal Schmidt) [RHEL-57751]
- ptp: ptp_ines: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: stmmac: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- sfc/siena: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- sfc: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- qede: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- enic: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: thunderx: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- liquidio: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: macb: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- amd-xgbe: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- bonding: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- tg3: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- bnxt_en: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- bnx2x: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- cxgb4: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- ixgbe: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- igc: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- igb: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- ice: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: netcp: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: ti: icssg-prueth: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: ethernet: ti: cpsw_ethtool: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: ethernet: ti: am65-cpsw-ethtool: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- mlxsw: spectrum: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- lan743x: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: mvpp2: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- octeontx2-pf: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: fec: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: hns3: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- net: renesas: rswitch: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- ionic: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- can: peak_usb: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- can: peak_canfd: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- can: dev: Remove setting of RX software timestamp (Michal Schmidt) [RHEL-57751]
- ethtool: RX software timestamp for all (Michal Schmidt) [RHEL-57751]
- ethtool: pse-pd: move pse validation into set (Michal Schmidt) [RHEL-57751]
- net: ethtool: cable-test: Release RTNL when the PHY isn't found (Michal Schmidt) [RHEL-57751]
- net: fix unreleased lock in cable test (Michal Schmidt) [RHEL-57751]
- ethtool: Add support for specifying information source in cable test results (Michal Schmidt) [RHEL-57751]
- ethtool: Extend cable testing interface with result source information (Michal Schmidt) [RHEL-57751]
- Documentation: networking: document phy_link_topology (Michal Schmidt) [RHEL-57751]
- net: ethtool: strset: Allow querying phy stats by index (Michal Schmidt) [RHEL-57751]
- net: ethtool: cable-test: Target the command to the requested PHY (Michal Schmidt) [RHEL-57751]
- net: ethtool: pse-pd: Target the command to the requested PHY (Michal Schmidt) [RHEL-57751]
- net: ethtool: plca: Target the command to the requested PHY (Michal Schmidt) [RHEL-57751]
- netlink: specs: add ethnl PHY_GET command set (Michal Schmidt) [RHEL-57751]
- net: ethtool: Introduce a command to list PHYs on an interface (Michal Schmidt) [RHEL-57751]
- netlink: specs: add phy-index as a header parameter (Michal Schmidt) [RHEL-57751]
- net: ethtool: Allow passing a phy index for some commands (Michal Schmidt) [RHEL-57751]
- net: sfp: Add helper to return the SFP bus name (Michal Schmidt) [RHEL-57751]
- net: phy: add helpers to handle sfp phy connect/disconnect (Michal Schmidt) [RHEL-57751]
- net: sfp: pass the phy_device when disconnecting an sfp module's PHY (Michal Schmidt) [RHEL-57751]
- net: phy: Introduce ethernet link topology representation (Michal Schmidt) [RHEL-57751]
- ethtool: Add new result codes for TDR diagnostics (Michal Schmidt) [RHEL-57751]
- Documentation: networking: correct spelling (Michal Schmidt) [RHEL-57751]
- netlink: specs: decode indirection table as u32 array (Michal Schmidt) [RHEL-57751]
- ethtool: rss: support skipping contexts during dump (Michal Schmidt) [RHEL-57751]
- ethtool: rss: support dumping RSS contexts (Michal Schmidt) [RHEL-57751]
- ethtool: rss: report info about additional contexts from XArray (Michal Schmidt) [RHEL-57751]
- ethtool: rss: move the device op invocation out of rss_prepare_data() (Michal Schmidt) [RHEL-57751]
- ethtool: rss: don't report key if device doesn't support it (Michal Schmidt) [RHEL-57751]
- bnxt: remove .cap_rss_ctx_supported from updated drivers (Michal Schmidt) [RHEL-57751]
- ethtool: make ethtool_ops::cap_rss_ctx_supported optional (Michal Schmidt) [RHEL-57751]
- ethtool: refactor checking max channels (Michal Schmidt) [RHEL-57751]
- net: ethtool: check rxfh_max_num_contexts != 1 at register time (Michal Schmidt) [RHEL-57751]
- ethtool: cmis_cdb: Remove unused declaration ethtool_cmis_page_fini() (Michal Schmidt) [RHEL-57751]
- ethtool: Don't check for NULL info in prepare_data callbacks (Michal Schmidt) [RHEL-57751]
- ppp: do not assume bh is held in ppp_channel_bridge_input() (Guillaume Nault) [RHEL-63598] {CVE-2024-49946}
- ppp: fix ppp_async_encode() illegal access (Guillaume Nault) [RHEL-63757] {CVE-2024-50035}
- powerpc/pseries/vas: Use usleep_range() to support HCALL delay (Mamatha Inamdar) [RHEL-44917]
- icmp: change the order of rate limits (Hangbin Liu) [RHEL-63235] {CVE-2024-47678}
- static_call: Replace pointless WARN_ON() in static_call_module_notify() (David Arcari) [RHEL-64532] {CVE-2024-49954}
- tracing/hwlat: Fix a race during cpuhp processing (Tomas Glozar) [RHEL-65271]
- tracing/timerlat: Fix a race during cpuhp processing (Tomas Glozar) [RHEL-65271] {CVE-2024-49866}
- tracing/timerlat: Drop interface_lock in stop_kthread() (Tomas Glozar) [RHEL-65271]
- tracing/timerlat: Fix duplicated kthread creation due to CPU online/offline (Tomas Glozar) [RHEL-65271]
- KVM: s390: Change virtual to physical address access in diag 0x258 handler (Thomas Huth) [RHEL-65229]
- KVM: s390: gaccess: Check if guest address is in memslot (Thomas Huth) [RHEL-65229]
- KVM: s390: Fix SORTL and DFLTCC instruction format error in __insn32_query (Thomas Huth) [RHEL-65229]
- s390/uv: Panic for set and remove shared access UVC errors (Thomas Huth) [RHEL-65229]
- KVM: s390: remove useless include (Thomas Huth) [RHEL-65229]
- s390/mm: Re-enable the shared zeropage for !PV and !skeys KVM guests (Thomas Huth) [RHEL-65229]
- mm/userfaultfd: Do not place zeropages when zeropages are disallowed (Thomas Huth) [RHEL-65229]
- KVM: s390: vsie: Use virt_to_phys for crypto control block (Thomas Huth) [RHEL-65229]
- KVM: s390: vsie: Use virt_to_phys for facility control block (Thomas Huth) [RHEL-65229]
- resource: fix region_intersects() vs add_memory_driver_managed() (Myron Stowe) [RHEL-64585] {CVE-2024-49878}
- bpf: devmap: provide rxq after redirect (Felix Maurer) [RHEL-65205]
- bpf: Make sure internal and UAPI bpf_redirect flags don't overlap (Felix Maurer) [RHEL-65205]
- sock_map: Add a cond_resched() in sock_hash_free() (Felix Maurer) [RHEL-63189 RHEL-65205] {CVE-2024-47710}
- bpf, net: Fix a potential race in do_sock_getsockopt() (Felix Maurer) [RHEL-65205]
- selftests/bpf: Add XDP_UMEM_TX_METADATA_LEN to XSK TX metadata test (Felix Maurer) [RHEL-65205]
- xsk: Require XDP_UMEM_TX_METADATA_LEN to actuate tx_metadata_len (Felix Maurer) [RHEL-65205]
- bpf: Fix a segment issue when downgrading gso_size (Felix Maurer) [RHEL-65205]
- bpf, arm64: Fix address emission with tag-based KASAN enabled (Felix Maurer) [RHEL-65205]
- bpf, arm64: Fix trampoline for BPF_TRAMP_F_CALL_ORIG (Felix Maurer) [RHEL-65205]
- xdp: fix invalid wait context of page_pool_destroy() (Felix Maurer) [RHEL-54828 RHEL-65205] {CVE-2024-43834}
- bpf: Fix too early release of tcx_entry (Felix Maurer) [RHEL-65205 RHEL-65858] {CVE-2024-41010}
- xdp: use flags field to disambiguate broadcast redirect (Felix Maurer) [RHEL-65205]
- bpf: Fix dev's rx stats for bpf_redirect_peer traffic (Felix Maurer) [RHEL-65205]
- veth: Use tstats per-CPU traffic counters (Felix Maurer) [RHEL-65205]
- tipc: guard against string buffer overrun (Xin Long) [RHEL-63545] {CVE-2024-49995}
- blk-rq-qos: fix crash on rq_qos_wait vs. rq_qos_wake_function race (CKI Backport Bot) [RHEL-65161] {CVE-2024-50082}
- devlink: Support setting max_io_eqs (CKI Backport Bot) [RHEL-64903]
- driver core: bus: Fix double free in driver API bus_register() (CKI Backport Bot) [RHEL-63832] {CVE-2024-50055}
- redhat: Add CONFIG_CRYPTO_HMAC_S390 config files (Mete Durlu) [RHEL-50799]
- s390/crypto: Add hardware acceleration for HMAC modes (Mete Durlu) [RHEL-50799]

* Fri Nov 15 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-530.el9]
- wifi: save new module iwlmvm-tests in internal rpm (Jose Ignacio Tornos Martinez) [RHEL-50013]
- config: wifi: disable new unsupported configuration options (Jose Ignacio Tornos Martinez) [RHEL-50013]
- Revert "wifi: mac80211: move radar detect work to sdata" (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: clear trans->state earlier upon error (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: free skb on error path in ieee80211_beacon_get_ap() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't wait for tx queues if firmware is dead (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: allow 6 GHz channels in MLO scan (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: pause TCM when the firmware is stopped (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: fix wgds rev 3 exact size (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: take the mutex before running link selection (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix iwl_mvm_max_scan_ie_fw_cmd_room() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix iwl_mvm_scan_fits() calculation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: lower message level for FW buffer destination (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix hibernation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: fix beacon SSID mismatch handling (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: fix NULL pointer dereference in ath11k_mac_get_eirp_power() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mwifiex: duplicate static structs used in driver instances (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: correctly lookup DMA address in SG table (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7921: fix NULL pointer access in mt7921_ipv6_addr_change (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcmfmac: cfg80211: Handle SSID based pmksa deletion (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: rtl8192du: Initialise value32 in _rtl92du_init_queue_reserved_page (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: use 128 bytes aligned iova in transmit path for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix soft lockup on suspend (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7921: fix null pointer access in mt792x_mac_link_bss_remove (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix reusing outside iterator in ath12k_wow_vif_set_wakeups() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: correct S1G beacon length calculation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: fix reporting failed MLO links status with cfg80211_connect_done (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: use monitor sdata with driver only if desired (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix build vs old compiler (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: fix AP chandef capturing in CSA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: correctly reference TSO page information (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt792x: fix scheduler interference in drv own process (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: enabling MLO when the firmware supports it (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: remove the unused mt7925_mcu_set_chan_info (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mac_link_bss_add for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mcu_bss_basic_tlv for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mcu_set_timing for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mcu_sta_phy_tlv for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mcu_sta_rate_ctrl_tlv for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_mcu_sta_eht_mld_tlv for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mcu_sta_update for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mcu_add_bss_info for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mcu_bss_mld_tlv for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mcu_sta_mld_tlv for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_[assign,unassign]_vif_chanctx (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: add def_wcid to struct mt76_wcid (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: report link information in rx status (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update rate index according to link id (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in the mt7925_ipv6_addr_change (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in the BSS_CHANGED_ARP_FILTER handler (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in mt7925_vif_connect_iter (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in mt7925_sta_set_decap_offload (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in mt7925_mac_sta_assoc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in mt7925_txwi_free (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in mt7925_mcu_set_beacon_filter (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in the BSS_CHANGED_PS handler (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling to mt7925_change_chanctx (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in mt7925_set_key (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling to txwi (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in mt7925_mac_sta_remove (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add link handling in mt7925_mac_sta_add (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_change_sta_links (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_change_vif_links (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_uni_roc_event (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_set_link_key (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: set mt7925_mcu_sta_key_tlv according to link id (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: set Tx queue parameters according to link id (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt7925_mac_link_sta_[add, assoc, remove] for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: update mt76_connac_mcu_uni_add_dev for MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: simpify mt7925_mcu_sta_cmd logic by removing fw_offload (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_mac_link_bss_remove to remove per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_mac_link_bss_add to create per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_mac_link_sta_remove to remove per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_mac_link_sta_assoc to associate per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_mac_link_sta_add to create per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_basic_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_mld_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_add_bss_info for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_hdr_trans_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt762x: extend mt76_connac_mcu_sta_basic_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt792x: extend mt76_connac_get_phy_mode_v2 for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_get_phy_mode for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_get_phy_mode_ext for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_phy_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_ht_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_vht_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_amsdu_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_he_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_he_6g_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_eht_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_rate_ctrl_tlv with per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_state_v2_tlv for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_sta_update for per-link STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: mt7925_mcu_set_chctx rely on mt7925_mcu_bss_rlm_tlv (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add mt7925_mcu_bss_rlm_tlv to constitue the RLM TLV (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_uni_bss_ps for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_uni_bss_bcnft for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_[abort, set]_roc for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_set_bss_pm for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_basic_tlv for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_sec_tlv for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: remove unused parameters in mt7925_mcu_bss_bmc_tlv (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_bmc_tlv for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_mld_tlv for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_qos_tlv for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_he_tlv for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_color_tlv for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_bss_ifs_tlv for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_set_timing for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_add_bss_info for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: extend mt7925_mcu_set_tx with for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt792x: extend mt76_connac_mcu_uni_add_dev for per-link BSS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: support for split bss_info_changed method (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt792x: add struct mt792x_chanctx (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt792x: add struct mt792x_link_sta (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt792x: add struct mt792x_bss_conf (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mwifiex: Do not return unused priv in mwifiex_get_priv_by_id() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: add support for multi-radio wiphy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: add wiphy radio assignment and validation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: move code in ieee80211_link_reserve_chanctx to a helper (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: extend ifcomb check functions for multi-radio (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: add radio index to ieee80211_chanctx_conf (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: add support for DFS with multiple radios (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: add helper for checking if a chandef is valid on a radio (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: extend interface combination check for multi-radio (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: add support for advertising multiple radios belonging to a wiphy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: chanctx emulation set CHANGE_CHANNEL when in_reconfig (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: virt_wifi: don't use strlen() in const context (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: fix warning (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: do not check BSS color collision in certain cases (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: cancel color change finalize work when link is stopped (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: virt_wifi: avoid reporting connection success with wrong SSID (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: clear vif drv_priv after remove_interface when stopping (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: nl80211: split helper function from nl80211_put_iface_combinations (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: fix default typo (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: unify the selection logic of RFK table when MCC (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: mac: parse MRC C2H failure report (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bx: add extra handles of BTC for 8852BT in 8852b_common (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bx: move BTC common code from 8852b to 8852b_common (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: usb: schedule rx work after everything is set up (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: re-enable MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Add support for LARI_CONFIG_CHANGE_CMD v12 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Remove debug message (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: document remaining mvm data (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: api: fix missing RX descriptor kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: document PPAG table command union correctly (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: api: add puncturing to PHY context docs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: api: mac: fix kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: api: fix memory region kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add missing string for ROC EMLSR block (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: release TXQ lock during reclaim (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: keep BHs disabled when TXing from reclaim (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: use already mapped data when TXing an AMSDU (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: keep the TSO and workaround pages mapped (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: map entire SKB when sending AMSDUs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: return a new allocation for hdr page space (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: simplify EMLSR blocking (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: align reorder buffer entries to cacheline (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: clean up reorder buffer data (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't send an ROC command with max_delay = 0 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix interface combinations (Jose Ignacio Tornos Martinez) [RHEL-50013]
- bus: mhi: host: Allow controller drivers to specify name for the MHI controller (Jose Ignacio Tornos Martinez) [RHEL-50013]
- bus: mhi: host: Add support for Foxconn SDX72 modems (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bt: rfk: add RCK (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bt: rfk: add DACK (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bt: rfk: add RX DCK (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bt: rfk: add IQK (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: constrain TX power according to Transmit Power Envelope (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add coexistence policy for hardware scan (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Support TQM stats (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Support pdev error stats (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Support Transmit Scheduler stats (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Dump additional Tx PDEV HTT stats (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Add support to parse requested stats_type (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Add htt_stats_dump file ops support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Add support to enable debugfs_htt_stats (Jose Ignacio Tornos Martinez) [RHEL-50013]
- bus: mhi: host: pci_generic: Use unique 'mhi_pci_dev_info' for product families (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: remove DEAUTH_NEED_MGD_TX_PREP (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: fix kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: Use the link BSS configuration for beacon processing (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: remove key data from get_key callback (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: nl80211: don't give key data to userspace (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix driver initialization for WoW unsupported devices (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: 8188f: Limit TX power index (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bt: rfk: add DPK (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bt: rfk: add TSSI (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: add polling for LPS H2C to ensure FW received (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: enable beacon filter after swapping firmware (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: prevent to send unexpected H2C during download Firmware (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: fix GTK offload H2C skbuff issue (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: update config mac for 802.11ax chip (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: update WoWLAN reason register for different FW (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: append security header offset for different cipher (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcmfmac: of: Support interrupts-extended (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcmsmac: advertise MFP_CAPABLE to enable WPA3 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix peer metadata parsing (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Fix pdev id sent to firmware for single phy devices (Jose Ignacio Tornos Martinez) [RHEL-50013]
- net: rfkill: Correct return value in invalid parameter case (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix rs.h kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: api: datapath: fix kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fix remaining mistagged kernel-doc comments (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fix prototype mismatch kernel-doc warnings (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fix kernel-doc in iwl-fh.h (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fix kernel-doc in iwl-trans.h (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: pcie: fix kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: dvm: fix kernel-doc warnings (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't log error for failed UATS table read (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: trans: make bad state warnings (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: api: fix some kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: remove init_dbg module parameter (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: update the BA notification API (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: always unblock EMLSR on ROC end (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: use IWL_FW_CHECK for link ID check (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't flush BSSes on restart with MLD API (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: remove MVM prefix from scan API (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: remove AX101, AX201 and AX203 support from LNL (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't limit VLP/AFC to UATS-enabled (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: enable VLP AP on VLP channels (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mei: clarify iwl_mei_pldr_req() docs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: rename 'pldr_sync' (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Fix associated initiator key setting (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: dissolve iwl_mvm_mac_remove_interface_common() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: trans: remove unused status bits (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: don't assume op_mode_nic_config exists (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: bump FW API to 92 for BZ/SC devices (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: trans: remove unused function parameter (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: remove IWL_MVM_PARSE_NVM (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: support fast resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fix iwl_mvm_get_valid_rx_ant() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: unify and fix interface combinations (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: pcie: fix a few legacy register accesses for new devices (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: inform the low level if drv_stop() is a suspend (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: Always call tracing (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: check SSID in beacon (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: correcty limit wider BW TDLS STAs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: add ieee80211_tdls_sta_link_id() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: update STA/chandef width during switch (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: make ieee80211_chan_bw_change() able to use reserved (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: optionally pass chandef to ieee80211_sta_cur_vht_bw() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: optionally pass chandef to ieee80211_sta_cap_rx_bw() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: handle protected dual of public action (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: restrict public action ECSA frame handling (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: refactor CSA queue block/unblock (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: handle keepalive during WoWLAN suspend and resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: support GTK rekey offload (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: support ARP and NS offload (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: implement hardware data filter (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add WoW net-detect functionality (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add basic WoW functionalities (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: implement WoW enable and wakeup commands (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add ATH12K_DBG_WOW log level (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: use swap() in rtl8xxxu_switch_ports() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: usb: Further limit the TX aggregation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: un-embedd netdev from mt76_dev (Jose Ignacio Tornos Martinez) [RHEL-50013]
- bus: mhi: ep: Do not allocate memory for MHI objects from DMA zone (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix mbssid max interface advertisement (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix firmware crash due to invalid peer nss (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix legacy peer association due to missing HT or 6 GHz capabilities (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix uninitialize symbol error on ath12k_peer_assoc_h_he() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix NULL pointer access in ath12k_mac_op_get_survey() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: modify the calculation of the average signal strength in station mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: fix ack signal strength calculation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: disable SDIO func IRQ before suspend (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: remove suspend/resume from cfg80211 part (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: move sdio suspend method next to resume and pm ops definition (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: do not keep sdio bus claimed during suspend/resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: let host->chip suspend/resume notifications manage chip wake/sleep (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: disable power sequencer (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Remove unused ath12k_base from ath12k_hw (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Fix WARN_ON during firmware crash in split-phy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: pci: fix RX tag race condition resulting in wrong RX length (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: pci: support 36-bit PCI DMA address (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: adopt firmware whose version is equal or less but closest (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 885xbx: apply common settings to 8851B, 8852B and 8852BT (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bx: add extra handles for 8852BT in 8852b_common (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852bx: move common code from 8852b to 8852b_common (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: use 'time_left' variable with wait_for_completion_timeout() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- net: qrtr: ns: Ignore ENODEV failures in ns (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcmfmac: use 'time_left' variable with wait_event_timeout() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: use ROC for P2P device activities (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: separate non-BSS/ROC EMLSR blocking (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: bump min API version for Qu/So devices (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix re-enabling EMLSR (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: remove struct iwl_trans_ops (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: pcie: integrate TX queue code (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: api: fix includes in debug.h (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: move TXQ bytecount limit to queue code (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix DTIM skip powersave config (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: bump minimum API version in BZ/SC to 90 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: remove unneeded debugfs entries (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: honor WIPHY_FLAG_SPLIT_SCAN_6GHZ in cfg80211_conn_scan (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: clean up 'ret' in sta_link_apply_parameters() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: fix erroneous errors for STA changes (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: add 320 MHz to hwsim channel widths (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: nl80211: remove the FTMs per burst limit for NDP ranging (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: reject non-conformant 6 GHz center frequencies (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: add regulatory flag to allow VLP AP operation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: refactor regulatory beaconing checking (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: refactor 6 GHz AP power type parsing (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: refactor channel checks (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: move enum ieee80211_ap_reg_power to cfg80211 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ieee80211: remove unused enum ieee80211_client_reg_power (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: use BIT() for flag enums (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: nl80211: expose can-monitor channel property (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: fix typo in cfg80211_calculate_bitrate_he() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: Remove generic .ndo_get_stats64 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: Move stats allocation to core (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: make hash table duplicates more survivable (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: correct EHT EIRP TPE parsing (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: handle symlink cleanup for per pdev debugfs dentry (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: unregister per pdev debugfs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix per pdev debugfs registration (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: fix wrong handling of CCMP256 and GCMP ciphers (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: avoid unnecessary MSDU drop in the Rx error process (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: use 'time_left' variable with wait_event_timeout() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix ACPI warning when resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: modify remain on channel for single wiphy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add hw_link_id in ath12k_pdev (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add panic handler (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: chan: Use swap() in rtw89_swap_sub_entity() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcm80211: remove unused structs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcm80211: use sizeof(*pointer) instead of sizeof(type) (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: do not process consecutive RDDM event (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix memory leak in ath12k_dp_rx_peer_frag_setup() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: handle return value of usb init TX/RX (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Enable the new rtl8192du driver (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Add rtl8192du/sw.c (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Constify rtl_hal_cfg.{ops,usb_interface_cfg} and rtl_priv.cfg (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Add rtl8192du/dm.{c,h} (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Add rtl8192du/fw.{c,h} and rtl8192du/led.{c,h} (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Add rtl8192du/rf.{c,h} (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Add rtl8192du/trx.{c,h} (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Add rtl8192du/phy.{c,h} (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Add rtl8192du/hw.{c,h} (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Add new members to struct rtl_priv for RTL8192DU (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Add rtl8192du/table.{c,h} (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: rtl8192d: Use "rtl92d" prefix (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: nl80211: clean up coalescing rule handling (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: handle HW restart during ROC (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: check ieee80211_bss_info_change_notify() against MLD (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: move Bz and Gl iwl_dev_info entries (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: move amsdu_size parsing to iwlwifi (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: remove redundant prints (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix a wrong comment (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: declare band variable in the scope (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: show full firmware ID in debugfs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add debug data for MPDU counting (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: use only beacon BSS load for active links (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add support for version 10 of the responder config command (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add support for version 14 of the range request command (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: modify iwl_mvm_ftm_set_secured_ranging() parameters (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: initiator: move setting the sta_id into a function (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Remove debug related code (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: initiator: move setting target flags into a function (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: handle TPE advertised by AP (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: move a constant to constants.h (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: remove IWL_MVM_USE_NSSN_SYNC (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Enable p2p low latency (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: report 64-bit radiotap timestamp (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add an option to use ptp clock for rx timestamp (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix wrong definition of CE ring's base address (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix race due to setting ATH12K_FLAG_EXT_IRQ_ENABLED too early (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: fix wrong definition of CE ring's base address (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Fix devmem address prefix when logging (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: Fix P2P behavior for WiFi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: add LDPC and STBC to rx_status and radiotap known fields for monitor mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: fill STBC and LDPC capabilities to TX descriptor (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852c: correct logic and restore PCI PHY EQ after device resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix firmware crash during reo reinject (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix invalid memory access while processing fragmented packets (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: change DMA direction while mapping reinjected packets (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: improve the rx descriptor error information (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: refactor rx descriptor CMEM configuration (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: send DelBA with correct BSSID (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: reset negotiated TTLM on disconnect (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: don't stop TTLM works again (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: cancel TTLM teardown work earlier (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: cancel multi-link reconf work on disconnect (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: fix TTLM teardown work (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: use __counted_by where appropriate (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: Add EHT UL MU-MIMO flag in ieee80211_bss_conf (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: refactor chanreq.ap setting (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: handle TPE element during CSA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: handle wider bandwidth OFDMA during CSA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: collect some CSA data into sub-structs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: mlme: handle cross-link CSA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: restrict operation during radar detection (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: move radar detect work to sdata (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Add support for LARI_CONFIG_CHANGE_CMD v11 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: move code from iwl-eeprom-parse to dvm (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: kill iwl-eeprom-read (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't skip link selection (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add mvm-specific guard (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: simplify TX tracing (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: tracing: fix condition to allocate buf1 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: leave a print in the logs when we call fw_nmi() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: disable dynamic EMLSR when AUTO_EML is false (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: use vif P2P type helper (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't track used links separately (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: always print the firmware version in hex (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: avoid bad FW config on RXQ DMA failure (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: api: Add new timepoint for scan failure (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mei: unify iwl_mei_set_power_limit() prototype (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: mark bad no-data RX as having bad PLCP (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: bump FW API to 91 for BZ/SC devices (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add a of print of a few commands (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Use the SMPS cfg of the correct link (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't always set antenna in beacon template cmd (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: remove redundant reading from NVM file (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: remove fw_running op (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Don't set NO_HT40+/- flags on 6 GHz band (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: call ieee80211_sta_recalc_aggregates on A-MSDU size update (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: set A-MSDU size on the correct link (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: define link_sta in the relevant scope (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: debugfs: add entry for setting maximum TXOP time (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: allow UAPSD when in SCM (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: simplify the uAPSD coexistence limitation code (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: dvm: clean up rs_get_rate() logic (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: track changes in AP's TPE (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: pass parsed TPE data to drivers (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: fix TPE power levels (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ieee80211/ath11k: remove IEEE80211_MAX_NUM_PWR_LEVEL (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: update 6 GHz AP power type before association (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: remove extra link STA functions (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: remove outdated comments (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: add tracing for wiphy work (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: sort trace events again (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: nl80211: disallow setting special AP channel widths (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ieee80211: document two FTM related functions (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ieee80211: document function return values (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ieee80211: remove ieee80211_next_tbtt_present() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: radiotap: document ieee80211_get_radiotap_len() return value (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ieee80211: add missing doc short descriptions (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: regulatory: remove extra documentation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: correct hardware value of nominal packet padding for WiFi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852b: restore setting for RFE type 5 after device resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: fix HW scan not aborting properly (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix Smatch warnings on ath12k_core_suspend() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: dynamic VLAN support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rt2x00: remove unused delayed work data from link description (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mwifiex: Fix interface type change (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: read MAC address from fuse at probe (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: make sdio deinit function really deinit the sdio card (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: add function to read mac address from eFuse (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: set wilc_set_mac_address parameter as const (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: register net device only after bus being fully initialized (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: set net device registration as last step during interface creation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix ack signal strength calculation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: use correct MAX_RADIOS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: remove duplicate definition of MAX_RADIOS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: remove redundant peer delete for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Fix tx completion ring (WBM2SW) setup failure (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: skip sending vdev down for channel switch (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add EMA beacon support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add MBSSID beacon support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: refactor arvif security parameter configuration (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: configure MBSSID parameters in AP mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: create a structure for WMI vdev up parameters (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: rename MBSSID fields in wmi_vdev_up_cmd (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: configure MBSSID params in vdev create/start (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: advertise driver capabilities for MBSSID and EMA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: support SMPS configuration for 6 GHz (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: refactor SMPS configuration (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add 6 GHz params in peer assoc command (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix survey dump collection in 6 GHz (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Correct 6 GHz frequency value in rx status (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add channel 2 into 6 GHz channel list (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: add LED and GPIO controlling support for various chipsets (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcmsmac: LCN PHY code is used for BCM4313 2G-only device (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: support mac_id number according to chip (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: switch to register vif_cfg_changed and link_info_changed (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: cam: tweak relation between sec CAM and addr CAM (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: ser: avoid multiple deinit on same CAM (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: allocate dummy net_device dynamically (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: ath10k: add qcom,no-msa-ready-indicator prop (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: do not always wait for MSA_READY indicator (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: initialize 'ret' in ath12k_dp_rxdma_ring_sel_config_wcn7850() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix misspelling of "dma" in num_rxmda_per_pdev (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: fix misspelling of "dma" in num_rxmda_per_pdev (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: avoid double SW2HW_MACID conversion (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: initialize 'ret' in ath11k_qmi_load_file_target_mem() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: initialize 'ret' in ath12k_qmi_load_file_target_mem() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: usb: Fix disconnection after beacon loss (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: usb: Simplify rtw_usb_write_data (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Un-embed dummy device (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: Un-embed dummy device (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: remove invalid peer create logic (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: avoid duplicated vdev down (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: avoid duplicated vdev stop (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: remove unused variable monitor_flags (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Remove unused tcl_*_ring configuration (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Remove unsupported tx monitor handling (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix calling correct function for rx monitor mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: skip status ring entry processing (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: drop failed transmitted frames from metric calculation. (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Don't drop tx_status in failure case (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add multi device support for WBM idle ring buffer setup (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Introduce device index (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Refactor idle ring descriptor setup (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Replace "chip" with "device" in hal Rx return buffer manager (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: unmap the CE in ath11k_ahb_probe() error path (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: refactor CE remap & unmap (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Add lock to protect the hardware state (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Refactor the hardware state (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Refactor the hardware recovery procedure (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: ath11k_mac_op_ipv6_changed(): use list_for_each_entry() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: check vif for NULL/ERR_PTR before dereference (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: avoid link lookup in statistics (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't wake up rx_sync_waitq upon RFKILL (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: properly set WIPHY_FLAG_SUPPORTS_EXT_KEK_KCK (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: fix ies_len type in connect path (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: fix BSS_CHANGED_UNSOL_BCAST_PROBE_RESP (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: disable softirqs for queued frame handling (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: fix monitor channel with chanctx emulation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: Recalc offload when monitor stop (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: scan: correctly check if PSC listen period is needed (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix ROC version check (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: unlock mvm mutex (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: wext: add extra SIOCSIWSCAN data check (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: wext: set ssids=NULL for passive scans (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Ignore IEEE80211_CONF_CHANGE_RETRY_LIMITS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7615: add missing chanctx ops (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: document SRCU usage instead of SRCU (Jose Ignacio Tornos Martinez) [RHEL-50013]
- Revert "wifi: wilc1000: set atomic flag on kmemdup in srcu critical section" (Jose Ignacio Tornos Martinez) [RHEL-50013]
- Revert "wifi: wilc1000: convert list management to RCU" (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: fix UBSAN noise in ieee80211_prep_hw_scan() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: correctly parse Spatial Reuse Parameter Set element (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: fix Spatial Reuse element size check (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Fix scan abort handling with HW rfkill (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: properly set 6 GHz channel direct probe option (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: handle BA session teardown in RF-kill (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Handle BIGTK cipher in kek_kck cmd (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: remove stale STA link data during restart (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: dbg_ini: move iwl_dbg_tlv_free outside of debugfs ifdef (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: set properly mac header (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: revert gen2 TX A-MPDU size to 64 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: d3: fix WoWLAN command version lookup (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: always set the TWT IE offset (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't initialize csa_work twice (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: pass proper link id for channel switch started notification (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: fix 6 GHz scan request building (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: handle tasklet frames before stopping (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: apply mcast rate only if interface is up (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: pmsr: use correct nla_get_uX functions (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: fully move wiphy work to unbound workqueue (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: mesh: init nonpeer_pm to active by default in mesh sdata (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: mesh: Fix leak of mesh_preq_queue objects (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: move power type check to ASSOC stage when connecting to 6 GHz AP (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: fix WCN6750 firmware crash caused by 17 num_vdevs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: drop owner assignment (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: fix QCOM_RPROC_COMMON dependency (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: Fix error path in ath11k_pcic_ext_irq_config (Jose Ignacio Tornos Martinez) [RHEL-50013]
- net: qrtr: ns: Fix module refcnt (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Ensure prph_mac dump includes all addresses (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't request statistics in restart (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: exit EMLSR if secondary link is not used (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add beacon template version 14 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: align UATS naming with firmware (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Force SCU_ACTIVE for specific platforms (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: record and return channel survey information (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add the firmware API for channel survey (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Fix race in scan completion (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Add a print for invalid link pair due to bandwidth (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add a debugfs for reading EMLSR blocking reasons (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Add active EMLSR blocking reasons prints (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: bump FW API to 90 for BZ/SC devices (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix primary link setting (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: use already determined cmd_id (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't reset link selection during restart (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Print EMLSR states name (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Block EMLSR when a p2p/softAP vif is active (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix typo in debug print (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: exit EMLSR when CSA happens (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Disable/enable EMLSR due to link's bandwidth/band (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: avoid always prefering single-link (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: trigger link selection upon TTLM start/end (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: consider FWs recommendation for EMLSR (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Activate EMLSR based on traffic volume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't always unblock EMLSR (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Always allow entering EMLSR from debugfs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add a debugfs for (un)blocking EMLSR (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: trigger link selection after exiting EMLSR (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: cleanup EMLSR when BT is active handling (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: 8192d: initialize rate_mask in rtl92de_update_hal_rate_mask() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Remove unused structs and avoid multiple -Wfamnae warnings (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: correct aSIFSTime for 6GHz band (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: add ARP offload feature (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: support WEP cipher on WoWLAN (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: support 802.11w PMF IGTK rekey (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: update latest PTK GTK info to mac80211 after resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: add GTK rekey feature related H2C commands (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: construct EAPoL packet for GTK rekey offload (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: use struct to fill H2C of WoWLAN global configuration (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: use struct to access firmware command h2c_dctl_sec_cam_v1 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: prepare PTK GTK info from mac80211 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: parsing Auth Key Management from associate request (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: refine WoWLAN flows of HCI interrupts and low power mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: wow: send RFK pre-nofity H2C command in WoWLAN mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: add support for BSS color (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: handle color change per link (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: handle color change per link (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: Clear mlo_links info when STA disconnects (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: pcie: allocate dummy net_device dynamically (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Use request_module_nowait (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: enable spectrum management (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7925: add EHT radiotap support in monitor mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7921e: add LED control support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7996: let upper layer handle MGMT frame protection (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7921: cqm rssi low/high event notify (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: make const arrays in functions static (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7996: add sanity checks for background radar trigger (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: connac: enable critical packet mode support for mt7992 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7996: fix potential memory leakage when reading chip temperature (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7996: fix non-main BSS no beacon issue for MBSS scenario (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: connac: enable HW CSO module for mt7996 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7996: set RCPI value in rate control command (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: connac: use peer address for station BMC entry (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7996: disable rx header translation for BMC entry (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: Remove unused of_gpio.h (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: sdio: move mcu queue size check inside critical section (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7921: introduce mt7920 PCIe support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7603: fix tx queue of loopback packets (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: add fallback in case of missing precal data (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: add mt7986, mt7916 and mt7981 pre-calibration (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: add support for disabling in-band discovery (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7996: only set MT76_MCU_RESET for the main phy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: only set MT76_MCU_RESET for the main phy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: fix HE PHY capabilities IE for station mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: fix bogus Tx/Rx airtime duration values (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: fix mcu command format for mt7915 tx stats (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: fix tx packet loss when scanning on DBDC (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: initialize rssi on adding stations (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix the problem that down grade phy mode operation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: cleanup includes (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: remove rtl8xxxu_ prefix from filenames (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: remove some unused includes (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852c: refine power sequence to imporve power consumption (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Adjust rtl8192d-common for USB (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Clean up rtl8192d-common a bit (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: Move code from rtl8192de to rtl8192d-common (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: rtl8192de: Fix endianness issue in RX path (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: rtl8192de: Fix low speed with WPA3-SAE (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: rtl8192de: Fix 5 GHz TX power (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix flush failure in recovery scenarios (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: check M3 buffer size as well whey trying to reuse it (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: rtl8723be: Make read-only arrays static const (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: Remove the redundant else branch in the function rtw89_phy_get_kpath (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Check and enable reports after run coex (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add Wi-Fi role v8 condition when set BTG control (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add Wi-Fi role v8 condition when set Bluetooth channel (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Fix unexpected value in version 7 slot parameter (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add Bluetooth version report version 7 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add Bluetooth frequency hopping map version 7 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add Bluetooth scan parameter report version 7 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add Wi-Fi null data status version 7 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852b: update hardware parameters for RFE type 5 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: fix CTS transmission issue with center frequency deviation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcmfmac: remove unused brcmf_usb_image struct (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcmsmac: ampdu: remove unused cb_del_ampdu_pars struct (Jose Ignacio Tornos Martinez) [RHEL-50013]
- bus: mhi: host: pci_generic: Add generic edl_trigger to allow devices to enter EDL mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- bus: mhi: host: Add a new API for getting channel doorbell offset (Jose Ignacio Tornos Martinez) [RHEL-50013]
- bus: mhi: host: Add sysfs entry to force device to enter EDL (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: drop fw.eboard file name (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: drop chip-specific board data file name (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: populate board data for WCN3990 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: Fix an error code problem in ath10k_dbg_sta_write_peer_debug_trigger() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: set mlo_capable_flags based on QMI PHY capability (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: read single_chip_mlo_support parameter from QMI PHY capability (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add support to handle beacon miss for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: allocate dummy net_device dynamically (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: allocate dummy net_device dynamically (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Re-order the index for the report from firmware (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add coexistence firmware control report version 8 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add GPIO signal control version 7 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add register monitor report v7 format (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Update Bluetooth polluted Wi-Fi TX logic (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add PTA path control condition for chip RTL8922A (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add version 3 report map of H2C command (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add v7 firmware cycle status report (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Allow Bluetooth doing traffic during Wi-Fi scan (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: Add LED control code for RTL8723BU (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: Add LED control code for RTL8192CU family (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: Add separate MAC init table for RTL8192CU (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: ACPI band edge channel power support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: ACPI CCA threshold support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: ACPI SAR support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: ACPI TAS support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: change supports_suspend to true for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: support suspend/resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: avoid stopping mac80211 queues in ath12k_core_restart() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: no need to handle pktlog during suspend/resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: flush all packets before suspend (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: decrease MHI channel buffer length to 8KB (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix warning on DMA ring capabilities event (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: do not dump SRNG statistics during resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: remove MHI LOOPBACK channels (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: rearrange IRQ enable/disable in reset path (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix kernel crash during resume (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix out-of-bound access of qmi_invoke_handler() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Refactor data path cmem init (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: displace the Tx and Rx descriptor in cookie conversion table (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Refactor the hardware cookie conversion init (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: avoid redundant code in Rx cookie conversion init (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: enable MFP support with security flag of RX descriptor (Jose Ignacio Tornos Martinez) [RHEL-50013]
- Revert "wifi: rtl8xxxu: enable MFP support" (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: suppress messages of failed to flush queue (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8922a: fix argument to hal_reset in bb_cfg_txrx_path (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: set WIPHY_FLAG_DISABLE_WEXT before MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: handle link ID during management Tx (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: handle sdata->u.ap.active flag with MLO (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: add return docs for regulatory functions (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: make some regulatory functions void (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: add return docs for sta_info_flush() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: keep mac80211 consistent on link activation failure (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: simplify ieee80211_assign_link_chanctx() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: reserve chanctx during find (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: fix cfg80211 function kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: Use wider regulatory for custom for 6GHz tests (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Don't allow EMLSR when the RSSI is low (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: disable EMLSR when we suspend with wowlan (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: get periodic statistics in EMLSR (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't recompute EMLSR mode in can_activate_links (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: implement EMLSR prevention mechanism. (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: exit EMLSR upon missed beacon (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: init vif works only once (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Add helper functions to update EMLSR status (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Implement new link selection algorithm (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: move EMLSR/links code (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: check if EMLSR is allowed before selecting links (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't always disable EMLSR due to BT coex (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: calculate EMLSR mode after connection (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: implement link grading (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: send ap_tx_power_constraints cmd to FW in AP mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: introduce esr_disable_reason (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Add support for LARI_CONFIG_CHANGE_CMD v10 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Add support for PPAG cmd v6 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: move lari_config handlig to regulatory (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: add a device ID for BZ-W (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: move WTAS macro to api file (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: extend STEP URM workaround for new devices (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: move phy band to nl80211 band helper (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Refactor tracking of scan UIDs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: defer link switch work in reconfig (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: Fix the TX power of RTL8192CU, RTL8723AU (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: don't use %%pK in dmesg format strings (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: enable service flag for survey dump stats (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: enable WIPHY_FLAG_DISABLE_WEXT (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: Fix error handling in ath11k_wmi_p2p_noa_event() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: ath11k: Drop "qcom,ipq8074-wcss-pil" from example (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: ath11k: add ieee80211-freq-limit property (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: add support DT ieee80211-freq-limit (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: regd: handle policy of 6 GHz SP according to BIOS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: acpi: process 6 GHz SP policy from ACPI DSM (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: regd: extend policy of UNII-4 for IC regulatory (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: regd: block 6 GHz by policy if not specific country (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852c: update TX power tables to R69.1 (2 of 2) (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852c: update TX power tables to R69.1 (1 of 2) (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: sar: correct TX power boundary for MAC domain (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: convert list management to RCU (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: set atomic flag on kmemdup in srcu critical section (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: dynamically update peer puncturing bitmap for STA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix mac id extraction when MSDU spillover in rx error path (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: support get_survey mac op for single wiphy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Modify rts threshold mac op for single wiphy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Modify set and get antenna mac ops for single wiphy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: modify regulatory support for single wiphy architecture (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Add additional checks for vif and sta iterators (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Cache vdev configs before vdev create (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fetch correct radio based on vdev status (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: scan statemachine changes for single wiphy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: vdev statemachine changes for single wiphy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: modify ath12k mac start/stop ops for single wiphy (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Modify add and remove chanctx ops for single wiphy support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: add multiple radio support in a single MAC HW un/register (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcmfmac: Fix spelling mistake "ivalid" -> "invalid" (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: correct the capital word typo (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: extend IEEE80211_KEY_FLAG_GENERATE_MMIE to other ciphers (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: Add missing return value documentation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: remove ieee80211_set_hw_80211_encap() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: correctly document struct mesh_table (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix link capable flags (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: extend the link capable flag (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: ath10k: describe firmware-name property (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: support board-specific firmware overrides (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mwifiex: replace open-coded module_sdio_driver() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: wilc1000: replace open-coded module_sdio_driver() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix hal_rx_buf_return_buf_manager documentation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: fix hal_rx_buf_return_buf_manager documentation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath9k: work around memset overflow warning (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix missing endianness conversion in wmi_vdev_create_cmd() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: debugfs: radar simulation support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: initial debugfs support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mwifiex: drop driver owner initialization (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: brcm80211: drop driver owner initialization (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: sdio: drop driver owner initialization (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: sdio: simplify module initialization (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8922a: configure UL MU/OFDMA power setting (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Set default CQM config if not present (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: remove unsupported interface type of mesh point (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852c: disable PCI PHY EQ to improve compatibility (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852c: add quirk to set PCI BER for certain platforms (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8852c: update TX power tables to R69 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: download firmware with five times retry (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8922a: add beacon filter and CQM support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8922a: download template probe requests for 6 GHz band (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8922a: update scan offload H2C fields (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: station mode only for SDIO chips (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: workaround dubious x | !y warning (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: disable txptctrl IMR to avoid flase alarm (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: coex: Prevent doing I/O during Wi-Fi power saving (Jose Ignacio Tornos Martinez) [RHEL-50013]
- net: rfkill: gpio: Convert to platform remove callback returning void (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: use kvcalloc() for codel vars (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Add support for LARI_CONFIG_CHANGE_CMD cmd v9 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Declare HE/EHT capabilities support for P2P interfaces (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Remove outdated comment (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: add support for BZ_W (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: Print a specific device name. (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: remove wrong CRF_IDs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: remove devices that never came out (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: reactivate multi-link later in restart (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: improve drop for action frame return (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: don't ask driver about no-op link changes (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: Declare HE/EHT capabilities support for P2P interfaces (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: clarify IEEE80211_STATUS_SUBDATA_MASK (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: don't enter idle during link switch (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: allocate STA links only for active links (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: enable monitor on passive/inactive channels (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: remove 6 GHz NVM override (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: don't support puncturing in 5 GHz (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fw: add clarifying comments about iwl_fwrt_dump_data (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: always apply 6 GHz probe limitations (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: add a kunit test for PCI table duplicates (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: add debugfs for forcing unprotected ranging request (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Add debugfs entry for triggering internal MLO scan (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Introduce internal MLO passive scan (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: add support for tearing down negotiated TTLM (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: add flag to disallow puncturing in 5 GHz (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: handle indoor AFC/LPI AP in probe response and beacon (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: handle indoor AFC/LPI AP on assoc success (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: fix BSS_CHANGED_MLD_TTLM description (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: clarify the dormant/suspended links docs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: move skip_beacons to be per link (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ieee80211: fix ieee80211_mle_basic_sta_prof_size_ok() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ieee80211: check for NULL in ieee80211_mle_size_ok() (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211_hwsim: set link ID information during Rx (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: nl80211: cleanup nl80211.h kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: nl80211: fix nl80211 uapi comment style issues (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: nl80211: rename enum plink_actions (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: spectmgmt: simplify 6 GHz HE/EHT handling (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: supplement parsing of puncturing bitmap (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: pcie: remove duplicate PCI IDs entry (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Refactor scan start (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: advertise IEEE80211_HW_HANDLES_QUIET_CSA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix flushing during quiet CSA (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: support wowlan notif version 4 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: skip keys of other links (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: stop assuming sta id 0 in d3 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: fix the sta id in offload (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: mvm: Move beacon filtering to be per link (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: iwlwifi: fix firmware API kernel doc (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath9k: eeprom: fix sparse endian warnings (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath9k: fix ath9k_use_msi declaration (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath9k: ath9k_set_moredata(): fix sparse warnings (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath: Convert sprintf/snprintf to sysfs_emit (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: always assume QoS mode in rtl8192cu (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtlwifi: drop WMM stubs from rtl8192cu (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mt76: mt7915: workaround too long expansion sparse warnings (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: remove duplicate definitions in wmi.h (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: do not process consecutive RDDM event (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Refactor error handler of Rxdma replenish (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Optimize the lock contention of used list in Rx data path (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: Refactor Rxdma buffer replinish argument (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: use correct flag field for 320 MHz channels (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: remove duplicate definitions in wmi.h (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: fix desc address calculation in wbm tx completion (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtl8xxxu: enable MFP support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mwifiex: Add missing MODULE_FIRMWARE() for SD8801 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: advertise P2P dev support for QCA6390/WCN6855/QCA2066 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: change scan flag scan_f_filter_prb_req for QCA6390/WCN6855/QCA2066 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: change WLAN_SCAN_PARAMS_MAX_IE_LEN from 256 to 512 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: implement handling of P2P NoA event (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: add P2P IE in beacon template (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: change interface combination for P2P mode (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: SDIO device driver for RTL8723CS (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Reset 8703b firmware before download (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Add rtw8703b_tables.c (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Add rtw8703b_tables.h (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Add rtw8703b.c (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Add rtw8703b.h (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Add definitions for 8703b chip (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Debug output for rtw8723x EFUSE (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Shared module for rtw8723x devices (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8922a: add 8922ae to Makefile and Kconfig (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: 8922a: update chip parameter for coex (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add TDMA slot parameter setting version 7 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add TDMA version 7 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add antenna setting function for RTL8922A (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: coex: Add WiFi role info format version 8 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: don't force enable power save on non-running vdevs (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw89: Correct EHT TX rate on 20MHz connection (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: adjust a comment to reflect reality (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath10k: poll service ready message before failing (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: fix soc_dp_stats debugfs file permission (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath11k: remove obsolete struct wmi_start_scan_arg (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: ath12k: remove obsolete struct wmi_start_scan_arg (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: rtw88: Add support for the SDIO based RTL8723DS chipset (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: use wiphy locked debugfs for sdata/link (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: mac80211: use wiphy locked debugfs helpers for agg_status (Jose Ignacio Tornos Martinez) [RHEL-50013]
- wifi: cfg80211: add locked debugfs wrappers (Jose Ignacio Tornos Martinez) [RHEL-50013]
- debugfs: fix wait/cancellation handling during remove (Jose Ignacio Tornos Martinez) [RHEL-50013]
- debugfs: initialize cancellations earlier (Jose Ignacio Tornos Martinez) [RHEL-50013]
- Revert "debugfs: annotate debugfs handlers vs. removal with lockdep" (Jose Ignacio Tornos Martinez) [RHEL-50013]
- debugfs: add API to allow debugfs operations cancellation (Jose Ignacio Tornos Martinez) [RHEL-50013]
- debugfs: annotate debugfs handlers vs. removal with lockdep (Jose Ignacio Tornos Martinez) [RHEL-50013]
- debugfs: fix automount d_fsdata usage (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: qcom: Update maintainers (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: qcom,ath11k: describe the ath11k on QCA6390 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: add ath11k pcie bindings (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: ath10k: add ieee80211-freq-limit property (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: Convert ath10k to YAML (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: drop redundant part of title (end, part two) (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: minor whitespace and name cleanups (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt: bindings: net: ath11k: add IPQ5018 compatible (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt: bindings: net: add bindings to add WoW support on WCN6750 (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: ath11k: change Kalle's email (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt: bindings: net: add bindings of WCN6750 for ath11k (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: white-space cleanups (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt: bindings: add new DT entry for ath11k PCI device support (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: ath9k: Change Toke as maintainer (Jose Ignacio Tornos Martinez) [RHEL-50013]
- dt-bindings: net: wireless: qca,ath9k: convert to the json-schema (Jose Ignacio Tornos Martinez) [RHEL-50013]
- vfio/pci: clean up a type in vfio_pci_ioctl_pci_hot_reset_groups() (Alex Williamson) [RHEL-61687]
- vfio/mdev: Constify struct kobj_type (Alex Williamson) [RHEL-61687]
- vfio: mdev: Remove unused function declarations (Alex Williamson) [RHEL-61687]
- vfio/fsl-mc: Remove unused variable 'hwirq' (Alex Williamson) [RHEL-61687]
- vfio/pci: Remove unused struct 'vfio_pci_mmap_vma' (Alex Williamson) [RHEL-61687]
- vfio-mdev: add missing MODULE_DESCRIPTION() macros (Alex Williamson) [RHEL-61687]
- vfio/pci: Fix typo in macro to declare accessors (Alex Williamson) [RHEL-61687]
- vfio/pci: Support 8-byte PCI loads and stores (Alex Williamson) [RHEL-61687]
- vfio/pci: Extract duplicated code into macro (Alex Williamson) [RHEL-61687]
- vfio/pci: Init the count variable in collecting hot-reset devices (Alex Williamson) [RHEL-61687]
- vfio/pci: Insert full vma on mmap'd MMIO fault (Alex Williamson) [RHEL-61687]
- vfio/pci: Use unmap_mapping_range() (Alex Williamson) [RHEL-61687]
- vfio: Create vfio_fs_type with inode per device (Alex Williamson) [RHEL-61687]
- vfio/pci: Restore zero affected bus reset devices warning (Alex Williamson) [RHEL-61687]
- vfio: remove an extra semicolon (Alex Williamson) [RHEL-61687]
- vfio/pci: Collect hot-reset devices to local buffer (Alex Williamson) [RHEL-61687]
- vfio/pci: Pass eventfd context object through irqfd (Alex Williamson) [RHEL-61687]
- vfio/pci: Pass eventfd context to IRQ handler (Alex Williamson) [RHEL-61687]
- MAINTAINERS: Orphan vfio fsl-mc bus driver (Alex Williamson) [RHEL-61687]
- vfio/platform: Convert to platform remove callback returning void (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Enforce PRE_COPY support (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Let firmware knows upon leaving PRE_COPY back to RUNNING (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Block incremental query upon migf state error (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Handle the EREMOTEIO error upon the SAVE command (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Add support for tracker object change event (Alex Williamson) [RHEL-61687]
- net/mlx5: Add the IFC related bits for query tracker (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Activate the chunk mode functionality (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Add support for READING in chunk mode (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Add support for SAVING in chunk mode (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Pre-allocate chunks for the STOP_COPY phase (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Rename some stuff to match chunk mode (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Enable querying state size which is > 4GB (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Refactor the SAVE callback to activate a work only upon an error (Alex Williamson) [RHEL-61687]
- vfio/mlx5: Wake up the reader post of disabling the SAVING migration file (Alex Williamson) [RHEL-61687]
- mptcp: pm: Fix uaf in __timer_delete_sync (CKI Backport Bot) [RHEL-60737] {CVE-2024-46858}
- x86/hyperv: fix kexec crash due to VP assist page corruption (CKI Backport Bot) [RHEL-60725] {CVE-2024-46864}
- hwmon: (adc128d818) Fix underflows seen when writing limit attributes (CKI Backport Bot) [RHEL-59378] {CVE-2024-46759}
- x86/extable: Remove unused fixup type EX_TYPE_COPY (Chris von Recklinghausen) [RHEL-24690]
- x86: re-introduce support for ERMS copies for user space accesses (Chris von Recklinghausen) [RHEL-24690]
- x86: rewrite '__copy_user_nocache' function (Chris von Recklinghausen) [RHEL-24690]
- x86: remove 'zerorest' argument from __copy_user_nocache() (Chris von Recklinghausen) [RHEL-24690]
- x86: improve on the non-rep 'copy_user' function (Chris von Recklinghausen) [RHEL-24690]
- x86: improve on the non-rep 'clear_user' function (Chris von Recklinghausen) [RHEL-24690]
- x86: inline the 'rep movs' in user copies for the FSRM case (Chris von Recklinghausen) [RHEL-24690]
- x86: move stac/clac from user copy routines into callers (Chris von Recklinghausen) [RHEL-24690]
- x86: don't use REP_GOOD or ERMS for user memory clearing (Chris von Recklinghausen) [RHEL-24690]
- x86: don't use REP_GOOD or ERMS for user memory copies (Chris von Recklinghausen) [RHEL-24690]
- x86/uaccess: Don't jump between functions (Chris von Recklinghausen) [RHEL-24690]
- x86/lib: Add fast-short-rep-movs check to copy_user_enhanced_fast_string() (Chris von Recklinghausen) [RHEL-24690]
- Revert "x86/uaccess: Don't jump between functions" (Chris von Recklinghausen) [RHEL-24690]

* Tue Nov 12 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-529.el9]
- tracing: Add the ::microcode field to the mce_record tracepoint (David Arcari) [RHEL-55136]
- tracing: Add the ::ppin field to the mce_record tracepoint (David Arcari) [RHEL-55136]
- x86/mce: Clean up TP_printk() output line of the 'mce_record' tracepoint (David Arcari) [RHEL-55136]
- bpf: Use raw_spinlock_t in ringbuf (Luis Claudio R. Goncalves) [RHEL-20608]
- netfilter: xtables: fix typo causing some targets not to load on IPv6 (Phil Sutter) [RHEL-63905] {CVE-2024-50038}
- netfilter: xtables: avoid NFPROTO_UNSPEC where needed (Phil Sutter) [RHEL-63905] {CVE-2024-50038}
- mptcp: fallback when MPTCP opts are dropped after 1st data (CKI Backport Bot) [RHEL-62218]
- fscache: delete fscache_cookie_lru_timer when fscache exits to avoid UAF (CKI Backport Bot) [RHEL-59451] {CVE-2024-46786}
- platform/x86/intel/pmc: Fix pmc_core_iounmap to call iounmap for valid addresses (David Arcari) [RHEL-65816 RHEL-65933] {CVE-2024-50107}
- platform/x86:intel/pmc: Revert "Enable the ACPI PM Timer to be turned off when suspended" (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Disable ACPI PM Timer disabling on Sky and Kaby Lake (David Arcari) [RHEL-65816]
- platform/x86/intel/pmt: Use PMT callbacks (David Arcari) [RHEL-65816]
- platform/x86/intel/vsec: Add PMT read callbacks (David Arcari) [RHEL-65816]
- clocksource: acpi_pm: Add external callback for suspend/resume (David Arcari) [RHEL-65816]
- platform/x86: intel/pmc: Ignore all LTRs during suspend (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Fix comment for the pmc_core_acpi_pm_timer_suspend_resume function (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Enable the ACPI PM Timer to be turned off when suspended (David Arcari) [RHEL-65816]
- platform/x86: intel/pmc: Remove unused param idx from pmc_for_each_mode() (David Arcari) [RHEL-65816]
- platform/x86/intel/vsec.h: Move to include/linux (David Arcari) [RHEL-65816]
- platform/x86/intel/pmc: Show live substate requirements (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Add support to undo ltr_ignore (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Use the Elvis operator (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Use DEFINE_SHOW_STORE_ATTRIBUTE macro (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Remove unneeded min_t check (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Add support to show ltr_ignore value (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Move pmc assignment closer to first usage (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Convert index variables to be unsigned (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Simplify mutex usage with cleanup helpers (David Arcari) [RHEL-65816]
- platform/x86:intel/pmc: Use the return value of pmc_core_send_msg (David Arcari) [RHEL-65816]
- platform/x86/intel: add missing MODULE_DESCRIPTION() macros (David Arcari) [RHEL-65816]
- platform/x86/intel/pmc: Switch to new Intel CPU model defines (David Arcari) [RHEL-65816]
- NFSD: Force all NFSv4.2 COPY requests to be synchronous (Olga Kornievskaia) [RHEL-64496] {CVE-2024-49974}
- powerpc/fadump: Fix section mismatch warning (Mamatha Inamdar) [RHEL-52914]
- powerpc/fadump: update documentation about bootargs_append (Mamatha Inamdar) [RHEL-52914]
- powerpc/fadump: pass additional parameters when fadump is active (Mamatha Inamdar) [RHEL-52914]
- powerpc/fadump: setup additional parameters for dump capture kernel (Mamatha Inamdar) [RHEL-52914]
- powerpc/pseries/fadump: add support for multiple boot memory regions (Mamatha Inamdar) [RHEL-52914]
- i2c: i801: Add support for Intel Arrow Lake-H (Steve Best) [RHEL-20114]
- xfrm: call xfrm_dev_policy_delete when kill policy (Sabrina Dubroca) [RHEL-63989]
- xfrm: fix netdev reference count imbalance (Sabrina Dubroca) [RHEL-63989]
- xfrm: Preserve vlan tags for transport mode software GRO (Sabrina Dubroca) [RHEL-63989]
- xfrm: set skb control buffer based on packet offload as well (Sabrina Dubroca) [RHEL-63989]
- xfrm: fix xfrm child route lookup for packet offload (Sabrina Dubroca) [RHEL-63989]
- Documentation: bonding: add XDP support explanation (Hangbin Liu) [RHEL-62339]
- bonding: return detailed error when loading native XDP fails (Hangbin Liu) [RHEL-62339]
- net: stmmac: dwmac-tegra: Fix link bring-up sequence (Jose Ignacio Tornos Martinez) [RHEL-32687]
- net: sysctl: allow dump_cpumask to handle higher numbers of CPUs (Antoine Tenart) [RHEL-61203]
- net: sysctl: do not reserve an extra char in dump_cpumask temporary buffer (Antoine Tenart) [RHEL-61203]
- net: sysctl: remove always-true condition (Antoine Tenart) [RHEL-61203]
- scsi: megaraid_sas: Remove trailing space after \n newline (Chandrakanth Patil) [RHEL-60013]
- scsi: megaraid_sas: struct MR_LD_VF_MAP: Replace 1-element arrays with flexible arrays (Chandrakanth Patil) [RHEL-60013]
- scsi: megaraid: Indent Kconfig option help text (Chandrakanth Patil) [RHEL-60013]
- scsi: mpt3sas: Remove trailing space after \n newline (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Avoid IOMMU page faults on REPORT ZONES (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Avoid possible run-time warning with long manufacturer strings (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Add missing kerneldoc parameter descriptions (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Replace deprecated strncpy() with strscpy() (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Prevent sending diag_reset when the controller is ready (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Update driver version to 48.100.00.00 (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Reload SBR without rebooting HBA (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Suppress a warning in debug kernel (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Replace dynamic allocations with local variables (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Replace a dynamic allocation with a local variable (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Fix typo of "TRIGGER" (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Fix an outdated comment (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Remove the iounit_pg8 member of the per-adapter struct (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Use struct_size() for struct size calculations (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Make MPI26_CONFIG_PAGE_PIOUNIT_1::PhyData[] a flexible array (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Make MPI2_CONFIG_PAGE_SASIOUNIT_1::PhyData[] a flexible array (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Make MPI2_CONFIG_PAGE_SASIOUNIT_0::PhyData[] a flexible array (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Make MPI2_CONFIG_PAGE_RAID_VOL_0::PhysDisk[] a flexible array (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Make MPI2_CONFIG_PAGE_IO_UNIT_8::Sensor[] a flexible array (Chandrakanth Patil) [RHEL-60026]
- scsi: mpt3sas: Use flexible arrays when obviously possible (Chandrakanth Patil) [RHEL-60026]
- ipvs: properly dereference pe in ip_vs_add_service (Phil Sutter) [RHEL-54908] {CVE-2024-42322}
- powerpc/mm: Fix boot crash with FLATMEM (Audra Mitchell) [RHEL-55462]
- powerpc/64s/radix: Don't warn on copros in radix__tlb_flush() (Audra Mitchell) [RHEL-55462]
- powerpc/mm/book3s64: Use 256M as the upper limit with coherent device memory attached (Audra Mitchell) [RHEL-55462]
- powerpc/mm/book3s64: Fix build error with SPARSEMEM disabled (Audra Mitchell) [RHEL-55462]
- powerpc/47x: Remove early_init_mmu_47x() to fix no previous prototype (Audra Mitchell) [RHEL-55462]
- powerpc/47x: Add prototype for mmu_init_secondary() (Audra Mitchell) [RHEL-55462]
- powerpc/radix: Move some functions into #ifdef CONFIG_KVM_BOOK3S_HV_POSSIBLE (Audra Mitchell) [RHEL-55462]
- powerpc/mm: Cleanup memory block size probing (Audra Mitchell) [RHEL-55462]
- powerpc/mm/altmap: Fix altmap boundary check (Audra Mitchell) [RHEL-55462]
- powerpc/kasan: Disable KCOV in KASAN code (Audra Mitchell) [RHEL-55462]
- powerpc: mm: convert to GENERIC_IOREMAP (Audra Mitchell) [RHEL-55462]
- powerpc/hugetlb: pte_alloc_huge() (Audra Mitchell) [RHEL-55462]
- powerpc: allow pte_offset_map[_lock]() to fail (Audra Mitchell) [RHEL-55462]
- powerpc: kvmppc_unmap_free_pmd() pte_offset_kernel() (Audra Mitchell) [RHEL-55462]
- powerpc/64s/radix: Fix exit lazy tlb mm switch with irqs enabled (Audra Mitchell) [RHEL-55462]
- powerpc/32s: Fix LLVM SMP build (Audra Mitchell) [RHEL-55462]
- powerpc/64s/radix: combine final TLB flush and lazy tlb mm shootdown IPIs (Audra Mitchell) [RHEL-55462]
- powerpc: Add mm_cpumask warning when context switching (Audra Mitchell) [RHEL-55462]
- powerpc/64s: Use dec_mm_active_cpus helper (Audra Mitchell) [RHEL-55462]
- powerpc: Account mm_cpumask and active_cpus in init_mm (Audra Mitchell) [RHEL-55462]
- powerpc/64s: Fix native_hpte_remove() to be irq-safe (Audra Mitchell) [RHEL-55462]
- powerpc: Use of_address_to_resource() (Audra Mitchell) [RHEL-55462]
- powerpc/embedded6xx/ls_uart: Add missing of_node_put() (Audra Mitchell) [RHEL-55462]
- powerpc/embedded6xx: Add missing of_node_put()s (Audra Mitchell) [RHEL-55462]
- powerpc/e500: Add missing prototype for 'relocate_init' (Audra Mitchell) [RHEL-55462]
- powerpc/64s/radix: Remove TLB_FLUSH_ALL test from range flushes (Audra Mitchell) [RHEL-55462]
- powerpc/64s/radix: mm->context.id should always be valid (Audra Mitchell) [RHEL-55462]
- powerpc/64s/radix: Remove need_flush_all test from radix__tlb_flush (Audra Mitchell) [RHEL-55462]
- powerpc/64s: enable MMU_LAZY_TLB_SHOOTDOWN (Audra Mitchell) [RHEL-55462]
- lazy tlb: shoot lazies, non-refcounting lazy tlb mm reference handling scheme (Audra Mitchell) [RHEL-55462]
- lazy tlb: allow lazy tlb mm refcounting to be configurable (Audra Mitchell) [RHEL-55462]
- lazy tlb: introduce lazy tlb mm refcount helper functions (Audra Mitchell) [RHEL-55462]
- kthread: simplify kthread_use_mm refcounting (Audra Mitchell) [RHEL-55462]
- powerpc/64s/hash: Make stress_hpt_timer_fn() static (Audra Mitchell) [RHEL-55462]
- powerpc/64s: Fix stress_hpt memblock alloc alignment (Audra Mitchell) [RHEL-55462]
- powerpc/64s/hash: add stress_hpt kernel boot option to increase hash faults (Audra Mitchell) [RHEL-55462]
- powerpc/64s: make linear_map_hash_lock a raw spinlock (Audra Mitchell) [RHEL-55462]
- powerpc/64s: make HPTE lock and native_tlbie_lock irq-safe (Audra Mitchell) [RHEL-55462]
- powerpc/64s: Add lockdep for HPTE lock (Audra Mitchell) [RHEL-55462]
- powerpc/64s: Fix hash__change_memory_range preemption warning (Audra Mitchell) [RHEL-55462]
- powerpc/64s: Disable preemption in hash lazy mmu mode (Audra Mitchell) [RHEL-55462]
- powerpc/highmem: Properly handle fragmented memory (Audra Mitchell) [RHEL-55462]
- powerpc/mm: Fix UBSAN warning reported on hugetlb (Audra Mitchell) [RHEL-55462]
- powerpc/mm/book3s/hash: Rename flush_tlb_pmd_range (Audra Mitchell) [RHEL-55462]
- powerpc/32: Remove wii_memory_fixups() (Audra Mitchell) [RHEL-55462]
- powerpc/32: Allow fragmented physical memory (Audra Mitchell) [RHEL-55462]
- powerpc/32: Drop a stale comment about reservation of gigantic pages (Audra Mitchell) [RHEL-55462]
- powerpc/fsl_booke: Make calc_cam_sz() static (Audra Mitchell) [RHEL-55462]
- powerpc: Remove stale declarations in mmu_decl.h (Audra Mitchell) [RHEL-55462]
- powerpc/mm: Rearrange if-else block to avoid clang warning (Audra Mitchell) [RHEL-55462]
- arm64/hugetlb: pte_alloc_huge() pte_offset_huge() (Audra Mitchell) [RHEL-55465]
- arm64: allow pte_offset_map() to fail (Audra Mitchell) [RHEL-55465]
- powerpc: Fix all occurences of duplicate words (Audra Mitchell) [RHEL-55462]
- powerpc/mm: Always update max/min_low_pfn in mem_topology_setup() (Audra Mitchell) [RHEL-55462]
- arm: allow pte_offset_map[_lock]() to fail (Audra Mitchell) [RHEL-55465]
- powerpc/32s: Fix boot failure with KASAN + SMP + JUMP_LABEL_FEATURE_CHECK_DEBUG (Audra Mitchell) [RHEL-55462]
- arm64: kasan: remove !KASAN_VMALLOC remnants (Audra Mitchell) [RHEL-55465]
- Revert "arm64: dma: Drop cache invalidation from arch_dma_prep_coherent()" (Audra Mitchell) [RHEL-55465]
- x86/mm: Use IPIs to synchronize LAM enablement (Audra Mitchell) [RHEL-55461]
- powerpc/32: Set an IBAT covering up to _einittext during init (Audra Mitchell) [RHEL-55462]
- arm64: dma: Drop cache invalidation from arch_dma_prep_coherent() (Audra Mitchell) [RHEL-55465]
- powerpc/32: Call mmu_mark_initmem_nx() regardless of data block mapping. (Audra Mitchell) [RHEL-55462]
- x86/mm: clarify "prev" usage in switch_mm_irqs_off() (Audra Mitchell) [RHEL-55461]
- powerpc/mm/kasan: rename kasan_init_32.c to init_32.c (Audra Mitchell) [RHEL-55462]
- mm: Warn on shadow stack memory in wrong vma (Audra Mitchell) [RHEL-55461]
- ARM: mm: kill unused runtime hook arch_iounmap() (Audra Mitchell) [RHEL-55465]
- Documentation/protection-keys: Clean up documentation for User Space pkeys (Audra Mitchell) [RHEL-55461]
- powerpc: Remove find_current_mm_pte() (Audra Mitchell) [RHEL-55462]
- ARM: add __arm_iomem_set_ro() to write-protect ioremapped area (Audra Mitchell) [RHEL-55465]

* Mon Nov 11 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-528.el9]
- net: Fix an unsafe loop on the list (CKI Backport Bot) [RHEL-63844] {CVE-2024-50024}
- serial: protect uart_port_dtr_rts() in uart_shutdown() too (CKI Backport Bot) [RHEL-63838] {CVE-2024-50058}
- net/sched: accept TCA_STAB only for root qdisc (CKI Backport Bot) [RHEL-63814] {CVE-2024-50039}
- s390/crypto: Display Query and Query Authentication Information in sysfs (Mete Durlu) [RHEL-56382]
- s390/crypto: Add Support for Query Authentication Information (Mete Durlu) [RHEL-56382]
- s390/crypto: Rework RRE and RRF CPACF inline functions (Mete Durlu) [RHEL-56382]
- s390/crypto: Add KDSA CPACF Instruction (Mete Durlu) [RHEL-56382]
- s390/cpacf: Make use of invalid opcode produce a link error (Mete Durlu) [RHEL-56382]
- s390/cpacf: Split and rework cpacf query functions (Mete Durlu) [RHEL-56382]
- dma-mapping: fix tracing dma_alloc/free with vmalloc'd memory (Jerry Snitselaar) [RHEL-61942]
- mmc: core: Only set maximum DMA segment size if DMA is supported (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: fix DMA API tracing for chained scatterlists (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: report unlimited DMA addressing in IOMMU DMA path (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: fix vmap and mmap of noncontiougs allocations (Jerry Snitselaar) [RHEL-61942]
- iommu/dma: remove most stubs in iommu-dma.h (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: reflow dma_supported (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: reliably inform about DMA support for IOMMU (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: add tracing for dma-mapping API calls (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: use IOMMU DMA calls for common alloc/free page calls (Jerry Snitselaar) [RHEL-61942]
- dma-direct: optimize page freeing when it is not addressable (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: clearly mark DMA ops as an architecture feature (Jerry Snitselaar) [RHEL-61942]
- vdpa_sim: don't select DMA_OPS (Jerry Snitselaar) [RHEL-61942]
- arm64: mm: keep low RAM dma zone (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: don't return errors from dma_set_max_seg_size (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: don't return errors from dma_set_seg_boundary (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: don't return errors from dma_set_min_align_mask (Jerry Snitselaar) [RHEL-61942]
- scsi: check that busses support the DMA API before setting dma parameters (Jerry Snitselaar) [RHEL-61942]
- arm64: mm: fix DMA zone when dma-ranges is missing (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: direct calls for dma-iommu (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: call ->unmap_page and ->unmap_sg unconditionally (Jerry Snitselaar) [RHEL-61942]
- arm64: support DMA zone above 4GB (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: replace zone_dma_bits by zone_dma_limit (Jerry Snitselaar) [RHEL-61942]
- dma-mapping: use bit masking to check VM_DMA_COHERENT (Jerry Snitselaar) [RHEL-61942]
- iommu: Set iommu_attach_handle->domain in core (Jerry Snitselaar) [RHEL-61942]
- iommufd: Avoid duplicated __iommu_group_set_core_domain() call (Jerry Snitselaar) [RHEL-61942]
- iommufd: Protect against overflow of ALIGN() during iova allocation (Jerry Snitselaar) [RHEL-61942]
- iommufd: Reorder struct forward declarations (Jerry Snitselaar) [RHEL-61942]
- iommufd: Check the domain owner of the parent before creating a nesting domain (Jerry Snitselaar) [RHEL-61942]
- iommufd/device: Enforce reserved IOVA also when attached to hwpt_nested (Jerry Snitselaar) [RHEL-55215]
- iommufd/selftest: Fix buffer read overrrun in the dirty test (Jerry Snitselaar) [RHEL-61942]
- iommufd: Reorder include files (Jerry Snitselaar) [RHEL-61942]
- iommu: Allow ATS to work on VFs when the PF uses IDENTITY (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Test for PAGING domains before freeing a domain (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Add kernel parameters to limit V1 page-sizes (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Do not set the D bit on AMD v2 table entries (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Correct the reported page sizes from the V1 table (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Remove the confusing dummy iommu_flush_ops tlb ops (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Fix typo of , instead of ; (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Remove conditions from domain free paths (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Narrow the use of struct protection_domain to invalidation (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Store the nid in io_pgtable_cfg instead of the domain (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Remove amd_io_pgtable::pgtbl_cfg (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Rename struct amd_io_pgtable iopt to pgtbl (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Remove the amd_iommu_domain_set_pt_root() and related (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Remove amd_iommu_domain_update() from page table freeing (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Set the pgsize_bitmap correctly (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Allocate the page table root using GFP_KERNEL (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Move allocation of the top table into v1_alloc_pgtable (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Make amd_iommu_dev_update_dte() static (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Rework amd_iommu_update_and_flush_device_table() (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Make amd_iommu_domain_flush_complete() static (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Make amd_iommu_dev_flush_pasid_all() static (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Handle error path in amd_iommu_probe_device() (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Remove unused DTE_GCR3_INDEX_* macros (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Make amd_iommu_is_attach_deferred() static (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Update event log pointer as soon as processing is complete (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Update PASID, GATS, GLX, SNPAVICSUP feature related macros (Jerry Snitselaar) [RHEL-61942]
- iommu/amd: Add blocked domain support (Jerry Snitselaar) [RHEL-61942]
- sizes.h: Add entries between SZ_32G and SZ_64T (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Introduce batched cache invalidation (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Add qi_batch for dmar_domain (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Refactor IOTLB and Dev-IOTLB flush for batching (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Factor out invalidation descriptor composition (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Unconditionally flush device TLB for pasid table updates (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Move PCI PASID enablement to probe path (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Fix potential lockup if qi_submit_sync called with 0 count (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Cleanup si_domain (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Add support for static identity domain (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Factor out helpers from domain_context_mapping_one() (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Remove has_iotlb_device flag (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Always reserve a domain ID for identity setup (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Remove identity mappings from si_domain (Jerry Snitselaar) [RHEL-61942]
- iommu/vt-d: Require DMA domain if hardware not support passthrough (Jerry Snitselaar) [RHEL-61942]
- hsr: Simplify code for announcing HSR nodes timer setup (Felix Maurer) [RHEL-63082]
- net: annotate data-races around dev->if_port (Ivan Vecera) [RHEL-62123]
- inet: bring NLM_DONE out to a separate recv() again (Ivan Vecera) [RHEL-62123]
- rtnetlink: provide RCU protection to rtnl_fill_prop_list() (Ivan Vecera) [RHEL-62123]
- rtnetlink: make rtnl_fill_link_ifmap() RCU ready (Ivan Vecera) [RHEL-62123]
- inet: switch inet_dump_fib() to RCU protection (Ivan Vecera) [RHEL-62123]
- nexthop: allow nexthop_mpath_fill_node() to be called without RTNL (Ivan Vecera) [RHEL-62123]
- inet: allow ip_valid_fib_dump_req() to be called with RTNL or RCU (Ivan Vecera) [RHEL-62123]
- ipv6: switch inet6_dump_ifinfo() to RCU protection (Ivan Vecera) [RHEL-62123]
- rtnetlink: add RTNL_FLAG_DUMP_UNLOCKED flag (Ivan Vecera) [RHEL-62123]
- rtnetlink: change nlk->cb_mutex role (Ivan Vecera) [RHEL-62123]
- netlink: hold nlk->cb_mutex longer in __netlink_dump_start() (Ivan Vecera) [RHEL-62123]
- netlink: fix netlink_diag_dump() return value (Ivan Vecera) [RHEL-62123]
- ipv6: use xarray iterator to implement inet6_dump_ifinfo() (Ivan Vecera) [RHEL-62123]
- ipv6: prepare inet6_fill_ifinfo() for RCU protection (Ivan Vecera) [RHEL-62123]
- ipv6: prepare inet6_fill_ifla6_attrs() for RCU (Ivan Vecera) [RHEL-62123]
- rtnetlink: prepare nla_put_iflink() to run under RCU (Ivan Vecera) [RHEL-62123]
- net: free altname using an RCU callback (Ivan Vecera) [RHEL-62123]
- net: fix removing a namespace with conflicting altnames (Ivan Vecera) [RHEL-62123]
- selftests: net: add very basic test for netdev names and namespaces (Ivan Vecera) [RHEL-62123]
- net: move altnames together with the netdevice (Ivan Vecera) [RHEL-62123]
- net: avoid UAF on deleted altname (Ivan Vecera) [RHEL-62123]
- net: check for altname conflicts when changing netdev's netns (Ivan Vecera) [RHEL-62123]
- net: fix ifname in netlink ntf during netns move (Ivan Vecera) [RHEL-62123]
- net: move from strlcpy with unused retval to strscpy (Ivan Vecera) [RHEL-62123]
- ipv6: make mc_forwarding atomic (Ivan Vecera) [RHEL-62123]
- net: introduce a function to check if a netdev name is in use (Ivan Vecera) [RHEL-62123]
- RDMA/bnxt_re: Fix the GID table length (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix a bug while setting up Level-2 PBL pages (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Change the sequence of updating the CQ toggle value (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix an error path in bnxt_re_add_device (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Avoid CPU lockups due fifo occupancy check loop (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix a possible NULL pointer dereference (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Return more meaningful error (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix incorrect dereference of srq in async event (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix out of bound check (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix the max CQ WQEs for older adapters (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix the max WQEs used in Static WQE mode (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Add a check for memory allocation (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix incorrect AVID type in WQE structure (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix a possible memory leak (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Remove the unused variable en_dev (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Recover the device when FW error is detected (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Group all operations under add_device and remove_device (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Use the aux device for L2 ULP callbacks (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Change aux driver data to en_info to hold more information (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix the max WQE size for static WQE support (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix the compatibility flag for variable size WQE (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Add support for MR Relaxed Ordering (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Avoid an extra hwrm per MR creation (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Rename a variable (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Update HW interface headers (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Share a page to expose per SRQ info with userspace (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Refactor the BNXT_RE_METHOD_GET_TOGGLE_MEM method (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Get the toggle bits from SRQ events (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Enable variable size WQEs for user space applications (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Handle variable WQE support for user applications (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix the table size for PSN/MSN entries (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Get the WQE index from slot index while completing the WQEs (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Add support for Variable WQE in Genp7 adapters (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Disable doorbell moderation if hardware register read fails (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Enable DB moderation for genP7 adapters (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Update the correct DB FIFO depth and mask for GenP7 (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Fix the max msix vectors macro (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Expose the MSN table capability for user library (Mohammad Heib) [RHEL-52759 RHEL-54646]
- RDMA/bnxt_re: Allow MSN table capability check (Mohammad Heib) [RHEL-52759 RHEL-54646]
- sch/netem: fix use after free in netem_dequeue (CKI Backport Bot) [RHEL-59498] {CVE-2024-46800}
- net: bridge: br_fdb_external_learn_add(): always set EXT_LEARN (Jamie Bainbridge) [RHEL-57739]
- selftests: net: bridge_vlan_aware: test that other TPIDs are seen as untagged (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: skip if kernel not support setting bridge fdb learning limit (Jamie Bainbridge) [RHEL-57739]
- net: bridge: mst: Check vlan state for egress decision (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Make vxlan-bridge-1d pass on debug kernels (Jamie Bainbridge) [RHEL-57739]
- selftests: libs: Expand "$@" where possible (Jamie Bainbridge) [RHEL-57739]
- net: bridge: fix an inconsistent indentation (Jamie Bainbridge) [RHEL-57739]
- selftests: net: lib: set 'i' as local (Jamie Bainbridge) [RHEL-57739]
- selftests/net: use tc rule to filter the na packet (Jamie Bainbridge) [RHEL-57739]
- selftests: net: use upstream mtools (Jamie Bainbridge) [RHEL-57739]
- net: bridge: switchdev: Improve error message for port_obj_add/del functions (Jamie Bainbridge) [RHEL-57739]
- net: bridge: fix corrupted ethernet header on multicast-to-unicast (Jamie Bainbridge) [RHEL-57739]
- net: bridge: fix multicast-to-unicast with fraglist GSO (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: add ability to assemble NETIFS array by driver name (Jamie Bainbridge) [RHEL-57739]
- net: bridge: remove redundant check of f->dst (Jamie Bainbridge) [RHEL-57739]
- bridge/br_netlink.c: no need to return void function (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: bail_on_lldpad() should SKIP (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: lib.sh: Validate NETIFS (Jamie Bainbridge) [RHEL-57739]
- selftests: net: Unify code of busywait() and slowwait() (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Support for performance sensitive tests (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Convert log_test() to recognize RET values (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Have RET track kselftest framework constants (Jamie Bainbridge) [RHEL-57739]
- selftests: lib: Define more kselftest exit codes (Jamie Bainbridge) [RHEL-57739]
- selftests/net: add variable NS_LIST for lib.sh (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: README: Document customization (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding.config.sample: Move overrides to lib.sh (Jamie Bainbridge) [RHEL-57739]
- selftests: net: libs: Change variable fallback syntax (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Make VXLAN ECN encap tests more robust (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Make vxlan-bridge-1q pass on debug kernels (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Parametrize mausezahn delay (Jamie Bainbridge) [RHEL-57739]
- net: bridge: Exit if multicast_init_stats fails (Jamie Bainbridge) [RHEL-57739]
- net: bridge: constify the struct device_type usage (Jamie Bainbridge) [RHEL-57739]
- bridge: vlan: use synchronize_net() when holding RTNL (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Add missing multicast routing config entries (Jamie Bainbridge) [RHEL-57739]
- selftests/net/forwarding: add slowwait functions (Jamie Bainbridge) [RHEL-57739]
- net: bridge: Use KMEM_CACHE instead of kmem_cache_create (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Remove duplicated lib.sh content (Jamie Bainbridge) [RHEL-57739]
- selftests: bonding: Add net/forwarding/lib.sh to TEST_INCLUDES (Jamie Bainbridge) [RHEL-57739]
- selftests: team: Add shared library scripts to TEST_INCLUDES (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Redefine relative_path variable (Jamie Bainbridge) [RHEL-57739]
- selftests: forwarding: Add missing config entries (Jamie Bainbridge) [RHEL-57739]
- net: bridge: Do not allocate stats in the driver (Jamie Bainbridge) [RHEL-57739]
- fscrypt: remove mention of symlink st_size quirk from documentation (Ian Kent) [RHEL-33888]
- MAINTAINERS: update idmapping tree (Ian Kent) [RHEL-33888]
- Add Seth Forshee as co-maintainer for idmapped mounts (Ian Kent) [RHEL-33888]
- ceph: allow idmapped setattr inode op (Ian Kent) [RHEL-33888]
- ceph: pass idmap to __ceph_setattr (Ian Kent) [RHEL-33888]
- nfsd: use vfs setgid helper (Ian Kent) [RHEL-33888]
- nfs: use vfs setgid helper (Ian Kent) [RHEL-33888]
- xfs: use consistent uid/gid when grabbing dquots for inodes (Ian Kent) [RHEL-33888]
- ovl: fix null pointer dereference in ovl_permission() (Ian Kent) [RHEL-33888]
- evm: Complete description of evm_inode_setattr() (Ian Kent) [RHEL-33888]
- smb: client: Fix -Wstringop-overflow issues (Ian Kent) [RHEL-33888]
- ovl: fix null pointer dereference in ovl_get_acl_rcu() (Ian Kent) [RHEL-33888]
- fs: move mnt_idmap (Ian Kent) [RHEL-33888]
- MAINTAINERS: add entry for idmapped mounts (Ian Kent) [RHEL-33888]
- fs: port vfs{g,u}id helpers to mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port fs{g,u}id helpers to mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port i_{g,u}id_into_vfs{g,u}id() to mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port i_{g,u}id_{needs_}update() to mnt_idmap (Ian Kent) [RHEL-33888]
- quota: port to mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port privilege checking helpers to mnt_idmap (Ian Kent) [RHEL-33888]
- f2fs: port to vfs{g,u}id_t and associated helpers (Ian Kent) [RHEL-33888]
- fs: port inode_owner_or_capable() to mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port inode_init_owner() to mnt_idmap (Ian Kent) [RHEL-33888]
- nilfs2: fix use-after-free bug of struct nilfs_root (Ian Kent) [RHEL-33888]
- fs: port acl to mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port xattr to mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port ->permission() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- may_linkat(): constify path (Ian Kent) [RHEL-33888]
- fs: port ->fileattr_set() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- ovl: support idmapped layers (Ian Kent) [RHEL-33888]
- ovl: handle idmappings in layer open helpers (Ian Kent) [RHEL-33888]
- ovl: handle idmappings in ovl_permission() (Ian Kent) [RHEL-33888]
- ovl: handle idmappings for layer fileattrs (Ian Kent) [RHEL-33888]
- ovl: use ovl_lookup_upper() wrapper (Ian Kent) [RHEL-33888]
- exportfs: support idmapped mounts (Ian Kent) [RHEL-33888]
- fs: port ->set_acl() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port ->get_acl() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port ->tmpfile() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- fuse: implement ->tmpfile() (Ian Kent) [RHEL-33888]
- fs: port ->mknod() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port ->rename() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- selftests/filesystems: grant executable permission to run_fat_tests.sh (Ian Kent) [RHEL-33888]
- selftests/filesystems: add a vfat RENAME_EXCHANGE test (Ian Kent) [RHEL-33888]
- fat: add renameat2 RENAME_EXCHANGE flag support (Ian Kent) [RHEL-33888]
- fat: factor out reusable code in vfat_rename() as helper functions (Ian Kent) [RHEL-33888]
- fat: add a vfat_rename2() and make existing .rename callback a helper (Ian Kent) [RHEL-33888]
- fs: port ->mkdir() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port ->symlink() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- autofs: remove unused ino field inode (Ian Kent) [RHEL-33888]
- autofs: add comment about autofs_mountpoint_changed() (Ian Kent) [RHEL-33888]
- autofs: use dentry info count instead of simple_empty() (Ian Kent) [RHEL-33888]
- autofs: make dentry info count consistent (Ian Kent) [RHEL-33888]
- autofs: use inode permission method for write access (Ian Kent) [RHEL-33888]
- fs: port ->create() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port ->getattr() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- erofs: support idmapped mounts (Ian Kent) [RHEL-33888]
- ubifs: Fix AA deadlock when setting xattr for encrypted file (Ian Kent) [RHEL-33888]
- ubifs: report correct st_size for encrypted symlinks (Ian Kent) [RHEL-33888]
- proc: report open files as size in stat() for /proc/pid/fd (Ian Kent) [RHEL-33888]
- f2fs: report correct st_size for encrypted symlinks (Ian Kent) [RHEL-33888]
- fs: port ->setattr() to pass mnt_idmap (Ian Kent) [RHEL-33888]
- fs: port vfs_*() helpers to struct mnt_idmap (Ian Kent) [RHEL-33888]
- f2fs: project ids aren't idmapped (Ian Kent) [RHEL-33888]
- acl: conver higher-level helpers to rely on mnt_idmap (Ian Kent) [RHEL-33888]
- fs: introduce dedicated idmap type for mounts (Ian Kent) [RHEL-33888]
- linux/mount.h: trim includes (Ian Kent) [RHEL-33888]
- fs: unset MNT_WRITE_HOLD on failure (Ian Kent) [RHEL-33888]
- mount_setattr(): clean the control flow and calling conventions (Ian Kent) [RHEL-33888]
- fs: clean up mount_setattr control flow (Ian Kent) [RHEL-33888]
- fs: don't open-code mnt_hold_writers() (Ian Kent) [RHEL-33888]
- fs: add mnt_allow_writers() and simplify mount_setattr_prepare() (Ian Kent) [RHEL-33888]
- fs: remove unused idmapping helpers (Ian Kent) [RHEL-33888]
- filelocks: use mount idmapping for setlease permission check (Ian Kent) [RHEL-33888]
- ovl: port to vfs{g,u}id_t and associated helpers (Ian Kent) [RHEL-33888]
- ima: use type safe idmapping helpers (Ian Kent) [RHEL-33888]
- ima: add gid support (Ian Kent) [RHEL-33888]
- ima: fix uid code style problems (Ian Kent) [RHEL-33888]
- apparmor: use type safe idmapping helpers (Ian Kent) [RHEL-33888]
- LSM: Remove double path_rename hook calls for RENAME_EXCHANGE (Ian Kent) [RHEL-33888]
- landlock: Format with clang-format (Ian Kent) [RHEL-33888]
- caps: use type safe idmapping helpers (Ian Kent) [RHEL-33888]
- fs: use type safe idmapping helpers (Ian Kent) [RHEL-33888]
- bprm_fill_uid(): don't open-code file_inode() (Ian Kent) [RHEL-33888]
- mnt_idmapping: add missing helpers (Ian Kent) [RHEL-33888]
- fs: use consistent setgid checks in is_sxid() (Ian Kent) [RHEL-33888]
- attr: use consistent sgid stripping checks (Ian Kent) [RHEL-33888]
- attr: add setattr_should_drop_sgid() (Ian Kent) [RHEL-33888]
- fs: move should_remove_suid() (Ian Kent) [RHEL-33888]
- attr: add in_group_or_capable() (Ian Kent) [RHEL-33888]
- posix_acl: Fix the type of sentinel in get_acl (Ian Kent) [RHEL-33888]
- orangefs: fix mode handling (Ian Kent) [RHEL-33888]
- ovl: call posix_acl_release() after error checking (Ian Kent) [RHEL-33888]
- evm: remove dead code in evm_inode_set_acl() (Ian Kent) [RHEL-33888]
- cifs: check whether acl is valid early (Ian Kent) [RHEL-33888]
- acl: make vfs_posix_acl_to_xattr() static (Ian Kent) [RHEL-33888]
- acl: remove a slew of now unused helpers (Ian Kent) [RHEL-33888]
- 9p: use stub posix acl handlers (Ian Kent) [RHEL-33888]
- cifs: use stub posix acl handlers (Ian Kent) [RHEL-33888]
- ovl: use stub posix acl handlers (Ian Kent) [RHEL-33888]
- ecryptfs: use stub posix acl handlers (Ian Kent) [RHEL-33888]
- evm: remove evm_xattr_acl_change() (Ian Kent) [RHEL-33888]
- xattr: use posix acl api (Ian Kent) [RHEL-33888]
- fuse: fixes after adapting to new posix acl api (Ian Kent) [RHEL-33888]
- fuse: port to vfs{g,u}id_t and associated helpers (Ian Kent) [RHEL-33888]
- ovl: use posix acl api (Ian Kent) [RHEL-33888]
- ovl: implement set acl method (Ian Kent) [RHEL-33888]
- ovl: implement get acl method (Ian Kent) [RHEL-33888]
- ovl: improve ovl_get_acl() if POSIX ACL support is off (Ian Kent) [RHEL-33888]
- ecryptfs: implement set acl method (Ian Kent) [RHEL-33888]
- ecryptfs: implement get acl method (Ian Kent) [RHEL-33888]
- acl: add vfs_remove_acl() (Ian Kent) [RHEL-33888]
- acl: add vfs_get_acl() (Ian Kent) [RHEL-33888]
- fs/posix_acl.c: avoid -Wempty-body warning (Ian Kent) [RHEL-33888]
- acl: add vfs_set_acl() (Ian Kent) [RHEL-33888]
- internal: add may_write_xattr() (Ian Kent) [RHEL-33888]
- evm: add post set acl hook (Ian Kent) [RHEL-33888]
- integrity: implement get and set acl hook (Ian Kent) [RHEL-33888]
- smack: implement get, set and remove acl hook (Ian Kent) [RHEL-33888]
- Smack: fix W=1 build warnings (Ian Kent) [RHEL-33888]
- selinux: implement get, set and remove acl hook (Ian Kent) [RHEL-33888]
- security: add get, remove and set acl hook (Ian Kent) [RHEL-33888]
- 9p: implement set acl method (Ian Kent) [RHEL-33888]
- 9p: implement get acl method (Ian Kent) [RHEL-33888]
- cifs: implement set acl method (Ian Kent) [RHEL-33888]
- cifs: implement get acl method (Ian Kent) [RHEL-33888]
- fs: add new get acl method (Ian Kent) [RHEL-33888]
- fs: rename current get acl method (Ian Kent) [RHEL-33888]
- fs: pass dentry to set acl method (Ian Kent) [RHEL-33888]
- f2fs: support idmapped mounts (Ian Kent) [RHEL-33888]
- orangefs: rework posix acl handling when creating new filesystem objects (Ian Kent) [RHEL-33888]
- xattr: always us is_posix_acl_xattr() helper (Ian Kent) [RHEL-33888]
- acl: fix the comments of posix_acl_xattr_set (Ian Kent) [RHEL-33888]
- xattr: constify value argument in vfs_setxattr() (Ian Kent) [RHEL-33888]
- ovl: use vfs_set_acl_prepare() (Ian Kent) [RHEL-33888]
- acl: move idmapping handling into posix_acl_xattr_set() (Ian Kent) [RHEL-33888]
- acl: add vfs_set_acl_prepare() (Ian Kent) [RHEL-33888]
- acl: return EOPNOTSUPP in posix_acl_fix_xattr_common() (Ian Kent) [RHEL-33888]
- open: always initialize ownership fields (Ian Kent) [RHEL-33888]
- acl: handle idmapped mounts for idmapped filesystems (Ian Kent) [RHEL-33888]
- ovl: handle idmappings in ovl_get_acl() (Ian Kent) [RHEL-33888]
- acl: make posix_acl_clone() available to overlayfs (Ian Kent) [RHEL-33888]
- ovl: enable RCU'd ->get_acl() (Ian Kent) [RHEL-33888]
- vfs: add rcu argument to ->get_acl() callback (Ian Kent) [RHEL-33888]
- acl: port to vfs{g,u}id_t (Ian Kent) [RHEL-33888]
- acl: move idmapped mount fixup into vfs_{g,s}etxattr() (Ian Kent) [RHEL-33888]
- mnt_idmapping: align kernel doc and parameter order (Ian Kent) [RHEL-33888]
- mnt_idmapping: return false when comparing two invalid ids (Ian Kent) [RHEL-33888]
- attr: fix kernel doc (Ian Kent) [RHEL-33888]
- attr: port attribute changes to new types (Ian Kent) [RHEL-33888]
- quota: port quota helpers mount ids (Ian Kent) [RHEL-33888]
- fs: port to iattr ownership update helpers (Ian Kent) [RHEL-33888]
- fs: introduce tiny iattr ownership update helpers (Ian Kent) [RHEL-33888]
- fs: use mount types in iattr (Ian Kent) [RHEL-33888]
- docs: Add small intro to idmap examples (Ian Kent) [RHEL-33888]
- fs: remove unused low-level mapping helpers (Ian Kent) [RHEL-33888]
- docs: update mapping documentation (Ian Kent) [RHEL-33888]
- doc: give a more thorough id handling explanation (Ian Kent) [RHEL-33888]

* Wed Nov 06 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-527.el9]
- dt-bindings: soc: qcom: pmic-glink: allow orientation-gpios (Desnes Nunes) [RHEL-59050]
- dt-bindings: soc: qcom: qcom,pmic-glink: document QCM6490 compatible (Desnes Nunes) [RHEL-59050]
- dt-bindings: soc: qcom: qcom,pmic-glink: document X1E80100 compatible (Desnes Nunes) [RHEL-59050]
- dt-bindings: soc: qcom: pmic-glink: document SM8650 compatible (Desnes Nunes) [RHEL-59050]
- dt-bindings: soc: qcom: qcom,pmic-glink: add a gpio used to determine the Type-C port plug orientation (Desnes Nunes) [RHEL-59050]
- dt-bindings: soc: qcom: qcom,pmic-glink: document SM8550 compatible (Desnes Nunes) [RHEL-59050]
- dt-bindings: soc: qcom: qcom,pmic-glink: document SM8450 compatible (Desnes Nunes) [RHEL-59050]
- USB: serial: mos7840: fix crash on resume (Desnes Nunes) [RHEL-59050] {CVE-2024-42244}
- USB: serial: option: add Rolling RW350-GL variants (Desnes Nunes) [RHEL-59050]
- USB: serial: option: add support for Foxconn T99W651 (Desnes Nunes) [RHEL-59050]
- USB: serial: option: add Netprisma LCUK54 series modules (Desnes Nunes) [RHEL-59050]
- usb: dwc3: pci: add support for the Intel Panther Lake (Desnes Nunes) [RHEL-59050]
- usb: core: add missing of_node_put() in usb_of_has_devices_or_graph (Desnes Nunes) [RHEL-59050]
- USB: Add USB_QUIRK_NO_SET_INTF quirk for START BP-850k (Desnes Nunes) [RHEL-59050]
- USB: core: Fix duplicate endpoint bug by clearing reserved bits in the descriptor (Desnes Nunes) [RHEL-59050] {CVE-2024-41035}
- xhci: always resume roothubs if xHC was reset during resume (Desnes Nunes) [RHEL-59050]
- usb: dwc3: core: Workaround for CSR read timeout (Desnes Nunes) [RHEL-59050]
- USB: serial: option: add Telit generic core-dump composition (Desnes Nunes) [RHEL-59050]
- USB: serial: option: add Fibocom FM350-GL (Desnes Nunes) [RHEL-59050]
- USB: serial: option: add Telit FN912 rmnet compositions (Desnes Nunes) [RHEL-59050]
- usb: dwc3: core: remove lock of otg mode during gadget suspend/resume to avoid deadlock (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: glink: fix child node release in probe function (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi_acpi: Add LG Gram quirk (Desnes Nunes) [RHEL-59050]
- usb: ucsi: stm32: fix command completion handling (Desnes Nunes) [RHEL-59050]
- usb: atm: cxacru: fix endpoint checking in cxacru_bind() (Desnes Nunes) [RHEL-59050]
- xhci: Apply broken streams quirk to Etron EJ188 xHCI host (Desnes Nunes) [RHEL-59050]
- xhci: Apply reset resume quirk to Etron EJ188 xHCI host (Desnes Nunes) [RHEL-59050]
- xhci: Set correct transferred length for cancelled bulk transfers (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: Ack also failed Get Error commands (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: realtek,rts5411: Add missing "additionalProperties" on child nodes (Desnes Nunes) [RHEL-59050]
- usb: typec: tcpm: Ignore received Hard Reset in TOGGLING state (Desnes Nunes) [RHEL-59050]
- USB: xen-hcd: Traverse host/ when CONFIG_USB_XEN_HCD is selected (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: glink: increase max ports for x1e80100 (Desnes Nunes) [RHEL-59050]
- Revert "usb: chipidea: move ci_ulpi_init after the phy initialization" (Desnes Nunes) [RHEL-59050]
- thunderbolt: debugfs: Fix margin debugfs node creation condition (Desnes Nunes) [RHEL-59050]
- usb: dwc3: core: Fix unused variable warning in core driver (Desnes Nunes) [RHEL-59050]
- usb: typec: tipd: rely on i2c_get_match_data() (Desnes Nunes) [RHEL-59050]
- usb: typec: tipd: fix event checking for tps6598x (Desnes Nunes) [RHEL-59050]
- usb: typec: tipd: fix event checking for tps25750 (Desnes Nunes) [RHEL-59050]
- usb: phy: tegra: Replace of_gpio.h by proper one (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: displayport: Fix potential deadlock (Desnes Nunes) [RHEL-59050]
- extcon: max8997: select IRQ_DOMAIN instead of depending on it (Desnes Nunes) [RHEL-59050]
- usb: core: Remove the useless struct usb_devmap which is just a bitmap (Desnes Nunes) [RHEL-59050]
- media: uvcvideo: Refactor iterators (Desnes Nunes) [RHEL-59050]
- media: gspca: cpia1: Use min macro (Desnes Nunes) [RHEL-59050]
- media: s2255: Use refcount_t instead of atomic_t for num_channels (Desnes Nunes) [RHEL-59050]
- media: uvcvideo: Use max() macro (Desnes Nunes) [RHEL-59050]
- USB: usb_parse_endpoint: ignore reserved bits (Desnes Nunes) [RHEL-59050]
- usb: xhci: compact 'trb_in_td()' arguments (Desnes Nunes) [RHEL-59050]
- usb: xhci: remove duplicate TRB_TO_SLOT_ID() calls (Desnes Nunes) [RHEL-59050]
- xhci: pci: Use PCI_VENDOR_ID_RENESAS (Desnes Nunes) [RHEL-59050]
- xhci: pci: Group out Thunderbolt xHCI IDs (Desnes Nunes) [RHEL-59050]
- xhci: pci: Use full names in PCI IDs for Intel platforms (Desnes Nunes) [RHEL-59050]
- usb: xhci: remove goto 'cleanup' in handle_tx_event() (Desnes Nunes) [RHEL-59050]
- usb: xhci: replace goto with return when possible in handle_tx_event() (Desnes Nunes) [RHEL-59050]
- usb: xhci: remove 'handling_skipped_tds' from handle_tx_event() (Desnes Nunes) [RHEL-59050]
- xhci: remove XHCI_TRUST_TX_LENGTH quirk (Desnes Nunes) [RHEL-59050]
- xhci: improve PORTSC register debugging output (Desnes Nunes) [RHEL-59050]
- usb: xhci: remove redundant variable 'erst_size' (Desnes Nunes) [RHEL-59050]
- usb: xhci: address off-by-one in xhci_num_trbs_free() (Desnes Nunes) [RHEL-59050]
- usb: xhci: improve debug message in xhci_ring_expansion_needed() (Desnes Nunes) [RHEL-59050]
- xhci: remove xhci_check_usb2_port_capability helper (Desnes Nunes) [RHEL-59050]
- xhci: stored cached port capability values in one place (Desnes Nunes) [RHEL-59050]
- USB: fix up for "usb: misc: onboard_hub: rename to onboard_dev" (Desnes Nunes) [RHEL-59050]
- thunderbolt: Correct trace output of firmware connection manager packets (Desnes Nunes) [RHEL-59050]
- thunderbolt: Fix kernel-doc for tb_tunnel_alloc_dp() (Desnes Nunes) [RHEL-59050]
- thunderbolt: Fix uninitialized variable in tb_tunnel_alloc_usb3() (Desnes Nunes) [RHEL-59050]
- usb: dwc3: core: Fix compile warning on s390 gcc in dwc3_get_phy call (Desnes Nunes) [RHEL-59050]
- memstick: rtsx_usb_ms: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-59050]
- memstick: rtsx_pci_ms: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-59050]
- memstick: rtsx_pci_ms: Drop if block with always false condition (Desnes Nunes) [RHEL-59050]
- thunderbolt: There are only 5 basic router registers in pre-USB4 routers (Desnes Nunes) [RHEL-59050]
- usb: dwc3: core: Refactor PHY logic to support Multiport Controller (Desnes Nunes) [RHEL-59050]
- usb: dwc3: core: Skip setting event buffers for host only controllers (Desnes Nunes) [RHEL-59050]
- usb: dwc3: core: Access XHCI address space temporarily to read port info (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: Add bindings for multiport properties on DWC3 controller (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: Add multiport suspend/resume support for wrapper (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: Enable wakeup for applicable ports of multiport (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: Refactor IRQ handling in glue driver (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: Add helper function to request wakeup interrupts (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: qcom,dwc3: fix interrupt max items (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: dwc3: Add QDU1000 compatible (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: qcom,dwc3: Add bindings for SC8280 Multiport (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: Remove ACPI support from glue driver (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: qcom,dwc3: fix a typo in interrupts' description (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: qcom,dwc3: Fix SDM660 clock description (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: Rename hs_phy_irq to qusb2_phy_irq (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: dwc3: Clean up hs_phy_irq in binding (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: qcom,dwc3: Add X1E80100 binding (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: qcom,dwc3: adjust number of interrupts on SM6125 (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: qcom,dwc3: document the SM8560 SuperSpeed DWC3 USB controller (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: dwc3: Add IPQ5018 compatible (Desnes Nunes) [RHEL-59050]
- USB: dwc3: qcom: fix ACPI platform device leak (Desnes Nunes) [RHEL-59050]
- USB: dwc3: qcom: fix software node leak on probe errors (Desnes Nunes) [RHEL-59050]
- USB: dwc3: qcom: fix resource leaks on probe deferral (Desnes Nunes) [RHEL-59050]
- USB: dwc3: qcom: simplify wakeup interrupt setup (Desnes Nunes) [RHEL-59050]
- USB: dwc3: qcom: fix wakeup after probe deferral (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: use dev_err_probe() where appropriate (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: Fix an error handling path in dwc3_qcom_probe() (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: Release the correct resources in dwc3_qcom_remove() (Desnes Nunes) [RHEL-59050]
- usb: dwc3: qcom: Fix potential memory leak (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: uhci: convert to dt schema (Desnes Nunes) [RHEL-59050]
- thunderbolt: No need to loop over all retimers if access fails (Desnes Nunes) [RHEL-59050]
- thunderbolt: Increase sideband access polling delay (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: usbmisc-imx: add fsl,imx8ulp-usbmisc compatible (Desnes Nunes) [RHEL-59050]
- media: uvcvideo: Disable autosuspend for Insta360 Link (Desnes Nunes) [RHEL-59050]
- media: uvcvideo: Fix power line control for Shine-Optics Camera (Desnes Nunes) [RHEL-59050]
- media: uvcvideo: Add quirk for Logitech Rally Bar (Desnes Nunes) [RHEL-59050]
- thunderbolt: Get rid of TB_CFG_PKG_PREPARE_TO_SLEEP (Desnes Nunes) [RHEL-59050]
- thunderbolt: Use correct error code with ERROR_NOT_SUPPORTED (Desnes Nunes) [RHEL-59050]
- usb: dwc3: Select 2.0 or 3.0 clk base on maximum_speed (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: glink: set orientation aware if supported (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: add update_connector callback (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: glink: use typec_set_orientation (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: glink: move GPIO reading into connector_status callback (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: add callback for connector status updates (Desnes Nunes) [RHEL-59050]
- media: v4l2-ctrls-core.c: Do not use iterator outside loop (Desnes Nunes) [RHEL-59050]
- thunderbolt: Allow USB3 bandwidth to be lower than maximum supported (Desnes Nunes) [RHEL-59050]
- thunderbolt: Fix calculation of consumed USB3 bandwidth on a path (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi_glink: drop special handling for CCI_BUSY (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi_glink: drop NO_PARTNER_PDOS quirk for sm8550 / sm8650 (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi_glink: enable the UCSI_DELAY_DEVICE_PDOS quirk on qcm6490 (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi_glink: enable the UCSI_DELAY_DEVICE_PDOS quirk (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi_glink: rework quirks implementation (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: fix UCSI on SM8550 & SM8650 Qualcomm devices (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: Add qcm6490-pmic-glink as needing PDOS quirk (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: Wait 20ms before reading CCI after a reset (Desnes Nunes) [RHEL-59050]
- usb: chipidea: move ci_ulpi_init after the phy initialization (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: hx3: Remove unneeded dr_mode (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: Document the Microchip USB2514 hub (Desnes Nunes) [RHEL-59050]
- usb: phy-generic: add short delay after pulling the reset pin (Desnes Nunes) [RHEL-59050]
- thunderbolt: Enable NVM upgrade support on Intel Maple Ridge (Desnes Nunes) [RHEL-59050]
- phy: core: make phy_class constant (Desnes Nunes) [RHEL-59050]
- usb: misc: uss720: check for incompatible versions of the Belkin F5U002 (Desnes Nunes) [RHEL-59050]
- usb: misc: uss720: add support for another variant of the Belkin F5U002 (Desnes Nunes) [RHEL-59050]
- usb: misc: uss720: document the names of the compatible devices (Desnes Nunes) [RHEL-59050]
- usb: misc: uss720: point pp->dev to usbdev->dev (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi_acpi: Remove Dell quirk (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: Never send a lone connector change ack (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: Stop abuse of bit definitions from ucsi.h (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: support delaying GET_PDOS for device (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: extract code to read PD caps (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: simplify partner's PD caps registration (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: always register a link to USB PD device (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: properly register partner's PD device (Desnes Nunes) [RHEL-59050]
- usb: typec: displayport: drop driver owner assignment (Desnes Nunes) [RHEL-59050]
- usb: typec: ucsi: Only enable supported notifications (Desnes Nunes) [RHEL-59050]
- phy: qcom: edp: Add set_mode op for configuring eDP/DP submode (Desnes Nunes) [RHEL-59050]
- phy: Add Embedded DisplayPort and DisplayPort submodes (Desnes Nunes) [RHEL-59050]
- redhat/configs: Adding CONFIG_PHY_FSL_SAMSUNG_HDMI_PHY (Desnes Nunes) [RHEL-59050]
- phy: freescale: add Samsung HDMI PHY (Desnes Nunes) [RHEL-59050]
- dt-bindings: phy: add binding for the i.MX8MP HDMI PHY (Desnes Nunes) [RHEL-59050]
- usb: misc: onboard_dev: add support for XMOS XVF3500 (Desnes Nunes) [RHEL-59050]
- usb: misc: onboard_dev: add support for non-hub devices (Desnes Nunes) [RHEL-59050]
- redhat/configs: rename CONFIG_USB_ONBOARD_HUB to CONFIG_USB_ONBOARD_DEV (Desnes Nunes) [RHEL-59050]
- ASoC: dt-bindings: xmos,xvf3500: add XMOS XVF3500 voice processor (Desnes Nunes) [RHEL-59050]
- ARM: multi_v7_defconfig: update ONBOARD_USB_HUB to ONBOAD_USB_DEV (Desnes Nunes) [RHEL-59050]
- ARM: multi_v7_defconfig: enable USB onboard HUB driver (Desnes Nunes) [RHEL-59050]
- arm64: defconfig: update ONBOARD_USB_HUB to ONBOARD_USB_DEV (Desnes Nunes) [RHEL-59050]
- drm: ci: arm64.config: update ONBOARD_USB_HUB to ONBOARD_USB_DEV (Desnes Nunes) [RHEL-59050]
- usb: misc: onboard_hub: rename to onboard_dev (Desnes Nunes) [RHEL-59050]
- usb: misc: onboard_usb_hub: Drop obsolete dependency on COMPILE_TEST (Desnes Nunes) [RHEL-59050]
- usb: misc: onboard_hub: use device supply names (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: ci-hdrc-usb2-imx: add compatible and clock-names restriction for imx93 (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: ci-hdrc-usb2-imx: add restrictions for reg, interrupts, clock and clock-names properties (Desnes Nunes) [RHEL-59050]
- dt-bindings: usb: chipidea,usb2-imx: move imx parts to dedicated schema (Desnes Nunes) [RHEL-59050]
- usb: chipidea: ci_hdrc_imx: align usb wakeup clock name with dt-bindings (Desnes Nunes) [RHEL-59050]
- usb: typec: stusb160x: convert to use maple tree register cache (Desnes Nunes) [RHEL-59050]
- USB: Use EHCI control transfer pid macros instead of constant values. (Desnes Nunes) [RHEL-59050]
- usb: chipidea: npcm: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-59050]
- USB: gadget: core: create sysfs link between udc and gadget (Desnes Nunes) [RHEL-59050]
- i2c: tiny-usb: check usb base class before assuming the interface on device is for this driver (Desnes Nunes) [RHEL-59050]
- i2c: Delete error messages for failed memory allocations (Desnes Nunes) [RHEL-59050]
- usb: phy: generic: add suspend support for regulator (Desnes Nunes) [RHEL-59050]
- qed: put cond_resched() in qed_dmae_operation_wait() (Michal Schmidt) [RHEL-6372]
- qed: allow the callee of qed_mcp_nvm_read() to sleep (Michal Schmidt) [RHEL-6372]
- qed: put cond_resched() in qed_grc_dump_ctx_data() (Michal Schmidt) [RHEL-6372]
- qed: make 'ethtool -d' 10 times faster (Michal Schmidt) [RHEL-6372]
- qed: allow sleep in qed_mcp_trace_dump() (Michal Schmidt) [RHEL-6372]
- ipv4: Don't reset ->flowi4_scope in ip_rt_fix_tos(). (Hangbin Liu) [RHEL-59754]
- iommu/amd: Fix argument order in amd_iommu_dev_flush_pasid_all() (Jerry Snitselaar) [RHEL-59981]
- redhat/configs: Increase LOCKDEP_STACK_TRACE_BITS to 20 (Waiman Long) [RHEL-59009]
- xfs: fix scrub stats file permissions (Bill O'Donnell) [RHEL-57114]
- xfs: fix an off-by-one error in xreap_agextent_binval (Bill O'Donnell) [RHEL-57114]
- xfs: Remove duplicate include (Bill O'Donnell) [RHEL-57114]
- xfs: use roundup_pow_of_two instead of ffs during xlog_find_tail (Bill O'Donnell) [RHEL-57114]
- xfs: only call xchk_stats_merge after validating scrub inputs (Bill O'Donnell) [RHEL-57114]
- xfs: require a relatively recent V5 filesystem for LARP mode (Bill O'Donnell) [RHEL-57114]
- xfs: reserve less log space when recovering log intent items (Bill O'Donnell) [RHEL-57114]
- xfs: fix again select in kconfig XFS_ONLINE_SCRUB_STATS (Bill O'Donnell) [RHEL-57114]
- xfs: fix select in config XFS_ONLINE_SCRUB_STATS (Bill O'Donnell) [RHEL-57114]
- fs/xfs: Fix typos in comments (Bill O'Donnell) [RHEL-57114]
- xfs: don't check reflink iflag state when checking cow fork (Bill O'Donnell) [RHEL-57114]
- xfs: simplify returns in xchk_bmap (Bill O'Donnell) [RHEL-57114]
- xfs: rewrite xchk_inode_is_allocated to work properly (Bill O'Donnell) [RHEL-57114]
- xfs: hide xfs_inode_is_allocated in scrub common code (Bill O'Donnell) [RHEL-57114]
- xfs: clear pagf_agflreset when repairing the AGFL (Bill O'Donnell) [RHEL-57114]
- xfs: allow userspace to rebuild metadata structures (Bill O'Donnell) [RHEL-57114]
- xfs: don't complain about unfixed metadata when repairs were injected (Bill O'Donnell) [RHEL-57114]
- xfs: allow the user to cancel repairs before we start writing (Bill O'Donnell) [RHEL-57114]
- xfs: always rescan allegedly healthy per-ag metadata after repair (Bill O'Donnell) [RHEL-57114]
- xfs: implement online scrubbing of rtsummary info (Bill O'Donnell) [RHEL-57114]
- xfs: move the realtime summary file scrubber to a separate source file (Bill O'Donnell) [RHEL-57114]
- xfs: wrap ilock/iunlock operations on sc->ip (Bill O'Donnell) [RHEL-57114]
- xfs: get our own reference to inodes that we want to scrub (Bill O'Donnell) [RHEL-57114]
- xfs: track usage statistics of online fsck (Bill O'Donnell) [RHEL-57114]
- xfs: create scaffolding for creating debugfs entries (Bill O'Donnell) [RHEL-57114]
- xfs: improve xfarray quicksort pivot (Bill O'Donnell) [RHEL-57114]
- xfs: cache pages used for xfarray quicksort convergence (Bill O'Donnell) [RHEL-57114]
- xfs: speed up xfarray sort by sorting xfile page contents directly (Bill O'Donnell) [RHEL-57114]
- xfs: teach xfile to pass back direct-map pages to caller (Bill O'Donnell) [RHEL-57114]
- xfs: convert xfarray insertion sort to heapsort using scratchpad memory (Bill O'Donnell) [RHEL-57114]
- xfs: enable sorting of xfile-backed arrays (Bill O'Donnell) [RHEL-57114]
- xfs: create a big array data structure (Bill O'Donnell) [RHEL-57114]
- xfs: use per-AG bitmaps to reap unused AG metadata blocks during repair (Bill O'Donnell) [RHEL-57114]
- xfs: reap large AG metadata extents when possible (Bill O'Donnell) [RHEL-57114]
- xfs: allow scanning ranges of the buffer cache for live buffers (Bill O'Donnell) [RHEL-57114]
- xfs: rearrange xrep_reap_block to make future code flow easier (Bill O'Donnell) [RHEL-57114]
- xfs: use deferred frees to reap old btree blocks (Bill O'Donnell) [RHEL-57114]
- xfs: only allow reaping of per-AG blocks in xrep_reap_extents (Bill O'Donnell) [RHEL-57114]
- xfs: only invalidate blocks if we're going to free them (Bill O'Donnell) [RHEL-57114]
- xfs: move the post-repair block reaping code to a separate file (Bill O'Donnell) [RHEL-57114]
- xfs: cull repair code that will never get used (Bill O'Donnell) [RHEL-57114]
- xfs: stabilize fs summary counters for online fsck (Bill O'Donnell) [RHEL-57114]
- pinctrl: Remove redundant null pointer checks in pinctrl_remove_device_debugfs() (Steve Best) [RHEL-61798]
- pinctrl: core: fix possible memory leak when pinctrl_enable() fails (Steve Best) [RHEL-61798]
- pinctrl: core: reset gpio_device in loop in pinctrl_pins_show() (Steve Best) [RHEL-61798]
- pinctrl: core: take into account the pins array in pinctrl_pins_show() (Steve Best) [RHEL-61798]
- pinctrl: core: comment that pinctrl_add_gpio_range() is deprecated (Steve Best) [RHEL-61798]
- pwm: Provide wrappers for storing and getting driver private data (Steve Best) [RHEL-61798]
- pinctrl: intel: Constify struct intel_pinctrl parameter (Steve Best) [RHEL-61798]
- pinctrl: baytrail: Drop duplicate return statement (Steve Best) [RHEL-61798]
- pinctrl: intel: Inline intel_gpio_community_irq_handler() (Steve Best) [RHEL-61798]
- pinctrl: intel: Introduce for_each_intel_gpio_group() helper et al. (Steve Best) [RHEL-61798]
- pinctrl: intel: Constify intel_get_community() returned object (Steve Best) [RHEL-61798]
- pinctrl: intel: Implement high impedance support (Steve Best) [RHEL-61798]
- pinctrl: intel: Refactor __intel_gpio_set_direction() to be more useful (Steve Best) [RHEL-61798]
- pinctrl: intel: Add __intel_gpio_get_direction() helper (Steve Best) [RHEL-61798]
- pinctrl: baytrail: Add pinconf group for uart3 (Steve Best) [RHEL-61798]
- pinctrl: baytrail: Fix selecting gpio pinctrl state (Steve Best) [RHEL-61798]
- pinctrl: lynxpoint: Simplify code with cleanup helpers (Steve Best) [RHEL-61798]
- pinctrl: lynxpoint: Replace kernel.h by what is actually being used (Steve Best) [RHEL-61798]
- pinctrl: lynxpoint: drop runtime PM support (Steve Best) [RHEL-61798]
- pinctrl: lynxpoint: Make use of pm_ptr() (Steve Best) [RHEL-61798]
- pinctrl: lynxpoint: reuse common functions from pinctrl-intel (Steve Best) [RHEL-61798]
- pinctrl: lynxpoint: Convert to use new memeber in struct intel_function (Steve Best) [RHEL-61798]
- pinctrl: lynxpoint: Add missing header(s) (Steve Best) [RHEL-61798]
- pinctrl: lynxpoint: Switch to to embedded struct pingroup (Steve Best) [RHEL-61798]
- sctp: ensure sk_state is set to CLOSED if hashing fails in sctp_listen_start (Xin Long) [RHEL-63283]
- sctp: set sk_state back to CLOSED if autobind fails in sctp_listen_start (Xin Long) [RHEL-63283]
- sctp: Fix null-ptr-deref in reuseport_add_sock(). (Xin Long) [RHEL-63283]
- sctp: cancel a blocking accept when shutdown a listen socket (Xin Long) [RHEL-63283]
- dmaengine: Fix spelling mistakes (Jerry Snitselaar) [RHEL-63088]
- dmaengine: avoid non-constant format string (Jerry Snitselaar) [RHEL-63088]
- dmaengine: idxd: Add new DSA and IAA device IDs for Diamond Rapids platform (Jerry Snitselaar) [RHEL-63088]
- dmaengine: idxd: Add a new DSA device ID for Granite Rapids-D platform (Jerry Snitselaar) [RHEL-38566]
- dmaengine: ti: k3-udma: Remove unused declarations (Jerry Snitselaar) [RHEL-63088]
- dmaengine: dmatest: Explicitly cast divisor to u32 (Jerry Snitselaar) [RHEL-63088]
- dmaengine: idxd: Convert comma to semicolon (Jerry Snitselaar) [RHEL-63088]
- dmaengine: dw: Unify ret-val local variables naming (Jerry Snitselaar) [RHEL-63088]
- dmaengine: dw: Simplify max-burst calculation procedure (Jerry Snitselaar) [RHEL-63088]
- dmaengine: dw: Define encode_maxburst() above prepare_ctllo() callbacks (Jerry Snitselaar) [RHEL-63088]
- dmaengine: dw: Simplify prepare CTL_LO methods (Jerry Snitselaar) [RHEL-63088]
- bnxt_en: Don't clear ntuple filters and rss contexts during ethtool ops (Michal Schmidt) [RHEL-54645]
- bnxt_en : Fix memory out-of-bounds in bnxt_fill_hw_rss_tbl() (Michal Schmidt) [RHEL-54645]
- eth: bnxt: populate defaults in the RSS context struct (Michal Schmidt) [RHEL-54645]
- eth: bnxt: reject unsupported hash functions (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix RSS logic in __bnxt_reserve_rings() (Michal Schmidt) [RHEL-54645]
- eth: bnxt: use the indir table from ethtool context (Michal Schmidt) [RHEL-54645]
- eth: bnxt: bump the entry size in indir tables to u32 (Michal Schmidt) [RHEL-54645]
- eth: bnxt: pad out the correct indirection table (Michal Schmidt) [RHEL-54645]
- eth: bnxt: use the RSS context XArray instead of the local list (Michal Schmidt) [RHEL-54645]
- eth: bnxt: use context priv for struct bnxt_rss_ctx (Michal Schmidt) [RHEL-54645]
- eth: bnxt: depend on core cleaning up RSS contexts (Michal Schmidt) [RHEL-54645]
- eth: bnxt: remove rss_ctx_bmap (Michal Schmidt) [RHEL-54645]
- eth: bnxt: move from .set_rxfh to .create_rxfh_context and friends (Michal Schmidt) [RHEL-54645]
- eth: bnxt: allow deleting RSS contexts when the device is down (Michal Schmidt) [RHEL-54645]
- bnxt: fix crashes when reducing ring count with active RSS contexts (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix the resource check condition for RSS contexts (Michal Schmidt) [RHEL-54645]
- bnxt_en: Remove atomic operations on ptp->tx_avail (Michal Schmidt) [RHEL-54645]
- bnxt_en: Increase the max total outstanding PTP TX packets to 4 (Michal Schmidt) [RHEL-54645]
- bnxt_en: Let bnxt_stamp_tx_skb() return error code (Michal Schmidt) [RHEL-54645]
- bnxt_en: Remove an impossible condition check for PTP TX pending SKB (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor all PTP TX timestamp fields into a struct (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add BCM5760X specific PHC registers mapping (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add TX timestamp completion logic (Michal Schmidt) [RHEL-54645]
- bnxt_en: Allow some TX packets to be unprocessed in NAPI (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add is_ts_pkt field to struct bnxt_sw_tx_bd (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add new TX timestamp completion definitions (Michal Schmidt) [RHEL-54645]
- bnxt_en: implement netdev_queue_mgmt_ops (Michal Schmidt) [RHEL-54645]
- bnxt_en: split rx ring helpers out from ring helpers (Michal Schmidt) [RHEL-54645]
- bnxt_en: Cap the size of HWRM_PORT_PHY_QCFG forwarded response (Michal Schmidt) [RHEL-54645]
- bnxt_en: fix atomic counter for ptp packets (Michal Schmidt) [RHEL-54645]
- bnxt_en: add timestamping statistics support (Michal Schmidt) [RHEL-54645]
- bnxt_en: silence clang build warning (Michal Schmidt) [RHEL-54645]
- bnxt: fix bnxt_get_avail_msix() returning negative values (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add VF PCI ID for 5760X (P7) chips (Michal Schmidt) [RHEL-54645]
- bnxt_en: Optimize recovery path ULP locking in the driver (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add a mutex to synchronize ULP operations (Michal Schmidt) [RHEL-54645]
- bnxt_en: Don't call ULP_STOP/ULP_START during L2 reset (Michal Schmidt) [RHEL-54645]
- bnxt_en: Don't support offline self test when RoCE driver is loaded (Michal Schmidt) [RHEL-54645]
- bnxt_en: share NQ ring sw_stats memory with subrings (Michal Schmidt) [RHEL-54645]
- eth: bnxt: fix counting packets discarded due to OOM and netpoll (Michal Schmidt) [RHEL-54645]
- bnxt_en: flower: validate control flags (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix the PCI-AER routines (Michal Schmidt) [RHEL-54645]
- bnxt_en: refactor reset close code (Michal Schmidt) [RHEL-54645]
- bnxt_en: Update MODULE_DESCRIPTION (Michal Schmidt) [RHEL-54645]
- bnxt_en: Utilize ulp client resources if RoCE is not registered (Michal Schmidt) [RHEL-54645]
- bnxt_en: Change MSIX/NQs allocation policy (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor bnxt_rdma_aux_device_init/uninit functions (Michal Schmidt) [RHEL-54645]
- bnxt_en: Remove unneeded MSIX base structure fields and code (Michal Schmidt) [RHEL-54645]
- bnxt_en: Remove a redundant NULL check in bnxt_register_dev() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Skip ethtool RSS context configuration in ifdown state (Michal Schmidt) [RHEL-54645]
- bnxt_en: Reset PTP tx_avail after possible firmware reset (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix error recovery for RoCE ulp client (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix possible memory leak in bnxt_rdma_aux_device_init() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix PTP firmware timeout parameter (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add warning message about disallowed speed change (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add XDP Metadata support (Michal Schmidt) [RHEL-54645]
- bnxt_en: Change bnxt_rx_xdp function prototype (Michal Schmidt) [RHEL-54645]
- bnxt_en: Allocate page pool per numa node (Michal Schmidt) [RHEL-54645]
- bnxt_en: Enable XPS by default on driver load (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add delay to handle Downstream Port Containment (DPC) AER (Michal Schmidt) [RHEL-54645]
- bnxt_en: Support adding ntuple rules on RSS contexts (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor bnxt_cfg_rfs_ring_tbl_idx() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Support RSS contexts in ethtool .{get|set}_rxfh() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor bnxt_set_rxfh() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add a new_rss_ctx parameter to bnxt_rfs_capable() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Simplify bnxt_rfs_capable() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor RSS indir alloc/set functions (Michal Schmidt) [RHEL-54645]
- bnxt_en: Introduce rss ctx structure, alloc/free functions (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor VNIC alloc and cfg functions (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add helper function bnxt_hwrm_vnic_rss_cfg_p5() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Retry PTP TX timestamp from FW for 1 second (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add a timeout parameter to bnxt_hwrm_port_ts_query() (Michal Schmidt) [RHEL-54645]
- eth: bnxt: support per-queue statistics (Michal Schmidt) [RHEL-54645]
- bnxt_en: fix accessing vnic_info before allocating it (Michal Schmidt) [RHEL-54645]
- bnxt_en: Use the new VNIC to create ntuple filters (Michal Schmidt) [RHEL-54645]
- bnxt_en: Create and setup the additional VNIC for adding ntuple filters (Michal Schmidt) [RHEL-54645]
- bnxt_en: Provision for an additional VNIC for ntuple filters (Michal Schmidt) [RHEL-54645]
- bnxt_en: Define BNXT_VNIC_DEFAULT for the default vnic index (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor bnxt_set_features() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add bnxt_get_total_vnics() to calculate number of VNICs (Michal Schmidt) [RHEL-54645]
- bnxt_en: Check additional resources in bnxt_check_rings() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Improve RSS context reservation infrastructure (Michal Schmidt) [RHEL-54645]
- bnxt_en: Explicitly specify P5 completion rings to reserve (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor ring reservation functions (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add RSS support for IPSEC headers (Michal Schmidt) [RHEL-54645]
- bnxt_en: Invalidate user filters when needed (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add support for user configured RSS key (Michal Schmidt) [RHEL-54645]
- bnxt_en: Restore all the user created L2 and ntuple filters (Michal Schmidt) [RHEL-54645]
- bnxt_en: Retain user configured filters when closing (Michal Schmidt) [RHEL-54645]
- bnxt_en: Save user configured filters in a lookup list (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add separate function to delete the filter structure (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add drop action support for ntuple (Michal Schmidt) [RHEL-54645]
- bnxt_en: Enhance ethtool ntuple support for ip flows besides TCP/UDP (Michal Schmidt) [RHEL-54645]
- bnxt_en: implement fully specified 5-tuple masks (Michal Schmidt) [RHEL-54645]
- bnxt_en: Support ethtool -n to display ether filters. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add ethtool -N support for ether filters. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Use firmware provided maximum filter counts. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Make PTP timestamp HWRM more silent (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix possible crash after creating sw mqprio TCs (Michal Schmidt) [RHEL-54645]
- bnxt_en: Prevent kernel warning when running offline self test (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix RSS table entries calculation for P5_PLUS chips (Michal Schmidt) [RHEL-54645]
- bnxt_en: Wait for FLR to complete during probe (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix RCU locking for ntuple filters in bnxt_rx_flow_steer() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix RCU locking for ntuple filters in bnxt_srxclsrldel() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Remove unneeded variable in bnxt_hwrm_clear_vnic_filter() (Michal Schmidt) [RHEL-54645]
- bnxt_en: Fix compile error without CONFIG_RFS_ACCEL (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add support for ntuple filter deletion by ethtool. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add support for ntuple filters added from ethtool. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add ntuple matching flags to the bnxt_ntuple_filter structure. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor ntuple filter removal logic in bnxt_cfg_ntp_filters(). (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor the hash table logic for ntuple filters. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor filter insertion logic in bnxt_rx_flow_steer(). (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add new BNXT_FLTR_INSERTED flag to bnxt_filter_base struct. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add bnxt_lookup_ntp_filter_from_idx() function (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add function to calculate Toeplitz hash (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor L2 filter alloc/free firmware commands. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Re-structure the bnxt_ntuple_filter structure. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add bnxt_l2_filter hash table. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Refactor bnxt_ntuple_filter structure. (Michal Schmidt) [RHEL-54645]
- bnxt_en: Make PTP TX timestamp HWRM query silent (Michal Schmidt) [RHEL-54645]
- bnxt_en: Skip nic close/open when configuring tstamp filters (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add support for UDP GSO on 5760X chips (Michal Schmidt) [RHEL-54645]
- bnxt_en: add rx_filter_miss extended stats (Michal Schmidt) [RHEL-54645]
- bnxt_en: Configure UDP tunnel TPA (Michal Schmidt) [RHEL-54645]
- bnxt_en: Add support for VXLAN GPE (Michal Schmidt) [RHEL-54645]
- bnxt_en: Use proper TUNNEL_DST_PORT_ALLOC* commands (Michal Schmidt) [RHEL-54645]
- bnxt_en: Allocate extra QP backing store memory when RoCE FW reports it (Michal Schmidt) [RHEL-54645]
- bnxt_en: Support TX coalesced completion on 5760X chips (Michal Schmidt) [RHEL-54645]
- eth: bnxt: link NAPI instances to queues and IRQs (Michal Schmidt) [RHEL-54645]
- bnxt_en: move bnxt_rx_ts_valid() to its upstream location (Michal Schmidt) [RHEL-54645]
- net: tcp: accept old ack during closing (Jamie Bainbridge) [RHEL-60572]
- pinctrl: intel: Move debounce validation out of the lock (Steve Best) [RHEL-65439]

* Tue Nov 05 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-526.el9]
- powerpc64/bpf: jit support for signed division and modulo (Artem Savkov) [RHEL-33019]
- powerpc64/bpf: jit support for sign extended mov (Artem Savkov) [RHEL-33019]
- powerpc64/bpf: jit support for sign extended load (Artem Savkov) [RHEL-33019]
- powerpc64/bpf: jit support for unconditional byte swap (Artem Savkov) [RHEL-33019]
- powerpc64/bpf: jit support for 32bit offset jmp instruction (Artem Savkov) [RHEL-33019]
- powerpc/bpf/32: Fix failing test_bpf tests (Artem Savkov) [RHEL-33019]
- arm64: bpf: fix 32bit unconditional bswap (Artem Savkov) [RHEL-29141]
- of: module: add buffer overflow check in of_modalias() (cki-backport-bot) [RHEL-44273] {CVE-2024-38541}
- Documentation/ABI/configfs-tsm: Fix an unexpected indentation silly (Paolo Bonzini) [RHEL-49791]
- x86/sev: Do RMP memory coverage check after max_pfn has been set (Paolo Bonzini) [RHEL-49791]
- x86/sev: Move SEV compilation units (Paolo Bonzini) [RHEL-49791]
- virt: sev-guest: Mark driver struct with __refdata to prevent section mismatch (Paolo Bonzini) [RHEL-49791]
- x86/sev: Allow non-VMPL0 execution when an SVSM is present (Paolo Bonzini) [RHEL-49791]
- x86/sev: Extend the config-fs attestation support for an SVSM (Paolo Bonzini) [RHEL-49791]
- x86/sev: Take advantage of configfs visibility support in TSM (Paolo Bonzini) [RHEL-49791]
- fs/configfs: Add a callback to determine attribute visibility (Paolo Bonzini) [RHEL-49791]
- sev-guest: configfs-tsm: Allow the privlevel_floor attribute to be updated (Paolo Bonzini) [RHEL-49791]
- virt: sev-guest: Choose the VMPCK key based on executing VMPL (Paolo Bonzini) [RHEL-49791]
- x86/sev: Provide guest VMPL level to userspace (Paolo Bonzini) [RHEL-49791]
- x86/sev: Provide SVSM discovery support (Paolo Bonzini) [RHEL-49791]
- x86/sev: Use the SVSM to create a vCPU when not in VMPL0 (Paolo Bonzini) [RHEL-49791]
- x86/sev: Perform PVALIDATE using the SVSM when not at VMPL0 (Paolo Bonzini) [RHEL-49791]
- x86/sev: Fix __reserved field in sev_config (Paolo Bonzini) [RHEL-15585]
- x86/sev: Use kernel provided SVSM Calling Areas (Paolo Bonzini) [RHEL-49791]
- x86/sev: Check for the presence of an SVSM in the SNP secrets page (Paolo Bonzini) [RHEL-49791]
- x86/irqflags: Provide native versions of the local_irq_save()/restore() (Paolo Bonzini) [RHEL-49791]
- ACPI: tables: Print MULTIPROC_WAKEUP when MADT is parsed (Paolo Bonzini) [RHEL-15585]
- x86/acpi: Add support for CPU offlining for ACPI MADT wakeup method (Paolo Bonzini) [RHEL-15585]
- x86/mm: Introduce kernel_ident_mapping_free() (Paolo Bonzini) [RHEL-15585]
- x86/smp: Add smp_ops.stop_this_cpu() callback (Paolo Bonzini) [RHEL-15585]
- x86/acpi: Do not attempt to bring up secondary CPUs in the kexec case (Paolo Bonzini) [RHEL-15585]
- x86/acpi: Rename fields in the acpi_madt_multiproc_wakeup structure (Paolo Bonzini) [RHEL-15585]
- x86/mm: Do not zap page table entries mapping unaccepted memory table during kdump (Paolo Bonzini) [RHEL-15585]
- x86/mm: Make e820__end_ram_pfn() cover E820_TYPE_ACPI ranges (Paolo Bonzini) [RHEL-15585]
- x86/tdx: Convert shared memory back to private on kexec (Paolo Bonzini) [RHEL-15585]
- x86/mm: Add callbacks to prepare encrypted memory for kexec (Paolo Bonzini) [RHEL-15585]
- x86/tdx: Account shared memory (Paolo Bonzini) [RHEL-15585]
- x86/mm: Return correct level from lookup_address() if pte is none (Paolo Bonzini) [RHEL-15585]
- x86/mm: Make x86_platform.guest.enc_status_change_*() return an error (Paolo Bonzini) [RHEL-15585]
- x86/kexec: Keep CR4.MCE set during kexec for TDX guest (Paolo Bonzini) [RHEL-15585]
- x86/relocate_kernel: Use named labels for less confusion (Paolo Bonzini) [RHEL-15585]
- cpu/hotplug, x86/acpi: Disable CPU offlining for ACPI MADT wakeup (Paolo Bonzini) [RHEL-15585]
- cpu/hotplug: Add support for declaring CPU offlining not supported (Paolo Bonzini) [RHEL-15585]
- x86/acpi: Remove __ro_after_init from acpi_mp_wake_mailbox (Paolo Bonzini) [RHEL-15585]
- x86/apic: Mark acpi_mp_wake_* variables as __ro_after_init (Paolo Bonzini) [RHEL-15585]
- x86/acpi: Extract ACPI MADT wakeup code into a separate file (Paolo Bonzini) [RHEL-15585]
- x86/kexec: Remove spurious unconditional JMP from from identity_mapped() (Paolo Bonzini) [RHEL-15585]
- cpu: Drop "extern" from function declarations in cpuhplock.h (Paolo Bonzini) [RHEL-15585]
- x86/sev: Make the VMPL0 checking more straight forward (Paolo Bonzini) [RHEL-15585]
- x86/sev: Rename snp_init() in boot/compressed/sev.c (Paolo Bonzini) [RHEL-15585]
- x86/sev: Shorten struct name snp_secrets_page_layout to snp_secrets_page (Paolo Bonzini) [RHEL-15585]
- x86/pat: Fix W^X violation false-positives when running as Xen PV guest (Paolo Bonzini) [RHEL-15585]
- x86/pat: Restructure _lookup_address_cpa() (Paolo Bonzini) [RHEL-15585]
- x86/mm: Use lookup_address_in_pgd_attr() in show_fault_oops() (Paolo Bonzini) [RHEL-15585]
- x86/pat: Introduce lookup_address_in_pgd_attr() (Paolo Bonzini) [RHEL-15585]
- x86/mm/cpa: Warn for set_memory_XXcrypted() VMM fails (Paolo Bonzini) [RHEL-15585]
- dm-verity: introduce the options restart_on_error and panic_on_error (Benjamin Marzinski) [RHEL-59523]
- Revert "dm: requeue IO if mapping table not yet available" (Benjamin Marzinski) [RHEL-59523]
- dm integrity: fix gcc 5 warning (Benjamin Marzinski) [RHEL-59523]
- dm: treat alloc_dax() -EOPNOTSUPP failure as non-fatal (Benjamin Marzinski) [RHEL-59523]
- configs: dm: CONFIG_DM_VERITY_VERIFY_ROOTHASH_SIG_PLATFORM_KEYRING (Benjamin Marzinski) [RHEL-59523]
- dm-integrity: fix a race condition when accessing recalc_sector (Benjamin Marzinski) [RHEL-59523]
- dm persistent data: fix memory allocation failure (Benjamin Marzinski) [RHEL-59523]
- Documentation: dm-crypt.rst warning + error fix (Benjamin Marzinski) [RHEL-59523]
- dm resume: don't return EINVAL when signalled (Benjamin Marzinski) [RHEL-59523]
- dm suspend: return -ERESTARTSYS instead of -EINTR (Benjamin Marzinski) [RHEL-59523]
- dm: Constify struct dm_block_validator (Benjamin Marzinski) [RHEL-59523]
- dm-integrity: introduce the Inline mode (Benjamin Marzinski) [RHEL-59523]
- dm: introduce the target flag mempool_needs_integrity (Benjamin Marzinski) [RHEL-59523]
- dm raid: fix stripes adding reshape size issues (Benjamin Marzinski) [RHEL-34750]
- dm raid: move _get_reshape_sectors() as prerequisite to fixing reshape size issues (Benjamin Marzinski) [RHEL-34750]
- dm-crypt: support for per-sector NVMe metadata (Benjamin Marzinski) [RHEL-59523]
- dm mpath: don't call dm_get_device in multipath_message (Benjamin Marzinski) [RHEL-59523]
- dm: factor out helper function from dm_get_device (Benjamin Marzinski) [RHEL-59523]
- dm-verity: fix dm_is_verity_target() when dm-verity is builtin (Benjamin Marzinski) [RHEL-59523]
- dm: Remove max_secure_erase_granularity (Benjamin Marzinski) [RHEL-59523]
- dm: Remove max_write_zeroes_granularity (Benjamin Marzinski) [RHEL-59523]
- dm: stop using blk_limits_io_{min,opt} (Benjamin Marzinski) [RHEL-59523]
- dm verity: add support for signature verification with platform keyring (Benjamin Marzinski) [RHEL-59523]
- dm-verity: hash blocks with shash import+finup when possible (Benjamin Marzinski) [RHEL-59523]
- dm-verity: make verity_hash() take dm_verity_io instead of ahash_request (Benjamin Marzinski) [RHEL-59523]
- dm-verity: always "map" the data blocks (Benjamin Marzinski) [RHEL-59523]
- dm-verity: provide dma_alignment limit in io_hints (Benjamin Marzinski) [RHEL-59523]
- dm-verity: make real_digest and want_digest fixed-length (Benjamin Marzinski) [RHEL-59523]
- dm-verity: move data hash mismatch handling into its own function (Benjamin Marzinski) [RHEL-59523]
- dm-verity: move hash algorithm setup into its own function (Benjamin Marzinski) [RHEL-59523]
- dm init: Handle minors larger than 255 (Benjamin Marzinski) [RHEL-59523]
- dm cache metadata: remove unused struct 'thunk' (Benjamin Marzinski) [RHEL-59523]
- dm io: remove code duplication between sync_io and aysnc_io (Benjamin Marzinski) [RHEL-59523]
- dm io: don't call the async_io notify.fn on invalid num_regions (Benjamin Marzinski) [RHEL-59523]
- dm io: bump num_bvecs to handle offset memory (Benjamin Marzinski) [RHEL-59523]
- dm: optimize flushes (Benjamin Marzinski) [RHEL-59523]
- dm-integrity: set discard_granularity to logical block size (Benjamin Marzinski) [RHEL-59523]
- dm-delay: remove timer_lock (Benjamin Marzinski) [RHEL-59523]
- dm-delay: change locking to avoid contention (Benjamin Marzinski) [RHEL-59523]
- dm-delay: fix max_delay calculations (Benjamin Marzinski) [RHEL-59523]
- dm-delay: fix hung task introduced by kthread mode (Benjamin Marzinski) [RHEL-59523]
- dm-delay: fix workqueue delay_timer race (Benjamin Marzinski) [RHEL-59523]
- dm-crypt: don't set WQ_CPU_INTENSIVE for WQ_UNBOUND crypt_queue (Benjamin Marzinski) [RHEL-59523]
- dm-crypt: export sysfs of all workqueues (Benjamin Marzinski) [RHEL-59523]
- dm-crypt: add the optional "high_priority" flag (Benjamin Marzinski) [RHEL-59523]
- MAINTAINERS: Remove incorrect M: tag for dm-devel@lists.linux.dev (Benjamin Marzinski) [RHEL-59523]
- dm-verity: Convert from tasklet to BH workqueue (Benjamin Marzinski) [RHEL-59523]
- dm-crypt: Convert from tasklet to BH workqueue (Benjamin Marzinski) [RHEL-59523]
- dm: update relevant MODULE_AUTHOR entries to latest dm-devel mailing list (Benjamin Marzinski) [RHEL-59523]
- dm ioctl: update DM_DRIVER_EMAIL to new dm-devel mailing list (Benjamin Marzinski) [RHEL-59523]
- dm verity: set DM_TARGET_SINGLETON feature flag (Benjamin Marzinski) [RHEL-59523]
- dm crypt: Fix IO priority lost when queuing write bios (Benjamin Marzinski) [RHEL-59523]
- dm verity: Fix IO priority lost when reading FEC and hash (Benjamin Marzinski) [RHEL-59523]
- dm bufio: Support IO priority (Benjamin Marzinski) [RHEL-59523]
- dm io: Support IO priority (Benjamin Marzinski) [RHEL-59523]
- dm crypt: remove redundant state settings after waking up (Benjamin Marzinski) [RHEL-59523]
- dm thin: add braces around conditional code that spans lines (Benjamin Marzinski) [RHEL-59523]
- timekeeping: Add function to convert realtime to base clock (Ivan Vecera) [RHEL-61639]
- x86/tsc: Remove obsolete ART to TSC conversion functions (Ivan Vecera) [RHEL-61639]
- ice/ptp: Remove convert_art_to_tsc() (Ivan Vecera) [RHEL-61639]
- ALSA: hda: Remove convert_art_to_tsc() (Ivan Vecera) [RHEL-61639]
- stmmac: intel: Remove convert_art_to_tsc() (Ivan Vecera) [RHEL-61639]
- igc: Remove convert_art_ns_to_tsc() (Ivan Vecera) [RHEL-61639]
- e1000e: Replace convert_art_to_tsc() (Ivan Vecera) [RHEL-61639]
- x86/tsc: Provide ART base clock information for TSC (Ivan Vecera) [RHEL-61639]
- timekeeping: Provide infrastructure for converting to/from a base clock (Ivan Vecera) [RHEL-61639]
- kvmclock: Unexport kvmclock clocksource (Ivan Vecera) [RHEL-61639]
- treewide: Remove system_counterval_t.cs, which is never read (Ivan Vecera) [RHEL-61639]
- timekeeping: Evaluate system_counterval_t.cs_id instead of .cs (Ivan Vecera) [RHEL-61639]
- ptp/kvm, arm_arch_timer: Set system_counterval_t.cs_id to constant (Ivan Vecera) [RHEL-61639]
- x86/kvm, ptp/kvm: Add clocksource ID, set system_counterval_t.cs_id (Ivan Vecera) [RHEL-61639]
- x86/tsc: Add clocksource ID, set system_counterval_t.cs_id (Ivan Vecera) [RHEL-61639]
- timekeeping: Add clocksource ID to struct system_counterval_t (Ivan Vecera) [RHEL-61639]
- x86/tsc: Correct kernel-doc notation (Ivan Vecera) [RHEL-61639]
- add missing includes and forward declarations to networking includes under linux/ (Ivan Vecera) [RHEL-61639]
- ipv4: ip_gre: Fix drops of small packets in ipgre_xmit (Guillaume Nault) [RHEL-61892]
- ip6_tunnel: Fix broken GRO (Guillaume Nault) [RHEL-61892]
- nvme: use helper nvme_ctrl_state in nvme_keep_alive_finish function (Maurizio Lombardi) [RHEL-51888]
- nvme: make keep-alive synchronous operation (Maurizio Lombardi) [RHEL-51888]
- nvme-loop: flush off pending I/O while shutting down loop controller (Maurizio Lombardi) [RHEL-51888]
- nvme-pci: fix race condition between reset and nvme_dev_disable() (Maurizio Lombardi) [RHEL-51888]
- nvme-multipath: defer partition scanning (Maurizio Lombardi) [RHEL-51888]
- nvme: disable CC.CRIME (NVME_CC_CRIME) (Maurizio Lombardi) [RHEL-51888]
- nvme: delete unnecessary fallthru comment (Maurizio Lombardi) [RHEL-51888]
- nvmet-rdma: use sbitmap to replace rsp free list (Maurizio Lombardi) [RHEL-51888]
- nvme: tcp: avoid race between queue_lock lock and destroy (Maurizio Lombardi) [RHEL-51888]
- nvmet-passthru: clear EUID/NGUID/UUID while using loop target (Maurizio Lombardi) [RHEL-51888]
- nvme: remove CC register read-back during enabling (Maurizio Lombardi) [RHEL-51888]
- nvme: null terminate nvme_tls_attrs (Maurizio Lombardi) [RHEL-51888]
- nvme-multipath: avoid hang on inaccessible namespaces (Maurizio Lombardi) [RHEL-51888]
- nvme-multipath: system fails to create generic nvme device (Maurizio Lombardi) [RHEL-51888]
- nvme-pci: qdepth 1 quirk (Maurizio Lombardi) [RHEL-51888]
- nvme-tcp: fix link failure for TCP auth (Maurizio Lombardi) [RHEL-51888]
- nvme: Convert comma to semicolon (Maurizio Lombardi) [RHEL-51888]
- nvme: fix metadata handling in nvme-passthrough (Maurizio Lombardi) [RHEL-51888]
- nvme: rename apptag and appmask to lbat and lbatm (Maurizio Lombardi) [RHEL-51888]
- nvme-rdma: send cntlid in the RDMA_CM_REQUEST Private Data (Maurizio Lombardi) [RHEL-51888]
- nvme-target: do not check authentication status for admin commands twice (Maurizio Lombardi) [RHEL-51888]
- nvmet-auth: allow to clear DH-HMAC-CHAP keys (Maurizio Lombardi) [RHEL-51888]
- nvme-sysfs: add 'tls_keyring' attribute (Maurizio Lombardi) [RHEL-51888]
- nvme-sysfs: add 'tls_configured_key' sysfs attribute (Maurizio Lombardi) [RHEL-51888]
- nvme: split off TLS sysfs attributes into a separate group (Maurizio Lombardi) [RHEL-51888]
- nvme: add a newline to the 'tls_key' sysfs attribute (Maurizio Lombardi) [RHEL-51888]
- nvme-tcp: check for invalidated or revoked key (Maurizio Lombardi) [RHEL-51888]
- nvme-tcp: sanitize TLS key handling (Maurizio Lombardi) [RHEL-51888]
- nvme-keyring: restrict match length for version '1' identifiers (Maurizio Lombardi) [RHEL-51888]
- nvme_core: scan namespaces asynchronously (Maurizio Lombardi) [RHEL-51888]
- nvmet: Identify-Active Namespace ID List command should reject invalid nsid (Maurizio Lombardi) [RHEL-51888]
- nvme-pci: Add sleep quirk for Samsung 990 Evo (Maurizio Lombardi) [RHEL-51888]
- nvme-pci: allocate tagset on reset if necessary (Maurizio Lombardi) [RHEL-51888]
- nvmet-tcp: fix kernel crash if commands allocation fails (Maurizio Lombardi) [RHEL-51888]
- nvme: use better description for async reset reason (Maurizio Lombardi) [RHEL-51888]
- nvmet: Make nvmet_debugfs static (Maurizio Lombardi) [RHEL-51888]
- nvme: Remove unused field (Maurizio Lombardi) [RHEL-51888]
- nvme: move stopping keep-alive into nvme_uninit_ctrl() (Maurizio Lombardi) [RHEL-51888]
- nvme: reorganize nvme_ns_head fields (Maurizio Lombardi) [RHEL-51888]
- nvme: change data type of lba_shift (Maurizio Lombardi) [RHEL-51888]
- nvme: remove a field from nvme_ns_head (Maurizio Lombardi) [RHEL-51888]
- nvme: remove unused parameter (Maurizio Lombardi) [RHEL-51888]
- nvme-core: choose PIF from QPIF if QPIFS supports and PIF is QTYPE (Maurizio Lombardi) [RHEL-51888]
- nvme-pci: Fix the instructions for disabling power management (Maurizio Lombardi) [RHEL-51888]
- nvme: remove redundant bdev local variable (Maurizio Lombardi) [RHEL-51888]
- nvme-fabrics: Use seq_putc() in __nvmf_concat_opt_tokens() (Maurizio Lombardi) [RHEL-51888]
- nvme/pci: Add APST quirk for Lenovo N60z laptop (Maurizio Lombardi) [RHEL-51888]
- nvmet-auth: fix nvmet_auth hash error handling (Maurizio Lombardi) [RHEL-51888]
- nvme: implement ->get_unique_id (Maurizio Lombardi) [RHEL-51888]
- nvme-pci: do not directly handle subsys reset fallout (Maurizio Lombardi) [RHEL-51888]
- redhat: add CONFIG_NVME_TARGET_DEBUGFS file (Maurizio Lombardi) [RHEL-51888]
- nvme-fcloop: implement 'host_traddr' (Maurizio Lombardi) [RHEL-51888]
- nvmet-fc: implement host_traddr() (Maurizio Lombardi) [RHEL-51888]
- nvmet-rdma: implement host_traddr() (Maurizio Lombardi) [RHEL-51888]
- nvmet-tcp: implement host_traddr() (Maurizio Lombardi) [RHEL-51888]
- nvmet: add 'host_traddr' callback for debugfs (Maurizio Lombardi) [RHEL-51888]
- nvmet: add debugfs support (Maurizio Lombardi) [RHEL-51888]
- nvme: rename CDR/MORE/DNR to NVME_STATUS_* (Maurizio Lombardi) [RHEL-51888]
- nvme: fix status magic numbers (Maurizio Lombardi) [RHEL-51888]
- nvme: rename nvme_sc_to_pr_err to nvme_status_to_pr_err (Maurizio Lombardi) [RHEL-51888]
- nvme: split device add from initialization (Maurizio Lombardi) [RHEL-51888]
- nvme: fc: split controller bringup handling (Maurizio Lombardi) [RHEL-51888]
- nvme: rdma: split controller bringup handling (Maurizio Lombardi) [RHEL-51888]
- nvme: tcp: split controller bringup handling (Maurizio Lombardi) [RHEL-51888]
- nvme: apple: fix device reference counting (Maurizio Lombardi) [RHEL-51888]
- nvmet-fc: Remove __counted_by from nvmet_fc_tgt_queue.fod[] (Maurizio Lombardi) [RHEL-51888]
- nvmet: make 'tsas' attribute idempotent for RDMA (Maurizio Lombardi) [RHEL-51888]
- nvme: fixup comment for nvme RDMA Provider Type (Maurizio Lombardi) [RHEL-51888]
- nvme-apple: add missing MODULE_DESCRIPTION() (Maurizio Lombardi) [RHEL-51888]
- nvmet: do not return 'reserved' for empty TSAS values (Maurizio Lombardi) [RHEL-51888]
- nvme: fix NVME_NS_DEAC may incorrectly identifying the disk as EXT_LBA. (Maurizio Lombardi) [RHEL-51888]
- nvmet-passthru: propagate status from id override functions (Maurizio Lombardi) [RHEL-51888]
- nvme: fix nvme_pr_* status code parsing (Maurizio Lombardi) [RHEL-51888]
- nvme: adjust multiples of NVME_CTRL_PAGE_SIZE in offset (Maurizio Lombardi) [RHEL-51888]
- nvme: remove sgs and sws (Maurizio Lombardi) [RHEL-51888]
- nvme-rdma, nvme-tcp: include max reconnects for reconnect logging (Maurizio Lombardi) [RHEL-51888]
- nvmet-rdma: Avoid o(n^2) loop in delete_ctrl (Maurizio Lombardi) [RHEL-51888]
- nvme: do not retry authentication failures (Maurizio Lombardi) [RHEL-51888]
- nvme-fabrics: short-circuit reconnect retries (Maurizio Lombardi) [RHEL-51888]
- nvme: return kernel error codes for admin queue connect (Maurizio Lombardi) [RHEL-51888]
- nvmet: return DHCHAP status codes from nvmet_setup_auth() (Maurizio Lombardi) [RHEL-51888]
- nvmet: lock config semaphore when accessing DH-HMAC-CHAP key (Maurizio Lombardi) [RHEL-51888]
- nvmet-rdma: fix possible bad dereference when freeing rsps (Maurizio Lombardi) [RHEL-51888]
- nvmet: prevent sprintf() overflow in nvmet_subsys_nsid_exists() (Maurizio Lombardi) [RHEL-51888]
- nvmet: make nvmet_wq unbound (Maurizio Lombardi) [RHEL-51888]
- nvmet-auth: return the error code to the nvmet_auth_ctrl_hash() callers (Maurizio Lombardi) [RHEL-51888]
- nvme-pci: Add quirk for broken MSIs (Maurizio Lombardi) [RHEL-51888]
- nvmet: fix nvme status code when namespace is disabled (Maurizio Lombardi) [RHEL-51888]
- nvmet-tcp: fix possible memory leak when tearing down a controller (Maurizio Lombardi) [RHEL-51888]
- nvmet-auth: replace pr_debug() with pr_err() to report an error. (Maurizio Lombardi) [RHEL-51888]
- nvmet-auth: return the error code to the nvmet_auth_host_hash() callers (Maurizio Lombardi) [RHEL-51888]
- nvme-fc: rename free_ctrl callback to match name pattern (Maurizio Lombardi) [RHEL-51888]
- nvmet-fc: move RCU read lock to nvmet_fc_assoc_exists (Maurizio Lombardi) [RHEL-51888]
- nvmet: implement unique discovery NQN (Maurizio Lombardi) [RHEL-51888]
- nvmet-rdma: remove NVMET_RDMA_REQ_INVALIDATE_RKEY flag (Maurizio Lombardi) [RHEL-51888]
- nvme: remove redundant BUILD_BUG_ON check (Maurizio Lombardi) [RHEL-51888]
- nvme/tcp: Add wq_unbound modparam for nvme_tcp_wq (Maurizio Lombardi) [RHEL-51888]
- nvme-tcp: Export the nvme_tcp_wq to sysfs (Maurizio Lombardi) [RHEL-51888]
- drivers/nvme: Add quirks for device 126f:2262 (Maurizio Lombardi) [RHEL-51888]
- nvme: parse format command's lbafu when tracing (Maurizio Lombardi) [RHEL-51888]
- nvme: add tracing of reservation commands (Maurizio Lombardi) [RHEL-51888]
- nvme: parse zns command's zsa and zrasf to string (Maurizio Lombardi) [RHEL-51888]
- nvme: use nvme_disk_is_ns_head helper (Maurizio Lombardi) [RHEL-51888]
- nvmet: add tracing of zns commands (Maurizio Lombardi) [RHEL-51888]
- nvmet: add tracing of authentication commands (Maurizio Lombardi) [RHEL-51888]
- nvme-apple: Convert to platform remove callback returning void (Maurizio Lombardi) [RHEL-51888]
- nvmet-tcp: do not continue for invalid icreq (Maurizio Lombardi) [RHEL-51888]
- nvme: change shutdown timeout setting message (Maurizio Lombardi) [RHEL-51888]
- static_call: Handle module init failure correctly in static_call_del_module() (CKI Backport Bot) [RHEL-64157] {CVE-2024-50002}
- RDMA/nldev: Fix NULL pointer dereferences issue in rdma_nl_notify_event (Kamal Heib) [RHEL-56245]
- RDMA/core: Provide rdma_user_mmap_disassociate() to disassociate mmap pages (Kamal Heib) [RHEL-56245]
- RDMA/nldev: Add missing break in rdma_nl_notify_err_msg() (Kamal Heib) [RHEL-56245]
- RDMA/nldev: Expose whether RDMA monitoring is supported (Kamal Heib) [RHEL-56245]
- RDMA/nldev: Add support for RDMA monitoring (Kamal Heib) [RHEL-56245]
- RDMA/device: Remove optimization in ib_device_get_netdev() (Kamal Heib) [RHEL-56245]
- IB/iser: Remove unused declaration in header file (Kamal Heib) [RHEL-56245]
- treewide: correct the typo 'retun' (Kamal Heib) [RHEL-56245]
- IB/core: Fix ib_cache_setup_one error flow cleanup (Kamal Heib) [RHEL-56245]
- RDMA/mad: Simplify an alloc_ordered_workqueue() invocation (Kamal Heib) [RHEL-56245]
- RDMA/ipoib: Remove unused declarations (Kamal Heib) [RHEL-56245]
- RDMA/core: Remove unused declaration rdma_resolve_ip_route() (Kamal Heib) [RHEL-56245]
- RDMA: Pass uverbs_attr_bundle as part of '.reg_user_mr_dmabuf' API (Kamal Heib) [RHEL-56245]
- RDMA/umem: Introduce an option to revoke DMABUF umem (Kamal Heib) [RHEL-56245]
- RDMA/umem: Add support for creating pinned DMABUF umem with a given dma device (Kamal Heib) [RHEL-56245]
- RDMA/nldev: Enhance netlink message parsing and validation (Kamal Heib) [RHEL-56245]
- RDMA/mad: Improve handling of timed out WRs of mad agent (Kamal Heib) [RHEL-56245]
- nvdimm: Fix devs leaks in scan_labels() (Jeff Moyer) [RHEL-52818]
- device-dax: correct pgoff align in dax_set_mapping() (Jeff Moyer) [RHEL-52818 RHEL-63870] {CVE-2024-50022}
- Documentation: probes: Add a new ret_ip callback parameter (Viktor Malik) [RHEL-64700]
- fprobe: Add entry/exit callbacks types (Viktor Malik) [RHEL-64700]
- fprobe: Pass return address to the handlers (Viktor Malik) [RHEL-64700]
- fprobe: Fix to ensure the number of active retprobes is not zero (Viktor Malik) [RHEL-64700]
- tracing: fprobe: Initialize ret valiable to fix smatch error (Viktor Malik) [RHEL-64700]
- docs: tracing: Update fprobe documentation (Viktor Malik) [RHEL-64700]
- lib/test_fprobe: Add a testcase for skipping exit_handler (Viktor Malik) [RHEL-64700]
- fprobe: Skip exit_handler if entry_handler returns !0 (Viktor Malik) [RHEL-64700]
- lib/test_fprobe: Add a test case for nr_maxactive (Viktor Malik) [RHEL-64700]
- fprobe: Add nr_maxactive to specify rethook_node pool size (Viktor Malik) [RHEL-64700]
- lib/test_fprobe: Add private entry_data testcases (Viktor Malik) [RHEL-64700]
- fprobe: Pass entry_data to handlers (Viktor Malik) [RHEL-64700]

* Fri Nov 01 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-525.el9]
- selftests/powerpc: Add a test for execute-only memory (Mamatha Inamdar) [RHEL-52742]
- perf daemon: Fix the build on more 32-bit architectures (Michael Petlan) [RHEL-29795]
- perf python: include "util/sample.h" (Michael Petlan) [RHEL-29795]
- perf lock contention: Fix spinlock and rwlock accounting (Michael Petlan) [RHEL-29795]
- perf test pmu: Set uninitialized PMU alias to null (Michael Petlan) [RHEL-29795]
- perf daemon: Fix the build on 32-bit architectures (Michael Petlan) [RHEL-29795]
- tools/include: Sync uapi/linux/perf.h with the kernel sources (Michael Petlan) [RHEL-29795]
- perf tools: Add tools/include/uapi/README (Michael Petlan) [RHEL-29795]
- perf arch events: Fix duplicate RISC-V SBI firmware event name (Michael Petlan) [RHEL-29795]
- perf docs: Document cross compilation (Michael Petlan) [RHEL-29795]
- perf: build: Link lib 'zstd' for static build (Michael Petlan) [RHEL-29795]
- perf: build: Link lib 'lzma' for static build (Michael Petlan) [RHEL-29795]
- perf: build: Only link libebl.a for old libdw (Michael Petlan) [RHEL-29795]
- perf: build: Set Python configuration for cross compilation (Michael Petlan) [RHEL-29795]
- perf: build: Setup PKG_CONFIG_LIBDIR for cross compilation (Michael Petlan) [RHEL-29795]
- perf tool: fix dereferencing NULL al->maps (Michael Petlan) [RHEL-29795]
- radix tree test suite: put definition of bitmap_clear() into lib/bitmap.c (Michael Petlan) [RHEL-29795]
- perf dso: Fix build when libunwind is enabled (Michael Petlan) [RHEL-29795]
- tools: Make pkg-config dependency checks usable by other tools (Michael Petlan) [RHEL-29795]
- perf build: Warn if libtracefs is not found (Michael Petlan) [RHEL-29795]
- tools/lib/list_sort: remove redundant code for cond_resched handling (Michael Petlan) [RHEL-29795]
- perf trace: Fix iteration of syscall ids in syscalltbl->entries (Michael Petlan) [RHEL-29795]
- perf dso: Fix address sanitizer build (Michael Petlan) [RHEL-29795]
- perf mem: Warn if memory events are not supported on all CPUs (Michael Petlan) [RHEL-29795]
- perf arm-spe: Support multiple Arm SPE PMUs (Michael Petlan) [RHEL-29795]
- perf build x86: Fix SC2034 error in syscalltbl.sh (Michael Petlan) [RHEL-29795]
- perf record: Fix memset out-of-range error (Michael Petlan) [RHEL-29795]
- perf sched map: Add --fuzzy-name option for fuzzy matching in task names (Michael Petlan) [RHEL-29795]
- perf sched map: Add support for multiple task names using CSV (Michael Petlan) [RHEL-29795]
- perf sched map: Add task-name option to filter the output map (Michael Petlan) [RHEL-29795]
- perf build: Conditionally add feature check flags for libtrace{event,fs} (Michael Petlan) [RHEL-29795]
- perf install: Don't propagate subdir to Documentation submake (Michael Petlan) [RHEL-29795]
- perf vendor events arm64:: Add i.MX95 DDR Performance Monitor metrics (Michael Petlan) [RHEL-29795]
- perf vendor events arm64:: Add i.MX93 DDR Performance Monitor metrics (Michael Petlan) [RHEL-29795]
- perf report: Calling available function for stats printing (Michael Petlan) [RHEL-29795]
- perf intel-pt: Fix exclude_guest setting (Michael Petlan) [RHEL-29795]
- perf intel-pt: Fix aux_watermark calculation for 64-bit size (Michael Petlan) [RHEL-29795]
- perf sched replay: Fix -r/--repeat command line option for infinity (Michael Petlan) [RHEL-29795]
- perf: pmus: Remove unneeded semicolon (Michael Petlan) [RHEL-29795]
- perf stat: Use field separator in the metric header (Michael Petlan) [RHEL-29795]
- perf stat: Fix a segfault with --per-cluster --metric-only (Michael Petlan) [RHEL-29795]
- perf pmu: Don't de-duplicate core PMUs (Michael Petlan) [RHEL-29795]
- perf pmu: Restore full PMU name wildcard support (Michael Petlan) [RHEL-29795]
- perf report: Display pregress bar on redirected pipe data (Michael Petlan) [RHEL-29795]
- perf python: Clean up build dependencies (Michael Petlan) [RHEL-29795]
- perf python: Switch module to linking libraries from building source (Michael Petlan) [RHEL-29795]
- perf util: Make util its own library (Michael Petlan) [RHEL-29795]
- perf bench: Make bench its own library (Michael Petlan) [RHEL-29795]
- perf test: Make tests its own library (Michael Petlan) [RHEL-29795]
- perf pmu-events: Make pmu-events a library (Michael Petlan) [RHEL-29795]
- perf ui: Make ui its own library (Michael Petlan) [RHEL-29795]
- perf build: Add '*.a' to clean targets (Michael Petlan) [RHEL-29795]
- perf mem: Fix a segfault with NULL event->name (Michael Petlan) [RHEL-29795]
- perf tools: Fix a compiler warning of NULL pointer (Michael Petlan) [RHEL-29795]
- perf symbol: Simplify kernel module checking (Michael Petlan) [RHEL-29795]
- perf report: Fix condition in sort__sym_cmp() (Michael Petlan) [RHEL-29795]
- perf pmus: Fixes always false when compare duplicates aliases (Michael Petlan) [RHEL-29795]
- perf unwind-libunwind: Add malloc() failure handling (Michael Petlan) [RHEL-29795]
- util: constant -1 with expression of type char (Michael Petlan) [RHEL-29795]
- perf: Timehist account sch delay for scheduled out running (Michael Petlan) [RHEL-29795]
- perf tests: Add APX and other new instructions to x86 instruction decoder test (Michael Petlan) [RHEL-29795]
- perf intel pt: Add new JMPABS instruction to the Intel PT instruction decoder (Michael Petlan) [RHEL-29795]
- perf test: Check output of the probe ... --funcs command (Michael Petlan) [RHEL-29795]
- tools/perf: Fix parallel-perf python script to replace new python syntax ":=" usage (Michael Petlan) [RHEL-29795]
- tools/perf: Use is_perf_pid_map_name helper function to check dso's of pattern /tmp/perf-%%d.map (Michael Petlan) [RHEL-29795]
- tools/perf: Fix the string match for "/tmp/perf-$PID.map" files in dso__load (Michael Petlan) [RHEL-29795]
- perf test: Make test_arm_callgraph_fp.sh more robust (Michael Petlan) [RHEL-29795]
- perf build: Ensure libtraceevent and libtracefs versions have 3 components (Michael Petlan) [RHEL-29795]
- perf build: Use pkg-config for feature check for libtrace{event,fs} (Michael Petlan) [RHEL-29795]
- perf arm: Workaround ARM PMUs cpu maps having offline cpus (Michael Petlan) [RHEL-29795]
- perf stat: Fix the hard-coded metrics calculation on the hybrid (Michael Petlan) [RHEL-29795]
- perf doc: Add AMD IBS usage document (Michael Petlan) [RHEL-29795]
- perf hist: Honor symbol_conf.skip_empty (Michael Petlan) [RHEL-29795]
- perf hist: Add symbol_conf.skip_empty (Michael Petlan) [RHEL-29795]
- perf hist: Simplify __hpp_fmt() using hpp_fmt_data (Michael Petlan) [RHEL-29795]
- perf hist: Factor out __hpp__fmt_print() (Michael Petlan) [RHEL-29795]
- perf: sched map skips redundant lines with cpu filters (Michael Petlan) [RHEL-29795]
- perf test pmu: Warn don't fail for legacy mixed case event names (Michael Petlan) [RHEL-29795]
- tools/perf: Fix timing issue with parallel threads in perf bench wake-up-parallel (Michael Petlan) [RHEL-29795]
- tools/perf: Fix perf bench epoll to enable the run when some CPU's are offline (Michael Petlan) [RHEL-29795]
- tools/perf: Fix perf bench futex to enable the run when some CPU's are offline (Michael Petlan) [RHEL-29795]
- perf record: Ensure space for lost samples (Michael Petlan) [RHEL-29795]
- perf evsel: Refactor tool events (Michael Petlan) [RHEL-29795]
- perf test: Speed up test case 70 annotate basic tests (Michael Petlan) [RHEL-29795]
- perf stat: Choose the most disaggregate command line option (Michael Petlan) [RHEL-29795]
- perf stat: Make options local (Michael Petlan) [RHEL-29795]
- perf maps: Add/use a sorted insert for fixup overlap and insert (Michael Petlan) [RHEL-29795]
- perf maps: Reduce sorting for overlapping mappings (Michael Petlan) [RHEL-29795]
- perf maps: Fix use after free in __maps__fixup_overlap_and_insert (Michael Petlan) [RHEL-29795]
- perf script: netdev-times: add location parameter to consume_skb (Michael Petlan) [RHEL-29795]
- perf: parse-events: Fix compilation error while defining DEBUG_PARSER (Michael Petlan) [RHEL-29795]
- perf hisi-ptt: remove unused struct 'hisi_ptt_queue' (Michael Petlan) [RHEL-29795]
- perf genelf: remove unused struct 'options' (Michael Petlan) [RHEL-29795]
- perf top: Allow filters on events (Michael Petlan) [RHEL-29795]
- perf bpf filter: Add uid and gid terms (Michael Petlan) [RHEL-29795]
- perf bpf filter: Give terms their own enum (Michael Petlan) [RHEL-29795]
- tools api io: Move filling the io buffer to its own function (Michael Petlan) [RHEL-29795]
- perf trace beauty: Always show mmap prot even though PROT_NONE (Michael Petlan) [RHEL-29795]
- perf trace beauty: Always show param if show_zero is set (Michael Petlan) [RHEL-29795]
- perf docs: Fix typos (Michael Petlan) [RHEL-29795]
- perf list: Fix the --no-desc option (Michael Petlan) [RHEL-29795]
- perf arm-spe: Unaligned pointer work around (Michael Petlan) [RHEL-29795]
- perf tests: Add some pmu core functionality tests (Michael Petlan) [RHEL-29795]
- perf pmus: Sort/merge/aggregate PMUs like mrvl_ddr_pmu (Michael Petlan) [RHEL-29795]
- tools: build: use correct lib name for libtracefs feature detection (Michael Petlan) [RHEL-29795]
- perf dsos: When adding a dso into sorted dsos maintain the sort order (Michael Petlan) [RHEL-29795]
- perf comm str: Avoid sort during insert (Michael Petlan) [RHEL-29795]
- perf bpf: Fix handling of minimal vmlinux.h file when interrupting the build (Michael Petlan) [RHEL-29795]
- tools headers UAPI: Sync kvm headers with the kernel sources (Michael Petlan) [RHEL-29795]
- KVM: PPC: Fix documentation for ppc mmu caps (Michael Petlan) [RHEL-29795]
- Revert "perf parse-events: Prefer sysfs/JSON hardware events over legacy" (Michael Petlan) [RHEL-29795]
- tools lib subcmd: Show parent options in help (Michael Petlan) [RHEL-29795]
- perf pmu: Count sys and cpuid JSON events separately (Michael Petlan) [RHEL-29795]
- perf stat: Don't display metric header for non-leader uncore events (Michael Petlan) [RHEL-29795]
- perf annotate-data: Ensure the number of type histograms (Michael Petlan) [RHEL-29795]
- perf daemon: Fix file leak in daemon_session__control (Michael Petlan) [RHEL-29795]
- libsubcmd: Fix parse-options memory leak (Michael Petlan) [RHEL-29795]
- perf lock: Avoid memory leaks from strdup() (Michael Petlan) [RHEL-29795]
- perf sched: Rename 'switches' column header to 'count' and add usage description, options for latency (Michael Petlan) [RHEL-29795]
- perf tools: Ignore deleted cgroups (Michael Petlan) [RHEL-29795]
- perf parse: Allow tracepoint names to start with digits (Michael Petlan) [RHEL-29795]
- perf parse-events: Add new 'fake_tp' parameter for tests (Michael Petlan) [RHEL-29795]
- perf parse-events: pass parse_state to add_tracepoint (Michael Petlan) [RHEL-29795]
- perf tracepoint: Don't scan all tracepoints to test if one exists (Michael Petlan) [RHEL-29795]
- perf dwarf-aux: Fix build with HAVE_DWARF_CFI_SUPPORT (Michael Petlan) [RHEL-29795]
- perf thread: Fixes to thread__new() related to initializing comm (Michael Petlan) [RHEL-29795]
- perf report: Avoid SEGV in report__setup_sample_type() (Michael Petlan) [RHEL-29795]
- perf comm: Fix comm_str__put() for reference count checking (Michael Petlan) [RHEL-29795]
- perf ui browser: Avoid SEGV on title (Michael Petlan) [RHEL-29795]
- perf dwarf-aux: Print array type name with "[]" (Michael Petlan) [RHEL-29795]
- perf hist: Avoid 'struct hist_entry_iter' mem_info memory leak (Michael Petlan) [RHEL-29795]
- perf mem-info: Add reference count checking (Michael Petlan) [RHEL-29795]
- perf mem-info: Move mem-info out of mem-events and symbol (Michael Petlan) [RHEL-29795]
- perf comm: Add reference count checking to 'struct comm_str' (Michael Petlan) [RHEL-29795]
- perf cpumap: Remove refcnt from 'struct cpu_aggr_map' (Michael Petlan) [RHEL-29795]
- perf block-info: Remove unused refcount (Michael Petlan) [RHEL-29795]
- perf ui browser: Don't save pointer to stack memory (Michael Petlan) [RHEL-29795]
- perf bench internals inject-build-id: Fix trap divide when collecting just one DSO (Michael Petlan) [RHEL-29795]
- perf probe: Use zfree() to avoid possibly accessing dangling pointers (Michael Petlan) [RHEL-29795]
- perf auxtrace: Allow number of queues to be specified (Michael Petlan) [RHEL-29795]
- perf cs-etm: Print error for new PERF_RECORD_AUX_OUTPUT_HW_ID versions (Michael Petlan) [RHEL-29795]
- perf annotate: Fix a comment about multi_regs in extract_reg_offset function (Michael Petlan) [RHEL-29795]
- perf kwork: Use zfree() to avoid possibly accessing dangling pointers (Michael Petlan) [RHEL-29795]
- perf callchain: Use zfree() to avoid possibly accessing dangling pointers (Michael Petlan) [RHEL-29795]
- perf annotate: Use zfree() to avoid possibly accessing dangling pointers (Michael Petlan) [RHEL-29795]
- perf dso: Use container_of() to avoid a pointer in 'struct dso_data' (Michael Petlan) [RHEL-29795]
- perf symbol-elf: dso__load_sym_internal() reference count fixes (Michael Petlan) [RHEL-29795]
- perf symbol-elf: Ensure dso__put() in machine__process_ksymbol_register() (Michael Petlan) [RHEL-29795]
- perf map: Add missing dso__put() in map__new() (Michael Petlan) [RHEL-29795]
- perf dso: Add reference count checking and accessor functions (Michael Petlan) [RHEL-29795]
- perf dsos: Switch hand crafted code to bsearch() (Michael Petlan) [RHEL-29795]
- perf dsos: Remove __dsos__findnew_link_by_longname_id() (Michael Petlan) [RHEL-29795]
- perf dsos: Remove __dsos__addnew() (Michael Petlan) [RHEL-29795]
- perf dsos: Switch backing storage to array from rbtree/list (Michael Petlan) [RHEL-29795]
- perf trace: Disable syscall augmentation with record (Michael Petlan) [RHEL-29795]
- perf pmu: Assume sysfs events are always the same case (Michael Petlan) [RHEL-29795]
- perf test pmu: Test all sysfs PMU event names are the same case (Michael Petlan) [RHEL-29795]
- perf test pmu: Add an eagerly loaded event test (Michael Petlan) [RHEL-29795]
- perf test pmu: Refactor format test and exposed test APIs (Michael Petlan) [RHEL-29795]
- perf test pmu-events: Make it clearer that pmu-events tests JSON events (Michael Petlan) [RHEL-29795]
- perf maps: Remove check_invariants() from maps__lock() (Michael Petlan) [RHEL-29795]
- perf cs-etm: Improve version detection and error reporting (Michael Petlan) [RHEL-29795]
- perf cs-etm: Remove repeated fetches of the ETM PMU (Michael Petlan) [RHEL-29795]
- perf cs-etm: Use struct perf_cpu as much as possible (Michael Petlan) [RHEL-29795]
- perf annotate-data: Check kind of stack variables (Michael Petlan) [RHEL-29795]
- perf annotate-data: Handle multi regs in find_data_type_block() (Michael Petlan) [RHEL-29795]
- perf annotate-data: Check memory access with two registers (Michael Petlan) [RHEL-29795]
- perf annotate-data: Handle direct global variable access (Michael Petlan) [RHEL-29795]
- perf annotate-data: Collect global variables in advance (Michael Petlan) [RHEL-29795]
- perf dwarf-aux: Add die_collect_global_vars() (Michael Petlan) [RHEL-29795]
- perf test: Reintroduce -p/--parallel and make -S/--sequential the default (Michael Petlan) [RHEL-29795]
- perf annotate: Fix data type profiling on stdio (Michael Petlan) [RHEL-29795]
- perf build: Pretend scandirat is missing with msan (Michael Petlan) [RHEL-29795]
- perf intel-pt: Fix unassigned instruction op (discovered by MemorySanitizer) (Michael Petlan) [RHEL-29795]
- perf record: Fix comment misspellings (Michael Petlan) [RHEL-29795]
- perf annotate: Update DSO binary type when trying build-id (Michael Petlan) [RHEL-29795]
- perf annotate: Fallback disassemble to objdump when capstone fails (Michael Petlan) [RHEL-29795]
- perf annotate-data: Check if 'struct annotation_source' was allocated on 'perf report' TUI (Michael Petlan) [RHEL-29795]
- perf test: Add a new test for 'perf annotate' (Michael Petlan) [RHEL-29795]
- perf parse-events: Tidy the setting of the default event name (Michael Petlan) [RHEL-29795]
- perf parse-events: Minor grouping tidy up (Michael Petlan) [RHEL-29795]
- perf parse-event: Constify event_symbol arrays (Michael Petlan) [RHEL-29795]
- perf parse-events: Improvements to modifier parsing (Michael Petlan) [RHEL-29795]
- perf parse-events: Inline parse_events_evlist_error (Michael Petlan) [RHEL-29795]
- perf parse-events: Improve error message for bad numbers (Michael Petlan) [RHEL-29795]
- perf parse-events: Inline parse_events_update_lists (Michael Petlan) [RHEL-29795]
- perf parse-events: Prefer sysfs/JSON hardware events over legacy (Michael Petlan) [RHEL-29795]
- perf parse-events: Constify parse_events_add_numeric (Michael Petlan) [RHEL-29795]
- perf parse-events: Handle PE_TERM_HW in name_or_raw (Michael Petlan) [RHEL-29795]
- perf parse-events: Legacy cache names on all PMUs and lower priority (Michael Petlan) [RHEL-29795]
- perf tests parse-events: Use "branches" rather than "cache-references" (Michael Petlan) [RHEL-29795]
- perf pmu: Refactor perf_pmu__match() (Michael Petlan) [RHEL-29795]
- perf parse-events: Avoid copying an empty list (Michael Petlan) [RHEL-29795]
- perf parse-events: Directly pass PMU to parse_events_add_pmu() (Michael Petlan) [RHEL-29795]
- perf parse-events: Factor out '<event_or_pmu>/.../' parsing (Michael Petlan) [RHEL-29795]
- tools headers: Synchronize linux/bits.h with the kernel sources (Michael Petlan) [RHEL-29795]
- perf scripts python: Add a script to run instances of 'perf script' in parallel (Michael Petlan) [RHEL-29795]
- perf tests shell kprobes: Add missing description as used by 'perf test' output (Michael Petlan) [RHEL-29795]
- Revert "tools headers: Remove almost unused copy of uapi/stat.h, add few conditional defines" (Michael Petlan) [RHEL-29795]
- perf probe-event: Better error message for a too-long probe name (Michael Petlan) [RHEL-29795]
- perf probe-event: Un-hardcode sizeof(buf) (Michael Petlan) [RHEL-29795]
- perf stat: Add new field in stat_config to enable hardware aware grouping (Michael Petlan) [RHEL-29795]
- perf test shell arm_coresight: Increase buffer size for Coresight basic tests (Michael Petlan) [RHEL-29795]
- perf genelf: Fix compiling with libelf on rv32 (Michael Petlan) [RHEL-29795]
- perf vendor events arm64: AmpereOne/AmpereOneX: Mark L1D_CACHE_INVAL impacted by errata (Michael Petlan) [RHEL-29795]
- perf docs: Document bpf event modifier (Michael Petlan) [RHEL-29795]
- perf tools: Enable configs required for test_uprobe_from_different_cu.sh (Michael Petlan) [RHEL-29795]
- perf report: Add weight[123] output fields (Michael Petlan) [RHEL-29795]
- perf hist: Add weight fields to hist entry stats (Michael Petlan) [RHEL-29795]
- perf hist: Move histogram related code to hist.h (Michael Petlan) [RHEL-29795]
- perf annotate-data: Handle RSP if it's not the FB register (Michael Petlan) [RHEL-29795]
- perf annotate-data: Improve debug message with location info (Michael Petlan) [RHEL-29795]
- perf bench uprobe: Add uretprobe variant of uprobe benchmarks (Michael Petlan) [RHEL-29795]
- perf bench uprobe: Remove lib64 from libc.so.6 binary path (Michael Petlan) [RHEL-29795]
- perf trace beauty: Add shellcheck to scripts (Michael Petlan) [RHEL-29795]
- perf util: Add shellcheck to generate-cmdlist.sh (Michael Petlan) [RHEL-29795]
- perf arch x86: Add shellcheck to build (Michael Petlan) [RHEL-29795]
- perf build: Add shellcheck to tools/perf scripts (Michael Petlan) [RHEL-29795]
- perf dsos: Switch more loops to dsos__for_each_dso() (Michael Petlan) [RHEL-29795]
- perf dso: Move dso functions out of dsos.c (Michael Petlan) [RHEL-29795]
- perf dsos: Introduce dsos__for_each_dso() (Michael Petlan) [RHEL-29795]
- perf dsos: Tidy reference counting and locking (Michael Petlan) [RHEL-29795]
- perf dsos: Attempt to better abstract DSOs internals (Michael Petlan) [RHEL-29795]
- perf record: Fix debug message placement for test consumption (Michael Petlan) [RHEL-29795]
- perf annotate: Skip DSOs not found (Michael Petlan) [RHEL-29795]
- perf report: Do not collect sample histogram unnecessarily (Michael Petlan) [RHEL-29795]
- perf report: Add a menu item to annotate data type in TUI (Michael Petlan) [RHEL-29795]
- perf annotate-data: Support event group display in TUI (Michael Petlan) [RHEL-29795]
- perf annotate-data: Add hist_entry__annotate_data_tui() (Michael Petlan) [RHEL-29795]
- perf annotate-data: Add hist_entry__annotate_data_tty() (Michael Petlan) [RHEL-29795]
- perf annotate: Show progress of sample processing (Michael Petlan) [RHEL-29795]
- perf annotate-data: Skip sample histogram for stack canary (Michael Petlan) [RHEL-29795]
- perf metrics: Remove the "No_group" metric group (Michael Petlan) [RHEL-29795]
- perf annotate: Get rid of symbol__ensure_annotate() (Michael Petlan) [RHEL-29795]
- perf annotate-data: Do not delete non-asm lines (Michael Petlan) [RHEL-29795]
- perf annotate-data: Fix global variable lookup (Michael Petlan) [RHEL-29795]
- tools subcmd: Add check_if_command_finished() (Michael Petlan) [RHEL-29795]
- perf annotate: Move 'start' field struct to 'struct annotated_source' (Michael Petlan) [RHEL-29795]
- perf annotate: Move nr_events struct to 'struct annotated_source' (Michael Petlan) [RHEL-29795]
- perf annotate: Move 'max_jump_sources' struct to 'struct annotated_source' (Michael Petlan) [RHEL-29795]
- perf annotate: Move 'widths' struct to 'struct annotated_source' (Michael Petlan) [RHEL-29795]
- perf annotate: Get rid of offsets array (Michael Petlan) [RHEL-29795]
- perf annotate: Check annotation lines more efficiently (Michael Petlan) [RHEL-29795]
- perf annotate: Introduce annotated_source__get_line() (Michael Petlan) [RHEL-29795]
- perf annotate: Staticize some local functions (Michael Petlan) [RHEL-29795]
- perf annotate: Fix annotation_calc_lines() to pass correct address to get_srcline() (Michael Petlan) [RHEL-29795]
- perf script: Consolidate capstone print functions (Michael Petlan) [RHEL-29795]
- perf script: Add capstone support for '-F +brstackdisasm' (Michael Petlan) [RHEL-29795]
- perf script: Support 32bit code under 64bit OS with capstone (Michael Petlan) [RHEL-29795]
- perf stat: Do not fail on metrics on s390 z/VM systems (Michael Petlan) [RHEL-29795]
- perf report: Fix PAI counter names for s390 virtual machines (Michael Petlan) [RHEL-29795]
- perf annotate: Initialize 'arch' variable not to trip some -Werror=maybe-uninitialized (Michael Petlan) [RHEL-29795]
- perf build: Add LIBTRACEEVENT_DIR build option (Michael Petlan) [RHEL-29795]
- treewide: remove meaningless assignments in Makefiles (Michael Petlan) [RHEL-29795]
- perf beauty: Fix AT_EACCESS undeclared build error for system with kernel versions lower than v5.8 (Michael Petlan) [RHEL-29795]
- perf annotate: Add symbol name when using capstone (Michael Petlan) [RHEL-29795]
- perf annotate: Use libcapstone to disassemble (Michael Petlan) [RHEL-29795]
- perf annotate: Split out util/disasm.c (Michael Petlan) [RHEL-29795]
- tools perf: Fix compilation error with new binutils (Michael Petlan) [RHEL-29795]
- perf annotate: Add and use ins__is_nop() (Michael Petlan) [RHEL-29795]
- perf annotate: Use ins__is_xxx() if possible (Michael Petlan) [RHEL-29795]
- perf evsel: Use evsel__name_is() helper (Michael Petlan) [RHEL-29795]
- perf sched timehist: Fix -g/--call-graph option failure (Michael Petlan) [RHEL-29795]
- perf annotate: Honor output options with --data-type (Michael Petlan) [RHEL-29795]
- perf annotate: Get rid of duplicate --group option item (Michael Petlan) [RHEL-29795]
- perf beauty: Move uapi/linux/vhost.h copy out of the directory used to build perf (Michael Petlan) [RHEL-29795]
- perf dso: Reorder members to save space in 'struct dso' (Michael Petlan) [RHEL-29795]
- perf lock contention: Trim backtrace by skipping traceiter functions (Michael Petlan) [RHEL-29795]
- perf probe: Add missing libgen.h header needed for using basename() (Michael Petlan) [RHEL-29795]
- perf trace: Fix 'newfstatat'/'fstatat' argument pretty printing (Michael Petlan) [RHEL-29795]
- perf trace: Beautify the 'flags' arg of unlinkat (Michael Petlan) [RHEL-29795]
- perf beauty: Introduce faccessat2 flags scnprintf routine (Michael Petlan) [RHEL-29795]
- perf beauty: Introduce scrape script for the 'statx' syscall 'mask' argument (Michael Petlan) [RHEL-29795]
- perf beauty: Introduce scrape script for various fs syscalls 'flags' arguments (Michael Petlan) [RHEL-29795]
- perf tests: Run tests in parallel by default (Michael Petlan) [RHEL-29795]
- perf help: Lower levenshtein penality for deleting character (Michael Petlan) [RHEL-29795]
- perf tools: Suggest inbuilt commands for unknown command (Michael Petlan) [RHEL-29795]
- perf test: Read child test 10 times a second rather than 1 (Michael Petlan) [RHEL-29795]
- perf tools: Add/use PMU reverse lookup from config to name (Michael Petlan) [RHEL-29795]
- perf tools: Use pmus to describe type from attribute (Michael Petlan) [RHEL-29795]
- perf list: Give more details about raw event encodings (Michael Petlan) [RHEL-29795]
- perf list: Allow wordwrap to wrap on commas (Michael Petlan) [RHEL-29795]
- perf pmu: Drop "default_core" from alias names (Michael Petlan) [RHEL-29795]
- perf list: Add tracepoint encoding to detailed output (Michael Petlan) [RHEL-29795]
- perf beauty: Introduce scrape script for 'clone' syscall 'flags' argument (Michael Petlan) [RHEL-29795]
- perf annotate-data: Do not retry for invalid types (Michael Petlan) [RHEL-29795]
- perf annotate-data: Add a cache for global variable types (Michael Petlan) [RHEL-29795]
- perf annotate-data: Add stack canary type (Michael Petlan) [RHEL-29795]
- perf annotate-data: Handle ADD instructions (Michael Petlan) [RHEL-29795]
- perf annotate-data: Support general per-cpu access (Michael Petlan) [RHEL-29795]
- perf annotate-data: Track instructions with a this-cpu variable (Michael Petlan) [RHEL-29795]
- perf annotate-data: Handle this-cpu variables in kernel (Michael Petlan) [RHEL-29795]
- perf annotate: Parse x86 segment register location (Michael Petlan) [RHEL-29795]
- perf annotate-data: Check register state for type (Michael Petlan) [RHEL-29795]
- perf annotate-data: Implement instruction tracking (Michael Petlan) [RHEL-29795]
- perf annotate-data: Handle call instructions (Michael Petlan) [RHEL-29795]
- perf annotate-data: Handle global variable access (Michael Petlan) [RHEL-29795]
- perf annotate-data: Add get_global_var_type() (Michael Petlan) [RHEL-29795]
- perf annotate-data: Add update_insn_state() (Michael Petlan) [RHEL-29795]
- perf annotate-data: Maintain variable type info (Michael Petlan) [RHEL-29795]
- perf annotate-data: Add debug messages (Michael Petlan) [RHEL-29795]
- perf annotate: Add annotate_get_basic_blocks() (Michael Petlan) [RHEL-29795]
- perf annotate-data: Introduce 'struct data_loc_info' (Michael Petlan) [RHEL-29795]
- perf map: Add map__objdump_2rip() (Michael Petlan) [RHEL-29795]
- perf dwarf-aux: Add die_find_func_rettype() (Michael Petlan) [RHEL-29795]
- perf dwarf-aux: Handle type transfer for memory access (Michael Petlan) [RHEL-29795]
- perf dwarf-aux: Add die_collect_vars() (Michael Petlan) [RHEL-29795]
- perf dwarf-aux: Remove unused pc argument (Michael Petlan) [RHEL-29795]
- perf cpumap: Use perf_cpu_map__for_each_cpu when possible (Michael Petlan) [RHEL-29795]
- perf stat: Remove duplicate cpus_map_matched function (Michael Petlan) [RHEL-29795]
- perf arm64 header: Remove unnecessary CPU map get and put (Michael Petlan) [RHEL-29795]
- perf cpumap: Clean up use of perf_cpu_map__has_any_cpu_or_is_empty (Michael Petlan) [RHEL-29795]
- perf intel-pt/intel-bts: Switch perf_cpu_map__has_any_cpu_or_is_empty use (Michael Petlan) [RHEL-29795]
- perf arm-spe/cs-etm: Directly iterate CPU maps (Michael Petlan) [RHEL-29795]
- libperf cpumap: Ensure empty cpumap is NULL from alloc (Michael Petlan) [RHEL-29795]
- libperf cpumap: Add any, empty and min helpers (Michael Petlan) [RHEL-29795]
- perf auxtrace: Fix multiple use of --itrace option (Michael Petlan) [RHEL-29795]
- perf script: Show also errors for --insn-trace option (Michael Petlan) [RHEL-29795]
- perf docs arm_spe: Clarify more SPE requirements related to KPTI (Michael Petlan) [RHEL-29795]
- tools headers: Remove almost unused copy of uapi/stat.h, add few conditional defines (Michael Petlan) [RHEL-29795]
- tools headers: Remove now unused copies of uapi/{fcntl,openat2}.h and asm/fcntl.h (Michael Petlan) [RHEL-29795]
- perf beauty: Use the system linux/fcntl.h instead of a copy from the kernel (Michael Petlan) [RHEL-29795]
- perf beauty: Move prctl.h files (uapi/linux and x86's) copy out of the directory used to build perf (Michael Petlan) [RHEL-29795]
- perf beauty: Stop using the copy of uapi/linux/prctl.h (Michael Petlan) [RHEL-29795]
- perf beauty: Move arch/x86/include/asm/irq_vectors.h copy out of the directory used to build perf (Michael Petlan) [RHEL-29795]
- perf beauty: Move uapi/sound/asound.h copy out of the directory used to build perf (Michael Petlan) [RHEL-29795]
- perf beauty: Move uapi/linux/usbdevice_fs.h copy out of the directory used to build perf (Michael Petlan) [RHEL-29795]
- perf beauty: Move uapi/linux/mount.h copy out of the directory used to build perf (Michael Petlan) [RHEL-29795]
- perf beauty: Don't include uapi/linux/mount.h, use sys/mount.h instead (Michael Petlan) [RHEL-29795]
- perf beauty: Move uapi/linux/fs.h copy out of the directory used to build perf (Michael Petlan) [RHEL-29795]
- perf beauty: Fix dependency of tables using uapi/linux/mount.h (Michael Petlan) [RHEL-29795]
- perf c2c: Fix a punctuation (Michael Petlan) [RHEL-29795]
- perf trace: Collect sys_nanosleep first argument (Michael Petlan) [RHEL-29795]
- x86/insn: Add support for APX EVEX instructions to the opcode map (Michael Petlan) [RHEL-29795]
- x86/insn: Add support for APX EVEX to the instruction decoder logic (Michael Petlan) [RHEL-29795]
- x86/insn: x86/insn: Add support for REX2 prefix to the instruction decoder opcode map (Michael Petlan) [RHEL-29795]
- x86/insn: Add support for REX2 prefix to the instruction decoder logic (Michael Petlan) [RHEL-29795]
- x86/insn: Add misc new Intel instructions (Michael Petlan) [RHEL-29795]
- x86/insn: Add Key Locker instructions to the opcode map (Michael Petlan) [RHEL-29795]
- x86/opcode: Add ERET[US] instructions to the x86 opcode map (Michael Petlan) [RHEL-29795]
- x86/cpufeatures,opcode,msr: Add the WRMSRNS instruction support (Michael Petlan) [RHEL-29795]
- x86/insn: Add VEX versions of VPDPBUSD, VPDPBUSDS, VPDPWSSD and VPDPWSSDS (Michael Petlan) [RHEL-29795]
- x86/insn: Fix PUSH instruction in x86 instruction decoder opcode map (Michael Petlan) [RHEL-29795]
- x86/insn: Directly assign x86_64 state in insn_init() (Michael Petlan) [RHEL-29795]
- x86/insn: Remove superfluous checks from instruction decoding routines (Michael Petlan) [RHEL-29795]
- perf/aux: Fix AUX buffer serialization (Michael Petlan) [RHEL-29795]
- uprobes: Use kzalloc to allocate xol area (Michael Petlan) [RHEL-29795]
- perf/x86/intel: Limit the period on Haswell (Michael Petlan) [RHEL-29795]
- perf/bpf: Don't call bpf_overflow_handler() for tracing events (Michael Petlan) [RHEL-29795]
- perf/x86: Fix smp_processor_id()-in-preemptible warnings (Michael Petlan) [RHEL-29795]
- perf/x86/intel/cstate: Add pkg C2 residency counter for Sierra Forest (Michael Petlan) [RHEL-29795]
- perf/core: fix several typos (Michael Petlan) [RHEL-29795]
- perf/x86/intel: Add a distinct name for Granite Rapids (Michael Petlan) [RHEL-29795]
- perf/x86/intel/ds: Fix non 0 retire latency on Raptorlake (Michael Petlan) [RHEL-29795]
- perf/x86/intel: Hide Topdown metrics events if the feature is not enumerated (Michael Petlan) [RHEL-29795]
- perf/x86/intel/uncore: Fix the bits of the CHA extended umask for SPR (Michael Petlan) [RHEL-29795]
- perf: Split __perf_pending_irq() out of perf_pending_irq() (Michael Petlan) [RHEL-29795]
- perf: Don't disable preemption in perf_pending_task(). (Michael Petlan) [RHEL-29795]
- perf: Move swevent_htable::recursion into task_struct. (Michael Petlan) [RHEL-29795]
- perf: Shrink the size of the recursion counter. (Michael Petlan) [RHEL-29795]
- perf: Enqueue SIGTRAP always via task_work. (Michael Petlan) [RHEL-29795]
- task_work: Add TWA_NMI_CURRENT as an additional notify mode. (Michael Petlan) [RHEL-29795]
- perf: Move irq_work_queue() where the event is prepared. (Michael Petlan) [RHEL-29795]
- perf/x86/amd/uncore: Avoid PMU registration if counters are unavailable (Michael Petlan) [RHEL-29795]
- perf/x86/intel/cstate: Fix Alderlake/Raptorlake/Meteorlake (Michael Petlan) [RHEL-29795]
- perf: Make rb_alloc_aux() return an error immediately if nr_pages <= 0 (Michael Petlan) [RHEL-29795]
- perf: Fix default aux_watermark calculation (Michael Petlan) [RHEL-29795]
- perf: Prevent passing zero nr_pages to rb_alloc_aux() (Michael Petlan) [RHEL-29795]
- perf/x86/intel/pt: Fix pt_topa_entry_for_page() address calculation (Michael Petlan) [RHEL-29795]
- perf/x86/intel/pt: Fix a topa_entry base address calculation (Michael Petlan) [RHEL-29795]
- perf/x86/intel/pt: Fix topa_entry base length (Michael Petlan) [RHEL-29795]
- perf/x86/intel/uncore: Support HBM and CXL PMON counters (Michael Petlan) [RHEL-29795]
- perf/x86/uncore: Cleanup unused unit structure (Michael Petlan) [RHEL-29795]
- perf/x86/uncore: Apply the unit control RB tree to PCI uncore units (Michael Petlan) [RHEL-29795]
- perf/x86/uncore: Apply the unit control RB tree to MSR uncore units (Michael Petlan) [RHEL-29795]
- perf/x86/uncore: Apply the unit control RB tree to MMIO uncore units (Michael Petlan) [RHEL-29795]
- perf/x86/uncore: Retrieve the unit ID from the unit control RB tree (Michael Petlan) [RHEL-29795]
- perf/x86/uncore: Support per PMU cpumask (Michael Petlan) [RHEL-29795]
- perf/x86/uncore: Save the unit control address of all units (Michael Petlan) [RHEL-29795]
- perf/x86: Serialize set_attr_rdpmc() (Michael Petlan) [RHEL-29795]
- perf/x86/rapl: Switch to new Intel CPU model defines (Michael Petlan) [RHEL-29795]
- x86/cpu: Switch to new Intel CPU model defines (Michael Petlan) [RHEL-29795]
- drivers/perf: pmuv3: don't expose SW_INCR event in sysfs (Michael Petlan) [RHEL-29795]
- drivers: perf: arm_pmuv3: Add new macro PMUV3_INIT_MAP_EVENT() (Michael Petlan) [RHEL-29795]
- drivers: perf: arm_pmuv3: Drop some unused arguments from armv8_pmu_init() (Michael Petlan) [RHEL-29795]
- drivers: perf: arm_pmuv3: Read PMMIR_EL1 unconditionally (Michael Petlan) [RHEL-29795]
- arm64: pmuv3: dynamically map PERF_COUNT_HW_BRANCH_INSTRUCTIONS (Michael Petlan) [RHEL-29795]
- perf/core: Fix missing wakeup when waiting for context reference (Michael Petlan) [RHEL-29795]
- perf/x86/intel: Add missing MODULE_DESCRIPTION() lines (Michael Petlan) [RHEL-29795]
- perf/x86/rapl: Add missing MODULE_DESCRIPTION() line (Michael Petlan) [RHEL-29795]
- perf/x86/cstate: Remove unused 'struct perf_cstate_msr' (Michael Petlan) [RHEL-29795]
- perf/x86/rapl: Rename 'maxdie' to nr_rapl_pmu and 'dieid' to rapl_pmu_idx (Michael Petlan) [RHEL-29795]
- uprobes: reduce contention on uprobes_tree access (Michael Petlan) [RHEL-29795]
- arm64: Add USER_STACKTRACE support (Michael Petlan) [RHEL-29795]
- perf/bpf: Mark perf_event_set_bpf_handler() and perf_event_free_bpf_handler() as inline too (Michael Petlan) [RHEL-29795]
- selftests/perf_events: Test FASYNC with watermark wakeups (Michael Petlan) [RHEL-29795]
- perf/ring_buffer: Trigger IO signals for watermark_wakeup (Michael Petlan) [RHEL-29795]
- perf: Move perf_event_fasync() to perf_event.h (Michael Petlan) [RHEL-29795]
- perf/bpf: Change the !CONFIG_BPF_SYSCALL stubs to static inlines (Michael Petlan) [RHEL-29795]
- perf/bpf: Allow a BPF program to suppress all sample side effects (Michael Petlan) [RHEL-29795]
- perf/bpf: Remove unneeded uses_default_overflow_handler() (Michael Petlan) [RHEL-29795]
- perf/bpf: Call BPF handler directly, not through overflow machinery (Michael Petlan) [RHEL-29795]
- perf/bpf: Remove #ifdef CONFIG_BPF_SYSCALL from struct perf_event members (Michael Petlan) [RHEL-29795]
- perf/bpf: Create bpf_overflow_handler() stub for !CONFIG_BPF_SYSCALL (Michael Petlan) [RHEL-29795]
- perf/bpf: Reorder bpf_overflow_handler() ahead of __perf_event_overflow() (Michael Petlan) [RHEL-29795]
- perf/x86/rapl: Add support for Intel Lunar Lake (Michael Petlan) [RHEL-29795]
- perf/x86/rapl: Add support for Intel Arrow Lake (Michael Petlan) [RHEL-29795]
- perf/core: Reduce PMU access to adjust sample freq (Michael Petlan) [RHEL-29795]
- perf/core: Optimize perf_adjust_freq_unthr_context() (Michael Petlan) [RHEL-29795]
- perf/x86/amd: Don't reject non-sampling events with configured LBR (Michael Petlan) [RHEL-29795]
- perf/x86/amd: Support capturing LBR from software events (Michael Petlan) [RHEL-29795]
- perf/x86/amd: Avoid taking branches before disabling LBR (Michael Petlan) [RHEL-29795]
- perf/x86/amd: Ensure amd_pmu_core_disable_all() is always inlined (Michael Petlan) [RHEL-29795]
- perf/x86/rapl: Prefer struct_size() over open coded arithmetic (Michael Petlan) [RHEL-29795]
- x86/cpu/topology: Rename topology_max_die_per_package() [partial] (Michael Petlan) [RHEL-29795]
- KVM: VMX: Also clear SGX EDECCSSA in KVM CPU caps when SGX is disabled (Vladis Dronov) [RHEL-22826]
- KVM: VMX: Do not account for temporary memory allocation in ECREATE emulation (Vladis Dronov) [RHEL-22826]
- x86/cpu: Clarify the error message when BIOS does not support SGX (Vladis Dronov) [RHEL-22826]
- x86/sgx: Fix a W=1 build warning in function comment (Vladis Dronov) [RHEL-22826]
- x86/sgx: Log information when a node lacks an EPC section (Vladis Dronov) [RHEL-22826]
- x86/sgx: Fix deadlock in SGX NUMA node search (Vladis Dronov) [RHEL-22826 RHEL-63522] {CVE-2024-49856}
- selftests/sgx: Skip non X86_64 platform (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Remove incomplete ABI sanitization code in test enclave (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Discard unsupported ELF sections (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Ensure expected location of test enclave buffer (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Ensure test enclave buffer is entirely preserved (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Fix linker script asserts (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Handle relocations in test enclave (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Produce static-pie executable for test enclave (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Remove redundant enclave base address save/restore (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Specify freestanding environment for enclave compilation (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Separate linker options (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Include memory clobber for inline asm in test enclave (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Fix uninitialized pointer dereferences in encl_get_entry (Vladis Dronov) [RHEL-22826]
- selftests/sgx: Fix uninitialized pointer dereference in error path (Vladis Dronov) [RHEL-22826]
- x86/headers: Remove unnecessary #include <asm/export.h> (Vladis Dronov) [RHEL-22826]
- efi: libstub: Move screen_info handling to common code (Maxim Levitsky) [RHEL-60834]
- s390/ap: Fix CCA crypto card behavior within protected execution environment (Mete Durlu) [RHEL-62840]
- s390/iucv: Fix vargs handling in iucv_alloc_device() (Mete Durlu) [RHEL-50786]
- s390/smsgiucv_app: Make use of iucv_alloc_device() (Mete Durlu) [RHEL-50786]
- s390/netiucv: Make use of iucv_alloc_device() (Mete Durlu) [RHEL-50786]
- s390/iucv: Provide iucv_alloc_device() / iucv_release_device() (Mete Durlu) [RHEL-50786]
- s390/iucv: use new address translation helpers (Mete Durlu) [RHEL-50786]
- s390/ctcm: use new address translation helpers (Mete Durlu) [RHEL-50786]
- s390/lcs: use new address translation helpers (Mete Durlu) [RHEL-50786]
- s390/qeth: use new address translation helpers (Mete Durlu) [RHEL-50786]
- s390/iucv: fix receive buffer virtual vs physical address confusion (Mete Durlu) [RHEL-50786]
- net/af_iucv: fix virtual vs physical address confusion (Mete Durlu) [RHEL-50786]
- net/iucv: fix the allocation size of iucv_path_table array (Mete Durlu) [RHEL-50786]
- net/iucv: fix virtual vs physical address confusion (Mete Durlu) [RHEL-50786]
- hwmon: (ibmpex) Fix possible UAF when ibmpex_register_bmc() fails (CKI Backport Bot) [RHEL-63712] {CVE-2022-49029}
- platform/x86: ISST: Fix the KASAN report slab-out-of-bounds bug (CKI Backport Bot) [RHEL-63950] {CVE-2024-49886}
- x86/ioapic: Handle allocation failures gracefully (CKI Backport Bot) [RHEL-64153] {CVE-2024-49927}
- x86/microcode/AMD: Remove unused PATCH_MAX_SIZE macro (David Arcari) [RHEL-64439]
- x86/microcode/AMD: Avoid -Wformat warning with clang-15 (David Arcari) [RHEL-64439]
- x86/microcode: Remove unused struct cpu_info_ctx (David Arcari) [RHEL-64439]
- x86/microcode/intel: Add a minimum required revision for late loading [partial] (David Arcari) [RHEL-64439]
- x86/microcode/intel: Remove redundant microcode late updated message (David Arcari) [RHEL-64439]
- x86/microcode/intel: Switch to new Intel CPU model defines (David Arcari) [RHEL-64439]
- tools/verification: Use pkg-config in lib_setup of Makefile.config (Crystal Wood) [RHEL-50871]
- tools/verification: Use tools/build makefiles on rv (Crystal Wood) [RHEL-50871]
- xen-netfront: Fix NULL sring after live migration (Vitaly Kuznetsov) [RHEL-63751] {CVE-2022-48969}
- xen/netfront: destroy queues before real_num_tx_queues is zeroed (Vitaly Kuznetsov) [RHEL-63751]
- gitlab-ci: provide consistent kcidb_tree_name (Michael Hofmann)
- powercap: intel_rapl: Fix off by one in get_rpi() (CKI Backport Bot) [RHEL-63250] {CVE-2024-49862}
- s390/crypto: Add hardware acceleration for full AES-XTS mode (Mete Durlu) [RHEL-50939]
- s390/kprobes: Avoid stop machine if possible (Mete Durlu) [RHEL-50800]
- s390/setup: Recognize sequential instruction fetching facility (Mete Durlu) [RHEL-50800]
- s390/disassembler: Remove duplicate instruction format RSY_RDRU (Mete Durlu) [RHEL-50795]
- s390/disassembler: Add instructions (Mete Durlu) [RHEL-50795]
- s390/disassembler: Update instruction mnemonics to latest spec (Mete Durlu) [RHEL-50795]
- s390/disassembler: Use proper format specifiers for operand values (Mete Durlu) [RHEL-50795]
- s390/pai_ext: Update PAI extension 1 counters (Mete Durlu) [RHEL-50794]
- s390/pai_crypto: Add support for MSA 10 and 11 pai counters (Mete Durlu) [RHEL-50794]
- s390/zfcp: use new address translation helpers (Mete Durlu) [RHEL-50787]
- s390/cio: use new address translation helpers (Mete Durlu) [RHEL-50787]
- s390/sha3: Fix SHA3 selftests failures (Mete Durlu) [RHEL-50771]
- s390/setup: Recognize sequential instruction fetching facility (Mete Durlu) [RHEL-50771]
- redhat: Add CONFIG_SCHED_TOPOLOGY_VERTICAL and CONFIG_HIPERDISPATCH_ON config files (Mete Durlu) [RHEL-50766]
- s390/hiperdispatch: Add hiperdispatch debug counters (Mete Durlu) [RHEL-50766]
- s390/hiperdispatch: Add hiperdispatch debug attributes (Mete Durlu) [RHEL-50766]
- s390/hiperdispatch: Add hiperdispatch sysctl interface (Mete Durlu) [RHEL-50766]
- s390/hiperdispatch: Add trace events (Mete Durlu) [RHEL-50766]
- s390/hiperdispatch: Add steal time averaging (Mete Durlu) [RHEL-50766]
- s390/hiperdispatch: Introduce hiperdispatch (Mete Durlu) [RHEL-50766]
- s390/smp: Add cpu capacities (Mete Durlu) [RHEL-50766]
- s390/topology: Add config option to switch to vertical during boot (Mete Durlu) [RHEL-50766]
- s390/topology: Add sysctl handler for polarization (Mete Durlu) [RHEL-50766]
- s390/wti: Add debugfs file to display missed grace periods per cpu (Mete Durlu) [RHEL-50766]
- s390/wti: Add wti accounting for missed grace periods (Mete Durlu) [RHEL-50766]
- s390/wti: Prepare graceful CPU pre-emption on wti reception (Mete Durlu) [RHEL-50766]
- s390/wti: Introduce infrastructure for warning track interrupt (Mete Durlu) [RHEL-50766]
- i40e: Fix macvlan leak by synchronizing access to mac_filter_hash (Kamal Heib) [RHEL-49813 RHEL-52666]
- i40e: Remove setting of RX software timestamp (Kamal Heib) [RHEL-49813 RHEL-52666]
- i40e: Add Energy Efficient Ethernet ability for X710 Base-T/KR/KX cards (Kamal Heib) [RHEL-49813 RHEL-52666]
- i40e: correct i40e_addr_to_hkey() name in kdoc (Kamal Heib) [RHEL-49813 RHEL-52666]
- net: intel: Remove MODULE_AUTHORs (Kamal Heib) [RHEL-49813 RHEL-52666]
- i40e: Fix XDP program unloading while removing the driver (Kamal Heib) [RHEL-49813 RHEL-52666]
- net: intel: Use *-y instead of *-objs in Makefile (Kamal Heib) [RHEL-49813 RHEL-52666]
- i40e: flower: validate control flags (Kamal Heib) [RHEL-49813 RHEL-52666]
- i40e: avoid forward declarations in i40e_nvm.c (Kamal Heib) [RHEL-49813 RHEL-52666]
- net: intel: implement modern PM ops declarations (Kamal Heib) [RHEL-49813 RHEL-52666]
- tcp: fix TFO SYN_RECV to not zero retrans_stamp with retransmits out (Paolo Abeni) [RHEL-62865]
- tcp: fix tcp_enter_recovery() to zero retrans_stamp when it's safe (Paolo Abeni) [RHEL-62865]
- tcp: fix to allow timestamp undo if no retransmits were sent (Paolo Abeni) [RHEL-62865]
- tcp: check skb is non-NULL in tcp_rto_delta_us() (Paolo Abeni) [RHEL-62865]
- tcp: fix forever orphan socket caused by tcp_abort (Paolo Abeni) [RHEL-62865]
- tcp: Update window clamping condition (Paolo Abeni) [RHEL-62865]
- tcp: Adjust clamping window for applications specifying SO_RCVBUF (Paolo Abeni) [RHEL-62865]
- tcp: fix incorrect undo caused by DSACK of TLP retransmit (Paolo Abeni) [RHEL-62865]
- UPSTREAM: tcp: fix DSACK undo in fast recovery to call tcp_try_to_open() (Paolo Abeni) [RHEL-62865]
- tcp: fix tcp_rcv_fastopen_synack() to enter TCP_CA_Loss for failed TFO (Paolo Abeni) [RHEL-62865]
- tcp: clear tp->retrans_stamp in tcp_rcv_fastopen_synack() (Paolo Abeni) [RHEL-62865]
- tcp: fix race in tcp_v6_syn_recv_sock() (Paolo Abeni) [RHEL-62865]
- tcp: avoid premature drops in tcp_add_backlog() (Paolo Abeni) [RHEL-62865]
- tcp: increase the default TCP scaling ratio (Paolo Abeni) [RHEL-62865]
- tcp: replace TCP_SKB_CB(skb)->tcp_tw_isn with a per-cpu field (Paolo Abeni) [RHEL-62865]
- tcp: propagate tcp_tw_isn via an extra parameter to ->route_req() (Paolo Abeni) [RHEL-62865]
- tcp: call tcp_try_undo_recovery when an RTOd TFO SYNACK is ACKed (Paolo Abeni) [RHEL-62865]
- perf/x86/intel/uncore: Add LNL uncore iMC freerunning support (Michael Petlan) [RHEL-20061]
- perf/x86/intel/uncore: Add Lunar Lake support (Michael Petlan) [RHEL-20061]
- perf/x86/intel/uncore: Factor out common MMIO init and ops functions (Michael Petlan) [RHEL-20061]
- perf/x86/intel/uncore: Add Arrow Lake support (Michael Petlan) [RHEL-20061]
- intel_th: pci: Add Meteor Lake-S CPU support (Michael Petlan) [RHEL-15631]
- intel_th: pci: Add Meteor Lake-S support (Michael Petlan) [RHEL-15633]
- perf/x86/intel/uncore: Use D0:F0 as a default device (Michael Petlan) [RHEL-15665]
- gso: fix udp gso fraglist segmentation after pull from frag_list (Paolo Abeni) [RHEL-62848]
- udp6: fix potential access to stale information (Paolo Abeni) [RHEL-62848]
- s390/ap: Fix deadlock caused by recursive lock of the AP bus scan mutex (Mete Durlu) [RHEL-61700]
- s390/mm: Add cond_resched() to cmm_alloc/free_pages() (Mete Durlu) [RHEL-61701]
- KVM: arm64: Ensure vgic_ready() is ordered against MMIO registration (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Fix shift-out-of-bounds bug (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Unregister redistributor for failed vCPU creation (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Move data barrier to end of split walk (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Release pfn, i.e. put page, if copying MTE tags hits ZONE_DEVICE (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Disallow copying MTE to guest memory while KVM is dirty logging (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Ensure TLBI uses correct VMID after changing context (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Invalidate EL1&0 TLB entries for all VMIDs in nvhe hyp init (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Constrain the host to the maximum shared SVE VL with pKVM (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Fix __pkvm_init_vcpu cptr_el2 error path (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Fix kvm_has_feat*() handling of negative features (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Add memory length checks and remove inline in do_ffa_mem_xfer (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Enforce S2 alignment when contiguous bit is set (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Make ICC_*SGI*_EL1 undef in the absence of a vGICv3 (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Ensure canonical IPA is hugepage-aligned when handling fault (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: vgic: Don't hold config_lock while unregistering redistributors (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: vgic-debug: Don't put unmarked LPIs (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: vgic: Hold config_lock while tearing down a CPU interface (Shaoqin Huang) [RHEL-57113]
- KVM: selftests: arm64: Correct feature test for S1PIE in get-reg-list (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Tidying up PAuth code in KVM (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: vgic-debug: Exit the iterator properly w/o LPI (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Enforce dependency on an ARMv8.4-aware toolchain (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: free kvm->arch.nested_mmus with kvfree() (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: vgic: fix unexpected unlock sparse warnings (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: fix kdoc warnings in W=1 builds (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: fix override-init warnings in W=1 builds (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Allow the use of SVE+NV (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Add additional trap setup for CPTR_EL2 (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Add trap description for CPTR_EL2 (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Add TCPAC/TTA to CPTR->CPACR conversion helper (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Honor guest hypervisor's FP/SVE traps in CPTR_EL2 (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Load guest FP state for ZCR_EL2 trap (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Handle CPACR_EL1 traps (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Spin off helper for programming CPTR traps (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Ensure correct VL is loaded before saving SVE state (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Use guest hypervisor's max VL when running nested guest (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Save guest's ZCR_EL2 when in hyp context (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Load guest hyp's ZCR into EL1 state (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Handle ZCR_EL2 traps (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Forward SVE traps to guest hypervisor (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Forward FP/ASIMD traps to guest hypervisor (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nVHE: Support CONFIG_CFI_CLANG at EL2 (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Introduce print_nvhe_hyp_panic helper (Shaoqin Huang) [RHEL-57113]
- arm64: Introduce esr_brk_comment, esr_is_cfi_brk (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: VHE: Mark __hyp_call_panic __noreturn (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nVHE: gen-hyprel: Skip R_AARCH64_ABS32 (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nVHE: Simplify invalid_host_el2_vect (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Fix __pkvm_init_switch_pgd call ABI (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Fix clobbered ELR in sync abort/SError (Shaoqin Huang) [RHEL-57113]
- arm64: Add CFI error handling (Shaoqin Huang) [RHEL-57113]
- KVM: selftests: Assert that MPIDR_EL1 is unchanged across vCPU reset (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Unfudge ID_AA64PFR0_EL1 masking (Shaoqin Huang) [RHEL-57113]
- KVM: selftests: arm64: Test writes to CTR_EL0 (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: rename functions for invariant sys regs (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: show writable masks for feature registers (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Treat CTR_EL0 as a VM feature ID register (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: unify code to prepare traps (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Use accessors for modifying ID registers (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Add helper for writing ID regs (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Use read-only helper for reading VM ID registers (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Make idregs debugfs iterator search sysreg table directly (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Get sys_reg encoding from descriptor in idregs_debug_show() (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Truely enable nXS TLBI operations (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Add handling of NXS-flavoured TLBI operations (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Add handling of range-based TLBI operations (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Add handling of outer-shareable TLBI operations (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Invalidate TLBs based on shadow S2 TTL-like information (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Tag shadow S2 entries with guest's leaf S2 level (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Handle FEAT_TTL hinted TLB operations (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Handle TLBI IPAS2E1{,IS} operations (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Handle TLBI ALLE1{,IS} operations (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Handle TLBI VMALLS12E1{,IS} operations (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Handle TLB invalidation targeting L2 stage-1 (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Handle EL2 Stage-1 TLB invalidation (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Add Stage-1 EL2 invalidation primitives (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Unmap/flush shadow stage 2 page tables (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Handle shadow stage 2 page faults (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Implement nested Stage-2 page table walk logic (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Support multiple nested Stage-2 mmu structures (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Update the identification range for the FF-A smcs (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Add support for FFA_PARTITION_INFO_GET (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Trap FFA_VERSION host call in pKVM (Shaoqin Huang) [RHEL-57113]
- firmware: arm_ffa: Make ffa_bus_type const (Shaoqin Huang) [RHEL-57113]
- firmware: arm_ffa: Declare ffa_bus_type structure in the header (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Use GFP_KERNEL_ACCOUNT for sysreg_masks allocation (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Add early_param to control WFx trapping (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: Replace custom macros with fields from ID_AA64PFR0_EL1 (Shaoqin Huang) [RHEL-57113]
- KVM: Documentation: Enumerate allowed value macros of `irq_type` (Shaoqin Huang) [RHEL-57113]
- KVM: Documentation: Correct the VGIC V2 CPU interface addr space size (Shaoqin Huang) [RHEL-57113]
- Revert "KVM: arm64: nv: Fix RESx behaviour of disabled FGTs with negative polarity" (Shaoqin Huang) [RHEL-57113]
- KVM: arm64: nv: Fix RESx behaviour of disabled FGTs with negative polarity (Shaoqin Huang) [RHEL-57113]
- perf test record.sh: Raise limit of open file descriptors (Michael Petlan) [RHEL-1340]
- Enable CONFIG_DMA_NUMA_CMA for x86_64 and aarch64 (Chris von Recklinghausen) [RHEL-59179]
- Make setting of cma_pernuma tech preview (Chris von Recklinghausen) [RHEL-59179]
- ELF: fix kernel.randomize_va_space double read (Rafael Aquini) [RHEL-60757] {CVE-2024-46826}
- mm/vmalloc: fix page mapping if vm_area_alloc_pages() with high order fallback to order 0 (Rafael Aquini) [RHEL-58558] {CVE-2024-45022}
- bonding: support xfrm state update (CKI Backport Bot) [RHEL-50630]
- bonding: Add ESN support to IPSec HW offload (CKI Backport Bot) [RHEL-50630]
- bonding: add common function to check ipsec device (CKI Backport Bot) [RHEL-50630]
- bonding: change ipsec_lock from spin lock to mutex (CKI Backport Bot) [RHEL-50630]
- bonding: extract the use of real_device into local variable (CKI Backport Bot) [RHEL-50630]
- bonding: implement xdo_dev_state_free and call it after deletion (CKI Backport Bot) [RHEL-50630]
- bonding: fix xfrm state handling when clearing active slave (CKI Backport Bot) [RHEL-50630]
- bonding: fix bond_ipsec_offload_ok return type (CKI Backport Bot) [RHEL-50630]
- bonding: fill IPsec state validation failure reason (CKI Backport Bot) [RHEL-50630]
- iommu/arm-smmu-v3: Convert comma to semicolon (Jerry Snitselaar) [RHEL-55203]
- iommu/arm-smmu-v3: Fix last_sid_idx calculation for sid_bits==32 (Jerry Snitselaar) [RHEL-55203]
- iommu: Use of_property_present() (Jerry Snitselaar) [RHEL-59985]
- iommu/io-pgtable-arm: Optimise non-coherent unmap (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu-qcom: apply num_context_bank fixes for SDM630 / SDM660 (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu-v3: Use the new rb tree helpers (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu-v3-test: Test masters with stall enabled (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu-v3: Match Stall behaviour for S2 (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu-qcom: Work around SDM845 Adreno SMMU w/ 16K pages (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu-qcom: hide last LPASS SMMU context bank from linux (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu-v3: Fix a NULL vs IS_ERR() check (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu-v3: Remove the unused empty definition (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu: Un-demote unhandled-fault msg (Jerry Snitselaar) [RHEL-59985]
- iommu/arm-smmu-v3: Reorganize struct arm_smmu_ctx_desc_cfg (Jerry Snitselaar) [RHEL-55203]
- iommu/arm-smmu-v3: Add types for each level of the CD table (Jerry Snitselaar) [RHEL-55203]
- iommu/arm-smmu-v3: Shrink the cdtab l1_desc array (Jerry Snitselaar) [RHEL-55203]
- iommu/arm-smmu-v3: Do not use devm for the cd table allocations (Jerry Snitselaar) [RHEL-55203]
- iommu/arm-smmu-v3: Remove strtab_base/cfg (Jerry Snitselaar) [RHEL-55203]
- iommu/arm-smmu-v3: Reorganize struct arm_smmu_strtab_cfg (Jerry Snitselaar) [RHEL-55203]
- iommu/arm-smmu-v3: Add types for each level of the 2 level stream table (Jerry Snitselaar) [RHEL-55203]
- iommu/arm-smmu-v3: Add arm_smmu_strtab_l1/2_idx() (Jerry Snitselaar) [RHEL-55203]
- netem: fix return value if duplicate enqueue fails (CKI Backport Bot) [RHEL-58529] {CVE-2024-45016}
- net: bridge: mcast: wait for previous gc cycles when removing port (CKI Backport Bot) [RHEL-56229] {CVE-2024-44934}
- ice: Add a per-VF limit on number of FDIR filters (CKI Backport Bot) [RHEL-55011] {CVE-2024-42291}
- kernel.spec: remove py3_shbang_opts (Hangbin Liu) [RHEL-50532]
- redhat/configs: Enable CONFIG_PTP_1588_CLOCK_MOCK in kernel-modules-internal (Davide Caratti) [RHEL-47747]

* Wed Oct 30 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-524.el9]
- bpf: improve error message for unsupported helper (Jerome Marchand) [RHEL-23649]
- libbpf: keep FD_CLOEXEC flag when dup()'ing FD (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Cover verifier checks for mutating sockmap/sockhash (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add tests for may_goto with negative offset. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Tests with may_goto and jumps to the 1st insn (Jerome Marchand) [RHEL-23649]
- bpf: fix overflow check in adjust_jmp_off() (Jerome Marchand) [RHEL-23649]
- bpf: add check for invalid name in btf_name_valid_section() (Jerome Marchand) [RHEL-23649]
- arm64: prohibit probing on arch_kunwind_consume_entry() (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Fix incorrect parameters in NULL pointer checking (Jerome Marchand) [RHEL-23649]
- redhat/configs: add CONFIG_DEBUG_INFO_BTF_MODULES (Jerome Marchand) [RHEL-23649]
- bpf: Fix may_goto with negative offset. (Jerome Marchand) [RHEL-23649]
- bpf: Fix the corner case with may_goto and jump to the 1st insn. (Jerome Marchand) [RHEL-23649]
- bpf: Fix remap of arena. (Jerome Marchand) [RHEL-23649]
- bpf: Fix a potential use-after-free in bpf_link_free() (Jerome Marchand) [RHEL-23649]
- bpf: Allow delete from sockmap/sockhash only if update is allowed (Jerome Marchand) [RHEL-23649]
- libbpf: fix feature detectors when using token_fd (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test PROBE_MEM of VSYSCALL_ADDR on x86-64 (Jerome Marchand) [RHEL-23649]
- bpf, x86: Fix PROBE_MEM runtime load check (Jerome Marchand) [RHEL-23649]
- bpf: verifier: prevent userspace memory access (Jerome Marchand) [RHEL-23649]
- bpf, arm64: Fix incorrect runtime stats (Jerome Marchand) [RHEL-23649]
- bpf: Fix a verifier verbose message (Jerome Marchand) [RHEL-23649]
- bpf, kconfig: Fix DEBUG_INFO_BTF_MODULES Kconfig definition (Jerome Marchand) [RHEL-23649]
- x86/bpf: Fix IP after emitting call depth accounting (Jerome Marchand) [RHEL-23649]
- bpf: fix possible file descriptor leaks in verifier (Jerome Marchand) [RHEL-23649]
- tools/resolve_btfids: fix build with musl libc (Jerome Marchand) [RHEL-23649]
- bpf: support deferring bpf_link dealloc to after RCU grace period (Jerome Marchand) [RHEL-23649]
- bpf: put uprobe link's path and task in release callback (Jerome Marchand) [RHEL-23649]
- bpf: Check bloom filter map value size (Jerome Marchand) [RHEL-23649]
- bpf: fix warning for crash_kexec (Jerome Marchand) [RHEL-23649]
- bpf: verifier: reject addr_space_cast insn without arena (Jerome Marchand) [RHEL-23649]
- selftests/bpf: verifier_arena: fix mmap address for arm64 (Jerome Marchand) [RHEL-23649]
- bpf: verifier: fix addr_space_cast from as(1) to as(0) (Jerome Marchand) [RHEL-23649]
- libbpf: Define MFD_CLOEXEC if not available (Jerome Marchand) [RHEL-23649]
- arm64: bpf: fix 32bit unconditional bswap (Jerome Marchand) [RHEL-23649]
- bpf: report RCU QS in cpumap kthread (Jerome Marchand) [RHEL-23649]
- rcu: add a helper to report consolidated flavor QS (Jerome Marchand) [RHEL-23649]
- bpf, arm64: fix bug in BPF_LDX_MEMSX (Jerome Marchand) [RHEL-23649]
- libbpf: fix u64-to-pointer cast on 32-bit arches (Jerome Marchand) [RHEL-23649]
- s390/bpf: Fix bpf_plt pointer arithmetic (Jerome Marchand) [RHEL-23649]
- bpf: Remove arch_unprotect_bpf_trampoline() (Jerome Marchand) [RHEL-23649]
- bpf: Remove unnecessary err < 0 check in bpf_struct_ops_map_update_elem (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add arena test case for 4Gbyte corner case (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Remove hard coded PAGE_SIZE macro. (Jerome Marchand) [RHEL-23649]
- libbpf, selftests/bpf: Adjust libbpf, bpftool, selftests to match LLVM (Jerome Marchand) [RHEL-23649]
- bpf: Clarify bpf_arena comments. (Jerome Marchand) [RHEL-23649]
- scripts/bpf_doc: Use silent mode when exec make cmd (Jerome Marchand) [RHEL-23649]
- bpf: Temporarily disable atomic operations in BPF arena (Jerome Marchand) [RHEL-23649]
- bpf: move sleepable flag from bpf_prog_aux to bpf_prog (Jerome Marchand) [RHEL-23649]
- bpf: hardcode BPF_PROG_PACK_SIZE to 2MB * num_possible_nodes() (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add kprobe multi triggering benchmarks (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add bpf_arena_htab test. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add bpf_arena_list test. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add unit tests for bpf_arena_alloc/free_pages (Jerome Marchand) [RHEL-23649]
- bpf: Add helper macro bpf_addr_space_cast() (Jerome Marchand) [RHEL-23649]
- libbpf: Recognize __arena global variables. (Jerome Marchand) [RHEL-23649]
- bpftool: Recognize arena map type (Jerome Marchand) [RHEL-23649]
- libbpf: Add support for bpf_arena. (Jerome Marchand) [RHEL-23649]
- libbpf: Add __arg_arena to bpf_helpers.h (Jerome Marchand) [RHEL-23649]
- bpf: Recognize btf_decl_tag("arg: Arena") as PTR_TO_ARENA. (Jerome Marchand) [RHEL-23649]
- bpf: Recognize addr_space_cast instruction in the verifier. (Jerome Marchand) [RHEL-23649]
- bpf: Add x86-64 JIT support for bpf_addr_space_cast instruction. (Jerome Marchand) [RHEL-23649]
- bpf: Add x86-64 JIT support for PROBE_MEM32 pseudo instructions. (Jerome Marchand) [RHEL-23649]
- bpf: Disasm support for addr_space_cast instruction. (Jerome Marchand) [RHEL-23649]
- bpf: Introduce bpf_arena. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add fexit and kretprobe triggering benchmarks (Jerome Marchand) [RHEL-23649]
- mm: Introduce vmap_page_range() to map pages in PCI address space (Jerome Marchand) [RHEL-23649]
- arm64, bpf: Use bpf_prog_pack for arm64 bpf trampoline (Jerome Marchand) [RHEL-23649]
- bpf: Fix stackmap overflow check on 32-bit arches (Jerome Marchand) [RHEL-23649]
- bpf: Fix hashtab overflow check on 32-bit arches (Jerome Marchand) [RHEL-23649]
- bpf: Fix DEVMAP_HASH overflow check on 32-bit arches (Jerome Marchand) [RHEL-23649]
- bpf: Tell bpf programs kernel's PAGE_SIZE (Jerome Marchand) [RHEL-23649]
- bpftool: rename is_internal_mmapable_map into is_mmapable_map (Jerome Marchand) [RHEL-23649]
- libbpf: Allow specifying 64-bit integers in map BTF. (Jerome Marchand) [RHEL-23649]
- bpf: Plumb get_unmapped_area() callback into bpf_map_ops (Jerome Marchand) [RHEL-23649]
- bpf: Recognize '__map' suffix in kfunc arguments (Jerome Marchand) [RHEL-23649]
- bpf: Allow kfuncs return 'void *' (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test cases for '?' in BTF names (Jerome Marchand) [RHEL-23649]
- bpf: Allow all printable characters in BTF DATASEC names (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test case for SEC("?.struct_ops") (Jerome Marchand) [RHEL-23649]
- libbpf: Rewrite btf datasec names starting from '?' (Jerome Marchand) [RHEL-23649]
- libbpf: Struct_ops in SEC("?.struct_ops") / SEC("?.struct_ops.link") (Jerome Marchand) [RHEL-23649]
- libbpf: Replace elf_state->st_ops_* fields with SEC_ST_OPS sec_type (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Verify struct_ops autoload/autocreate sync (Jerome Marchand) [RHEL-23649]
- libbpf: Sync progs autoload with maps autocreate for struct_ops maps (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test autocreate behavior for struct_ops maps (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Bad_struct_ops test (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Utility functions to capture libbpf log in test_progs (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test struct_ops map definition with type suffix (Jerome Marchand) [RHEL-23649]
- libbpf: Honor autocreate flag for struct_ops maps (Jerome Marchand) [RHEL-23649]
- libbpf: Tie struct_ops programs to kernel BTF ids, not to local ids (Jerome Marchand) [RHEL-23649]
- libbpf: Allow version suffixes (___smth) for struct_ops types (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test may_goto (Jerome Marchand) [RHEL-23649]
- bpf: Add cond_break macro (Jerome Marchand) [RHEL-23649]
- bpf: Recognize that two registers are safe when their ranges match (Jerome Marchand) [RHEL-23649]
- bpf: Introduce may_goto instruction (Jerome Marchand) [RHEL-23649]
- mm: Introduce VM_SPARSE kind and vm_area_[un]map_pages(). (Jerome Marchand) [RHEL-23649]
- mm: Enforce VM_IOREMAP flag and range in ioremap_page_range. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test struct_ops maps with a large number of struct_ops program. (Jerome Marchand) [RHEL-23649]
- bpf: struct_ops supports more than one page for trampolines. (Jerome Marchand) [RHEL-23649]
- bpf, net: validate struct_ops when updating value. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Extend uprobe/uretprobe triggering benchmarks (Jerome Marchand) [RHEL-23649]
- libbpf: Correct debug message in btf__load_vmlinux_btf (Jerome Marchand) [RHEL-23649]
- bpf, docs: Rename legacy conformance group to packet (Jerome Marchand) [RHEL-23649]
- bpf, docs: Use IETF format for field definitions in instruction-set.rst (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test if shadow types work correctly. (Jerome Marchand) [RHEL-23649]
- bpftool: Add an example for struct_ops map and shadow type. (Jerome Marchand) [RHEL-23649]
- bpftool: Generated shadow variables for struct_ops maps. (Jerome Marchand) [RHEL-23649]
- libbpf: Convert st_ops->data to shadow type. (Jerome Marchand) [RHEL-23649]
- libbpf: Set btf_value_type_id of struct bpf_map for struct_ops. (Jerome Marchand) [RHEL-23649]
- bpf: Replace bpf_lpm_trie_key 0-length array with flexible array (Jerome Marchand) [RHEL-23649]
- bpf, arm64: use bpf_prog_pack for memory management (Jerome Marchand) [RHEL-23649]
- arm64: patching: implement text_poke API (Jerome Marchand) [RHEL-23649]
- bpf, arm64: support exceptions (Jerome Marchand) [RHEL-23649]
- arm64: stacktrace: Implement arch_bpf_stack_walk() for the BPF JIT (Jerome Marchand) [RHEL-23649]
- arm64: stacktrace: factor out kunwind_stack_walk() (Jerome Marchand) [RHEL-23649]
- arm64: stacktrace: factor out kernel unwind state (Jerome Marchand) [RHEL-23649]
- bpf: add is_async_callback_calling_insn() helper (Jerome Marchand) [RHEL-23649]
- bpf: introduce in_sleepable() helper (Jerome Marchand) [RHEL-23649]
- bpf: allow more maps in sleepable bpf programs (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test case for lacking CFI stub functions. (Jerome Marchand) [RHEL-23649]
- bpf: Check cfi_stubs before registering a struct_ops type. (Jerome Marchand) [RHEL-23649]
- bpf: Clarify batch lookup/lookup_and_delete semantics (Jerome Marchand) [RHEL-23649]
- bpf, docs: specify which BPF_ABS and BPF_IND fields were zero (Jerome Marchand) [RHEL-23649]
- bpf, docs: Fix typos in instruction-set.rst (Jerome Marchand) [RHEL-23649]
- bpf: Shrink size of struct bpf_map/bpf_array. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Remove intermediate test files. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Remove empty TEST_CUSTOM_PROGS (Jerome Marchand) [RHEL-23649]
- bpf: Fix test verif_scale_strobemeta_subprogs failure due to llvm19 (Jerome Marchand) [RHEL-23649]
- bpf: improve duplicate source code line detection (Jerome Marchand) [RHEL-23649]
- libbpf: Make remark about zero-initializing bpf_*_info structs (Jerome Marchand) [RHEL-23649]
- bpf: Use O(log(N)) binary search to find line info record (Jerome Marchand) [RHEL-23649]
- bpf: emit source code file name and line number in verifier log (Jerome Marchand) [RHEL-23649]
- selftests/bpf: add anonymous user struct as global subprog arg test (Jerome Marchand) [RHEL-23649]
- bpf: don't infer PTR_TO_CTX for programs with unnamed context type (Jerome Marchand) [RHEL-23649]
- bpf: handle bpf_user_pt_regs_t typedef explicitly for PTR_TO_CTX global arg (Jerome Marchand) [RHEL-23649]
- bpf: simplify btf_get_prog_ctx_type() into btf_is_prog_ctx_type() (Jerome Marchand) [RHEL-23649]
- bpf: remove check in __cgroup_bpf_run_filter_skb (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test PTR_MAYBE_NULL arguments of struct_ops operators. (Jerome Marchand) [RHEL-23649]
- bpf: Create argument information for nullable arguments. (Jerome Marchand) [RHEL-23649]
- bpf: Move __kfunc_param_match_suffix() to btf.c. (Jerome Marchand) [RHEL-23649]
- bpf: add btf pointer to struct bpf_ctx_arg_aux. (Jerome Marchand) [RHEL-23649]
- libbpf: Add support to GCC in CORE macro definitions (Jerome Marchand) [RHEL-23649]
- bpf: Abstract loop unrolling pragmas in BPF selftests (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Ensure fentry prog cannot attach to bpf_spin_{lock,unlcok}() (Jerome Marchand) [RHEL-23649]
- bpf: Mark bpf_spin_{lock,unlock}() helpers with notrace correctly (Jerome Marchand) [RHEL-23649]
- bpf: Have bpf_rdonly_cast() take a const pointer (Jerome Marchand) [RHEL-23649]
- bpf, docs: Update ISA document title (Jerome Marchand) [RHEL-23649]
- bpf: Allow compiler to inline most of bpf_local_storage_lookup() (Jerome Marchand) [RHEL-23649]
- bpf, btf: Check btf for register_bpf_struct_ops (Jerome Marchand) [RHEL-23649]
- bpf, btf: Add check_btf_kconfigs helper (Jerome Marchand) [RHEL-23649]
- bpf, btf: Fix return value of register_btf_id_dtor_kfuncs (Jerome Marchand) [RHEL-23649]
- bpf: Merge two CONFIG_BPF entries (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Mark cpumask kfunc declarations as __weak (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Fix error checking for cpumask_success__load() (Jerome Marchand) [RHEL-23649]
- bpf: Use -Wno-address-of-packed-member in some selftests (Jerome Marchand) [RHEL-23649]
- bpf, docs: Fix typos in instructions-set.rst (Jerome Marchand) [RHEL-23649]
- selftests/bpf: mark dynptr kfuncs __weak to make them optional on old kernels (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add tests for RCU lock transfer between subprogs (Jerome Marchand) [RHEL-23649]
- bpf: Transfer RCU lock state between subprog calls (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add test for static subprog call in lock cs (Jerome Marchand) [RHEL-23649]
- bpf: Allow calling static subprogs while holding a bpf_spin_lock (Jerome Marchand) [RHEL-23649]
- bpf, docs: Expand set of initial conformance groups (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Fix flaky selftest lwt_redirect/lwt_reroute (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Suppress warning message of an unused variable. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Fix flaky test ptr_untrusted (Jerome Marchand) [RHEL-23649]
- bpf: Remove an unnecessary check. (Jerome Marchand) [RHEL-23649]
- selftests/bpf: add more cases for __arg_trusted __arg_nullable args (Jerome Marchand) [RHEL-23649]
- bpf: handle trusted PTR_TO_BTF_ID_OR_NULL in argument check logic (Jerome Marchand) [RHEL-23649]
- selftests/bpf: trace_helpers.c: do not use poisoned type (Jerome Marchand) [RHEL-23649]
- selftests/bpf: States pruning checks for scalar vs STACK_MISC (Jerome Marchand) [RHEL-23649]
- bpf: Handle scalar spill vs all MISC in stacksafe() (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add test cases for narrowing fill (Jerome Marchand) [RHEL-23649]
- bpf: Preserve boundaries and track scalars on narrowing fill (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test tracking spilled unbounded scalars (Jerome Marchand) [RHEL-23649]
- bpf: Track spilled unbounded scalars (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Fix bench runner SIGSEGV (Jerome Marchand) [RHEL-23649]
- libbpf: Add missed btf_ext__raw_data() API (Jerome Marchand) [RHEL-23649]
- libbpf: Add btf__new_split() API that was declared but not implemented (Jerome Marchand) [RHEL-23649]
- libbpf: Add missing LIBBPF_API annotation to libbpf_set_memlock_rlim API (Jerome Marchand) [RHEL-23649]
- libbpf: Call memfd_create() syscall directly (Jerome Marchand) [RHEL-23649]
- bpf: Minor clean-up to sleepable_lsm_hooks BTF set (Jerome Marchand) [RHEL-23649]
- bpf: treewide: Annotate BPF kfuncs in BTF (Jerome Marchand) [RHEL-23649]
- bpf: btf: Add BTF_KFUNCS_START/END macro pair (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Enable inline bpf_kptr_xchg() test for RV64 (Jerome Marchand) [RHEL-23649]
- bpf, docs: Clarify which legacy packet instructions existed (Jerome Marchand) [RHEL-23649]
- libbpf: Remove unnecessary null check in kernel_supports() (Jerome Marchand) [RHEL-23649]
- bpf: btf: Support flags for BTF_SET8 sets (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Disable IPv6 for lwt_redirect test (Jerome Marchand) [RHEL-23649]
- selftests/bpf: convert bpf_rdonly_cast() uses to bpf_core_cast() macro (Jerome Marchand) [RHEL-23649]
- libbpf: add bpf_core_cast() macro (Jerome Marchand) [RHEL-23649]
- selftests/bpf: add trusted global subprog arg tests (Jerome Marchand) [RHEL-23649]
- libbpf: add __arg_trusted and __arg_nullable tag macros (Jerome Marchand) [RHEL-23649]
- bpf: add arg:nullable tag to be combined with trusted pointers (Jerome Marchand) [RHEL-23649]
- bpf: add __arg_trusted global func arg tag (Jerome Marchand) [RHEL-23649]
- bpf: Move -Wno-compare-distinct-pointer-types to BPF_CFLAGS (Jerome Marchand) [RHEL-23649]
- bpf: Build type-punning BPF selftests with -fno-strict-aliasing (Jerome Marchand) [RHEL-23649]
- bpf,token: Use BIT_ULL() to convert the bit mask (Jerome Marchand) [RHEL-23649]
- bpf: Generate const static pointers for kernel helpers (Jerome Marchand) [RHEL-23649]
- libbpf: Add some details for BTF parsing failures (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Remove "&>" usage in the selftests (Jerome Marchand) [RHEL-23649]
- bpf: move arg:ctx type enforcement check inside the main logic loop (Jerome Marchand) [RHEL-23649]
- libbpf: integrate __arg_ctx feature detector into kernel_supports() (Jerome Marchand) [RHEL-23649]
- bpf: Use -Wno-error in certain tests when building with GCC (Jerome Marchand) [RHEL-23649]
- docs/bpf: Improve documentation of 64-bit immediate instructions (Jerome Marchand) [RHEL-23649]
- bpf: Remove unused field "mod" in struct bpf_trampoline (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Drop return in bpf_testmod_exit (Jerome Marchand) [RHEL-23649]
- libbpf: Fix faccessat() usage on Android (Jerome Marchand) [RHEL-23649]
- bpftool: Be more portable by using POSIX's basename() (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add missing line break in test_verifier (Jerome Marchand) [RHEL-23649]
- bpf, docs: Clarify definitions of various instructions (Jerome Marchand) [RHEL-23649]
- bpf: Fix error checks against bpf_get_btf_vmlinux(). (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Incorporate LSM policy to token-based tests (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add tests for LIBBPF_BPF_TOKEN_PATH envvar (Jerome Marchand) [RHEL-23649]
- libbpf: Support BPF token path setting through LIBBPF_BPF_TOKEN_PATH envvar (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add tests for BPF object load with implicit token (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add BPF object loading tests with explicit token passing (Jerome Marchand) [RHEL-23649]
- libbpf: Wire up BPF token support at BPF object level (Jerome Marchand) [RHEL-23649]
- libbpf: Wire up token_fd into feature probing logic (Jerome Marchand) [RHEL-23649]
- libbpf: Move feature detection code into its own file (Jerome Marchand) [RHEL-23649]
- libbpf: Further decouple feature checking logic from bpf_object (Jerome Marchand) [RHEL-23649]
- libbpf: Split feature detectors definitions from cached results (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Utilize string values for delegate_xxx mount options (Jerome Marchand) [RHEL-23649]
- bpf: Support symbolic BPF FS delegation mount options (Jerome Marchand) [RHEL-23649]
- bpf: Fail BPF_TOKEN_CREATE if no delegation option was set on BPF FS (Jerome Marchand) [RHEL-23649]
- bpf,selinux: Allocate bpf_security_struct per BPF token (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add BPF token-enabled tests (Jerome Marchand) [RHEL-23649]
- libbpf: Add BPF token support to bpf_prog_load() API (Jerome Marchand) [RHEL-23649]
- libbpf: Add BPF token support to bpf_btf_load() API (Jerome Marchand) [RHEL-23649]
- libbpf: Add BPF token support to bpf_map_create() API (Jerome Marchand) [RHEL-23649]
- libbpf: Add bpf_token_create() API (Jerome Marchand) [RHEL-23649]
- bpf,lsm: Add BPF token LSM hooks (Jerome Marchand) [RHEL-23649]
- bpf,lsm: Refactor bpf_map_alloc/bpf_map_free LSM hooks (Jerome Marchand) [RHEL-23649]
- bpf,lsm: Refactor bpf_prog_alloc/bpf_prog_free LSM hooks (Jerome Marchand) [RHEL-23649]
- bpf: Consistently use BPF token throughout BPF verifier logic (Jerome Marchand) [RHEL-23649]
- bpf: Take into account BPF token when fetching helper protos (Jerome Marchand) [RHEL-23649]
- bpf: Add BPF token support to BPF_PROG_LOAD command (Jerome Marchand) [RHEL-23649]
- bpf: Add BPF token support to BPF_BTF_LOAD command (Jerome Marchand) [RHEL-23649]
- bpf: Add BPF token support to BPF_MAP_CREATE command (Jerome Marchand) [RHEL-23649]
- bpf: Introduce BPF token object (Jerome Marchand) [RHEL-23649]
- bpf: Add BPF token delegation mount options to BPF FS (Jerome Marchand) [RHEL-23649]
- bpf: Align CAP_NET_ADMIN checks with bpf_capable() approach (Jerome Marchand) [RHEL-23649]
- libbpf: Ensure undefined bpf_attr field stays 0 (Jerome Marchand) [RHEL-23649]
- libbpf: Correct bpf_core_read.h comment wrt bpf_core_relo struct (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Skip callback tests if jit is disabled in test_verifier (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Move is_jit_enabled() into testing_helpers (Jerome Marchand) [RHEL-23649]
- selftests/bpf: test case for register_bpf_struct_ops(). (Jerome Marchand) [RHEL-23649]
- bpf: export btf_ctx_access to modules. (Jerome Marchand) [RHEL-23649]
- libbpf: Find correct module BTFs for struct_ops maps and progs. (Jerome Marchand) [RHEL-23649]
- bpf, net: switch to dynamic registration (Jerome Marchand) [RHEL-23649]
- bpf: validate value_type (Jerome Marchand) [RHEL-23649]
- bpf: hold module refcnt in bpf_struct_ops map creation and prog verification. (Jerome Marchand) [RHEL-23649]
- bpf: pass attached BTF to the bpf_struct_ops subsystem (Jerome Marchand) [RHEL-23649]
- bpf: lookup struct_ops types from a given module BTF. (Jerome Marchand) [RHEL-23649]
- bpf: pass btf object id in bpf_map_info. (Jerome Marchand) [RHEL-23649]
- bpf: make struct_ops_map support btfs other than btf_vmlinux. (Jerome Marchand) [RHEL-23649]
- bpf: add struct_ops_tab to btf. (Jerome Marchand) [RHEL-23649]
- bpf, net: introduce bpf_struct_ops_desc. (Jerome Marchand) [RHEL-23649]
- bpf: get type information with BTF_ID_LIST (Jerome Marchand) [RHEL-23649]
- bpf: refactory struct_ops type initialization to a function. (Jerome Marchand) [RHEL-23649]
- bpftool: Display cookie for kprobe multi link (Jerome Marchand) [RHEL-23649]
- bpftool: Display cookie for perf event link probes (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add fill_link_info test for perf event (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add cookies check for perf_event fill_link_info test (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add cookies check for kprobe_multi fill_link_info test (Jerome Marchand) [RHEL-23649]
- bpf: Store cookies in kprobe_multi bpf_link_info data (Jerome Marchand) [RHEL-23649]
- bpf: Add cookie to perf_event bpf_link_info records (Jerome Marchand) [RHEL-23649]
- bpf: Use r constraint instead of p constraint in selftests (Jerome Marchand) [RHEL-23649]
- bpf: fix constraint in test_tcpbpf_kern.c (Jerome Marchand) [RHEL-23649]
- bpf: avoid VLAs in progs/test_xdp_dynptr.c (Jerome Marchand) [RHEL-23649]
- libbpf: call dup2() syscall directly (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Enable kptr_xchg_inline test for arm64 (Jerome Marchand) [RHEL-23649]
- bpf, arm64: Enable the inline of bpf_kptr_xchg() (Jerome Marchand) [RHEL-23649]
- bpf, docs: Clarify that MOVSX is only for BPF_X not BPF_K (Jerome Marchand) [RHEL-23649]
- bpf: Refactor ptr alu checking rules to allow alu explicitly (Jerome Marchand) [RHEL-23649]
- selftest/bpf: Add map_in_maps with BPF_MAP_TYPE_PERF_EVENT_ARRAY values (Jerome Marchand) [RHEL-23649]
- libbpf: Apply map_set_def_max_entries() for inner_maps on creation (Jerome Marchand) [RHEL-23649]
- bpf: Sync uapi bpf.h header for the tooling infra (Jerome Marchand) [RHEL-23649]
- bpf, docs: Fix bpf_redirect_peer header doc (Jerome Marchand) [RHEL-23649]
- bpftool: Silence build warning about calloc() (Jerome Marchand) [RHEL-23649]
- bpf: Minor improvements for bpf_cmp. (Jerome Marchand) [RHEL-23649]
- docs/bpf: Fix an incorrect statement in verifier.rst (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add a selftest with not-8-byte aligned BPF_ST (Jerome Marchand) [RHEL-23649]
- bpf: Track aligned st store as imprecise spilled registers (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test assigning ID to scalars on spill (Jerome Marchand) [RHEL-23649]
- bpf: Assign ID to scalars on spill (Jerome Marchand) [RHEL-23649]
- bpf: Add the get_reg_width function (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Update LLVM Phabricator links (Jerome Marchand) [RHEL-23649]
- selftests/bpf: detect testing prog flags support (Jerome Marchand) [RHEL-23649]
- Introduce concept of conformance groups (Jerome Marchand) [RHEL-23649]
- bpf: Add the assign_scalar_id_before_mov function (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Add a test case for 32-bit spill tracking (Jerome Marchand) [RHEL-23649]
- bpf: Make bpf_for_each_spilled_reg consider narrow spills (Jerome Marchand) [RHEL-23649]
- selftests/bpf: check if imprecise stack spills confuse infinite loop detection (Jerome Marchand) [RHEL-23649]
- bpf: make infinite loop detection in is_state_visited() exact (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Fix the u64_offset_to_skb_data test (Jerome Marchand) [RHEL-23649]
- bpf: support multiple tags per argument (Jerome Marchand) [RHEL-23649]
- bpf: prepare btf_prepare_func_args() for multiple tags per argument (Jerome Marchand) [RHEL-23649]
- selftests/bpf: fix test_loader check message (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Test the inlining of bpf_kptr_xchg() (Jerome Marchand) [RHEL-23649]
- selftests/bpf: Factor out get_xlated_program() helper (Jerome Marchand) [RHEL-23649]
- bpf: Support inlining bpf_kptr_xchg() helper (Jerome Marchand) [RHEL-23649]
- powerpc/perf: Fix power9 event alternatives (Mamatha Inamdar) [RHEL-56636]
- Revert "mm: disable CONFIG_PER_VMA_LOCK until its fixed" (Rafael Aquini) [RHEL-27743]
- userfaultfd: don't BUG_ON() if khugepaged yanks our page table (Rafael Aquini) [RHEL-27743]
- userfaultfd: fix checks for huge PMDs (Rafael Aquini) [RHEL-27743 RHEL-59459] {CVE-2024-46787}
- x86/shstk: Handle vfork clone failure correctly (Rafael Aquini) [RHEL-27743]
- x86/shstk: Remove useless clone error handling (Rafael Aquini) [RHEL-27743]
- x86/shstk: Delay signal entry SSP write until after user accesses (Rafael Aquini) [RHEL-27743]
- x86/shstk: Make return uprobe work with shadow stack (Rafael Aquini) [RHEL-27743]
- buffer: Make bh_offset() work for compound pages (Rafael Aquini) [RHEL-27743]
- fs: use nth_page() in place of direct struct page manipulation (Rafael Aquini) [RHEL-27743]
- jbd2: Remove page size assumptions (Rafael Aquini) [RHEL-27743]
- selftests/mm/ksm_functional: prevent unmapping undefined address (Rafael Aquini) [RHEL-27743]
- mm/damon/core.c: avoid unintentional filtering out of schemes (Rafael Aquini) [RHEL-27743]
- mm/debug_vm_pgtable: fix BUG_ON with pud advanced test (Rafael Aquini) [RHEL-27743]
- mm/userfaultfd: allow hugetlb change protection upon poison entry (Rafael Aquini) [RHEL-27743]
- highmem: fix a memory copy problem in memcpy_from_folio (Rafael Aquini) [RHEL-27743]
- maple_tree: do not preallocate nodes for slot stores (Rafael Aquini) [RHEL-27743]
- arm64/mm: make set_ptes() robust when OAs cross 48-bit boundary (Rafael Aquini) [RHEL-27743]
- arm64: Mark the 'addr' argument to set_ptes() and __set_pte_at() as unused (Rafael Aquini) [RHEL-27743]
- arm64/mm: Hoist synchronization out of set_ptes() loop (Rafael Aquini) [RHEL-27743]
- arm64/mm: Intercept pfn changes in set_pte_at() (Rafael Aquini) [RHEL-27743]
- selinux: revert our use of vma_is_initial_heap() (Rafael Aquini) [RHEL-27743]
- mm: fix VMA heap bounds checking (Rafael Aquini) [RHEL-27743]
- mm: abstract moving to the next PFN (Rafael Aquini) [RHEL-27743]
- mm: fix old/young bit handling in the faulting path (Rafael Aquini) [RHEL-27743]
- s390/mm: Add NULL pointer check to crst_table_free() base_crst_free() (Rafael Aquini) [RHEL-27743]
- mm/ksm: fix ksm_zero_pages accounting (Rafael Aquini) [RHEL-27743]
- mm/ksm: remove redundant code in ksm_fork (Rafael Aquini) [RHEL-27743]
- mm/ksm: fix ksm_pages_scanned accounting (Rafael Aquini) [RHEL-27743]
- powerpc/vmcore: Add MMU information to vmcoreinfo (Rafael Aquini) [RHEL-27743]
- powerpc/mm: Avoid calling arch_enter/leave_lazy_mmu() in set_ptes (Rafael Aquini) [RHEL-27743]
- powerpc/8xx: fix size given to set_huge_pte_at() (Rafael Aquini) [RHEL-27743]
- mm: add printf attribute to shrinker_debugfs_name_alloc (Rafael Aquini) [RHEL-27743]
- mm: shrinker: add infrastructure for dynamically allocating shrinker (Rafael Aquini) [RHEL-27743]
- mm: shrinker: remove redundant shrinker_rwsem in debugfs operations (Rafael Aquini) [RHEL-27743]
- mm: vmscan: move shrinker-related code into a separate file (Rafael Aquini) [RHEL-27743]
- mm: move some shrinker-related function declarations to mm/internal.h (Rafael Aquini) [RHEL-27743]
- kasan: disable kasan_non_canonical_hook() for HW tags (Rafael Aquini) [RHEL-27743]
- mm/damon/sysfs: check DAMOS regions update progress from before_terminate() (Rafael Aquini) [RHEL-27743]
- mm: fix vm_brk_flags() to not bail out while holding lock (Rafael Aquini) [RHEL-27743]
- arm64: hugetlb: fix set_huge_pte_at() to work with all swap entries (Rafael Aquini) [RHEL-27743]
- mm: hugetlb: add huge page size param to set_huge_pte_at() (Rafael Aquini) [RHEL-27743]
- kasan: Cleanup the __HAVE_ARCH_SHADOW_MAP usage (Rafael Aquini) [RHEL-27743]
- mm: report success more often from filemap_map_folio_range() (Rafael Aquini) [RHEL-27743]
- filemap: add filemap_map_order0_folio() to handle order0 folio (Rafael Aquini) [RHEL-27743]
- slab: kmalloc_size_roundup() must not return 0 for non-zero size (Rafael Aquini) [RHEL-27743]
- kasan: Add (pmd|pud)_init for LoongArch zero_(pud|p4d)_populate process (Rafael Aquini) [RHEL-27743]
- kasan: Add __HAVE_ARCH_SHADOW_MAP to support arch specific mapping (Rafael Aquini) [RHEL-27743]
- kfence: Defer the assignment of the local variable addr (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: use rcu lock instead of tasklist_lock when collect_procs() (Rafael Aquini) [RHEL-27743]
- MAINTAINERS: add rmap.h to mm entry (Rafael Aquini) [RHEL-27743]
- rmap: remove anon_vma_link() nommu stub (Rafael Aquini) [RHEL-27743]
- hugetlb: clear flags in tail pages that will be freed individually (Rafael Aquini) [RHEL-27743]
- hugetlb: add documentation for vma_kernel_pagesize() (Rafael Aquini) [RHEL-27743]
- mm/khugepaged: fix collapse_pte_mapped_thp() versus uffd (Rafael Aquini) [RHEL-27743]
- mm/huge_memory: work on folio->swap instead of page->private when splitting folio (Rafael Aquini) [RHEL-27743]
- mm/swap: inline folio_set_swap_entry() and folio_swap_entry() (Rafael Aquini) [RHEL-27743]
- mm/swap: use dedicated entry for swap in folio (Rafael Aquini) [RHEL-27743]
- mm/swap: stop using page->private on tail pages for THP_SWAP (Rafael Aquini) [RHEL-27743]
- memcg: remove duplication detection for mem_cgroup_uncharge_swap (Rafael Aquini) [RHEL-27743]
- mm: remove checks for pte_index (Rafael Aquini) [RHEL-27743]
- mm/pgtable: define pte_index so that preprocessor could recognize it (Rafael Aquini) [RHEL-27743]
- mm: remove enum page_entry_size (Rafael Aquini) [RHEL-27743]
- mm: allow ->huge_fault() to be called without the mmap_lock held (Rafael Aquini) [RHEL-27743]
- mm: move PMD_ORDER to pgtable.h (Rafael Aquini) [RHEL-27743]
- mm: add orphaned kernel-doc to the rst files. (Rafael Aquini) [RHEL-27743]
- mm: fix clean_record_shared_mapping_range kernel-doc (Rafael Aquini) [RHEL-27743]
- mm: fix get_mctgt_type() kernel-doc (Rafael Aquini) [RHEL-27743]
- mm: fix kernel-doc warning from tlb_flush_rmaps() (Rafael Aquini) [RHEL-27743]
- mm: convert split_huge_pages_pid() to use a folio (Rafael Aquini) [RHEL-27743]
- mm: add tail private fields to struct folio (Rafael Aquini) [RHEL-27743]
- mm: remove folio_test_transhuge() (Rafael Aquini) [RHEL-27743]
- mm: free up a word in the first tail page (Rafael Aquini) [RHEL-27743]
- mm: rearrange page flags (Rafael Aquini) [RHEL-27743]
- mm: add large_rmappable page flag (Rafael Aquini) [RHEL-27743]
- mm: remove HUGETLB_PAGE_DTOR (Rafael Aquini) [RHEL-27743]
- mm: remove free_compound_page() and the compound_page_dtors array (Rafael Aquini) [RHEL-27743]
- mm: convert prep_transhuge_page() to folio_prep_large_rmappable() (Rafael Aquini) [RHEL-27743]
- mm: convert free_transhuge_folio() to folio_undo_large_rmappable() (Rafael Aquini) [RHEL-27743]
- mm: convert free_huge_page() to free_huge_folio() (Rafael Aquini) [RHEL-27743]
- mm: call free_huge_page() directly (Rafael Aquini) [RHEL-27743]
- pagemap: remove wait_on_page_locked_killable() (Rafael Aquini) [RHEL-27743]
- mm/z3fold: remove obsolete comment for struct z3fold_pool (Rafael Aquini) [RHEL-27743]
- mm,thp: fix smaps THPeligible output alignment (Rafael Aquini) [RHEL-27743]
- mm,thp: no space after colon in Mem-Info fields (Rafael Aquini) [RHEL-27743]
- net-memcg: Fix scope of sockmem pressure indicators (Rafael Aquini) [RHEL-27743]
- mm/secretmem: use a folio in secretmem_fault() (Rafael Aquini) [RHEL-27743]
- mm: allow fault_dirty_shared_page() to be called under the VMA lock (Rafael Aquini) [RHEL-27743]
- mm/ksm: add pages scanned metric (Rafael Aquini) [RHEL-27743]
- mm/page_alloc: use get_pfnblock_migratetype to avoid extra page_to_pfn (Rafael Aquini) [RHEL-27743]
- mm/page_alloc: remove unnecessary inner __get_pfnblock_flags_mask (Rafael Aquini) [RHEL-27743]
- tmpfs: trivial support for direct IO (Rafael Aquini) [RHEL-27743]
- mm: page_alloc: remove unused parameter from reserve_highatomic_pageblock() (Rafael Aquini) [RHEL-27743]
- mm: invalidation check mapping before folio_contains (Rafael Aquini) [RHEL-27743]
- tmpfs: track free_ispace instead of free_inodes (Rafael Aquini) [RHEL-27743]
- xattr: simple_xattr_set() return old_xattr to be freed (Rafael Aquini) [RHEL-27743]
- writeback: remove redundant checks for root memcg (Rafael Aquini) [RHEL-27743]
- mm: zswap: update comment for struct zswap_entry (Rafael Aquini) [RHEL-27743]
- mm: memtest: convert to memtest_report_meminfo() (Rafael Aquini) [RHEL-27743]
- mm: remove pgtable_{pmd, pte}_page_{ctor, dtor}() wrappers (Rafael Aquini) [RHEL-27743]
- um: convert {pmd, pte}_free_tlb() to use ptdescs (Rafael Aquini) [RHEL-27743]
- arm64: convert various functions to use ptdescs (Rafael Aquini) [RHEL-27743]
- arm: convert various functions to use ptdescs (Rafael Aquini) [RHEL-27743]
- pgalloc: convert various functions to use ptdescs (Rafael Aquini) [RHEL-27743]
- asm-generic: Prepare for riscv use of pud_alloc_one and pud_free (Rafael Aquini) [RHEL-27743]
- mm: remove page table members from struct page (Rafael Aquini) [RHEL-27743]
- s390: convert various pgalloc functions to use ptdescs (Rafael Aquini) [RHEL-27743]
- x86: convert various functions to use ptdescs (Rafael Aquini) [RHEL-27743]
- powerpc: convert various functions to use ptdescs (Rafael Aquini) [RHEL-27743]
- mm: create ptdesc equivalents for pgtable_{pte,pmd}_page_{ctor,dtor} (Rafael Aquini) [RHEL-27743]
- mm: convert ptlock_free() to use ptdescs (Rafael Aquini) [RHEL-27743]
- mm: convert pmd_ptlock_free() to use ptdescs (Rafael Aquini) [RHEL-27743]
- mm: convert ptlock_init() to use ptdescs (Rafael Aquini) [RHEL-27743]
- mm: convert pmd_ptlock_init() to use ptdescs (Rafael Aquini) [RHEL-27743]
- mm: convert ptlock_ptr() to use ptdescs (Rafael Aquini) [RHEL-27743]
- mm: convert ptlock_alloc() to use ptdescs (Rafael Aquini) [RHEL-27743]
- mm: convert pmd_pgtable_page() callers to use pmd_ptdesc() (Rafael Aquini) [RHEL-27743]
- mm: add utility functions for ptdesc (Rafael Aquini) [RHEL-27743]
- pgtable: create struct ptdesc (Rafael Aquini) [RHEL-27743]
- mm: add PAGE_TYPE_OP folio functions (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: use helper macro llist_for_each_entry_safe() (Rafael Aquini) [RHEL-27743]
- mm/mm_init: use helper macro BITS_PER_LONG and BITS_PER_BYTE (Rafael Aquini) [RHEL-27743]
- mm/compaction: remove unused parameter pgdata of fragmentation_score_wmark (Rafael Aquini) [RHEL-27743]
- mm/compaction: only set skip flag if cc->no_set_skip_hint is false (Rafael Aquini) [RHEL-27743]
- mm/compaction: remove unnecessary return for void function (Rafael Aquini) [RHEL-27743]
- mm/compaction: correct comment to complete migration failure (Rafael Aquini) [RHEL-27743]
- mm/compaction: correct comment of cached migrate pfn update (Rafael Aquini) [RHEL-27743]
- mm/compaction: correct comment of fast_find_migrateblock in isolate_migratepages (Rafael Aquini) [RHEL-27743]
- mm/compaction: skip page block marked skip in isolate_migratepages_block (Rafael Aquini) [RHEL-27743]
- mm/compaction: correct last_migrated_pfn update in compact_zone (Rafael Aquini) [RHEL-27743]
- mm/compaction: remove unnecessary "else continue" at end of loop in isolate_freepages_block (Rafael Aquini) [RHEL-27743]
- mm/compaction: remove unnecessary cursor page in isolate_freepages_block (Rafael Aquini) [RHEL-27743]
- mm/compaction: merge end_pfn boundary check in isolate_freepages_range (Rafael Aquini) [RHEL-27743]
- mm/compaction: set compact_cached_free_pfn correctly in update_pageblock_skip (Rafael Aquini) [RHEL-27743]
- mm/compaction: avoid unneeded pageblock_end_pfn when no_set_skip_hint is set (Rafael Aquini) [RHEL-27743]
- mm/compaction: correct comment of candidate pfn in fast_isolate_freepages (Rafael Aquini) [RHEL-27743]
- mm: compaction: skip the memory hole rapidly when isolating free pages (Rafael Aquini) [RHEL-27743]
- mm: compaction: use the correct type of list for free pages (Rafael Aquini) [RHEL-27743]
- mm: no need to export mm_kobj (Rafael Aquini) [RHEL-27743]
- mm/hugetlb.c: use helper macro K() (Rafael Aquini) [RHEL-27743]
- mm/mmap.c: use helper macro K() (Rafael Aquini) [RHEL-27743]
- mm/nommu.c: use helper macro K() (Rafael Aquini) [RHEL-27743]
- mm/shmem.c: use helper macro K() (Rafael Aquini) [RHEL-27743]
- mm/swap_state.c: use helper macro K() (Rafael Aquini) [RHEL-27743]
- mm/swapfile.c: use helper macro K() (Rafael Aquini) [RHEL-27743]
- mm: remove redundant K() macro definition (Rafael Aquini) [RHEL-27743]
- selftest/mm: ksm_functional_tests: Add PROT_NONE test (Rafael Aquini) [RHEL-27743]
- selftest/mm: ksm_functional_tests: test in mmap_and_merge_range() if anything got merged (Rafael Aquini) [RHEL-27743]
- selftest: add a testcase of ksm zero pages (Rafael Aquini) [RHEL-27743]
- pgtable: improve pte_protnone() comment (Rafael Aquini) [RHEL-27743]
- mm/gup: don't implicitly set FOLL_HONOR_NUMA_FAULT (Rafael Aquini) [RHEL-27743]
- kvm: explicitly set FOLL_HONOR_NUMA_FAULT in hva_to_pfn_slow() (Rafael Aquini) [RHEL-27743]
- mm/memcg: fix wrong function name above obj_cgroup_charge_zswap() (Rafael Aquini) [RHEL-27743]
- mm/page_alloc: remove unneeded variable base (Rafael Aquini) [RHEL-27743]
- mm/z3fold: use helper function put_z3fold_locked() and put_z3fold_locked_list() (Rafael Aquini) [RHEL-27743]
- Docs/ABI/damon: update for DAMON monitoring target type DAMOS filter (Rafael Aquini) [RHEL-27743]
- selftests/damon/sysfs: test damon_target filter (Rafael Aquini) [RHEL-27743]
- mm/damon/sysfs-schemes: support target damos filter (Rafael Aquini) [RHEL-27743]
- mm/damon/core: implement target type damos filter (Rafael Aquini) [RHEL-27743]
- Docs/ABI/damon: update for address range DAMOS filter (Rafael Aquini) [RHEL-27743]
- selftests/damon/sysfs: test address range damos filter (Rafael Aquini) [RHEL-27743]
- mm/damon/core-test: add a unit test for __damos_filter_out() (Rafael Aquini) [RHEL-27743]
- mm/damon/sysfs-schemes: support address range type DAMOS filter (Rafael Aquini) [RHEL-27743]
- mm/damon/core: introduce address range type damos filter (Rafael Aquini) [RHEL-27743]
- mm/damon/core: update kernel-doc comments for DAMOS filters supports of each DAMON operations set (Rafael Aquini) [RHEL-27743]
- Docs/ABI/damon: update for tried_regions/total_bytes (Rafael Aquini) [RHEL-27743]
- selftests/damon/sysfs: test tried_regions/total_bytes file (Rafael Aquini) [RHEL-27743]
- mm/damon/sysfs: implement a command for updating only schemes tried total bytes (Rafael Aquini) [RHEL-27743]
- mm/damon/sysfs-schemes: implement DAMOS tried total bytes file (Rafael Aquini) [RHEL-27743]
- mm: call update_mmu_cache_range() in more page fault handling paths (Rafael Aquini) [RHEL-27743]
- filemap: batch PTE mappings (Rafael Aquini) [RHEL-27743]
- mm: convert do_set_pte() to set_pte_range() (Rafael Aquini) [RHEL-27743]
- rmap: add folio_add_file_rmap_range() (Rafael Aquini) [RHEL-27743]
- filemap: add filemap_map_folio_range() (Rafael Aquini) [RHEL-27743]
- ceph: switch back to testing for NULL folio->private in ceph_dirty_folio (Rafael Aquini) [RHEL-27743]
- ceph: check folio PG_private bit instead of folio->private (Rafael Aquini) [RHEL-27743]
- mm: use flush_icache_pages() in do_set_pmd() (Rafael Aquini) [RHEL-27743]
- mm: tidy up set_ptes definition (Rafael Aquini) [RHEL-27743]
- mm: rationalise flush_icache_pages() and flush_icache_page() (Rafael Aquini) [RHEL-27743]
- mm: remove page_mapping_file() (Rafael Aquini) [RHEL-27743]
- x86: implement the new page table range API (Rafael Aquini) [RHEL-27743]
- um: implement the new page table range API (Rafael Aquini) [RHEL-27743]
- um/mm: support __HAVE_ARCH_PTE_SWP_EXCLUSIVE (Rafael Aquini) [RHEL-27743]
- s390: implement the new page table range API (Rafael Aquini) [RHEL-27743]
- powerpc: implement the new page table range API (Rafael Aquini) [RHEL-27743]
- powerpc/book3s: Inline first level of update_mmu_cache() (Rafael Aquini) [RHEL-27743]
- arm64: implement the new page table range API (Rafael Aquini) [RHEL-27743]
- arm: implement the new page table range API (Rafael Aquini) [RHEL-27743]
- mm: add default definition of set_ptes() (Rafael Aquini) [RHEL-27743]
- mm: remove ARCH_IMPLEMENTS_FLUSH_DCACHE_FOLIO (Rafael Aquini) [RHEL-27743]
- mm: add folio_flush_mapping() (Rafael Aquini) [RHEL-27743]
- mm: add generic flush_icache_pages() and documentation (Rafael Aquini) [RHEL-27743]
- mm: convert page_table_check_pte_set() to page_table_check_ptes_set() (Rafael Aquini) [RHEL-27743]
- minmax: add in_range() macro (Rafael Aquini) [RHEL-27743]
- mm: disable kernelcore=mirror when no mirror memory (Rafael Aquini) [RHEL-27743]
- tmpfs: verify {g,u}id mount options correctly (Rafael Aquini) [RHEL-27743]
- mm/memcg: update obsolete comment above parent_mem_cgroup() (Rafael Aquini) [RHEL-27743]
- mm/page_alloc: avoid unneeded alike_pages calculation (Rafael Aquini) [RHEL-27743]
- mm: hugetlb: use flush_hugetlb_tlb_range() in move_hugetlb_page_tables() (Rafael Aquini) [RHEL-27743]
- mm/damon/core-test: add a test for damos_new_filter() (Rafael Aquini) [RHEL-27743]
- perf/core: use vma_is_initial_stack() and vma_is_initial_heap() (Rafael Aquini) [RHEL-27743]
- selinux: use vma_is_initial_stack() and vma_is_initial_heap() (Rafael Aquini) [RHEL-27743]
- mm: factor out VMA stack and heap checks (Rafael Aquini) [RHEL-27743]
- mm/percpu.c: print error message too if atomic alloc failed (Rafael Aquini) [RHEL-27743]
- mm/percpu.c: optimize the code in pcpu_setup_first_chunk() a little bit (Rafael Aquini) [RHEL-27743]
- mm/percpu.c: remove redundant check (Rafael Aquini) [RHEL-27743]
- mm/percpu: Remove some local variables in pcpu_populate_pte (Rafael Aquini) [RHEL-27743]
- damon: use pmdp_get instead of drectly dereferencing pmd (Rafael Aquini) [RHEL-27743]
- mm/memcg: fix obsolete function name in mem_cgroup_protection() (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: add PageOffline() check (Rafael Aquini) [RHEL-27743]
- mm/memory.c: fix some kernel-doc comments (Rafael Aquini) [RHEL-27743]
- mm: kmsan: use helper macros PAGE_ALIGN and PAGE_ALIGN_DOWN (Rafael Aquini) [RHEL-27743]
- mm: kmsan: use helper macro offset_in_page() (Rafael Aquini) [RHEL-27743]
- mm: kmsan: use helper function page_size() (Rafael Aquini) [RHEL-27743]
- powerpc/book3s64/radix: add debug message to give more details of vmemmap allocation (Rafael Aquini) [RHEL-27743]
- powerpc/book3s64/radix: remove mmu_vmemmap_psize (Rafael Aquini) [RHEL-27743]
- powerpc/book3s64/radix: add support for vmemmap optimization for radix (Rafael Aquini) [RHEL-27743]
- powerpc: Select ARCH_WANTS_MODULES_DATA_IN_VMALLOC on book3s/32 and 8xx (Rafael Aquini) [RHEL-27743]
- powerpc/book3s64/vmemmap: switch radix to use a different vmemmap handling function (Rafael Aquini) [RHEL-27743]
- powerpc/book3s64/mm: Fix DirectMap stats in /proc/meminfo (Rafael Aquini) [RHEL-27743]
- powerpc/book3s64/mm: Use PAGE_KERNEL instead of opencoding (Rafael Aquini) [RHEL-27743]
- powerpc/mm/dax: Fix the condition when checking if altmap vmemap can cross-boundary (Rafael Aquini) [RHEL-27743]
- powerpc: Fix pud_mkwrite() definition after pte_mkwrite() API changes (Rafael Aquini) [RHEL-27743]
- powerpc/book3s64/mm: enable transparent pud hugepage (Rafael Aquini) [RHEL-27743]
- powerpc/mm/trace: convert trace event to trace event class (Rafael Aquini) [RHEL-27743]
- powerpc/mm/book3s64: Use pmdp_ptep helper instead of typecasting. (Rafael Aquini) [RHEL-27743]
- mm/vmemmap optimization: split hugetlb and devdax vmemmap optimization (Rafael Aquini) [RHEL-27743]
- Randomized slab caches for kmalloc() (Rafael Aquini) [RHEL-27743]
- percpu: adjust the value of PERCPU_DYNAMIC_EARLY_SIZE (Rafael Aquini) [RHEL-27743]
- mm: make MEMFD_CREATE into a selectable config option (Rafael Aquini) [RHEL-27743]
- mm/huge pud: use transparent huge pud helpers only with CONFIG_TRANSPARENT_HUGEPAGE (Rafael Aquini) [RHEL-27743]
- mm: add pud_same similar to __HAVE_ARCH_P4D_SAME (Rafael Aquini) [RHEL-27743]
- mm/vmemmap: allow architectures to override how vmemmap optimization works (Rafael Aquini) [RHEL-27743]
- mm/vmemmap: improve vmemmap_can_optimize and allow architectures to override (Rafael Aquini) [RHEL-27743]
- mm: change pudp_huge_get_and_clear_full take vm_area_struct as arg (Rafael Aquini) [RHEL-27743]
- mm/hugepage pud: allow arch-specific helper function to check huge page pud support (Rafael Aquini) [RHEL-27743]
- mm/thp: simplify has_transparent_hugepage by using IS_BUILTIN (Rafael Aquini) [RHEL-27743]
- mm: handle faults that merely update the accessed bit under the VMA lock (Rafael Aquini) [RHEL-27743]
- mm: handle swap and NUMA PTE faults under the VMA lock (Rafael Aquini) [RHEL-27743]
- mm: run the fault-around code under the VMA lock (Rafael Aquini) [RHEL-27743]
- mm: move FAULT_FLAG_VMA_LOCK check down from do_fault() (Rafael Aquini) [RHEL-27743]
- mm: move FAULT_FLAG_VMA_LOCK check down in handle_pte_fault() (Rafael Aquini) [RHEL-27743]
- mm: handle some PMD faults under the VMA lock (Rafael Aquini) [RHEL-27743]
- mm: handle PUD faults under the VMA lock (Rafael Aquini) [RHEL-27743]
- mm: move FAULT_FLAG_VMA_LOCK check from handle_mm_fault() (Rafael Aquini) [RHEL-27743]
- mm: allow per-VMA locks on file-backed VMAs (Rafael Aquini) [RHEL-27743]
- mm/mmap: change vma iteration order in do_vmi_align_munmap() (Rafael Aquini) [RHEL-27743]
- maple_tree: reduce resets during store setup (Rafael Aquini) [RHEL-27743]
- maple_tree: refine mas_preallocate() node calculations (Rafael Aquini) [RHEL-27743]
- maple_tree: update mas_preallocate() testing (Rafael Aquini) [RHEL-27743]
- maple_tree: move mas_wr_end_piv() below mas_wr_extend_null() (Rafael Aquini) [RHEL-27743]
- mm: set up vma iterator for vma_iter_prealloc() calls (Rafael Aquini) [RHEL-27743]
- mm: use vma_iter_clear_gfp() in nommu (Rafael Aquini) [RHEL-27743]
- maple_tree: adjust node allocation on mas_rebalance() (Rafael Aquini) [RHEL-27743]
- maple_tree: re-introduce entry to mas_preallocate() arguments (Rafael Aquini) [RHEL-27743]
- mm: remove re-walk from mmap_region() (Rafael Aquini) [RHEL-27743]
- maple_tree: introduce __mas_set_range() (Rafael Aquini) [RHEL-27743]
- mm: remove prev check from do_vmi_align_munmap() (Rafael Aquini) [RHEL-27743]
- mm: change do_vmi_align_munmap() tracking of VMAs to remove (Rafael Aquini) [RHEL-27743]
- maple_tree: add benchmarking for mas_prev() (Rafael Aquini) [RHEL-27743]
- maple_tree: add benchmarking for mas_for_each (Rafael Aquini) [RHEL-27743]
- mm/mprotect: fix obsolete function name in change_pte_range() (Rafael Aquini) [RHEL-27743]
- mm/page_io: convert bio_associate_blkg_from_page() to take in a folio (Rafael Aquini) [RHEL-27743]
- mm/page_io: convert count_swpout_vm_event() to take in a folio (Rafael Aquini) [RHEL-27743]
- mm/page_io: use a folio in swap_writepage_bdev_async() (Rafael Aquini) [RHEL-27743]
- mm/page_io: use a folio in swap_writepage_bdev_sync() (Rafael Aquini) [RHEL-27743]
- mm/page_io: use a folio in sio_read_complete() (Rafael Aquini) [RHEL-27743]
- mm/page_io: use a folio in __end_swap_bio_read() (Rafael Aquini) [RHEL-27743]
- mm/page_io: use a folio in __end_swap_bio_write() (Rafael Aquini) [RHEL-27743]
- mm/page_io: remove unneeded SetPageError() (Rafael Aquini) [RHEL-27743]
- mm/page_io: remove unneeded ClearPageUptodate() (Rafael Aquini) [RHEL-27743]
- mm/page_io: introduce bio_first_folio_all() (Rafael Aquini) [RHEL-27743]
- mm: fix obsolete function name above debug_pagealloc_enabled_static() (Rafael Aquini) [RHEL-27743]
- mm/hugetlb: get rid of page_hstate() (Rafael Aquini) [RHEL-27743]
- mm/page_ext: use page_ext_data helper in page_owner (Rafael Aquini) [RHEL-27743]
- mm/page_ext: use page_ext_data helper in page_table_check (Rafael Aquini) [RHEL-27743]
- mm/page_ext: add common function to get client data from page_ext (Rafael Aquini) [RHEL-27743]
- mm/rmap: correct stale comment of rmap_walk_anon and rmap_walk_file (Rafael Aquini) [RHEL-27743]
- mm: kfence: allocate kfence_metadata at runtime (Rafael Aquini) [RHEL-27743]
- mm/tlbbatch: introduce arch_flush_tlb_batched_pending() (Rafael Aquini) [RHEL-27743]
- mm/tlbbatch: rename and extend some functions (Rafael Aquini) [RHEL-27743]
- mm/tlbbatch: introduce arch_tlbbatch_should_defer() (Rafael Aquini) [RHEL-27743]
- mm/memcg: minor cleanup for mc_handle_present_pte() (Rafael Aquini) [RHEL-27743]
- mm/page_ext: move page_ext_operations definition under CONFIG_PAGE_EXTENSION (Rafael Aquini) [RHEL-27743]
- mm/vmstat: remove unused page_ext.h from vmstat (Rafael Aquini) [RHEL-27743]
- mm/page_poison: remove unused page_ext.h from page_poison (Rafael Aquini) [RHEL-27743]
- mm/mm_init.c: drop node_start_pfn from adjust_zone_range_for_zone_movable() (Rafael Aquini) [RHEL-27743]
- mm/mmap: change detached vma locking scheme (Rafael Aquini) [RHEL-27743]
- maple_tree: relax lockdep checks for on-stack trees (Rafael Aquini) [RHEL-27743]
- mm/mmap: clean up validate_mm() calls (Rafael Aquini) [RHEL-27743]
- mm/page_ext: move functions around for minor cleanups to page_ext (Rafael Aquini) [RHEL-27743]
- mm/page_ext: remove rollback for untouched mem_section in online_page_ext (Rafael Aquini) [RHEL-27743]
- mm/page_ext: remove unused return value of offline_page_ext (Rafael Aquini) [RHEL-27743]
- mm/hwpoison: rename hwp_walk* to hwpoison_walk* (Rafael Aquini) [RHEL-27743]
- mm/page_table_check: remove unused parameter in [__]page_table_check_pud_set (Rafael Aquini) [RHEL-27743]
- mm/page_table_check: remove unused parameter in [__]page_table_check_pmd_set (Rafael Aquini) [RHEL-27743]
- mm/page_table_check: remove unused parameter in [__]page_table_check_pte_set (Rafael Aquini) [RHEL-27743]
- mm/page_table_check: remove unused parameter in [__]page_table_check_pud_clear (Rafael Aquini) [RHEL-27743]
- mm/page_table_check: remove unused parameter in [__]page_table_check_pmd_clear (Rafael Aquini) [RHEL-27743]
- mm/page_table_check: remove unused parameter in [__]page_table_check_pte_clear (Rafael Aquini) [RHEL-27743]
- mm/page_table_check: remove unused parameters in page_table_check_set() (Rafael Aquini) [RHEL-27743]
- mm/page_table_check: remove unused parameters in page_table_check_clear() (Rafael Aquini) [RHEL-27743]
- mm/memcg: fix obsolete comment above MEM_CGROUP_MAX_RECLAIM_LOOPS (Rafael Aquini) [RHEL-27743]
- mm/huge_memory: use RMAP_NONE when calling page_add_anon_rmap() (Rafael Aquini) [RHEL-27743]
- jbd2: use a folio in jbd2_journal_write_metadata_buffer() (Rafael Aquini) [RHEL-27743]
- migrate: use folio_set_bh() instead of set_bh_page() (Rafael Aquini) [RHEL-27743]
- fs/buffer: convert create_page_buffers to folio_create_buffers (Rafael Aquini) [RHEL-27743]
- fs/buffer: add folio_create_empty_buffers helper (Rafael Aquini) [RHEL-27743]
- buffer: add folio_alloc_buffers() helper (Rafael Aquini) [RHEL-27743]
- fs/buffer: add folio_set_bh helper (Rafael Aquini) [RHEL-27743]
- highmem: add memcpy_to_folio() and memcpy_from_folio() (Rafael Aquini) [RHEL-27743]
- selftests/mm: add tests for HWPOISON hugetlbfs read (Rafael Aquini) [RHEL-27743]
- hugetlbfs: improve read HWPOISON hugepage (Rafael Aquini) [RHEL-27743]
- mm/hwpoison: check if a raw page in a hugetlb folio is raw HWPOISON (Rafael Aquini) [RHEL-27743]
- mm/hwpoison: delete all entries before traversal in __folio_free_raw_hwp (Rafael Aquini) [RHEL-27743]
- mm/mmap: move vma operations to mm_struct out of the critical section of file mapping lock (Rafael Aquini) [RHEL-27743]
- mm: remove clear_page_idle() (Rafael Aquini) [RHEL-27743]
- mm: delete mmap_write_trylock() and vma_try_start_write() (Rafael Aquini) [RHEL-27743]
- mm/pgtable: notes on pte_offset_map[_lock]() (Rafael Aquini) [RHEL-27743]
- mm/khugepaged: delete khugepaged_collapse_pte_mapped_thps() (Rafael Aquini) [RHEL-27743]
- mm/khugepaged: collapse_pte_mapped_thp() with mmap_read_lock() (Rafael Aquini) [RHEL-27743]
- mm/khugepaged: retract_page_tables() without mmap or vma lock (Rafael Aquini) [RHEL-27743]
- mm/pgtable: add pte_free_defer() for pgtable as page (Rafael Aquini) [RHEL-27743]
- s390: add pte_free_defer() for pgtables sharing page (Rafael Aquini) [RHEL-27743]
- sparc: add pte_free_defer() for pte_t *pgtable_t (Rafael Aquini) [RHEL-27743]
- powerpc: add pte_free_defer() for pgtables sharing page (Rafael Aquini) [RHEL-27743]
- powerpc: assert_pte_locked() use pte_offset_map_nolock() (Rafael Aquini) [RHEL-27743]
- mm/pgtable: add PAE safety to __pte_offset_map() (Rafael Aquini) [RHEL-27743]
- mm/pgtable: add rcu_read_lock() and rcu_read_unlock()s (Rafael Aquini) [RHEL-27743]
- mm: userfaultfd: add new UFFDIO_POISON ioctl: fix (Rafael Aquini) [RHEL-27743]
- mm/memory_hotplug: document the signal_pending() check in offline_pages() (Rafael Aquini) [RHEL-27743]
- mm/slub: remove freelist_dereference() (Rafael Aquini) [RHEL-27743]
- mm/slub: remove redundant kasan_reset_tag() from freelist_ptr calculations (Rafael Aquini) [RHEL-27743]
- mm/slub: refactor freelist to use custom type (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: fix race window when trying to get hugetlb folio (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: fetch compound head after extra page refcnt is held (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: minor cleanup for comments and codestyle (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: remove unneeded header files (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: use local variable huge to check hugetlb page (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: don't account hwpoison_filter() filtered pages (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: ensure moving HWPoison flag to the raw error pages (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: remove unneeded PageHuge() check (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: fix potential page refcnt leak in memory_failure() (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: remove unneeded page state check in shake_page() (Rafael Aquini) [RHEL-27743]
- mm: memory-failure: remove unneeded 'inline' annotation (Rafael Aquini) [RHEL-27743]
- mm/memory: pass folio into do_page_mkwrite() (Rafael Aquini) [RHEL-27743]
- mm/mm_init.c: mark check_for_memory() as __init (Rafael Aquini) [RHEL-27743]
- mm/mm_init.c: update obsolete comment in get_pfn_range_for_nid() (Rafael Aquini) [RHEL-27743]
- mm/mm_init.c: remove obsolete macro HASH_SMALL (Rafael Aquini) [RHEL-27743]
- zsmalloc: remove obj_tagged() (Rafael Aquini) [RHEL-27743]
- zsmalloc: remove zs_compact_control (Rafael Aquini) [RHEL-27743]
- zsmalloc: move migration destination zspage inuse check (Rafael Aquini) [RHEL-27743]
- zsmalloc: do not scan for allocated objects in empty zspage (Rafael Aquini) [RHEL-27743]
- mm-make-pte_marker_swapin_error-more-general-fix (Rafael Aquini) [RHEL-27743]
- mm/memcg: minor cleanup for MEM_CGROUP_ID_MAX (Rafael Aquini) [RHEL-27743]
- selftests/mm: add uffd unit test for UFFDIO_POISON (Rafael Aquini) [RHEL-27743]
- selftests/mm: refactor uffd_poll_thread to allow custom fault handlers (Rafael Aquini) [RHEL-27743]
- mm: userfaultfd: document and enable new UFFDIO_POISON feature (Rafael Aquini) [RHEL-27743]
- mm: userfaultfd: support UFFDIO_POISON for hugetlbfs (Rafael Aquini) [RHEL-27743]
- mm: userfaultfd: add new UFFDIO_POISON ioctl (Rafael Aquini) [RHEL-27743]
- mm: userfaultfd: extract file size check out into a helper (Rafael Aquini) [RHEL-27743]
- mm: userfaultfd: check for start + len overflow in validate_range (Rafael Aquini) [RHEL-27743]
- mm: make PTE_MARKER_SWAPIN_ERROR more general (Rafael Aquini) [RHEL-27743]
- mm: correct stale comment of function check_pte (Rafael Aquini) [RHEL-27743]
- mm: fix some kernel-doc comments (Rafael Aquini) [RHEL-27743]
- mm/sparse: remove redundant judgments from macro for_each_present_section_nr (Rafael Aquini) [RHEL-27743]
- x86/shstk: Move arch detail comment out of core mm (Rafael Aquini) [RHEL-27743]
- rmap: pass the folio to __page_check_anon_rmap() (Rafael Aquini) [RHEL-27743]
- mm: cma: print cma name as well in cma_alloc debug (Rafael Aquini) [RHEL-27743]
- mm/memory: convert do_read_fault() to use folios (Rafael Aquini) [RHEL-27743]
- mm/memory: convert do_shared_fault() to folios (Rafael Aquini) [RHEL-27743]
- mm/memory: convert wp_page_shared() to use folios (Rafael Aquini) [RHEL-27743]
- mm/memory: convert do_page_mkwrite() to use folios (Rafael Aquini) [RHEL-27743]
- mm: ioremap: remove unneeded ioremap_allowed and iounmap_allowed (Rafael Aquini) [RHEL-27743]
- arm64 : mm: add wrapper function ioremap_prot() (Rafael Aquini) [RHEL-27743]
- mm: move is_ioremap_addr() into new header file (Rafael Aquini) [RHEL-27743]
- mm/ioremap: consider IOREMAP space in generic ioremap (Rafael Aquini) [RHEL-27743]
- s390: mm: convert to GENERIC_IOREMAP (Rafael Aquini) [RHEL-27743]
- mm/ioremap: add slab availability checking in ioremap_prot (Rafael Aquini) [RHEL-27743]
- mm: ioremap: allow ARCH to have its own ioremap method definition (Rafael Aquini) [RHEL-27743]
- mm/ioremap: define generic_ioremap_prot() and generic_iounmap() (Rafael Aquini) [RHEL-27743]
- shmem: convert to ctime accessor functions (Rafael Aquini) [RHEL-27743]
- shmem: convert to simple_rename_timestamp (Rafael Aquini) [RHEL-27743]
- fs: new helper: simple_rename_timestamp (Rafael Aquini) [RHEL-27743]
- mm: page_alloc: avoid false page outside zone error info (Rafael Aquini) [RHEL-27743]
- mm: remove page_rmapping() (Rafael Aquini) [RHEL-27743]
- mm: use a folio in fault_dirty_shared_page() (Rafael Aquini) [RHEL-27743]
- mm: handle userfaults under VMA lock (Rafael Aquini) [RHEL-27743]
- mm/memory.c: fix mismerge (Rafael Aquini) [RHEL-27743]
- mm: handle swap page faults under per-VMA lock (Rafael Aquini) [RHEL-27743]
- mm: move dummy_vm_ops out of a header (Rafael Aquini) [RHEL-27743]
- mm: remove CONFIG_PER_VMA_LOCK ifdefs (Rafael Aquini) [RHEL-27743]
- mm: change folio_lock_or_retry to use vm_fault directly (Rafael Aquini) [RHEL-27743]
- mm: drop per-VMA lock when returning VM_FAULT_RETRY or VM_FAULT_COMPLETED (Rafael Aquini) [RHEL-27743]
- powerc/mm: try VMA lock-based page fault handling first (Rafael Aquini) [RHEL-27743]
- x86/mm: Check shadow stack page fault errors (Rafael Aquini) [RHEL-27743]
- s390/mm: fix per vma lock fault handling (Rafael Aquini) [RHEL-27743]
- s390/mm: try VMA lock-based page fault handling first (Rafael Aquini) [RHEL-27743]
- mm: add missing VM_FAULT_RESULT_TRACE name for VM_FAULT_COMPLETED (Rafael Aquini) [RHEL-27743]
- mm: make show_free_areas() static (Rafael Aquini) [RHEL-27743]
- mm: remove arguments of show_mem() (Rafael Aquini) [RHEL-27743]
- init/initramfs: Fix argument forwarding to panic() in panic_show_mem() (Rafael Aquini) [RHEL-27743]
- mm/gup: retire follow_hugetlb_page() (Rafael Aquini) [RHEL-27743]
- mm/gup: accelerate thp gup even for "pages != NULL" (Rafael Aquini) [RHEL-27743]
- mm/gup: cleanup next_page handling (Rafael Aquini) [RHEL-27743]
- mm/hugetlb: add page_mask for hugetlb_follow_page_mask() (Rafael Aquini) [RHEL-27743]
- mm/hugetlb: prepare hugetlb_follow_page_mask() for FOLL_PIN (Rafael Aquini) [RHEL-27743]
- mm/hugetlb: handle FOLL_DUMP well in follow_page_mask() (Rafael Aquini) [RHEL-27743]
- mm: remove folio_account_redirty (Rafael Aquini) [RHEL-27743]
- mm: increase usage of folio_next_index() helper (Rafael Aquini) [RHEL-27743]
- mm: zswap: multiple zpools support (Rafael Aquini) [RHEL-27743]
- ksm: consider KSM-placed zeropages when calculating KSM profit (Rafael Aquini) [RHEL-27743]
- ksm: add ksm zero pages for each process (Rafael Aquini) [RHEL-27743]
- ksm: count all zero pages placed by KSM (Rafael Aquini) [RHEL-27743]
- ksm: support unsharing KSM-placed zero pages (Rafael Aquini) [RHEL-27743]
- selftests/x86: Add shadow stack test (Rafael Aquini) [RHEL-27743]
- x86/shstk: Wire in shadow stack interface (Rafael Aquini) [RHEL-27743]
- x86/shstk: Support WRSS for userspace (Rafael Aquini) [RHEL-27743]
- x86/shstk: Introduce map_shadow_stack syscall (Rafael Aquini) [RHEL-27743]
- x86/shstk: Check that signal frame is shadow stack mem (Rafael Aquini) [RHEL-27743]
- x86/shstk: Check that SSP is aligned on sigreturn (Rafael Aquini) [RHEL-27743]
- x86/shstk: Handle signals for shadow stack (Rafael Aquini) [RHEL-27743]
- x86/shstk: Add user control-protection fault handler (Rafael Aquini) [RHEL-27743]
- x86/shstk: Introduce routines modifying shstk (Rafael Aquini) [RHEL-27743]
- x86/shstk: Handle thread shadow stack (Rafael Aquini) [RHEL-27743]
- x86/shstk: Add user-mode shadow stack support (Rafael Aquini) [RHEL-27743]
- x86: Introduce userspace API for shadow stack (Rafael Aquini) [RHEL-27743]
- Documentation/x86: Add CET shadow stack description (Rafael Aquini) [RHEL-27743]
- arm: Add compile-time asserts for siginfo_t offsets (Rafael Aquini) [RHEL-27743]
- mm: Don't allow write GUPs to shadow stack memory (Rafael Aquini) [RHEL-27743]
- x86/mm: Teach pte_mkwrite() about stack memory (Rafael Aquini) [RHEL-27743]
- mm/mmap: Add shadow stack pages to memory accounting (Rafael Aquini) [RHEL-27743]
- mm: Add guard pages around a shadow stack. (Rafael Aquini) [RHEL-27743]
- mm: Introduce VM_SHADOW_STACK for shadow stack memory (Rafael Aquini) [RHEL-27743]
- mm: Move VM_UFFD_MINOR_BIT from 37 to 38 (Rafael Aquini) [RHEL-27743]
- mm: Re-introduce vm_flags to do_mmap() (Rafael Aquini) [RHEL-27743]
- mm/migrate_device: try to handle swapcache pages (Rafael Aquini) [RHEL-27743]
- mm: madvise: fix uneven accounting of psi (Rafael Aquini) [RHEL-27743]
- swap: remove remnants of polling from read_swap_cache_async (Rafael Aquini) [RHEL-27743]
- swap: stop add to avail list if swap is full (Rafael Aquini) [RHEL-27743]
- swap: cleanup duplicated WARN_ON in add_to_avail_list (Rafael Aquini) [RHEL-27743]
- mm: call arch_swap_restore() from unuse_pte() (Rafael Aquini) [RHEL-27743]
- memory tier: create CPUless memory tiers after obtaining HMAT info (John W. Linville) [RHEL-54609]
- memory tier: dax/kmem: introduce an abstract layer for finding, allocating, and putting memory types (John W. Linville) [RHEL-54609]
- mm/demotion: print demotion targets (John W. Linville) [RHEL-54609]
- memory tier: make memory_tier_subsys const (John W. Linville) [RHEL-54609]
- dax, kmem: calculate abstract distance with general interface (John W. Linville) [RHEL-54609]
- memory tier: use helper macro __ATTR_RW() (John W. Linville) [RHEL-54609]
- memory tier: rename destroy_memory_type() to put_memory_type() (John W. Linville) [RHEL-54609]
- memory tier: use helper function destroy_memory_type() (John W. Linville) [RHEL-54609]
- cxl/cxl-event: include missing <linux/types.h> and <linux/uuid.h> (John W. Linville) [RHEL-54609]
- ACPICA: actbl1.h: Add EINJ CXL error types (John W. Linville) [RHEL-54609]
- ACPICA: Fix CXL 3.0 structure (RDPAS) in the CEDT table (John W. Linville) [RHEL-54609]
- perf: CXL: fix CPMU filter value mask length (John W. Linville) [RHEL-54609]
- perf: CXL: fix mismatched number of counters mask (John W. Linville) [RHEL-54609]
- PCI/CXL: Add 'cxl_bus' reset method for devices below CXL Ports (John W. Linville) [RHEL-54609]
- PCI/CXL: Fail bus reset if upstream CXL Port has SBR masked (John W. Linville) [RHEL-54609]
- dax: remove redundant assignment to variable rc (John W. Linville) [RHEL-54609]
- cxl/region: Fix a race condition in memory hotplug notifier (John W. Linville) [RHEL-54609]
- cxl: Add post-reset warning if reset results in loss of previously committed HDM decoders (John W. Linville) [RHEL-54609]
- Documentation/ABI/testing/debugfs-cxl: Fix "Unexpected indentation" (John W. Linville) [RHEL-54609]
- cxl: documentation: add missing files to cxl driver-api (John W. Linville) [RHEL-54609]
- cxl/region: check interleave capability (John W. Linville) [RHEL-54609]
- cxl/test: Add missing vmalloc.h for tools/testing/cxl/test/mem.c (John W. Linville) [RHEL-54609]
- PCI/CXL: Move CXL Vendor ID to pci_ids.h (John W. Linville) [RHEL-54609]
- workqueue: Split out workqueue_types.h (John W. Linville) [RHEL-54609]
- timers: Split out timer_types.h (John W. Linville) [RHEL-54609]
- cxl/region: Convert cxl_pmem_region_alloc to scope-based resource management (John W. Linville) [RHEL-54609]
- cxl/acpi: Cleanup __cxl_parse_cfmws() (John W. Linville) [RHEL-54609]
- cxl/core: Add region info to cxl_general_media and cxl_dram events (John W. Linville) [RHEL-54609]
- cxl/region: Move cxl_trace_hpa() work to the region driver (John W. Linville) [RHEL-54609]
- cxl/region: Move cxl_dpa_to_region() work to the region driver (John W. Linville) [RHEL-54609]
- cxl/hdm: Debug, use decoder name function (John W. Linville) [RHEL-54609]
- cxl: Fix use of phys_to_target_node() for x86 (John W. Linville) [RHEL-54609]
- cxl/hdm: dev_warn() on unsupported mixed mode decoder (John W. Linville) [RHEL-54609]
- cxl/test: Enhance event testing (John W. Linville) [RHEL-54609]
- cxl/hdm: Add debug message for invalid interleave granularity (John W. Linville) [RHEL-54609]
- cxl: Fix compile warning for cxl_security_ops extern (John W. Linville) [RHEL-54609]
- cxl/mbox: Add Clear Log mailbox command (John W. Linville) [RHEL-54609]
- cxl/mbox: Add Get Log Capabilities and Get Supported Logs Sub-List commands (John W. Linville) [RHEL-54609]
- cxl: Fix cxl_endpoint_get_perf_coordinate() support for RCH (John W. Linville) [RHEL-54609]
- cxl: Add checks to access_coordinate calculation to fail missing data (John W. Linville) [RHEL-54609]
- cxl: Consolidate dport access_coordinate ->hb_coord and ->sw_coord into ->coord (John W. Linville) [RHEL-54609]
- cxl: Fix incorrect region perf data calculation (John W. Linville) [RHEL-54609]
- cxl: Fix retrieving of access_coordinates in PCIe path (John W. Linville) [RHEL-54609]
- cxl: Remove checking of iter in cxl_endpoint_get_perf_coordinates() (John W. Linville) [RHEL-54609]
- cxl: remove CONFIG_CXL_PMU entry in drivers/cxl/Kconfig (John W. Linville) [RHEL-54609]
- lib/firmware_table: Provide buffer length argument to cdat_table_parse() (John W. Linville) [RHEL-54609]
- cxl/pci: Get rid of pointer arithmetic reading CDAT table (John W. Linville) [RHEL-54609]
- cxl/pci: Rename DOE mailbox handle to doe_mb (John W. Linville) [RHEL-54609]
- cxl: Fix the incorrect assignment of SSLBIS entry pointer initial location (John W. Linville) [RHEL-54609]
- cxl/core: Add CXL EINJ debugfs files (John W. Linville) [RHEL-54609]
- cxl/region: Deal with numa nodes not enumerated by SRAT (John W. Linville) [RHEL-54609]
- cxl/region: Add memory hotplug notifier for cxl region (John W. Linville) [RHEL-54609]
- ACPI: Add helper acpi_use_parent_companion (John W. Linville) [RHEL-54609]
- cxl/region: Add sysfs attribute for locality attributes of CXL regions (John W. Linville) [RHEL-54609]
- cxl/region: Calculate performance data for a region (John W. Linville) [RHEL-54609]
- cxl: Set cxlmd->endpoint before adding port device (John W. Linville) [RHEL-54609]
- cxl: Move QoS class to be calculated from the nearest CPU (John W. Linville) [RHEL-54609]
- cxl: Split out host bridge access coordinates (John W. Linville) [RHEL-54609]
- cxl: Split out combine_coordinates() for common shared usage (John W. Linville) [RHEL-54609]
- ACPI: HMAT / cxl: Add retrieval of generic port coordinates for both access classes (John W. Linville) [RHEL-54609]
- cxl: Fix sysfs export of qos_class for memdev (John W. Linville) [RHEL-54609]
- cxl: Remove unnecessary type cast in cxl_qos_class_verify() (John W. Linville) [RHEL-54609]
- cxl: Change 'struct cxl_memdev_state' *_perf_list to single 'struct cxl_dpa_perf' (John W. Linville) [RHEL-54609]
- cxl: Refactor to use __free() for cxl_root allocation in cxl_find_nvdimm_bridge() (John W. Linville) [RHEL-54609]
- cxl: Fix device reference leak in cxl_port_perf_data_calculate() (John W. Linville) [RHEL-54609]
- cxl: Convert find_cxl_root() to return a 'struct cxl_root *' (John W. Linville) [RHEL-54609]
- cxl: Introduce put_cxl_root() helper (John W. Linville) [RHEL-54609]
- cxl/test: Add support for qos_class checking (John W. Linville) [RHEL-54609]
- cxl/pci: Skip irq features if MSI/MSI-X are not supported (John W. Linville) [RHEL-54609]
- tools/testing/cxl: Disable "missing prototypes / declarations" warnings (John W. Linville) [RHEL-54609]
- cxl/core: use sysfs_emit() for attr's _show() (John W. Linville) [RHEL-54609]
- Merge branch 'for-6.8/cxl-cper' into for-6.8/cxl (John W. Linville) [RHEL-54609]
- cxl: Refactor to use __free() for cxl_root allocation in cxl_endpoint_port_probe() (John W. Linville) [RHEL-54609]
- cxl/region: use %%pap format to print resource_size_t (John W. Linville) [RHEL-54609]
- cxl/region: Add dev_dbg() detail on failure to allocate HPA space (John W. Linville) [RHEL-54609]
- cxl: Check qos_class validity on memdev probe (John W. Linville) [RHEL-54609]
- cxl: Export sysfs attributes for memory device QoS class (John W. Linville) [RHEL-54609]
- cxl: Store QTG IDs and related info to the CXL memory device context (John W. Linville) [RHEL-54609]
- cxl: Compute the entire CXL path latency and bandwidth data (John W. Linville) [RHEL-54609]
- cxl: Add helper function that calculate performance data for downstream ports (John W. Linville) [RHEL-54609]
- cxl: Store the access coordinates for the generic ports (John W. Linville) [RHEL-54609]
- tools/testing/cxl: Add hostbridge UID string for cxl_test mock hb devices (John W. Linville) [RHEL-54609]
- cxl: Calculate and store PCI link latency for the downstream ports (John W. Linville) [RHEL-54609]
- cxl: Add support for _DSM Function for retrieving QTG ID (John W. Linville) [RHEL-54609]
- cxl: Add callback to parse the SSLBIS subtable from CDAT (John W. Linville) [RHEL-54609]
- cxl: Add callback to parse the DSLBIS subtable from CDAT (John W. Linville) [RHEL-54609]
- cxl: Add callback to parse the DSMAS subtables from CDAT (John W. Linville) [RHEL-54609]
- cxl: Fix unregister_region() callback parameter assignment (John W. Linville) [RHEL-54609]
- cxl: Add Support for Get Timestamp (John W. Linville) [RHEL-54609]
- cxl/cdat: Free correct buffer on checksum error (John W. Linville) [RHEL-54609]
- cxl: Add cxl_num_decoders_committed() usage to cxl_test (John W. Linville) [RHEL-54609]
- cxl/hdm: Fix a benign lockdep splat (John W. Linville) [RHEL-54609]
- MAINTAINERS: Add tools/testing/cxl files to CXL (John W. Linville) [RHEL-54609]
- ACPICA: Add defines for CDAT SSLBIS (John W. Linville) [RHEL-54609]
- cxl: Add support for reading CXL switch CDAT table (John W. Linville) [RHEL-54609]
- cxl: Add checksum verification to CDAT from CXL (John W. Linville) [RHEL-54609]
- cxl: Export QTG ids from CFMWS to sysfs as qos_class attribute (John W. Linville) [RHEL-54609]
- cxl: Add decoders_committed sysfs attribute to cxl_port (John W. Linville) [RHEL-54609]
- cxl: Add cxl_decoders_committed() helper (John W. Linville) [RHEL-54609]
- tools/testing/cxl: Slow down the mock firmware transfer (John W. Linville) [RHEL-54609]
- tools/testing/cxl: Add 'sanitize notifier' support (John W. Linville) [RHEL-54609]
- tools/testing/cxl: Make cxl_memdev_state available to other command emulation (John W. Linville) [RHEL-54609]
- cxl/pci: Clarify devm host for memdev relative setup (John W. Linville) [RHEL-54609]
- cxl/pci: Remove inconsistent usage of dev_err_probe() (John W. Linville) [RHEL-54609]
- cxl/pci: Remove hardirq handler for cxl_request_irq() (John W. Linville) [RHEL-54609]
- cxl/pci: Cleanup 'sanitize' to always poll (John W. Linville) [RHEL-54609]
- cxl/pci: Remove unnecessary device reference management in sanitize work (John W. Linville) [RHEL-54609]
- cxl/pci: Update comment (John W. Linville) [RHEL-54609]
- cxl/port: Quiet warning messages from the cxl_test environment (John W. Linville) [RHEL-54609]
- cxl: minor whitespace fixups (John W. Linville) [RHEL-54609]
- net/sched: cls_flower: propagate tca[TCA_OPTIONS] to NL_REQ_ATTR_CHECK (Davide Caratti) [RHEL-3647]
- flow_dissector: set encapsulation control flags for non-IP (Davide Caratti) [RHEL-3647]
- flow_dissector: cleanup FLOW_DISSECTOR_KEY_ENC_FLAGS (Davide Caratti) [RHEL-3647]
- doc: netlink: specs: tc: flower: add enc-flags (Davide Caratti) [RHEL-3647]
- doc/netlink/specs: Update the tc spec (Davide Caratti) [RHEL-3647]
- net/sched: cls_flower: rework TCA_FLOWER_KEY_ENC_FLAGS usage (Davide Caratti) [RHEL-3647]
- net/sched: cls_flower: add tunnel flags to fl_{set,dump}_key_flags() (Davide Caratti) [RHEL-3647]
- flow_dissector: set encapsulated control flags from tun_flags (Davide Caratti) [RHEL-3647]
- flow_dissector: prepare for encapsulated control flags (Davide Caratti) [RHEL-3647]
- net/sched: cls_flower: add policy for TCA_FLOWER_KEY_FLAGS (Davide Caratti) [RHEL-3647]
- net/sched: cls_flower: prepare fl_{set,dump}_key_flags() for ENC_FLAGS (Davide Caratti) [RHEL-3647]
- net/sched: flower: define new tunnel flags (Davide Caratti) [RHEL-3647]
- doc: netlink: specs: tc: describe flower control flags (Davide Caratti) [RHEL-3647]
- net/sched: flower: refactor control flag definitions (Davide Caratti) [RHEL-3647]
- ice: flower: validate encapsulation control flags (Davide Caratti) [RHEL-3647]
- nfp: flower: validate encapsulation control flags (Davide Caratti) [RHEL-3647]
- net/mlx5e: flower: validate encapsulation control flags (Davide Caratti) [RHEL-3647]
- sfc: use flow_rule_is_supp_enc_control_flags() (Davide Caratti) [RHEL-3647]
- net/sched: cls_flower: add support for matching tunnel control flags (Davide Caratti) [RHEL-3647]
- flow_dissector: add support for tunnel control flags (Davide Caratti) [RHEL-3647]

* Fri Oct 25 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-523.el9]
- redhat/config: Enable CONFIG_RCU_TRACE (Waiman Long) [RHEL-62648]
- net: ena: Extend customer metrics reporting support (Kamal Heib) [RHEL-59968]
- net: ena: Add ENA Express metrics support (Kamal Heib) [RHEL-59968]
- net: ena: Change initial rx_usec interval (Kamal Heib) [RHEL-59968]
- net: ena: Changes around strscpy calls (Kamal Heib) [RHEL-59968]
- net: ena: Add validation for completion descriptors consistency (Kamal Heib) [RHEL-59968]
- net: ena: Reduce holes in ena_com structures (Kamal Heib) [RHEL-59968]
- net: ena: Add a counter for driver's reset failures (Kamal Heib) [RHEL-59968]
- net: ena: Set tx_info->xdpf value to NULL (Kamal Heib) [RHEL-59968]
- net: ena: Wrong missing IO completions check order (Kamal Heib) [RHEL-59968]
- net: ena: Fix potential sign extension issue (Kamal Heib) [RHEL-59968]
- sched/pelt: Use rq_clock_task() for hw_pressure (Phil Auld) [RHEL-56494]
- spinlock: Fix failing build for PREEMPT_RT (Phil Auld) [RHEL-56494]
- sched/core: Fix unbalance set_rq_online/offline() in sched_cpu_deactivate() (Phil Auld) [RHEL-56494]
- sched/smt: Fix unbalance sched_smt_present dec/inc (Phil Auld) [RHEL-57142] {CVE-2024-44958}
- sched/core: Introduce sched_set_rq_on/offline() helper (Phil Auld) [RHEL-56494]
- sched/cputime: Fix mul_u64_u64_div_u64() precision for cputime (Phil Auld) [RHEL-56494]
- sched/smt: Introduce sched_smt_present_inc/dec() helper (Phil Auld) [RHEL-57142] {CVE-2024-44958}
- sched: avoid using ilog2() in sched.h (Phil Auld) [RHEL-56494]
- rcu/tasks: Fix stale task snaphot for Tasks Trace (Phil Auld) [RHEL-56494]
- sched/core: Drop spinlocks on contention iff kernel is preemptible (Phil Auld) [RHEL-56494]
- sched.h: Move (spin|rwlock)_needbreak() to spinlock.h (Phil Auld) [RHEL-56494]
- sched/core: Move preempt_model_*() helpers from sched.h to preempt.h (Phil Auld) [RHEL-56494]
- sched/balance: Skip unnecessary updates to idle load balancer's flags (Phil Auld) [RHEL-56494]
- idle: Remove stale RCU comment (Phil Auld) [RHEL-56494]
- sched/headers: Move struct pre-declarations to the beginning of the header (Phil Auld) [RHEL-56494]
- sched/core: Clean up kernel/sched/sched.h a bit (Phil Auld) [RHEL-56494]
- sched/core: Simplify prefetch_curr_exec_start() (Phil Auld) [RHEL-56494]
- sched: Fix spelling in comments (Phil Auld) [RHEL-56494]
- sched/syscalls: Split out kernel/sched/syscalls.c from kernel/sched/core.c (Phil Auld) [RHEL-56494]
- sched/fair: Fix initial util_avg calculation (Phil Auld) [RHEL-56494]
- selftests/bpf: Adjust test_access_variable_array after a kernel function name change (Phil Auld) [RHEL-56494]
- arch/topology: Fix variable naming to avoid shadowing (Phil Auld) [RHEL-56494]
- sched/pelt: Remove shift of thermal clock (Phil Auld) [RHEL-56494]
- sched/cpufreq: Rename arch_update_thermal_pressure() => arch_update_hw_pressure() (Phil Auld) [RHEL-56494]
- thermal/cpufreq: Remove arch_update_thermal_pressure() (Phil Auld) [RHEL-56494]
- sched/cpufreq: Take cpufreq feedback into account (Phil Auld) [RHEL-56494]
- cpufreq: Add a cpufreq pressure feedback for the scheduler (Phil Auld) [RHEL-56494]
- sched/fair: Fix update of rd->sg_overutilized (Phil Auld) [RHEL-56494]
- sched/balancing: Simplify the sg_status bitmask and use separate ->overloaded and ->overutilized flags (Phil Auld) [RHEL-56494]
- sched/fair: Rename set_rd_overutilized_status() to set_rd_overutilized() (Phil Auld) [RHEL-56494]
- sched/fair: Rename SG_OVERLOAD to SG_OVERLOADED (Phil Auld) [RHEL-56494]
- sched/fair: Rename {set|get}_rd_overload() to {set|get}_rd_overloaded() (Phil Auld) [RHEL-56494]
- sched/fair: Rename root_domain::overload to ::overloaded (Phil Auld) [RHEL-56494]
- sched/fair: Use helper functions to access root_domain::overload (Phil Auld) [RHEL-56494]
- sched/fair: Check root_domain::overload value before update (Phil Auld) [RHEL-56494]
- sched/fair: Combine EAS check with root_domain::overutilized access (Phil Auld) [RHEL-56494]
- sched/fair: Simplify the continue_balancing logic in sched_balance_newidle() (Phil Auld) [RHEL-56494]
- sched/fair: Introduce is_rd_overutilized() helper function to access root_domain::overutilized (Phil Auld) [RHEL-56494]
- sched/fair: Add EAS checks before updating root_domain::overutilized (Phil Auld) [RHEL-56494]
- sched/fair: Don't double balance_interval for migrate_misfit (Phil Auld) [RHEL-56494]
- sched/topology: Remove root_domain::max_cpu_capacity (Phil Auld) [RHEL-56494]
- sched/fair: Check if a task has a fitting CPU when updating misfit (Phil Auld) [RHEL-56494]
- sched/topology: Export asym_cap_list (Phil Auld) [RHEL-56494]
- sched/fair: Fix typos in comments (Phil Auld) [RHEL-56494]
- sched/balancing: Fix a couple of outdated function names in comments (Phil Auld) [RHEL-56494]
- sched/balancing: Rename load_balance() => sched_balance_rq() (Phil Auld) [RHEL-56494]
- sched/balancing: Rename find_busiest_queue() => sched_balance_find_src_rq() (Phil Auld) [RHEL-56494]
- sched/balancing: Rename find_idlest_cpu() => sched_balance_find_dst_cpu() (Phil Auld) [RHEL-56494]
- sched/balancing: Rename find_idlest_group() => sched_balance_find_dst_group() (Phil Auld) [RHEL-56494]
- sched/balancing: Rename find_idlest_group_cpu() => sched_balance_find_dst_group_cpu() (Phil Auld) [RHEL-56494]
- sched/balancing: Rename newidle_balance() => sched_balance_newidle() (Phil Auld) [RHEL-56494]
- sched/balancing: Rename update_blocked_averages() => sched_balance_update_blocked_averages() (Phil Auld) [RHEL-56494]
- sched/balancing: Rename find_busiest_group() => sched_balance_find_src_group() (Phil Auld) [RHEL-56494]
- sched/balancing: Update comments in 'struct sg_lb_stats' and 'struct sd_lb_stats' (Phil Auld) [RHEL-56494]
- sched/balancing: Vertically align the comments of 'struct sg_lb_stats' and 'struct sd_lb_stats' (Phil Auld) [RHEL-56494]
- sched/balancing: Rename trigger_load_balance() => sched_balance_trigger() (Phil Auld) [RHEL-56494]
- sched/balancing: Rename scheduler_tick() => sched_tick() (Phil Auld) [RHEL-56494]
- docs: scheduler: Fix outdated parameter of rebalance_domains (Phil Auld) [RHEL-56494]
- sched/balancing: Rename rebalance_domains() => sched_balance_domains() (Phil Auld) [RHEL-56494]
- sched/balancing: Rename run_rebalance_domains() => sched_balance_softirq() (Phil Auld) [RHEL-56494]
- sched/balancing: Update run_rebalance_domains() comments (Phil Auld) [RHEL-56494]
- sched/balancing: Fix comments (trying to) refer to NOHZ_BALANCE_KICK (Phil Auld) [RHEL-56494]
- sched/debug: Allow CONFIG_SCHEDSTATS even on !KERNEL_DEBUG kernels (Phil Auld) [RHEL-56494]
- sched/debug: Increase SCHEDSTAT_VERSION to 16 (Phil Auld) [RHEL-56494]
- sched/balancing: Change 'enum cpu_idle_type' to have more natural definitions (Phil Auld) [RHEL-56494]
- sched/balancing: Remove reliance on 'enum cpu_idle_type' ordering when iterating [CPU_MAX_IDLE_TYPES] arrays in show_schedstat() (Phil Auld) [RHEL-56494]
- sched/balancing: Switch the 'DEFINE_SPINLOCK(balancing)' spinlock into an 'atomic_t sched_balance_running' flag (Phil Auld) [RHEL-56494]
- sched/numa, mm: do not try to migrate memory to memoryless nodes (Phil Auld) [RHEL-56494]
- sched/fair: Check the SD_ASYM_PACKING flag in sched_use_asym_prio() (Phil Auld) [RHEL-56494]
- sched/fair: Rework sched_use_asym_prio() and sched_asym_prefer() (Phil Auld) [RHEL-56494]
- sched/topology: Rename SD_SHARE_PKG_RESOURCES to SD_SHARE_LLC (Phil Auld) [RHEL-56494]
- sched/fair: Remove unused parameter from sched_asym() (Phil Auld) [RHEL-56494]
- sched/topology: Remove duplicate descriptions from TOPOLOGY_SD_FLAGS (Phil Auld) [RHEL-56494]
- sched/fair: Simplify the update_sd_pick_busiest() logic (Phil Auld) [RHEL-56494]
- sched/fair: Do strict inequality check for busiest misfit task group (Phil Auld) [RHEL-56494]
- sched/fair: Remove unnecessary goto in update_sd_lb_stats() (Phil Auld) [RHEL-56494]
- sched/fair: Add READ_ONCE() and use existing helper function to access ->avg_irq (Phil Auld) [RHEL-56494]
- sched/fair: Use existing helper functions to access ->avg_rt and ->avg_dl (Phil Auld) [RHEL-56494]
- sched/core: Simplify code by removing duplicate #ifdefs (Phil Auld) [RHEL-56494]
- RDMA/efa: Add support for node guid (Kamal Heib) [RHEL-59970]
- RDMA/efa: Add EFA 0xefa3 PCI ID (Kamal Heib) [RHEL-59970]
- RDMA/efa: Remove duplicate aenq enable macro (Kamal Heib) [RHEL-59970]
- RDMA/efa: Use offset_in_page() function (Kamal Heib) [RHEL-59970]
- RDMA/efa: Properly handle unexpected AQ completions (Kamal Heib) [RHEL-59970]
- RDMA/efa: Fail probe on missing BARs (Kamal Heib) [RHEL-59970]
- RDMA/efa: Support QP with unsolicited write w/ imm. receive (Kamal Heib) [RHEL-59970]
- RDMA/efa: Limit EQs to available MSI-X vectors (Kamal Heib) [RHEL-59970]
- RDMA/efa: Add EFA query MR support (Kamal Heib) [RHEL-59970]
- mm/memory-failure: use raw_spinlock_t in struct memory_failure_cpu (Wander Lairson Costa) [RHEL-52957]
- cgroup/pids: Avoid spurious event notification (Waiman Long) [RHEL-56023]
- mm: shmem: fix getting incorrect lruvec when replacing a shmem folio (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Eliminate unncessary sched domains rebuilds in hotplug (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Clear effective_xcpus on cpus_allowed clearing only if cpus.exclusive not set (Waiman Long) [RHEL-56023]
- cpumask: cleanup core headers inclusion (Waiman Long) [RHEL-56023]
- cgroup: Protect css->cgroup write under css_set_lock (Waiman Long) [RHEL-56023]
- cgroup/misc: Introduce misc.events.local (Waiman Long) [RHEL-56023]
- cgroup/rstat: add force idle show helper (Waiman Long) [RHEL-56023]
- cgroup/misc: Introduce misc.peak (Waiman Long) [RHEL-56023]
- cgroup: avoid the unnecessary list_add(dying_tasks) in cgroup_exit() (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Reduce the lock protecting CS_SCHED_LOAD_BALANCE (Waiman Long) [RHEL-56023]
- kernel/cgroup: cleanup cgroup_base_files when fail to add cgroup_psi_files (Waiman Long) [RHEL-56023]
- cgroup/pids: Add pids.events.local (Waiman Long) [RHEL-56023]
- cgroup/pids: Make event counters hierarchical (Waiman Long) [RHEL-56023]
- cgroup/pids: Separate semantics of pids.events related to pids.max (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Update comment on callback_lock (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Remove unnecessary zeroing (Waiman Long) [RHEL-56023]
- cgroup/rstat: add cgroup_rstat_cpu_lock helpers and tracepoints (Waiman Long) [RHEL-56023]
- selftests/cgroup: cpu_hogger init: use {} instead of {NULL} (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Remove outdated comment in sched_partition_write() (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Fix incorrect top_cpuset flags (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Avoid clearing CS_SCHED_LOAD_BALANCE twice (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Statically initialize more members of top_cpuset (Waiman Long) [RHEL-56023]
- cgroup: Avoid unnecessary looping in cgroup_no_v1() (Waiman Long) [RHEL-56023]
- cgroup, legacy_freezer: update comment for freezer_css_offline() (Waiman Long) [RHEL-56023]
- docs, cgroup: add entries for pids to cgroup-v2.rst (Waiman Long) [RHEL-56023]
- cgroup: don't call cgroup1_pidlist_destroy_all() for v2 (Waiman Long) [RHEL-56023]
- cgroup_freezer: update comment for freezer_css_online() (Waiman Long) [RHEL-56023]
- cgroup/rstat: desc member cgrp in cgroup_rstat_flush_release (Waiman Long) [RHEL-56023]
- cgroup/rstat: add cgroup_rstat_lock helpers and tracepoints (Waiman Long) [RHEL-56023]
- cgroup/pids: Remove superfluous zeroing (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Add test_cpuset_v1_hp.sh (Waiman Long) [RHEL-56023]
- selftests: cgroup: skip test_cgcore_lesser_ns_open when cgroup2 mounted without nsdelegate (Waiman Long) [RHEL-56023]
- cgroup/cpuset: Mark memory_spread_slab as obsolete (Waiman Long) [RHEL-56023]
- kernfs: Convert kernfs_path_from_node_locked() from strlcpy() to strscpy() (Waiman Long) [RHEL-56023]
- kernfs: Convert kernfs_name_locked() from strlcpy() to strscpy() (Waiman Long) [RHEL-56023]
- kernfs: Convert kernfs_walk_ns() from strlcpy() to strscpy() (Waiman Long) [RHEL-56023]
- selftests: add a selftest to verify hugetlb usage in memcg (Waiman Long) [RHEL-56023]
- hugetlb: memcg: account hugetlb-backed memory in memory controller (Waiman Long) [RHEL-56023]
- memcontrol: only transfer the memcg data for migration (Waiman Long) [RHEL-56023]
- memcontrol: add helpers for hugetlb memcg accounting (Waiman Long) [RHEL-56023]
- cgroup: Fix incorrect css_set_rwsem reference in comment (Waiman Long) [RHEL-56023]
- selftests: cgroup: Add cpuset migrations testcase (Waiman Long) [RHEL-56023]
- selftests: cgroup: Minor code reorganizations (Waiman Long) [RHEL-56023]
- selftests: cgroup: add zswap-memcg unwanted writeback test (Waiman Long) [RHEL-56023]
- selftests: cgroup: add test_zswap with no kmem bypass test (Waiman Long) [RHEL-56023]
- selftests: cgroup: add test_zswap program (Waiman Long) [RHEL-56023]
- kernfs: fix missing kernfs_idr_lock to remove an ID from the IDR (Waiman Long) [RHEL-56023]
- kernfs: remove an unused if statement in kernfs_path_from_node_locked() (Waiman Long) [RHEL-56023]
- kernfs: fix all kernel-doc warnings and multiple typos (Waiman Long) [RHEL-56023]
- sched/psi: Remove redundant cgroup_psi() when !CONFIG_CGROUPS (Waiman Long) [RHEL-56023]
- kernfs: Fix typo 'the the' in comment (Waiman Long) [RHEL-56023]
- cgroup: Add test_cpucg_max_nested() testcase (Waiman Long) [RHEL-56023]
- cgroup: Add test_cpucg_max() testcase (Waiman Long) [RHEL-56023]
- cgroup: Add test_cpucg_nested_weight_underprovisioned() testcase (Waiman Long) [RHEL-56023]
- cgroup: Adding test_cpucg_nested_weight_overprovisioned() testcase (Waiman Long) [RHEL-56023]
- cgroup: Add test_cpucg_weight_underprovisioned() testcase (Waiman Long) [RHEL-56023]
- cgroup: Add test_cpucg_weight_overprovisioned() testcase (Waiman Long) [RHEL-56023]
- cgroup: Add test_cpucg_stats() testcase to cgroup cpu selftests (Waiman Long) [RHEL-56023]
- cgroup: Add new test_cpu.c test suite in cgroup selftests (Waiman Long) [RHEL-56023]
- kernfs: fix typos in comments (Waiman Long) [RHEL-56023]
- selftests: cgroup: build error multiple outpt files (Waiman Long) [RHEL-56023]
- ext4: fix off by one issue in alloc_flex_gd() (Pavel Reichl) [RHEL-61252]
- perf script: Minimize "not reaching sample" for '-F +brstackinsn' (Michael Petlan) [RHEL-28499]
- selftests/livepatch: wait for atomic replace to occur JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- selftests/livepatch: define max test-syscall processes JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- selftests: livepatch: Test atomic replace against multiple modules JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- livepatch: Add "replace" sysfs attribute JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- selftests/livepatch: Add selftests for "replace" sysfs attribute JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- livepatch: Replace snprintf() with sysfs_emit() JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- livepatch: Rename KLP_* to KLP_TRANSITION_* JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- selftests: lib.mk: Do not process TEST_GEN_MODS_DIR JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- selftests: livepatch: Add initial .gitignore JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- selftests: livepatch: Test livepatching a heavily called syscall JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- kselftests: lib.mk: Add TEST_GEN_MODS_DIR variable JIRA: https://issues.redhat.com/browse/RHEL-61781 (Ryan Sullivan)
- sched/deadline: Use hrtick_enabled_dl() before start_hrtick_dl() (Phil Auld) [RHEL-61429]
- perf trace: Keep exited threads for summary (Michael Petlan) [RHEL-33443]
- bpf: Fix overrunning reservations in ringbuf (CKI Backport Bot) [RHEL-62881] {CVE-2024-41009}
- redhat: configs: decrease CONFIG_PCP_BATCH_SCALE_MAX (Rafael Aquini) [RHEL-62927]
- rtla/timerlat: Make timerlat_hist_cpu->*_count unsigned long long (Tomas Glozar) [RHEL-62190]
- rtla/timerlat: Make timerlat_top_cpu->*_count unsigned long long (Tomas Glozar) [RHEL-62190]
- mfd: intel-lpss: Add Intel Arrow Lake-H LPSS PCI IDs (Steve Best) [RHEL-20116]
- mfd: intel-lpss: Rename SPI intel_lpss_platform_info structs (Steve Best) [RHEL-20116]
- lib/generic-radix-tree.c: Fix rare race in __genradix_ptr_alloc() (Waiman Long) [RHEL-62140] {CVE-2024-47668}
- rcu: Use system_unbound_wq to avoid disturbing isolated CPUs (Waiman Long) [RHEL-50220]
- kvm: Note an RCU quiescent state on guest exit (Leonardo Bras) [RHEL-20288]
- rcu: Add rcutree.nohz_full_patience_delay to reduce nohz_full OS jitter (Leonardo Bras) [RHEL-20288]
- context_tracking: Fix KCSAN noinstr violation (Leonardo Bras) [RHEL-20288]
- spi: nxp-fspi: fix the KASAN report out-of-bounds bug (CKI Backport Bot) [RHEL-60743] {CVE-2024-46853}
- x86/kaslr: Expose and use the end of the physical memory address space (Waiman Long) [RHEL-55130 RHEL-55196 RHEL-58584]
- platform/mellanox: mlxbf-pmc: fix lockdep warning (Luiz Capitulino) [RHEL-58095]
- padata: Honor the caller's alignment in case of chunk_size 0 (Waiman Long) [RHEL-56164]
- padata: Fix possible divide-by-0 panic in padata_mt_helper() (Waiman Long) [RHEL-56164] {CVE-2024-43889}
- padata: Disable BH when taking works lock on MT path (Waiman Long) [RHEL-56164]
- Author: Gang Li padata: dispatch works on (Waiman Long) [RHEL-56164]
- padata: use alignment when calculating the number of worker threads (Waiman Long) [RHEL-56164]
- padata: Make kobj_type structure constant (Waiman Long) [RHEL-56164]
- padata: Mark padata_work_init() as __ref (Waiman Long) [RHEL-56164]
- padata: replace cpumask_weight with cpumask_empty in padata.c (Waiman Long) [RHEL-56164]
- padata: Remove repeated verbose license text (Waiman Long) [RHEL-56164]
- cgroup/cpuset: fix panic caused by partcmd_update (Waiman Long) [RHEL-57268] {CVE-2024-44975}
- redhat: configs: Enable CONFIG_TEGRA241_CMDQV (Jerry Snitselaar) [RHEL-36248]
- iommu/tegra241-cmdqv: Do not allocate vcmdq until dma_set_mask_and_coherent (Jerry Snitselaar) [RHEL-36248]
- iommu/tegra241-cmdqv: Drop static at local variable (Jerry Snitselaar) [RHEL-36248]
- iommu/tegra241-cmdqv: Fix ioremap() error handling in probe() (Jerry Snitselaar) [RHEL-36248]
- iommu/tegra241-cmdqv: Fix -Wformat-truncation warnings in lvcmdq_error_header (Jerry Snitselaar) [RHEL-36248]
- iommu/tegra241-cmdqv: Limit CMDs for VCMDQs of a guest owned VINTF (Jerry Snitselaar) [RHEL-36248]
- iommu/arm-smmu-v3: Start a new batch if new command is not supported (Jerry Snitselaar) [RHEL-36248]
- iommu/arm-smmu-v3: Add in-kernel support for NVIDIA Tegra241 (Grace) CMDQV (Jerry Snitselaar) [RHEL-36248]
- iommu/arm-smmu-v3: Add struct arm_smmu_impl_ops (Jerry Snitselaar) [RHEL-36248]
- iommu/arm-smmu-v3: Add acpi_smmu_iort_probe_model for impl (Jerry Snitselaar) [RHEL-36248]
- iommu/arm-smmu-v3: Add ARM_SMMU_OPT_TEGRA241_CMDQV (Jerry Snitselaar) [RHEL-36248]
- iommu/arm-smmu-v3: Make symbols public for CONFIG_TEGRA241_CMDQV (Jerry Snitselaar) [RHEL-36248]
- iommu/arm-smmu-v3: Pass in cmdq pointer to arm_smmu_cmdq_init (Jerry Snitselaar) [RHEL-36248]
- iommu/arm-smmu-v3: Pass in cmdq pointer to arm_smmu_cmdq_build_sync_cmd (Jerry Snitselaar) [RHEL-36248]
- iommu/arm-smmu-v3: Issue a batch of commands to the same cmdq (Jerry Snitselaar) [RHEL-36248]
- hrtimer: Report offline hrtimer enqueue (Waiman Long) [RHEL-55557]
- hrtimers: Push pending hrtimers away from outgoing CPU earlier (Waiman Long) [RHEL-55557]
- softirq: Fix suspicious RCU usage in __do_softirq() (Waiman Long) [RHEL-55557]
- rcu/tasks: Fix stale task snaphot for Tasks Trace (Waiman Long) [RHEL-55557]
- Revert "rcu-tasks: Fix synchronize_rcu_tasks() VS zap_pid_ns_processes()" (Waiman Long) [RHEL-55557]
- rcutorture: Use rcu_gp_slow_register/unregister() only for rcutype test (Waiman Long) [RHEL-55557]
- rcutorture: Fix invalid context warning when enable srcu barrier testing (Waiman Long) [RHEL-55557]
- rcutorture: Make stall-tasks directly exit when rcutorture tests end (Waiman Long) [RHEL-55557]
- rcutorture: Removing redundant function pointer initialization (Waiman Long) [RHEL-55557]
- rcutorture: Make rcutorture support print rcu-tasks gp state (Waiman Long) [RHEL-55557]
- rcutorture: Use the gp_kthread_dbg operation specified by cur_ops (Waiman Long) [RHEL-55557]
- rcutorture: Re-use value stored to ->rtort_pipe_count instead of re-reading (Waiman Long) [RHEL-55557]
- rcutorture: Fix rcu_torture_one_read() pipe_count overflow comment (Waiman Long) [RHEL-55557]
- rcutorture: Remove extraneous rcu_torture_pipe_update_one() READ_ONCE() (Waiman Long) [RHEL-55557]
- rcutorture: ASSERT_EXCLUSIVE_WRITER() for ->rtort_pipe_count updates (Waiman Long) [RHEL-55557]
- rcutorture: Dump GP kthread state on insufficient cb-flood laundering (Waiman Long) [RHEL-55557]
- rcutorture: Dump # online CPUs on insufficient cb-flood laundering (Waiman Long) [RHEL-55557]
- rcu-tasks: Fix show_rcu_tasks_trace_gp_kthread buffer overflow (Waiman Long) [RHEL-55557]
- rcu-tasks: Fix the comments for tasks_rcu_exit_srcu_stall_timer (Waiman Long) [RHEL-55557]
- rcu-tasks: Replace exit_tasks_rcu_start() initialization with WARN_ON_ONCE() (Waiman Long) [RHEL-55557]
- rcu: Allocate WQ with WQ_MEM_RECLAIM bit set (Waiman Long) [RHEL-55557]
- rcu: Support direct wake-up of synchronize_rcu() users (Waiman Long) [RHEL-55557]
- rcu: Add a trace event for synchronize_rcu_normal() (Waiman Long) [RHEL-55557]
- rcu: Reduce synchronize_rcu() latency (Waiman Long) [RHEL-55557]
- rcu: Add data structures for synchronize_rcu() (Waiman Long) [RHEL-55557]
- rcu: Fix buffer overflow in print_cpu_stall_info() (Waiman Long) [RHEL-55557]
- rcu: Mollify sparse with RCU guard (Waiman Long) [RHEL-55557]
- rcu: Remove redundant CONFIG_PROVE_RCU #if condition (Waiman Long) [RHEL-55557]
- rcu: Inform KCSAN of one-byte cmpxchg() in rcu_trc_cmpxchg_need_qs() (Waiman Long) [RHEL-55557]
- rcu: Make hotplug operations track GP state, not flags (Waiman Long) [RHEL-55557]
- rcu: Mark loads from rcu_state.n_online_cpus (Waiman Long) [RHEL-55557]
- rcu: Mark writes to rcu_sync ->gp_count field (Waiman Long) [RHEL-55557]
- rcu: Bring diagnostic read of rcu_state.gp_flags into alignment (Waiman Long) [RHEL-55557]
- rcu: Remove redundant READ_ONCE() of rcu_state.gp_flags in tree.c (Waiman Long) [RHEL-55557]
- rcu: Make Tiny RCU explicitly disable preemption (Waiman Long) [RHEL-55557]
- rcu: Remove redundant BH disabling in TINY_RCU (Waiman Long) [RHEL-55557]
- rcu: Create NEED_TASKS_RCU to factor out enablement logic (Waiman Long) [RHEL-55557]
- srcu: Make Tiny SRCU explicitly disable preemption (Waiman Long) [RHEL-55557]
- rcu: Make TINY_RCU depend on !PREEMPT_RCU rather than !PREEMPTION (Waiman Long) [RHEL-55557]
- rcu: Update lockdep while in RCU read-side critical section (Waiman Long) [RHEL-55557]
- rcu: Add lockdep checks and kernel-doc header to rcu_softirq_qs() (Waiman Long) [RHEL-55557]
- rcu: add a helper to report consolidated flavor QS (Waiman Long) [RHEL-55557]
- rcutorture: Suppress rtort_pipe_count warnings until after stalls (Waiman Long) [RHEL-55557]
- srcu: Improve comments about acceleration leak (Waiman Long) [RHEL-55557]
- rcu: Provide a boot time parameter to control lazy RCU (Waiman Long) [RHEL-55557]
- rcu: Rename jiffies_till_flush to jiffies_lazy_flush (Waiman Long) [RHEL-55557]
- rcu-tasks: Maintain real-time response in rcu_tasks_postscan() (Waiman Long) [RHEL-55557]
- rcu-tasks: Eliminate deadlocks involving do_exit() and RCU tasks (Waiman Long) [RHEL-55557]
- rcu-tasks: Maintain lists to eliminate RCU-tasks/do_exit() deadlocks (Waiman Long) [RHEL-55557]
- rcu-tasks: Initialize data to eliminate RCU-tasks/do_exit() deadlocks (Waiman Long) [RHEL-55557]
- rcu-tasks: Initialize callback lists at rcu_init() time (Waiman Long) [RHEL-55557]
- rcu-tasks: Add data to eliminate RCU-tasks/do_exit() deadlocks (Waiman Long) [RHEL-55557]
- rcu-tasks: Repair RCU Tasks Trace quiescence check (Waiman Long) [RHEL-55557]
- rcu/exp: Remove rcu_par_gp_wq (Waiman Long) [RHEL-55557]
- rcu/exp: Handle parallel exp gp kworkers affinity (Waiman Long) [RHEL-55557]
- rcu/exp: Make parallel exp gp kworker per rcu node (Waiman Long) [RHEL-55557]
- rcu/exp: Move expedited kthread worker creation functions above rcutree_prepare_cpu() (Waiman Long) [RHEL-55557]
- rcu: s/boost_kthread_mutex/kthread_mutex (Waiman Long) [RHEL-55557]
- rcu/exp: Remove full barrier upon main thread wakeup (Waiman Long) [RHEL-55557]
- rcu/nocb: Check rdp_gp->nocb_timer in __call_rcu_nocb_wake() (Waiman Long) [RHEL-55557]
- rcu/nocb: Fix WARN_ON_ONCE() in the rcu_nocb_bypass_lock() (Waiman Long) [RHEL-55557]
- rcu/nocb: Re-arrange call_rcu() NOCB specific code (Waiman Long) [RHEL-55557]
- rcu/nocb: Make IRQs disablement symmetric (Waiman Long) [RHEL-55557]
- rcu/nocb: Remove needless full barrier after callback advancing (Waiman Long) [RHEL-55557]
- rcu/nocb: Remove needless LOAD-ACQUIRE (Waiman Long) [RHEL-55557]
- rcu: Defer RCU kthreads wakeup when CPU is dying (Waiman Long) [RHEL-55557]
- srcu: Use try-lock lockdep annotation for NMI-safe access. (Waiman Long) [RHEL-55557]
- srcu: Explain why callbacks invocations can't run concurrently (Waiman Long) [RHEL-55557]
- srcu: No need to advance/accelerate if no callback enqueued (Waiman Long) [RHEL-55557]
- srcu: Remove superfluous callbacks advancing from srcu_gp_start() (Waiman Long) [RHEL-55557]
- rcu-tasks: Mark RCU Tasks accesses to current->rcu_tasks_idle_cpu (Waiman Long) [RHEL-55557]
- rcu: Force quiescent states only for ongoing grace period (Waiman Long) [RHEL-55557]
- rcu: Remove unused macros from rcupdate.h (Waiman Long) [RHEL-55557]
- rcutorture: Add fqs_holdoff check before fqs_task is created (Waiman Long) [RHEL-55557]
- rculist.h: docs: Fix wrong function summary (Waiman Long) [RHEL-55557]
- rcu: Remove unused function declaration rcu_eqs_special_set() (Waiman Long) [RHEL-55557]
- rcu: Use WRITE_ONCE() for assignments to ->next for rculist_nulls (Waiman Long) [RHEL-55557]
- rcu: Update synchronize_rcu_mult() comment for call_rcu_hurry() (Waiman Long) [RHEL-55557]
- srcu: Remove extraneous parentheses from srcu_read_lock() etc. (Waiman Long) [RHEL-55557]
- doc: Get rcutree module parameters back into alpha order (Waiman Long) [RHEL-55557]
- doc: Document rcutree.nocb_nobypass_lim_per_jiffy kernel parameter (Waiman Long) [RHEL-55557]
- doc: Document the rcutree.rcu_divisor kernel boot parameter (Waiman Long) [RHEL-55557]
- crypto: drbg - ensure drbg hmac sha512 is used in FIPS selftests (Charles Mirabile) [RHEL-34947]
- crypto: drbg - update FIPS CTR self-checks to aes256 (Charles Mirabile) [RHEL-34947]
- crypto: drbg - ensure most preferred type is FIPS health checked (Charles Mirabile) [RHEL-34947]
- crypto: tegra - Remove an incorrect iommu_fwspec_free() call in tegra_se_remove() (Charles Mirabile) [RHEL-34947]
- crypto: tegra - Fix some error codes (Charles Mirabile) [RHEL-34947]
- crypto: tegra - Convert to platform remove callback returning void (Charles Mirabile) [RHEL-34947]
- arm64: tegra: Add Tegra Security Engine DT nodes (Charles Mirabile) [RHEL-34947]
- arm64: defconfig: Enable Tegra Security Engine (Charles Mirabile) [RHEL-34947]
- gpu: host1x: Add Tegra SE to SID table (Charles Mirabile) [RHEL-34947]
- dt-bindings: crypto: Add Tegra Security Engine (Charles Mirabile) [RHEL-34947]
- redhat/configs: aarch64: enable Tegra Security Engine (Charles Mirabile) [RHEL-34947]
- crypto: tegra - Add Tegra Security Engine driver (Charles Mirabile) [RHEL-34947]
- crypto: hash - Add statesize to crypto_ahash (Charles Mirabile) [RHEL-34947]
- crypto: engine - Move crypto_engine_ops from request into crypto_alg (Charles Mirabile) [RHEL-34947]
- crypto: engine - Move struct crypto_engine into internal/engine.h (Charles Mirabile) [RHEL-34947]
- crypto: engine - Create internal/engine.h (Charles Mirabile) [RHEL-34947]
- crypto: engine - Move crypto inclusions out of header file (Charles Mirabile) [RHEL-34947]
- crypto: engine - Add KPP Support to Crypto Engine (Charles Mirabile) [RHEL-34947]
- crypto: api - Replace kernel.h with the necessary inclusions (Charles Mirabile) [RHEL-34947]
- docs: mm: fix vm overcommit documentation for OVERCOMMIT_GUESS (Vratislav Bendel) [RHEL-8588]

* Sun Oct 20 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-522.el9]
- tcp: fix mptcp DSS corruption due to large pmtu xmit (Paolo Abeni) [RHEL-55470]
- mptcp: handle consistently DSS corruption (Paolo Abeni) [RHEL-55470]
- redhat: spec: add drivers/net to kselftest package (Ivan Vecera) [RHEL-57764]
- netdevsim: fix backwards compatibility in nsim_get_iflink() (Ivan Vecera) [RHEL-57764]
- testing: net-drv: use stats64 for testing (Ivan Vecera) [RHEL-57764]
- net: selftest: add test for netdev netlink queue-get API (Ivan Vecera) [RHEL-57764]
- netdevsim: add NAPI support (Ivan Vecera) [RHEL-57764]
- selftests: net: py: check process exit code in bkg() and background cmd() (Ivan Vecera) [RHEL-57764]
- selftests: drv-net: add require_XYZ() helpers for validating env (Ivan Vecera) [RHEL-57764]
- selftests: drv-net: add a TCP ping test case (and useful helpers) (Ivan Vecera) [RHEL-57764]
- selftests: net: support matching cases by name prefix (Ivan Vecera) [RHEL-57764]
- selftests: drv-net: add a trivial ping test (Ivan Vecera) [RHEL-57764]
- selftests: drv-net: construct environment for running tests which require an endpoint (Ivan Vecera) [RHEL-57764]
- selftests: drv-net: factor out parsing of the env (Ivan Vecera) [RHEL-57764]
- selftests: drv-net: define endpoint structures (Ivan Vecera) [RHEL-57764]
- selftests: net: set the exit code correctly in Python tests (Ivan Vecera) [RHEL-57764]
- selftests: net: fix counting totals when some checks fail (Ivan Vecera) [RHEL-57764]
- net: netdevsim: select PAGE_POOL in Kconfig (Ivan Vecera) [RHEL-57764]
- selftests: net: exercise page pool reporting via netlink (Ivan Vecera) [RHEL-57764]
- selftests: net: support use of NetdevSimDev under "with" in python (Ivan Vecera) [RHEL-57764]
- selftests: net: print full exception on failure (Ivan Vecera) [RHEL-57764]
- selftests: net: print report check location in python tests (Ivan Vecera) [RHEL-57764]
- tools: ynl: don't return None for dumps (Ivan Vecera) [RHEL-57764]
- net: netdevsim: add some fake page pool use (Ivan Vecera) [RHEL-57764]
- selftests: net: reuse common code in bpf_offload (Ivan Vecera) [RHEL-57764]
- testing: net-drv: add a driver test for stats reporting (Ivan Vecera) [RHEL-57764]
- selftests: drivers: add scaffolding for Netlink tests in Python (Ivan Vecera) [RHEL-57764]
- netdevsim: report stats by default, like a real device (Ivan Vecera) [RHEL-57764]
- selftests: nl_netdev: add a trivial Netlink netdev test (Ivan Vecera) [RHEL-57764]
- selftests: net: add scaffolding for Netlink tests in Python (Ivan Vecera) [RHEL-57764]
- selftests: netdevsim: set test timeout to 10 minutes (Ivan Vecera) [RHEL-57764]
- selftests: netdevsim: add a config file (Ivan Vecera) [RHEL-57764]
- selftests: Introduce Makefile variable to list shared bash scripts (Ivan Vecera) [RHEL-57764]
- tools/net/ynl: Report netlink errors without stacktrace (Ivan Vecera) [RHEL-57764]
- tools/net/ynl: Add --output-json arg to ynl cli (Ivan Vecera) [RHEL-57764]
- netdev_features: remove NETIF_F_ALL_FCOE (Michal Schmidt) [RHEL-59091]
- netdev_features: convert NETIF_F_FCOE_MTU to dev->fcoe_mtu (Michal Schmidt) [RHEL-59091]
- netdev_features: convert NETIF_F_NETNS_LOCAL to dev->netns_local (Michal Schmidt) [RHEL-59091]
- netdev_features: convert NETIF_F_LLTX to dev->lltx (Michal Schmidt) [RHEL-59091]
- netdevice: convert private flags > BIT(31) to bitfields (Michal Schmidt) [RHEL-59091]
- RDMA/cxgb4: Added NULL check for lookup_atid (Kamal Heib) [RHEL-61394]
- RDMA/cxgb4: Remove unused declarations (Kamal Heib) [RHEL-61394]
- RDMA/cxgb4: use dma_mmap_coherent() for mapping non-contiguous memory (Kamal Heib) [RHEL-61394]
- RDMA/cxgb4: Delete unused c4iw_ep_redirect prototype (Kamal Heib) [RHEL-61394]
- RDMA/cxgb4: Check skb value for failure to allocate (Kamal Heib) [RHEL-61394]
- RDMA/cxgb4: Set sq_sig_type correctly (Kamal Heib) [RHEL-61394]
- crypto: qat - remove unused adf_devmgr_get_first (Vladis Dronov) [RHEL-52749]
- crypto: qat/qat_4xxx - fix off by one in uof_get_name() (Vladis Dronov) [RHEL-52749]
- crypto: qat/qat_420xx - fix off by one in uof_get_name() (Vladis Dronov) [RHEL-52749]
- crypto: qat - remove check after debugfs_create_dir() (Vladis Dronov) [RHEL-52749]
- crypto: qat - Remove trailing space after \n newline (Vladis Dronov) [RHEL-52749]
- crypto: qat - fix "Full Going True" macro definition (Vladis Dronov) [RHEL-52749]
- crypto: qat - Use static_assert() to check struct sizes (Vladis Dronov) [RHEL-52749]
- crypto: qat - allow disabling SR-IOV VFs (Vladis Dronov) [RHEL-52749]
- crypto: qat - ensure correct order in VF restarting handler (Vladis Dronov) [RHEL-52749]
- crypto: qat - fix recovery flow for VFs (Vladis Dronov) [RHEL-52749]
- crypto: qat - disable IOV in adf_dev_stop() (Vladis Dronov) [RHEL-52749]
- crypto: qat - preserve ADF_GENERAL_SEC (Vladis Dronov) [RHEL-52749]
- crypto: qat - fix unintentional re-enabling of error interrupts (Vladis Dronov) [RHEL-52749]
- crypto: qat - extend scope of lock in adf_cfg_add_key_value_param() (Vladis Dronov) [RHEL-52749]
- Documentation: qat: fix auto_reset attribute details (Vladis Dronov) [RHEL-52749]
- crypto: qat - initialize user_input.lock for rate_limiting (Vladis Dronov) [RHEL-52749]
- crypto: qat - make adf_ctl_class constant (Vladis Dronov) [RHEL-52749]
- crypto: qat - Fix typo (Vladis Dronov) [RHEL-52749]
- crypto: qat - fix linking errors when PCI_IOV is disabled (Vladis Dronov) [RHEL-52749]
- attr: block mode changes of symlinks (CKI Backport Bot) [RHEL-60822]
- selftests: netfilter: Fix nft_audit.sh for newer nft binaries (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: prevent nf_skb_duplicated corruption (Florian Westphal) [RHEL-60554]
- selftests: netfilter: add test case for recent mismatch bug (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: annotate data-races around element expiration (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: store new sets in dedicated list (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: Keep deleted flowtable hooks until after RCU (Florian Westphal) [RHEL-60554]
- netfilter: nft_dynset: annotate data-races around set timeout (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: reject expiration higher than timeout (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: reject element expiration with no timeout (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: elements with timeout below CONFIG_HZ never expire (Florian Westphal) [RHEL-60554]
- netfilter: nft_socket: Fix a NULL vs IS_ERR() bug in nft_socket_cgroup_subtree_level() (Florian Westphal) [RHEL-60554]
- netfilter: nft_socket: make cgroupsv2 matching work with namespaces (Florian Westphal) [RHEL-60554]
- netfilter: nft_socket: fix sk refcount leaks (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables_ipv6: consider network offset in netdev/egress validation (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: restore IP sanity checks for netdev/egress (Florian Westphal) [RHEL-60554]
- netfilter: flowtable: validate vlan header (Florian Westphal) [RHEL-60554]
- netfilter: nft_counter: Synchronize nft_counter_reset() against reader. (Florian Westphal) [RHEL-60554]
- netfilter: nft_counter: Disable BH in nft_counter_offload_stats(). (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: Introduce nf_tables_getobj_single (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: Audit log dump reset after the fact (Florian Westphal) [RHEL-60554]
- netfilter: nf_queue: drop packets with cloned unconfirmed conntracks (Florian Westphal) [RHEL-60554]
- netfilter: nft_set_pipapo_avx2: disable softinterrupts (Florian Westphal) [RHEL-60554]
- netfilter: nf_set_pipapo: fix initial map fill (Florian Westphal) [RHEL-60554]
- netfilter: ctnetlink: use helper function to calculate expect ID (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: rise cap on SELinux secmark context (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: unconditionally flush pending work before notifier (Florian Westphal) [RHEL-60554]
- netfilter: nft_payload: restore vlan q-in-q match support (Florian Westphal) [RHEL-60554]
- netfilter: nft_payload: skbuff vlan metadata mangle support (Florian Westphal) [RHEL-60554]
- netfilter: nft_payload: rebuild vlan header on h_proto access (Florian Westphal) [RHEL-60554]
- netfilter: nft_payload: rebuild vlan header when needed (Florian Westphal) [RHEL-60554]
- netfilter: nft_payload: move struct nft_payload_set definition where it belongs (Florian Westphal) [RHEL-60554]
- netfilter: nf_tables: add and use BE register load-store helpers (Florian Westphal) [RHEL-60554]
- wireguard: send: annotate intentional data race in checking empty queue (CKI Backport Bot) [RHEL-60227]
- wireguard: queueing: annotate intentional data race in cpu round robin (CKI Backport Bot) [RHEL-60227]
- dpll: extend lock_status_get() op by status error and expose to user (Petr Oros) [RHEL-59895]
- dpll: extend uapi by lock status error attribute (Petr Oros) [RHEL-59895]
- platform/x86/intel-uncore-freq: Add efficiency latency control to sysfs interface (David Arcari) [RHEL-46062]
- platform/x86/intel-uncore-freq: Add support for efficiency latency control (David Arcari) [RHEL-46062]
- platform/x86/intel-uncore-freq: Do not present separate package-die domain (David Arcari) [RHEL-46062]
- platform/x86/intel-uncore-freq: Use generic helpers for current frequency (David Arcari) [RHEL-46062]
- platform/x86/intel-uncore-freq: Rename the sysfs helper macro names (David Arcari) [RHEL-46062]
- platform/x86/intel-uncore-freq: Get rid of uncore_read_freq driver API (David Arcari) [RHEL-46062]
- platform/x86/intel-uncore-freq: Use uncore_index with read_control_freq (David Arcari) [RHEL-46062]
- platform/x86/intel-uncore-freq: Get rid of magic min_max argument (David Arcari) [RHEL-46062]
- platform/x86/intel-uncore-freq: Get rid of magic values (David Arcari) [RHEL-46062]
- platform/x86/intel-uncore-freq: Re-arrange bit masks (David Arcari) [RHEL-46062]
- platform/x86: intel-uncore-freq: Switch to new Intel CPU model defines (David Arcari) [RHEL-46062]
- selftests: forwarding: router_mpath_hash: Add a new selftest (Ivan Vecera) [RHEL-59087]
- selftests: forwarding: lib: Split sysctl_save() out of sysctl_set() (Ivan Vecera) [RHEL-59087]
- net: ipv4: Add a sysctl to set multipath hash seed (Ivan Vecera) [RHEL-59087]
- net: ipv4,ipv6: Pass multipath hash computation through a helper (Ivan Vecera) [RHEL-59087]
- Enable cryptographic curve25519 config flag for PowerPC (Mamatha Inamdar) [RHEL-52758]
- crypto: vmx - Improved AES/XTS performance of 6-way unrolling for ppc (Mamatha Inamdar) [RHEL-52758]
- crypto: ppc/curve25519 - Low-level primitives for ppc64le (Mamatha Inamdar) [RHEL-52758]
- crypto: ppc/curve25519 - Core functions for ppc64le (Mamatha Inamdar) [RHEL-52758]
- crypto: ppc/curve25519 - Update Kconfig and Makefile for ppc64le (Mamatha Inamdar) [RHEL-52758]

* Sat Oct 19 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-521.el9]
- ice: stop calling pci_disable_device() as we use pcim (Myron Stowe) [RHEL-59033]
- PCI: keystone: Fix if-statement expression in ks_pcie_quirk() (Myron Stowe) [RHEL-59033]
- PCI: Fix potential deadlock in pcim_intx() (Myron Stowe) [RHEL-59033]
- PCI: controller: Add missing MODULE_DESCRIPTION() macros (Myron Stowe) [RHEL-59033]
- PCI: Add missing MODULE_DESCRIPTION() macros (Myron Stowe) [RHEL-59033]
- PCI/PM: Switch to new Intel CPU model defines (Myron Stowe) [RHEL-59033]
- PCI: Use array for .id_table consistently (Myron Stowe) [RHEL-59033]
- ACPI: PCI: Remove unused struct 'acpi_handle_node' (Myron Stowe) [RHEL-59033]
- PCI: switchtec: Make switchtec_class constant (Myron Stowe) [RHEL-59033]
- PCI: vmd: Create domain symlink before pci_bus_add_devices() (Myron Stowe) [RHEL-59033]
- PCI: tegra: Remove unused struct 'tegra_pcie_soc' (Myron Stowe) [RHEL-59033]
- PCI: tegra194: Set EP alignment restriction for inbound ATU (Myron Stowe) [RHEL-59033]
- PCI: dw-rockchip: Refactor the driver to prepare for EP mode (Myron Stowe) [RHEL-59033]
- PCI: dw-rockchip: Add rockchip_pcie_get_ltssm() helper (Myron Stowe) [RHEL-59033]
- PCI: dw-rockchip: Fix weird indentation (Myron Stowe) [RHEL-59033]
- PCI: dw-rockchip: Fix initial PERST# GPIO value (Myron Stowe) [RHEL-59033]
- PCI: dw-rockchip: Add error messages in .probe() error paths (Myron Stowe) [RHEL-59033]
- PCI: rockchip: Use GPIOD_OUT_LOW flag while requesting ep_gpio (Myron Stowe) [RHEL-59033]
- PCI: rockchip-host: Wait 100ms after reset before starting configuration (Myron Stowe) [RHEL-59033]
- PCI: rockchip-host: Fix rockchip_pcie_host_init_port() PERST# handling (Myron Stowe) [RHEL-59033]
- PCI: rcar-gen4: Add support for R-Car V4H (Myron Stowe) [RHEL-59033]
- PCI: rcar-gen4: Add .ltssm_control() for other SoC support (Myron Stowe) [RHEL-59033]
- PCI: rcar-gen4: Add struct rcar_gen4_pcie_drvdata (Myron Stowe) [RHEL-59033]
- PCI: dwc: Add PCIE_PORT_{FORCE,LANE_SKEW} macros (Myron Stowe) [RHEL-59033]
- PCI: rcar: Demote WARN() to dev_warn_ratelimited() in rcar_pcie_wakeup() (Myron Stowe) [RHEL-59033]
- PCI: loongson: Enable MSI in LS7A Root Complex (Myron Stowe) [RHEL-59033]
- PCI: ls-gen4: Make struct mobiveil_rp_ops constant (Myron Stowe) [RHEL-59033]
- PCI: keystone: Add workaround for Errata #i2037 (AM65x SR 1.0) (Myron Stowe) [RHEL-59033]
- PCI: keystone: Don't enable BAR 0 for AM654x (Myron Stowe) [RHEL-59033]
- PCI: keystone: Relocate ks_pcie_set/clear_dbi_mode() (Myron Stowe) [RHEL-59033]
- PCI: exynos: Adapt to use bulk clock APIs (Myron Stowe) [RHEL-59033]
- PCI: dra7xx: Fix dra7xx_pcie_cpu_addr_fixup() parameter name (Myron Stowe) [RHEL-59033]
- PCI: artpec6: Fix artpec6_pcie_cpu_addr_fixup() parameter name (Myron Stowe) [RHEL-59033]
- PCI: al: Check IORESOURCE_BUS existence during probe (Myron Stowe) [RHEL-59033]
- PCI: dwc: ep: Enforce DWC specific 64-bit BAR limitation (Myron Stowe) [RHEL-59033]
- PCI: layerscape-ep: Use the generic dw_pcie_ep_linkdown() API to handle Link Down event (Myron Stowe) [RHEL-59033]
- PCI: qcom-ep: Use the generic dw_pcie_ep_linkdown() API to handle Link Down event (Myron Stowe) [RHEL-59033]
- PCI: dwc: ep: Remove dw_pcie_ep_init_notify() wrapper (Myron Stowe) [RHEL-59033]
- PCI: dwc: ep: Add a generic dw_pcie_ep_linkdown() API to handle Link Down event (Myron Stowe) [RHEL-59033]
- PCI: dwc: Add generic MSG TLP support for sending PME_Turn_Off when system suspend (Myron Stowe) [RHEL-59033]
- PCI: Add PCIE_MSG_CODE_PME_TURN_OFF message macro (Myron Stowe) [RHEL-59033]
- PCI: Add PCIE_MSG_CODE_ASSERT_INTx message macros (Myron Stowe) [RHEL-59033]
- PCI: dwc: Add outbound MSG TLPs support (Myron Stowe) [RHEL-59033]
- PCI: dwc: Consolidate args of dw_pcie_prog_outbound_atu() into a structure (Myron Stowe) [RHEL-59033]
- PCI: dwc: Fix index 0 incorrectly being interpreted as a free ATU slot (Myron Stowe) [RHEL-59033]
- PCI: dwc: Use msleep() in dw_pcie_wait_for_link() (Myron Stowe) [RHEL-59033]
- PCI: kirin: Convert to use agnostic GPIO API (Myron Stowe) [RHEL-59033]
- PCI: kirin: Convert kirin_pcie_parse_port() to scoped iterator (Myron Stowe) [RHEL-59033]
- PCI: imx6: Convert to use agnostic GPIO API (Myron Stowe) [RHEL-59033]
- PCI: dwc: Remove unused of_gpio.h inclusion (Myron Stowe) [RHEL-59033]
- PCI: aardvark: Remove unused of_gpio.h inclusion (Myron Stowe) [RHEL-59033]
- PCI: dra7xx: Add missing chained IRQ header inclusion (Myron Stowe) [RHEL-59033]
- Documentation: PCI: pci-endpoint: Fix EPF ops list (Myron Stowe) [RHEL-59033]
- misc: pci_endpoint_test: Remove unused pci_endpoint_test_bar_{readl,writel} functions (Myron Stowe) [RHEL-59033]
- misc: pci_endpoint_test: Document policy about adding pci_device_id (Myron Stowe) [RHEL-59033]
- misc: pci_endpoint_test: Refactor dma_set_mask_and_coherent() logic (Myron Stowe) [RHEL-59033]
- misc: pci_endpoint_test: Use memcpy_toio()/memcpy_fromio() for BAR tests (Myron Stowe) [RHEL-59033]
- misc: pci_endpoint_test: Add support for Rockchip rk3588 (Myron Stowe) [RHEL-59033]
- PCI: endpoint: Fix error handling in epf_ntb_epc_cleanup() (Myron Stowe) [RHEL-59033]
- PCI: endpoint: Clean up error handling in vpci_scan_bus() (Myron Stowe) [RHEL-59033]
- PCI: endpoint: Make pci_epc_class struct constant (Myron Stowe) [RHEL-59033]
- PCI: endpoint: Introduce 'epc_deinit' event and notify the EPF drivers (Myron Stowe) [RHEL-59033]
- PCI: endpoint: pci-epf-test: Handle Link Down event (Myron Stowe) [RHEL-59033]
- PCI: endpoint: pci-epf-{mhi/test}: Move DMA initialization to EPC init callback (Myron Stowe) [RHEL-59033]
- PCI: endpoint: pci-epf-test: Refactor pci_epf_test_unbind() function (Myron Stowe) [RHEL-59033]
- PCI: endpoint: Rename BME to Bus Master Enable (Myron Stowe) [RHEL-59033]
- PCI: endpoint: Rename core_init() callback in 'struct pci_epc_event_ops' to epc_init() (Myron Stowe) [RHEL-59033]
- PCI: endpoint: pci-epf-test: Use 'msix_capable' flag directly in pci_epf_test_alloc_space() (Myron Stowe) [RHEL-59033]
- PCI: endpoint: pci-epf-test: Make use of cached 'epc_features' in pci_epf_test_core_init() (Myron Stowe) [RHEL-59033]
- PCI: endpoint: Remove unused field in struct pci_epf_group (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: qcom: x1e80100: Make the MHI reg region mandatory (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: generic: Add ats-supported property (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: mediatek,mt7621-pcie: Add PCIe host topology ASCII graph (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: qcom: Add OPP table (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: xilinx-cpm: Fix overlapping of bridge register and 32-bit BAR addresses (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: rockchip: Add DesignWare based PCIe Endpoint controller (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: rockchip-dw-pcie: Fix description of legacy IRQ (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: rockchip-dw-pcie: Prepare for Endpoint mode support (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: snps,dw-pcie-ep: Add tx_int{a,b,c,d} legacy IRQs (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: snps,dw-pcie-ep: Add vendor specific interrupt-names (Myron Stowe) [RHEL-59033]
- dt-bindings: PCI: snps,dw-pcie-ep: Add vendor specific reg-name (Myron Stowe) [RHEL-59033]
- PCI: Relax bridge window tail sizing rules (Myron Stowe) [RHEL-59033]
- PCI: Make minimum bridge window alignment reference more obvious (Myron Stowe) [RHEL-59033]
- PCI: Fix resource double counting on remove & rescan (Myron Stowe) [RHEL-59033]
- resource: Export find_resource_space() (Myron Stowe) [RHEL-59033]
- resource: Handle simple alignment inside __find_resource_space() (Myron Stowe) [RHEL-59033]
- resource: Use typedef for alignf callback (Myron Stowe) [RHEL-59033]
- resource: Document find_resource_space() and resource_constraint (Myron Stowe) [RHEL-59033]
- resource: Rename find_resource() to find_resource_space() (Myron Stowe) [RHEL-59033]
- PCI: Warn on missing cfg_access_lock during secondary bus reset (Myron Stowe) [RHEL-59033]
- PCI/DPC: Disable DPC service on suspend (Myron Stowe) [RHEL-59033]
- PCI: Use preserve_config in place of pci_flags (Myron Stowe) [RHEL-59033]
- PCI: Unify ACPI and DT 'preserve config' support (Myron Stowe) [RHEL-59033]
- PCI: of: Add of_pci_preserve_config() for per-host bridge support (Myron Stowe) [RHEL-59033]
- PCI: Move PRESERVE_BOOT_CONFIG _DSM evaluation to pci_register_host_bridge() (Myron Stowe) [RHEL-59033]
- drm/vboxvideo: fix mapping leaks (Myron Stowe) [RHEL-59033]
- PCI: Add managed pcim_iomap_range() (Myron Stowe) [RHEL-59033]
- PCI: Remove legacy pcim_release() (Myron Stowe) [RHEL-59033]
- PCI: Fix devres regression in pci_intx() (Myron Stowe) [RHEL-59033]
- PCI: Add managed pcim_intx() (Myron Stowe) [RHEL-59033]
- PCI: Give pcim_set_mwi() its own devres cleanup callback (Myron Stowe) [RHEL-59033]
- PCI: Move struct pci_devres.pinned bit to struct pci_dev (Myron Stowe) [RHEL-59033]
- PCI: Remove struct pci_devres.enabled status bit (Myron Stowe) [RHEL-59033]
- PCI: Document hybrid devres hazards (Myron Stowe) [RHEL-59033]
- PCI: Add managed pcim_request_region() (Myron Stowe) [RHEL-59033]
- PCI: Deprecate pcim_iomap_table(), pcim_iomap_regions_request_all() (Myron Stowe) [RHEL-59033]
- PCI: Add managed partial-BAR request and map infrastructure (Myron Stowe) [RHEL-59033]
- PCI: Add devres helpers for iomap table (Myron Stowe) [RHEL-59033]
- PCI: Add and use devres helper for bit masks (Myron Stowe) [RHEL-59033]
- resource: add walk_system_ram_res_rev() (Myron Stowe) [RHEL-59033]
- kernel/resource: Increment by align value in get_free_mem_region() (Myron Stowe) [RHEL-59033]
- misc: pci_endpoint_test: Add deviceID for J721S2 PCIe EP device support (Myron Stowe) [RHEL-59033]
- resource: Unify next_resource() and next_resource_skip_children() (Myron Stowe) [RHEL-59033]
- resource: Reuse for_each_resource() macro (Myron Stowe) [RHEL-59033]
- PCI: move OF status = "disabled" detection to dev->match_driver (Myron Stowe) [RHEL-59033]
- PCI: Use of_property_present() for testing DT property presence (Myron Stowe) [RHEL-59033]
- resource: Replace printk(KERN_WARNING) by pr_warn(), printk() by pr_info() (Myron Stowe) [RHEL-59033]
- misc: pci_endpoint_test: Fix pci_endpoint_test_{copy,write,read}() panic (Myron Stowe) [RHEL-59033]
- misc: pci_endpoint_test: Aggregate params checking for xfer (Myron Stowe) [RHEL-59033]
- resource: add define macro for register address resources (Myron Stowe) [RHEL-59033]
- kernel/resource: fix kfree() of bootmem memory again (Myron Stowe) [RHEL-59033]
- PCI: of: Allow matching of an interrupt-map local to a PCI device (Myron Stowe) [RHEL-59033]
- RDMA: Remove unnecessary ternary operators (Kamal Heib) [RHEL-52273]
- RDMA/qedr: Remove a duplicate assignment in qedr_create_gsi_qp() (Kamal Heib) [RHEL-52273]
- RDMA/irdma: Annotate flexible array with __counted_by() in struct irdma_qvlist_info (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Remove duplicate assignment (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Add AE for too many RNRS (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Set the CQ read threshold for GEN 1 (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Validate max_send_wr and max_recv_wr (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Avoid free the non-cqp_request scratch (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Fix support for 64k pages (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Ensure iWarp QP queue memory is OS paged aligned (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Fix UAF in irdma_sc_ccq_get_cqe_info() (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Add wait for suspend on SQD (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Do not modify to SQD on error (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Use crypto_shash_digest() in irdma_ieq_check_mpacrc() (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Add support to re-register a memory region (Kamal Heib) [RHEL-49824]
- RDMA/irdma: Replace deprecated strncpy (Kamal Heib) [RHEL-49824]
- ibmvnic: Inspect header requirements before using scrq direct (Mamatha Inamdar) [RHEL-53368]
- ibmvnic: Perform tx CSO during send scrq direct (Mamatha Inamdar) [RHEL-53368]
- ibmvnic: Only record tx completed bytes once per handler (Mamatha Inamdar) [RHEL-53368]
- ibmvnic: Introduce send sub-crq direct (Mamatha Inamdar) [RHEL-53368]
- ibmvnic: Remove duplicate memory barriers in tx (Mamatha Inamdar) [RHEL-53368]
- ibmvnic: Reduce memcpys in tx descriptor generation (Mamatha Inamdar) [RHEL-53368]
- ibmvnic: Use header len helper functions on tx (Mamatha Inamdar) [RHEL-53368]
- ibmvnic: Only replenish rx pool when resources are getting low (Mamatha Inamdar) [RHEL-53368]
- ibmvnic: Return error code on TX scrq flush fail (Mamatha Inamdar) [RHEL-53368]
- ethtool: check device is present when getting link settings (Michal Schmidt) [RHEL-57750]
- net: ethtool: Allow write mechanism of LPL and both LPL and EPL (Michal Schmidt) [RHEL-57750]
- ethtool: Fix context creation with no parameters (Michal Schmidt) [RHEL-57750]
- net: ethtool: fix off-by-one error in max RSS context IDs (Michal Schmidt) [RHEL-57750]
- ethtool: fix the state of additional contexts with old API (Michal Schmidt) [RHEL-57750]
- ethtool: fix setting key and resetting indir at once (Michal Schmidt) [RHEL-57750]
- ethtool: rss: echo the context number back (Michal Schmidt) [RHEL-57750]
- netlink: specs: correct the spec of ethtool (Michal Schmidt) [RHEL-57750]
- net: Add struct kernel_ethtool_ts_info (Michal Schmidt) [RHEL-57750]
- net: Change the API of PHY default timestamp to MAC (Michal Schmidt) [RHEL-57750]
- net: phy: bcm54811: New link mode for BroadR-Reach (Michal Schmidt) [RHEL-57750]
- net: ethtool: pse-pd: Fix possible null-deref (Michal Schmidt) [RHEL-57750]
- net: ethtool: Monotonically increase the message sequence number (Michal Schmidt) [RHEL-57750]
- net: ethtool: let drivers declare max size of RSS indir table and key (Michal Schmidt) [RHEL-57750]
- net: ethtool: let drivers remove lost RSS contexts (Michal Schmidt) [RHEL-57750]
- net: ethtool: Fix RSS setting (Michal Schmidt) [RHEL-57750]
- ethtool: use the rss context XArray in ring deactivation safety-check (Michal Schmidt) [RHEL-57750]
- ethtool: fail closed if we can't get max channel used in indirection tables (Michal Schmidt) [RHEL-57750]
- ethtool: netlink: do not return SQI value if link is down (Michal Schmidt) [RHEL-57750]
- netlink: specs: Expand the PSE netlink command with C33 pw-limit attributes (Michal Schmidt) [RHEL-57750]
- net: ethtool: Add new power limit get and set features (Michal Schmidt) [RHEL-57750]
- net: pse-pd: Add new power limit get and set c33 features (Michal Schmidt) [RHEL-57750]
- netlink: specs: Expand the PSE netlink command with C33 new features (Michal Schmidt) [RHEL-57750]
- net: ethtool: pse-pd: Expand C33 PSE status with class, power and extended state (Michal Schmidt) [RHEL-57750]
- ethtool: move firmware flashing flag to struct ethtool_netdev_state (Michal Schmidt) [RHEL-57750]
- net: ethtool: fix compat with old RSS context API (Michal Schmidt) [RHEL-57750]
- net: ethtool: Fix the panic caused by dev being null when dumping coalesce (Michal Schmidt) [RHEL-57750]
- net: ethtool: use the tracking array for get_rxfh on custom RSS contexts (Michal Schmidt) [RHEL-57750]
- net: ethtool: add a mutex protecting RSS contexts (Michal Schmidt) [RHEL-57750]
- net: ethtool: add an extack parameter to new rxfh_context APIs (Michal Schmidt) [RHEL-57750]
- net: ethtool: let the core choose RSS context IDs (Michal Schmidt) [RHEL-57750]
- net: ethtool: record custom RSS contexts in the XArray (Michal Schmidt) [RHEL-57750]
- net: ethtool: attach an XArray of custom RSS contexts to a netdevice (Michal Schmidt) [RHEL-57750]
- net: move ethtool-related netdev state into its own struct (Michal Schmidt) [RHEL-57750]
- ethtool: Add ability to flash transceiver modules' firmware (Michal Schmidt) [RHEL-57750]
- ethtool: cmis_fw_update: add a layer for supporting firmware update using CDB (Michal Schmidt) [RHEL-57750]
- ethtool: cmis_cdb: Add a layer for supporting CDB commands (Michal Schmidt) [RHEL-57750]
- net: sfp: Add more extended compliance codes (Michal Schmidt) [RHEL-57750]
- ethtool: Veto some operations during firmware flashing process (Michal Schmidt) [RHEL-57750]
- net: no longer acquire RTNL in threaded_show() (Michal Schmidt) [RHEL-57750]
- ethtool: Add flashing transceiver modules' firmware notifications ability (Michal Schmidt) [RHEL-57750]
- ethtool: Add an interface for flashing transceiver modules' firmware (Michal Schmidt) [RHEL-57750]
- ethtool: Add ethtool operation to write to a transceiver module EEPROM (Michal Schmidt) [RHEL-57750]
- ethtool: provide customized dim profile management (Michal Schmidt) [RHEL-57750]
- netlink: specs: Fix pse-set command attributes (Michal Schmidt) [RHEL-57750]
- net: pse-pd: Use EOPNOTSUPP error code instead of ENOTSUPP (Michal Schmidt) [RHEL-57750]
- netlink: introduce type-checking attribute iteration (Michal Schmidt) [RHEL-57750]
- linux/dim: move useful macros to .h file (Michal Schmidt) [RHEL-57750]
- dim: initialize all struct fields (Michal Schmidt) [RHEL-57750]
- net: ethtool: remove unused struct 'cable_test_tdr_req_info' (Michal Schmidt) [RHEL-57750]
- ethtool: init tsinfo stats if requested (Michal Schmidt) [RHEL-57750]
- net: pse-pd: Use regulator framework within PSE framework (Michal Schmidt) [RHEL-57750]
- net: pse-pd: Add support for setup_pi_matrix callback (Michal Schmidt) [RHEL-57750]
- net: pse-pd: Add support for PSE PIs (Michal Schmidt) [RHEL-57750]
- netlink: specs: Expand the pse netlink command with PoE interface (Michal Schmidt) [RHEL-57750]
- netlink: specs: Modify pse attribute prefix (Michal Schmidt) [RHEL-57750]
- net: ethtool: pse-pd: Expand pse commands with the PSE PoE interface (Michal Schmidt) [RHEL-57750]
- net: pse-pd: Introduce PSE types enumeration (Michal Schmidt) [RHEL-57750]
- ethtool: Expand Ethernet Power Equipment with c33 (PoE) alongside PoDL (Michal Schmidt) [RHEL-57750]
- net: pse-pd: Rectify and adapt the naming of admin_cotrol member of struct pse_control_config (Michal Schmidt) [RHEL-57750]
- ethtool: update tsinfo statistics attribute docs with correct type (Michal Schmidt) [RHEL-57750]
- tools: ynl: ethtool.py: Output timestamping statistics from tsinfo-get operation (Michal Schmidt) [RHEL-57750]
- netlink: specs: ethtool: define header-flags as an enum (Michal Schmidt) [RHEL-57750]
- ethtool: add interface to read Tx hardware timestamping statistics (Michal Schmidt) [RHEL-57750]
- netlink: specs: define ethtool header flags (Michal Schmidt) [RHEL-57750]
- tools: ynl: ethtool.py: Make tool invokable from any CWD (Michal Schmidt) [RHEL-57750]
- net: ethtool: Add impedance mismatch result code to cable test (Michal Schmidt) [RHEL-57750]
- ethtool: remove ethtool_eee_use_linkmodes (Michal Schmidt) [RHEL-57750]
- ethtool: Add GTP RSS hash options to ethtool.h (Michal Schmidt) [RHEL-57750]
- ethtool: ignore unused/unreliable fields in set_eee op (Michal Schmidt) [RHEL-57750]
- tg3: copy only needed fields from userspace-provided EEE data (Michal Schmidt) [RHEL-57750]
- net: ethtool: eee: Remove legacy _u32 from keee (Michal Schmidt) [RHEL-57750]
- net: intel: i40e/igc: Remove setting Autoneg in EEE capabilities (Michal Schmidt) [RHEL-57750]
- tg3: fix bug caused by uninitialized variable (Michal Schmidt) [RHEL-57750]
- tg3: convert EEE handling to use linkmode bitmaps (Michal Schmidt) [RHEL-57750]
- net: qlogic: qede: Use linkmode helpers for EEE (Michal Schmidt) [RHEL-57750]
- net: intel: e1000e: Use linkmode helpers for EEE (Michal Schmidt) [RHEL-57750]
- net: ethernet: ixgbe: Convert EEE to use linkmodes (Michal Schmidt) [RHEL-57750]
- net: usb: ax88179_178a: Use linkmode helpers for EEE (Michal Schmidt) [RHEL-57750]
- net: usb: r8152: Use linkmode helpers for EEE (Michal Schmidt) [RHEL-57750]
- r8152: select CRC32 and CRYPTO/CRYPTO_HASH/CRYPTO_SHA256 (Michal Schmidt) [RHEL-57750]
- bnxt: convert EEE handling to use linkmode bitmaps (Michal Schmidt) [RHEL-57750]
- bnx2x: convert EEE handling to use linkmode bitmaps (Michal Schmidt) [RHEL-57750]
- net: atlantic: convert EEE handling to use linkmode bitmaps (Michal Schmidt) [RHEL-57750]
- net: ethtool: avoid rebuilds on UTS_RELEASE change (Michal Schmidt) [RHEL-57750]
- ethtool: do not use rtnl in ethnl_default_dumpit() (Michal Schmidt) [RHEL-57750]
- RDMA/iwcm: Fix WARNING:at_kernel/workqueue.c:#check_flush_dependency (Kamal Heib) [RHEL-56247]
- RDMA/core: Introduce "name_assign_type" for an IB device (Kamal Heib) [RHEL-56247]
- RDMA: Fix netdev tracker in ib_device_set_netdev (Kamal Heib) [RHEL-56247]
- RDMA/nldev: Add support to dump device type and parent device if exists (Kamal Heib) [RHEL-56247]
- RDMA/nldev: Add support to add/delete a sub IB device through netlink (Kamal Heib) [RHEL-56247]
- RDMA/core: Create GSI QP only when CM is supported (Kamal Heib) [RHEL-56247]
- RDMA: Set type of rdma_ah to IB for a SMI sub device (Kamal Heib) [RHEL-56247]
- RDMA/core: Support IB sub device with type "SMI" (Kamal Heib) [RHEL-56247]
- RDMA/core: Create "issm*" device nodes only when SMI is supported (Kamal Heib) [RHEL-56247]
- RDMA/device: Return error earlier if port in not valid (Kamal Heib) [RHEL-56247]
- RDMA: Pass entire uverbs attr bundle to create cq function (Kamal Heib) [RHEL-56247]
- IB/isert: remove the handling of last WQE reached event (Kamal Heib) [RHEL-56247]
- IB/core: add support for draining Shared receive queues (Kamal Heib) [RHEL-56247]
- RDMA/cache: Release GID table even if leak is detected (Kamal Heib) [RHEL-56247]
- RDMA/iwcm: Fix a use-after-free related to destroying CM IDs (Kamal Heib) [RHEL-56247]
- RDMA/iwcm: Simplify cm_work_handler() (Kamal Heib) [RHEL-56247]
- RDMA/iwcm: Simplify cm_event_handler() (Kamal Heib) [RHEL-56247]
- RDMA/iwcm: Change the return type of iwcm_deref_id() (Kamal Heib) [RHEL-56247]
- RDMA/iwcm: Use list_first_entry() where appropriate (Kamal Heib) [RHEL-56247]
- RDMA/cma: Fix kmemleak in rdma_core observed during blktests nvme/rdma use siw (Kamal Heib) [RHEL-56247]
- RDMA/IPoIB: Fix format truncation compilation errors (Kamal Heib) [RHEL-56247]
- RDMA/core: Remove NULL check before dev_{put, hold} (Kamal Heib) [RHEL-56247]
- RDMA/ipoib: Remove NULL check before dev_{put, hold} (Kamal Heib) [RHEL-56247]
- RDMA/core: Add an option to display driver-specific QPs in the rdmatool (Kamal Heib) [RHEL-56247]
- IB/core: Implement a limit on UMAD receive List (Kamal Heib) [RHEL-56247]
- RDMA/restrack: Fix potential invalid address access (Kamal Heib) [RHEL-56247]
- RDMA/cm: Print the old state when cm_destroy_id gets timeout (Kamal Heib) [RHEL-56247]
- RDMA/cm: add timeout to cm_destroy_id wait (Kamal Heib) [RHEL-56247]
- RDMA/uverbs: Avoid -Wflex-array-member-not-at-end warnings (Kamal Heib) [RHEL-56247]
- RDMA/uverbs: Remove flexible arrays from struct *_filter (Kamal Heib) [RHEL-56247]
- RDMA/device: Fix a race between mad_client and cm_client init (Kamal Heib) [RHEL-56247]
- RDMA/srpt: fix function pointer cast warnings (Kamal Heib) [RHEL-56247]
- RDMA/ipoib: Print symbolic error name instead of error code (Kamal Heib) [RHEL-56247]
- IB/iser: Prevent invalidating wrong MR (Kamal Heib) [RHEL-56247]
- IB/iser: iscsi_iser.h: fix kernel-doc warning and spellos (Kamal Heib) [RHEL-56247]
- RDMA/core: Fix umem iterator when PAGE_SIZE is greater then HCA pgsz (Kamal Heib) [RHEL-56247]
- RDMA/IPoIB: Add tx timeout work to recover queue stop situation (Kamal Heib) [RHEL-56247]
- RDMA/core: Remove NULL check before dev_{put, hold} (Kamal Heib) [RHEL-56247]
- RDMA/core: Add support to set privileged QKEY parameter (Kamal Heib) [RHEL-56247]
- RDMA/core: Fix a couple of obvious typos in comments (Kamal Heib) [RHEL-56247]
- IB/srp: Annotate struct srp_fr_pool with __counted_by (Kamal Heib) [RHEL-56247]
- RDMA/core: Annotate struct ib_pkey_cache with __counted_by (Kamal Heib) [RHEL-56247]
- RDMA: Annotate struct rdma_hw_stats with __counted_by (Kamal Heib) [RHEL-56247]
- RDMA/core: Add support to dump SRQ resource in RAW format (Kamal Heib) [RHEL-56247]
- RDMA/core: Add dedicated SRQ resource tracker function (Kamal Heib) [RHEL-56247]
- RDMA/core: Fix repeated words in comments (Kamal Heib) [RHEL-56247]
- IB: Use capital "OR" for multiple licenses in SPDX (Kamal Heib) [RHEL-56247]
- IB/core: Add more speed parsing in ib_get_width_and_speed() (Kamal Heib) [RHEL-56247]
- RDMA Remove unused function declarations (Kamal Heib) [RHEL-56247]
- RDMA: Make all 'class' structures const (Kamal Heib) [RHEL-56247]
- RDMA: Remove unnecessary ternary operators (Kamal Heib) [RHEL-56247]
- scsi: infiniband: srpt: Remove default fabric ops callouts (Kamal Heib) [RHEL-56247]
- treewide: use get_random_u32_inclusive() when possible (Kamal Heib) [RHEL-56247]
- treewide: use get_random_u32_below() instead of deprecated function (Kamal Heib) [RHEL-56247]
- iommu/hyper-v: Use helper instead of directly accessing affinity (Jerry Snitselaar) [RHEL-55466]
- iommu: Do not return 0 from map_pages if it doesn't do anything (Jerry Snitselaar) [RHEL-55466]
- iommufd: Do not allow creating areas without READ or WRITE (Jerry Snitselaar) [RHEL-55466]
- iommu: Handle iommu faults for a bad iopf setup (Jerry Snitselaar) [RHEL-55466]
- iommu: Remove unused declaration iommu_sva_unbind_gpasid() (Jerry Snitselaar) [RHEL-55466]
- MAINTAINERS: Update IOMMU tree location (Jerry Snitselaar) [RHEL-55466]
- iommu/vt-d: Fix incorrect domain ID in context flush helper (Jerry Snitselaar) [RHEL-54189]
- arm64: Properly clean up iommu-dma remnants (Jerry Snitselaar) [RHEL-55466]
- iommu: Restore lost return in iommu_report_device_fault() (Jerry Snitselaar) [RHEL-57229] {CVE-2024-44994}
- iommufd/device: Fix hwpt at err_unresv in iommufd_device_do_replace() (Jerry Snitselaar) [RHEL-55466]
- iommufd/selftest: Make dirty_ops static (Jerry Snitselaar) [RHEL-55466]
- iommufd: merge commit fixup for pfn_reader_user_init (Jerry Snitselaar) [RHEL-55466]
- Documentation/core-api: correct reference to SWIOTLB_DYNAMIC (Jerry Snitselaar) [RHEL-55466]
- iommufd: Use atomic_long_try_cmpxchg() in incr_user_locked_vm() (Jerry Snitselaar) [RHEL-55466]
- iommufd: Put constants for all the uAPI enums (Jerry Snitselaar) [RHEL-55466]
- iommufd: Fix error pointer checking (Jerry Snitselaar) [RHEL-55466]
- iommufd: Add check on user response code (Jerry Snitselaar) [RHEL-55466]
- iommufd: Remove IOMMUFD_PAGE_RESP_FAILURE (Jerry Snitselaar) [RHEL-55199]
- iommufd: Require drivers to supply the cache_invalidate_user ops (Jerry Snitselaar) [RHEL-55466]
- iommufd/selftest: Add coverage for IOPF test (Jerry Snitselaar) [RHEL-55199]
- iommufd/selftest: Add IOPF support for mock device (Jerry Snitselaar) [RHEL-55199]
- iommufd: Associate fault object with iommufd_hw_pgtable (Jerry Snitselaar) [RHEL-55199]
- iommufd: Fault-capable hwpt attach/detach/replace (Jerry Snitselaar) [RHEL-55199]
- iommufd: Add iommufd fault object (Jerry Snitselaar) [RHEL-55199]
- iommufd: Add fault and response message definitions (Jerry Snitselaar) [RHEL-55199]
- iommu: Extend domain attach group with handle support (Jerry Snitselaar) [RHEL-55199]
- iommu: Add attach handle to struct iopf_group (Jerry Snitselaar) [RHEL-55199]
- iommu: Remove sva handle list (Jerry Snitselaar) [RHEL-55199]
- iommu: Introduce domain attachment handle (Jerry Snitselaar) [RHEL-55199]
- iommu: Move IOMMU_DIRTY_NO_CLEAR define (Jerry Snitselaar) [RHEL-55200]
- iommu/arm-smmu-v3: Enable HTTU for stage1 with io-pgtable mapping (Jerry Snitselaar) [RHEL-55200]
- iommu/arm-smmu-v3: Add support for dirty tracking in domain alloc (Jerry Snitselaar) [RHEL-55200]
- iommu/arm-smmu-v3: Add feature detection for HTTU (Jerry Snitselaar) [RHEL-55200]
- iommu/io-pgtable-arm-v7s: Add a quirk to allow pgtable PA up to 35bit (Jerry Snitselaar) [RHEL-55200]
- iommu/arm-smmu-v3: Add support for domain_alloc_user fn (Jerry Snitselaar) [RHEL-55200]
- Patch:  iommu-io-pgtable-arm-Add-read_and_clear_dirty-support Author: Jerry Snitselaar <jsnitsel@redhat.com> Date:   2024-08-12 22:33:00 -0700 (Jerry Snitselaar) [RHEL-55200]
- iommu/arm-smmu-v3: add missing MODULE_DESCRIPTION() macro (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-v3: Shrink the strtab l1_desc array (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-v3: Do not zero the strtab twice (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-v3: Allow setting a S1 domain to a PASID (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Allow a PASID to be set when RID is IDENTITY/BLOCKED (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Test the STE S1DSS functionality (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Allow IDENTITY/BLOCKED to be set while PASID is used (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Put the SVA mmu notifier in the smmu_domain (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Keep track of arm_smmu_master_domain for SVA (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Make SVA allocate a normal arm_smmu_domain (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Thread SSID through the arm_smmu_attach_*() interface (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Do not use master->sva_enable to restrict attaches (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Add ssid to struct arm_smmu_master_domain (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Make changing domains be hitless for ATS (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Make smmu_domain->devices into an allocated list (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Start building a generic PASID layer (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Convert to domain_alloc_sva() (Jerry Snitselaar) [RHEL-36247]
- iommu/arm-smmu-v3: Use *-y instead of *-objs in Makefile (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-v3: Avoid uninitialized asid in case of error (Jerry Snitselaar) [RHEL-55448]
- iommu: arm-smmu: Fix Tegra workaround for PAGE_SIZE mappings (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-qcom: Register the TBU driver in qcom_smmu_impl_init (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-qcom: record reason for deferring probe (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu: Pretty-print context fault related regs (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-qcom-debug: Do not print for handled faults (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu: Add CB prefix to register bitfields (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-qcom: Don't build debug features as a kernel module (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-qcom: Use the custom fault handler on more platforms (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-qcom: Use a custom context fault handler for sdm845 (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu: Allow using a threaded handler for context interrupts (Jerry Snitselaar) [RHEL-55448]
- iommu/arm-smmu-qcom-debug: Add support for TBUs (Jerry Snitselaar) [RHEL-55448]
- iommu/vt-d: Fix identity map bounds in si_domain_init() (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Fix aligned pages in calculate_psi_aligned_address() (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Limit max address mask to MAX_AGAW_PFN_WIDTH (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Refactor PCI PRI enabling/disabling callbacks (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Add helper to flush caches for context change (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Add helper to allocate paging domain (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Downgrade warning for pre-enabled IR (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Remove control over Execute-Requested requests (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Remove comment for def_domain_type (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Handle volatile descriptor status read (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Use try_cmpxchg64() in intel_pasid_get_entry() (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Remove struct intel_svm (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Remove intel_svm_dev (Jerry Snitselaar) [RHEL-55450]
- iommu/vt-d: Fix missed device TLB cache tag (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Use cache helpers in arch_invalidate_secondary_tlbs (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Use cache_tag_flush_range() in cache_invalidate_user (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Cleanup use of iommu_flush_iotlb_psi() (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Use cache_tag_flush_range_np() in iotlb_sync_map (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Use cache_tag_flush_range() in tlb_sync (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Use cache_tag_flush_all() in flush_iotlb_all (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Add trace events for cache tag interface (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Add cache tag invalidation helpers (Jerry Snitselaar) [RHEL-54189]
- iommu/vt-d: Add cache tag assignment interface (Jerry Snitselaar) [RHEL-54189]
- iommu/amd: Convert comma to semicolon (Jerry Snitselaar) [RHEL-55450]
- iommu/amd: Use try_cmpxchg64() in v2_alloc_pte() (Jerry Snitselaar) [RHEL-55450]
- iommu/amd: Change log message severity (Jerry Snitselaar) [RHEL-55450]
- iommu/amd: Do not enable SNP when V2 page table is enabled (Jerry Snitselaar) [RHEL-55450]
- iommu: account IOMMU allocated memory (Jerry Snitselaar) [RHEL-54186]
- iommu: observability of the IOMMU allocations (Jerry Snitselaar) [RHEL-54186]
- iommu/tegra-smmu: use page allocation function provided by iommu-pages.h (Jerry Snitselaar) [RHEL-54186]
- iommu/io-pgtable-arm: use page allocation function provided by iommu-pages.h (Jerry Snitselaar) [RHEL-54186]
- iommu/amd: use page allocation function provided by iommu-pages.h (Jerry Snitselaar) [RHEL-54186]
- iommu/dma: use iommu_put_pages_list() to releae freelist (Jerry Snitselaar) [RHEL-54186]
- iommu/vt-d: add wrapper functions for page allocations (Jerry Snitselaar) [RHEL-54186]
- dma-debug: avoid deadlock between dma debug vs printk and netconsole (Jerry Snitselaar) [RHEL-55466]
- swiotlb: fix kernel-doc description for swiotlb_del_transient (Jerry Snitselaar) [RHEL-55466]
- swiotlb: reduce swiotlb pool lookups (Jerry Snitselaar) [RHEL-55466]
- change alloc_pages name in dma_map_ops to avoid name conflicts (Jerry Snitselaar) [RHEL-55466]
- dma-mapping: benchmark: Don't starve others when doing the test (Jerry Snitselaar) [RHEL-55466]
- dma-mapping: benchmark: handle NUMA_NO_NODE correctly (Jerry Snitselaar) [RHEL-55466]
- dma-mapping: benchmark: fix node id validation (Jerry Snitselaar) [RHEL-55466]
- dma-mapping: benchmark: avoid needless copy_to_user if benchmark fails (Jerry Snitselaar) [RHEL-55466]
- dma-mapping: benchmark: fix up kthread-related error handling (Jerry Snitselaar) [RHEL-55466]
- wifi: ath11k: Use iommu_paging_domain_alloc() (Jerry Snitselaar) [RHEL-55466]
- wifi: ath10k: Use iommu_paging_domain_alloc() (Jerry Snitselaar) [RHEL-55466]
- RDMA/usnic: Use iommu_paging_domain_alloc() (Jerry Snitselaar) [RHEL-55466]
- vhost-vdpa: Use iommu_paging_domain_alloc() (Jerry Snitselaar) [RHEL-55466]
- vfio/type1: Use iommu_paging_domain_alloc() (Jerry Snitselaar) [RHEL-55466]
- iommufd: Use iommu_paging_domain_alloc() (Jerry Snitselaar) [RHEL-55466]
- iommu: Add iommu_paging_domain_alloc() interface (Jerry Snitselaar) [RHEL-55466]
- arm64: dts: fvp: Enable PCIe ATS for Base RevC FVP (Jerry Snitselaar) [RHEL-55448]
- iommu/of: Support ats-supported device-tree property (Jerry Snitselaar) [RHEL-55466]
- dt-bindings: PCI: generic: Add ats-supported property (Jerry Snitselaar) [RHEL-55448]
- iommu: Remove iommu_fwspec ops (Jerry Snitselaar) [RHEL-55466]
- OF: Simplify of_iommu_configure() (Jerry Snitselaar) [RHEL-55466]
- ACPI: Retire acpi_iommu_fwspec_ops() (Jerry Snitselaar) [RHEL-55466]
- iommu: Resolve fwspec ops automatically (Jerry Snitselaar) [RHEL-55466]
- iommu/tegra-smmu: Pass correct fwnode to iommu_fwspec_init() (Jerry Snitselaar) [RHEL-55466]
- iommu/iova: Add missing MODULE_DESCRIPTION() macro (Jerry Snitselaar) [RHEL-55466]
- iommu/dma: Prune redundant pgprot arguments (Jerry Snitselaar) [RHEL-55466]
- iommu/dma: Fix domain init (Jerry Snitselaar) [RHEL-55466]
- dma-mapping: Simplify arch_setup_dma_ops() (Jerry Snitselaar) [RHEL-55466]
- iommu/dma: Centralise iommu_setup_dma_ops() (Jerry Snitselaar) [RHEL-55466]
- iommu/dma: Make limit checks self-contained (Jerry Snitselaar) [RHEL-55466]
- dma-mapping: Add helpers for dma_range_map bounds (Jerry Snitselaar) [RHEL-55466]
- OF: Simplify DMA range calculations (Jerry Snitselaar) [RHEL-55466]
- OF: Retire dma-ranges mask workaround (Jerry Snitselaar) [RHEL-55466]
- selftests/dma:remove unused variable (Jerry Snitselaar) [RHEL-55466]
- Documentation/core-api: add swiotlb documentation (Jerry Snitselaar) [RHEL-55466]
- iommu: virtio: drop owner assignment (Jerry Snitselaar) [RHEL-55466]
- iommu: Make iommu_sva_domain_alloc() static (Jerry Snitselaar) [RHEL-55466]
- kthread: add kthread_stop_put (Jerry Snitselaar) [RHEL-55466]
- uapi: Add missing _UAPI prefix to <asm-generic/types.h> include guard (Waiman Long) [RHEL-50732]
- hugetlb_encode.h: fix undefined behaviour (34 << 26) (Waiman Long) [RHEL-50732]
- Revert "fw loader: Remove the now superfluous sentinel element from ctl_table array" (Eric Chanudet) [RHEL-50129]
- net: add debugging checks in skb_attempt_defer_free() (Wander Lairson Costa) [RHEL-9145]
- net: optimize ____napi_schedule() to avoid extra NET_RX_SOFTIRQ (Wander Lairson Costa) [RHEL-9145]
- net: call skb_defer_free_flush() before each napi_poll() (Wander Lairson Costa) [RHEL-9145]
- net: do not consume a cacheline for system_page_pool (Wander Lairson Costa) [RHEL-9145]
- tcp: drop skb dst in tcp_rcv_established() (Wander Lairson Costa) [RHEL-9145]
- net: make sure net_rx_action() calls skb_defer_free_flush() (Wander Lairson Costa) [RHEL-9145]
- net: call skb_defer_free_flush() from __napi_busy_loop() (Wander Lairson Costa) [RHEL-9145]
- net: do not provide hard irq safety for sd->defer_lock (Wander Lairson Costa) [RHEL-9145]
- net: avoid irqsave in skb_defer_free_flush (Wander Lairson Costa) [RHEL-9145]
- net: avoid strange behavior with skb_defer_max == 1 (Wander Lairson Costa) [RHEL-9145]
- net: add skb_defer_max sysctl (Wander Lairson Costa) [RHEL-9145]
- net: use napi_consume_skb() in skb_defer_free_flush() (Wander Lairson Costa) [RHEL-9145]
- net: Rename rps_lock to backlog_lock. (Wander Lairson Costa) [RHEL-9145]
- net: Use backlog-NAPI to clean up the defer_list. (Wander Lairson Costa) [RHEL-9145]
- net: Allow to use SMP threads for backlog NAPI. (Wander Lairson Costa) [RHEL-9145]
- net: Remove conditional threaded-NAPI wakeup based on task state. (Wander Lairson Costa) [RHEL-9145]
- net: add generic percpu page_pool allocator (Wander Lairson Costa) [RHEL-9145]
- net: optimize napi_threaded_poll() vs RPS/RFS (Wander Lairson Costa) [RHEL-9145]
- net: make napi_threaded_poll() aware of sd->defer_list (Wander Lairson Costa) [RHEL-9145]
- net: optimize napi_schedule_rps() (Wander Lairson Costa) [RHEL-9145]
- net: add softnet_data.in_net_rx_action (Wander Lairson Costa) [RHEL-9145]
- net: napi_schedule_rps() cleanup (Wander Lairson Costa) [RHEL-9145]
- net: fix possible race in skb_attempt_defer_free() (Wander Lairson Costa) [RHEL-9145]
- net: generalize skb freeing deferral to per-cpu lists (Wander Lairson Costa) [RHEL-9145]
- net/tls: Fix another skb memory leak when running kTLS traffic (Wander Lairson Costa) [RHEL-9145]
- net/tls: Fix skb memory leak when running kTLS traffic (Wander Lairson Costa) [RHEL-9145]
- tcp: do not call tcp_cleanup_rbuf() if we have a backlog (Wander Lairson Costa) [RHEL-9145]
- tcp: Add a stub for sk_defer_free_flush() (Wander Lairson Costa) [RHEL-9145]
- tcp: add a missing sk_defer_free_flush() in tcp_splice_read() (Wander Lairson Costa) [RHEL-9145]
- net: Flush deferred skb free on socket destroy (Wander Lairson Costa) [RHEL-9145]
- tcp: defer skb freeing after socket lock is released (Wander Lairson Costa) [RHEL-9145]

* Fri Oct 18 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-520.el9]
- md: md-faulty: switch to new queue limit API (Ming Lei) [RHEL-56837]
- md: md-linear: switch to new queue limit API (Ming Lei) [RHEL-56837]
- block: rsxx: switch to new queue limit API (Ming Lei) [RHEL-56837]
- scsi: sd: Don't check if a write for REQ_ATOMIC (Ming Lei) [RHEL-56837]
- scsi: block: Don't check REQ_ATOMIC for reads (Ming Lei) [RHEL-56837]
- block: Fix elv_iosched_local_module handling of "none" scheduler (Ming Lei) [RHEL-56837]
- lib/sbitmap: define swap_lock as raw_spinlock_t (Ming Lei) [RHEL-56837]
- dm: always manage discard support in terms of max_hw_discard_sectors (Ming Lei) [RHEL-56837]
- dm-crypt: stop constraining max_segment_size to PAGE_SIZE (Ming Lei) [RHEL-56837]
- nvme: set BLK_FEAT_ZONED for ZNS multipath disks (Ming Lei) [RHEL-56837]
- scsi: sd: Move sd_read_cpr() out of the q->limits_lock region (Ming Lei) [RHEL-56837]
- nvdimm/pmem: Set dax flag for all 'PFN_MAP' cases (Ming Lei) [RHEL-56837]
- ata: pata_macio: Fix DMA table overflow (Ming Lei) [RHEL-56837]
- ata: pata_macio: Fix max_segment_size with PAGE_SIZE == 64K (Ming Lei) [RHEL-56837]
- mmc: sdhci: Fix max_seg_size for 64KiB PAGE_SIZE (Ming Lei) [RHEL-56837]
- signalfd: fix error return code (Ming Lei) [RHEL-56837]
- scsi: ipr: Remove several unused variables (Ming Lei) [RHEL-56837]
- nvme: don't create a multipath node for zero capacity devices (Ming Lei) [RHEL-56837]
- scsi: bsg: Pass dev to blk_mq_alloc_queue() (Ming Lei) [RHEL-56837]
- block: don't reject too large max_user_sectors in blk_validate_limits (Ming Lei) [RHEL-56837]
- nbd: correct the maximum value for discard sectors (Ming Lei) [RHEL-56837]
- block: Prevent deadlocks when switching elevators (Ming Lei) [RHEL-56837]
- bio-integrity: don't restrict the size of integrity metadata (Ming Lei) [RHEL-56837]
- block: fix detection of unsupported WRITE SAME in blkdev_issue_write_zeroes (Ming Lei) [RHEL-56837]
- block: Drop NULL check in bdev_write_zeroes_sectors() (Ming Lei) [RHEL-56837]
- block: Read max write zeroes once for __blkdev_issue_write_zeroes() (Ming Lei) [RHEL-56837]
- block: Fix lockdep warning in blk_mq_mark_tag_wait (Ming Lei) [RHEL-56837]
- blk-throttle: remove more latency dead-code (Ming Lei) [RHEL-56837]
- block: don't free the integrity payload in bio_integrity_unmap_free_user (Ming Lei) [RHEL-56837]
- block: don't free submitter owned integrity payload on I/O completion (Ming Lei) [RHEL-56837]
- block: call bio_integrity_unmap_free_user from blk_rq_unmap_user (Ming Lei) [RHEL-56837]
- block: don't call bio_uninit from bio_endio (Ming Lei) [RHEL-56837]
- block: also return bio_integrity_payload * from stubs (Ming Lei) [RHEL-56837]
- block: split integrity support out of bio.h (Ming Lei) [RHEL-56837]
- block: unmap and free user mapped integrity via submitter (Ming Lei) [RHEL-56837]
- nvme/io_uring: use helper for polled completions (Ming Lei) [RHEL-56837]
- io_uring/cmd: document some uring_cmd related helpers (Ming Lei) [RHEL-56837]
- io_uring/cmd: fix tw <-> issue_flags conversion (Ming Lei) [RHEL-56837]
- io_uring/cmd: kill one issue_flags to tw conversion (Ming Lei) [RHEL-56837]
- io_uring/cmd: move io_uring_try_cancel_uring_cmd() (Ming Lei) [RHEL-56837]
- blk-cgroup: move congestion_count to struct blkcg (Ming Lei) [RHEL-56837]
- sbitmap: fix io hung due to race on sbitmap_word::cleared (Ming Lei) [RHEL-56837]
- block: avoid polling configuration errors (Ming Lei) [RHEL-56837]
- block: Catch possible entries missing from rqf_name[] (Ming Lei) [RHEL-56837]
- block: Simplify definition of RQF_NAME() (Ming Lei) [RHEL-56837]
- block: Use enum to define RQF_x bit indexes (Ming Lei) [RHEL-56837]
- block: Catch possible entries missing from cmd_flag_name[] (Ming Lei) [RHEL-56837]
- block: Catch possible entries missing from alloc_policy_name[] (Ming Lei) [RHEL-56837]
- block: Catch possible entries missing from hctx_flag_name[] (Ming Lei) [RHEL-56837]
- block: Catch possible entries missing from hctx_state_name[] (Ming Lei) [RHEL-56837]
- block: Catch possible entries missing from blk_queue_flag_name[] (Ming Lei) [RHEL-56837]
- block: Make QUEUE_FLAG_x as an enum (Ming Lei) [RHEL-56837]
- block: Relocate BLK_MQ_MAX_DEPTH (Ming Lei) [RHEL-56837]
- block: Relocate BLK_MQ_CPU_WORK_BATCH (Ming Lei) [RHEL-56837]
- block: remove QUEUE_FLAG_STOPPED (Ming Lei) [RHEL-56837]
- block: Add missing entry to hctx_flag_name[] (Ming Lei) [RHEL-56837]
- block: Add zone write plugging entry to rqf_name[] (Ming Lei) [RHEL-56837]
- block: Add missing entries from cmd_flag_name[] (Ming Lei) [RHEL-56837]
- floppy: add missing MODULE_DESCRIPTION() macro (Ming Lei) [RHEL-56837]
- loop: add missing MODULE_DESCRIPTION() macro (Ming Lei) [RHEL-56837]
- xen/blkback: add missing MODULE_DESCRIPTION() macro (Ming Lei) [RHEL-56837]
- block/rnbd: Constify struct kobj_type (Ming Lei) [RHEL-56837]
- block: take offset into account in blk_bvec_map_sg again (Ming Lei) [RHEL-56837]
- block: fix get_max_segment_size() warning (Ming Lei) [RHEL-56837]
- loop: Don't bother validating blocksize (Ming Lei) [RHEL-56837]
- virtio_blk: Don't bother validating blocksize (Ming Lei) [RHEL-56837]
- null_blk: Don't bother validating blocksize (Ming Lei) [RHEL-56837]
- block: Validate logical block size in blk_validate_limits() (Ming Lei) [RHEL-56837]
- virtio_blk: Fix default logical block size fallback (Ming Lei) [RHEL-56837]
- block: pass a phys_addr_t to get_max_segment_size (Ming Lei) [RHEL-56837]
- block: add a bvec_phys helper (Ming Lei) [RHEL-56837]
- blk-lib: check for kill signal in ioctl BLKZEROOUT (Ming Lei) [RHEL-56837]
- block: limit the Write Zeroes to manually writing zeroes fallback (Ming Lei) [RHEL-56837]
- block: refacto blkdev_issue_zeroout (Ming Lei) [RHEL-56837]
- block: move read-only and supported checks into (__)blkdev_issue_zeroout (Ming Lei) [RHEL-56837]
- block: remove the LBA alignment check in __blkdev_issue_zeroout (Ming Lei) [RHEL-56837]
- block: factor out a blk_write_zeroes_limit helper (Ming Lei) [RHEL-56837]
- block: Remove blk_alloc_zone_bitmap() (Ming Lei) [RHEL-56837]
- block: Remove REQ_OP_ZONE_RESET_ALL emulation (Ming Lei) [RHEL-56837]
- block: remove gfp_flags from blkdev_zone_mgmt (Ming Lei) [RHEL-56837]
- dm: dm-zoned: guard blkdev_zone_mgmt with noio scope (Ming Lei) [RHEL-56837]
- zonefs: pass GFP_KERNEL to blkdev_zone_mgmt() call (Ming Lei) [RHEL-56837]
- dm: handle REQ_OP_ZONE_RESET_ALL (Ming Lei) [RHEL-56837]
- dm: Refactor is_abnormal_io() (Ming Lei) [RHEL-56837]
- null_blk: Introduce the zone_full parameter (Ming Lei) [RHEL-56837]
- loop: remove the unused inode variable in loop_configure (Ming Lei) [RHEL-56837]
- block: reuse original bio_vec array for integrity during clone (Ming Lei) [RHEL-56837]
- null_blk: don't initialize static 'g_virt_boundary' to false (Ming Lei) [RHEL-56837]
- block: t10-pi: Return correct ref tag when queue has no integrity profile (Ming Lei) [RHEL-56837]
- xen-blkfront: fix sector_size propagation to the block layer (Ming Lei) [RHEL-56837]
- null_blk: Fix description of the fua parameter (Ming Lei) [RHEL-56837]
- block/mq-deadline: Fix the tag reservation code (Ming Lei) [RHEL-56837]
- block: Call .limit_depth() after .hctx has been set (Ming Lei) [RHEL-56837]
- nvme: don't set io_opt if NOWS is zero (Ming Lei) [RHEL-56837]
- block: don't reduce max_sectors based on io_opt (Ming Lei) [RHEL-56837]
- block: remove a duplicate io_min check in blk_validate_limits (Ming Lei) [RHEL-56837]
- blk-wbt: don't throttle swap writes in direct reclaim (Ming Lei) [RHEL-56837]
- block: pass a gendisk to the queue_sysfs_entry methods (Ming Lei) [RHEL-56837]
- block: add helper macros to de-duplicate the queue sysfs attributes (Ming Lei) [RHEL-56837]
- block: simplify queue_logical_block_size (Ming Lei) [RHEL-56837]
- blk-throttle: fix lower control under super low iops limit (Ming Lei) [RHEL-56837]
- rnbd-cnt: don't set QUEUE_FLAG_SAME_FORCE (Ming Lei) [RHEL-56837]
- rnbd: don't set QUEUE_FLAG_SAME_COMP (Ming Lei) [RHEL-56837]
- mpt3sas_scsih: don't set QUEUE_FLAG_NOMERGES (Ming Lei) [RHEL-56837]
- megaraid_sas: don't set QUEUE_FLAG_NOMERGES (Ming Lei) [RHEL-56837]
- loop: don't set QUEUE_FLAG_NOMERGES (Ming Lei) [RHEL-56837]
- block: check bio alignment in blk_mq_submit_bio (Ming Lei) [RHEL-56837]
- block: Add ioprio to block_rq tracepoint (Ming Lei) [RHEL-56837]
- block: remove bio_integrity_process (Ming Lei) [RHEL-56837]
- block: switch on bio operation in bio_integrity_prep (Ming Lei) [RHEL-56837]
- block: remove allocation failure warnings in bio_integrity_prep (Ming Lei) [RHEL-56837]
- block: simplify adding the payload in bio_integrity_prep (Ming Lei) [RHEL-56837]
- block: only zero non-PI metadata tuples in bio_integrity_prep (Ming Lei) [RHEL-56837]
- loop: Fix a race between loop detach and loop open (Ming Lei) [RHEL-56837]
- block: Delete blk_queue_flag_test_and_set() (Ming Lei) [RHEL-56837]
- block: clean up the check in blkdev_iomap_begin() (Ming Lei) [RHEL-56837]
- block: use the right type for stub rq_integrity_vec() (Ming Lei) [RHEL-56837]
- block: move dma_pad_mask into queue_limits (Ming Lei) [RHEL-56837]
- block: remove the fallback case in queue_dma_alignment (Ming Lei) [RHEL-56837]
- block: remove disk_update_readahead (Ming Lei) [RHEL-56837]
- block: conding style fixup for blk_queue_max_guaranteed_bio (Ming Lei) [RHEL-56837]
- block: convert features and flags to __bitwise types (Ming Lei) [RHEL-56837]
- block: rename BLK_FEAT_MISALIGNED (Ming Lei) [RHEL-56837]
- block: correctly report cache type (Ming Lei) [RHEL-56837]
- md: set md-specific flags for all queue limits (Ming Lei) [RHEL-56837]
- block: change rq_integrity_vec to respect the iterator (Ming Lei) [RHEL-56837]
- block: fix the blk_queue_nonrot polarity (Ming Lei) [RHEL-56837]
- brd: add missing MODULE_DESCRIPTION() macro (Ming Lei) [RHEL-56837]
- cdrom: Add missing MODULE_DESCRIPTION() (Ming Lei) [RHEL-56837]
- block: Fix blk_validate_atomic_write_limits() build for arm32 (Ming Lei) [RHEL-56837]
- block: Cleanup block device zone helpers (Ming Lei) [RHEL-56837]
- block: Define bdev_nr_zones() as an inline function (Ming Lei) [RHEL-56837]
- null_blk: Do not set disk->nr_zones (Ming Lei) [RHEL-56837]
- nvme: Atomic write support (Ming Lei) [RHEL-56837]
- scsi: scsi_debug: Atomic write support (Ming Lei) [RHEL-56837]
- scsi: sd: Atomic write support (Ming Lei) [RHEL-56837]
- block: Add fops atomic write support (Ming Lei) [RHEL-56837]
- block: Add atomic write support for statx (Ming Lei) [RHEL-56837]
- block: Add core atomic write support (Ming Lei) [RHEL-56837]
- fs: Add initial atomic write support info to statx (Ming Lei) [RHEL-56837]
- fs: Initial atomic write support (Ming Lei) [RHEL-56837]
- block: Generalize chunk_sectors support as boundary support (Ming Lei) [RHEL-56837]
- block: Pass blk_queue_get_max_sectors() a request pointer (Ming Lei) [RHEL-56837]
- block: move the raid_partial_stripes_expensive flag into the features field (Ming Lei) [RHEL-56837]
- block: remove the discard_alignment flag (Ming Lei) [RHEL-56837]
- block: move the misaligned flag into the features field (Ming Lei) [RHEL-56837]
- block: renumber and rename the cache disabled flag (Ming Lei) [RHEL-56837]
- block: fix spelling and grammar for in writeback_cache_control.rst (Ming Lei) [RHEL-56837]
- block: remove the unused blk_bounce enum (Ming Lei) [RHEL-56837]
- block: move the bounce flag into the features field (Ming Lei) [RHEL-56837]
- block: move the skip_tagset_quiesce flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move the pci_p2pdma flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move the zone_resetall flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move the zoned flag into the features field (Ming Lei) [RHEL-56837]
- block: move the poll flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move the dax flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move the nowait flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move the synchronous flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move the stable_writes flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move the io_stat flag setting to queue_limits (Ming Lei) [RHEL-56837]
- block: move the add_random flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move the nonrot flag to queue_limits (Ming Lei) [RHEL-56837]
- block: move cache control settings out of queue->flags (Ming Lei) [RHEL-56837]
- block: remove blk_flush_policy (Ming Lei) [RHEL-56837]
- block: freeze the queue in queue_attr_store (Ming Lei) [RHEL-56837]
- nbd: move setting the cache control flags to __nbd_set_size (Ming Lei) [RHEL-56837]
- virtio_blk: remove virtblk_update_cache_mode (Ming Lei) [RHEL-56837]
- loop: fold loop_update_rotational into loop_reconfigure_limits (Ming Lei) [RHEL-56837]
- loop: also use the default block size from an underlying block device (Ming Lei) [RHEL-56837]
- loop: regularize upgrading the block size for direct I/O (Ming Lei) [RHEL-56837]
- loop: always update discard settings in loop_reconfigure_limits (Ming Lei) [RHEL-56837]
- loop: stop using loop_reconfigure_limits in __loop_clr_fd (Ming Lei) [RHEL-56837]
- sd: move zone limits setup out of sd_read_block_characteristics (Ming Lei) [RHEL-56837]
- sd: remove sd_is_zoned (Ming Lei) [RHEL-56837]
- xen-blkfront: don't disable cache flushes when they fail (Ming Lei) [RHEL-56837]
- z2ram: add missing MODULE_DESCRIPTION() macro (Ming Lei) [RHEL-56837]
- ataflop: add missing MODULE_DESCRIPTION() macro (Ming Lei) [RHEL-56837]
- amiflop: add missing MODULE_DESCRIPTION() macro (Ming Lei) [RHEL-56837]
- block, bfq: remove blkg_path() (Ming Lei) [RHEL-56837]
- block: cleanup flag_{show,store} (Ming Lei) [RHEL-56837]
- block: BFQ: Refactor bfq_exit_icq() to silence sparse warning (Ming Lei) [RHEL-56837]
- block: Drop locking annotation for limits_lock (Ming Lei) [RHEL-56837]
- bdev: make blockdev_mnt static (Ming Lei) [RHEL-56837]
- dm: Remove unused macro DM_ZONE_INVALID_WP_OFST (Ming Lei) [RHEL-56837]
- dm: Improve zone resource limits handling (Ming Lei) [RHEL-56837]
- dm: Call dm_revalidate_zones() after setting the queue limits (Ming Lei) [RHEL-56837]
- block: Improve checks on zone resource limits (Ming Lei) [RHEL-56837]
- block: move integrity information into queue_limits (Ming Lei) [RHEL-56837]
- nvme-multipath: don't inherit LBA-related fields for the multipath node (Ming Lei) [RHEL-56837]
- nvme: split nvme_update_zone_info (Ming Lei) [RHEL-56837]
- block: invert the BLK_INTEGRITY_{GENERATE,VERIFY} flags (Ming Lei) [RHEL-56837]
- block: bypass the STABLE_WRITES flag for protection information (Ming Lei) [RHEL-56837]
- block: don't require stable pages for non-PI metadata (Ming Lei) [RHEL-56837]
- block: use kstrtoul in flag_store (Ming Lei) [RHEL-56837]
- block: factor out flag_{store,show} helper for integrity (Ming Lei) [RHEL-56837]
- block: remove the blk_flush_integrity call in blk_integrity_unregister (Ming Lei) [RHEL-56837]
- block: remove the blk_integrity_profile structure (Ming Lei) [RHEL-56837]
- dm-integrity: use the nop integrity profile (Ming Lei) [RHEL-56837]
- block: add special APIs for run-time disabling of discard and friends (Ming Lei) [RHEL-56837]
- block: remove unused queue limits API (Ming Lei) [RHEL-56837]
- sr: convert to the atomic queue limits API (Ming Lei) [RHEL-56837]
- sd: convert to the atomic queue limits API (Ming Lei) [RHEL-56837]
- sd: cleanup zoned queue limits initialization (Ming Lei) [RHEL-56837]
- sd: factor out a sd_discard_mode helper (Ming Lei) [RHEL-56837]
- sd: simplify the disable case in sd_config_discard (Ming Lei) [RHEL-56837]
- sd: add a sd_disable_write_same helper (Ming Lei) [RHEL-56837]
- sd: add a sd_disable_discard helper (Ming Lei) [RHEL-56837]
- sd: simplify the ZBC case in provisioning_mode_store (Ming Lei) [RHEL-56837]
- block: take io_opt and io_min into account for max_sectors (Ming Lei) [RHEL-56837]
- rbd: increase io_opt again (Ming Lei) [RHEL-56837]
- ubd: untagle discard vs write zeroes not support handling (Ming Lei) [RHEL-56837]
- ubd: refactor the interrupt handler (Ming Lei) [RHEL-56837]
- nbd: Remove __force casts (Ming Lei) [RHEL-56837]
- block: Optimize disk zone resource cleanup (Ming Lei) [RHEL-56837]
- block: sed-opal: avoid possible wrong address reference in read_sed_opal_key() (Ming Lei) [RHEL-56837]
- loop: Disable fallocate() zero and discard if not supported (Ming Lei) [RHEL-56837]
- blk-throttle: Fix incorrect display of io.max (Ming Lei) [RHEL-56837]
- block: Fix zone write plugging handling of devices with a runt zone (Ming Lei) [RHEL-56837]
- block: Fix validation of zoned device with a runt zone (Ming Lei) [RHEL-56837]
- null_blk: Do not allow runt zone with zone capacity smaller then zone size (Ming Lei) [RHEL-56837]
- block: check for max_hw_sectors underflow (Ming Lei) [RHEL-56837]
- block: stack max_user_sectors (Ming Lei) [RHEL-56837]
- sd: also set max_user_sectors when setting max_sectors (Ming Lei) [RHEL-56837]
- null_blk: Print correct max open zones limit in null_init_zoned_dev() (Ming Lei) [RHEL-56837]
- block: delete redundant function declaration (Ming Lei) [RHEL-56837]
- dm: make dm_set_zones_restrictions work on the queue limits (Ming Lei) [RHEL-56837]
- dm: use queue_limits_set (Ming Lei) [RHEL-56837]
- dm: remove dm_check_zoned (Ming Lei) [RHEL-56837]
- dm: move setting zoned_enabled to dm_table_set_restrictions (Ming Lei) [RHEL-56837]
- block: remove blk_queue_max_integrity_segments (Ming Lei) [RHEL-56837]
- dm-integrity: set max_integrity_segments in dm_integrity_io_hints (Ming Lei) [RHEL-56837]
- nvdimm/btt: always set max_integrity_segments (Ming Lei) [RHEL-56837]
- nvdimm: remove nd_integrity_init (Ming Lei) [RHEL-56837]
- scsi: block: Remove now unused queue limits helpers (Ming Lei) [RHEL-56837]
- scsi: uas: Switch to using ->device_configure to configure queue limits (Ming Lei) [RHEL-56837]
- scsi: mpi3mr: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: mpi3mr: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: libata: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: hisi_sas: Call hisi_sas_slave_configure() from slave_configure_v3_hw() (Ming Lei) [RHEL-56837]
- scsi: pata_macio: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: sata_nv: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: usb-storage: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: pmcraid: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: ipr: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: hptiop: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: sbp2: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: mpt3sas: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: megaraid_sas: Switch to using ->device_configure (Ming Lei) [RHEL-56837]
- scsi: core: Add a device_configure method to the host template (Ming Lei) [RHEL-56837]
- scsi: core: Use the atomic queue limits API in scsi_add_lun() (Ming Lei) [RHEL-56837]
- scsi: ufs: ufs-exynos: Move setting the the DMA alignment to the init method (Ming Lei) [RHEL-56837]
- scsi: core: Add a dma_alignment field to the host and host template (Ming Lei) [RHEL-56837]
- scsi: core: Add a no_highmem flag to struct Scsi_Host (Ming Lei) [RHEL-56837]
- scsi: scsi_transport_fc: Add a max_bsg_segments field to struct fc_function_template (Ming Lei) [RHEL-56837]
- scsi: core: Initialize scsi midlayer limits before allocating the queue (Ming Lei) [RHEL-56837]
- scsi: mpi3mr: Pass queue_limits to bsg_setup_queue() (Ming Lei) [RHEL-56837]
- scsi: bsg: Pass queue_limits to bsg_setup_queue() (Ming Lei) [RHEL-56837]
- scsi: block: Add a helper to cancel atomic queue limit updates (Ming Lei) [RHEL-56837]
- ata: libata: Cleanup inline DMA helper functions (Ming Lei) [RHEL-56837]
- ata: libata-eh: Reduce "disable device" message verbosity (Ming Lei) [RHEL-56837]
- ata: libata-eh: Improve reset error messages (Ming Lei) [RHEL-56837]
- ata: libata-sata: Improve ata_sas_slave_configure() (Ming Lei) [RHEL-56837]
- ata: libata-core: Do not resume runtime suspended ports (Ming Lei) [RHEL-56837]
- ata: libata-core: Do not poweroff runtime suspended ports (Ming Lei) [RHEL-56837]
- ata: libata-core: Remove ata_port_resume_async() (Ming Lei) [RHEL-56837]
- ata: libata-core: Remove ata_port_suspend_async() (Ming Lei) [RHEL-56837]
- ata: libata-core: Detach a port devices on shutdown (Ming Lei) [RHEL-56837]
- ata: libata-core: Synchronize ata_port_detach() with hotplug (Ming Lei) [RHEL-56837]
- ata: libata-scsi: Cleanup ata_scsi_start_stop_xlat() (Ming Lei) [RHEL-56837]
- scsi: ipr: Remove SATA support (Ming Lei) [RHEL-56837]
- blk-throttle: remove unused struct 'avg_latency_bucket' (Ming Lei) [RHEL-56837]
- block: fix lost bio for plug enabled bio based device (Ming Lei) [RHEL-56837]
- block: t10-pi: add MODULE_DESCRIPTION() (Ming Lei) [RHEL-56837]
- cdrom: rearrange last_media_change check to avoid unintentional overflow (Ming Lei) [RHEL-56837]
- nbd: Fix signal handling (Ming Lei) [RHEL-56837]
- nbd: Remove a local variable from nbd_send_cmd() (Ming Lei) [RHEL-56837]
- nbd: Improve the documentation of the locking assumptions (Ming Lei) [RHEL-56837]
- nbd: Remove superfluous casts (Ming Lei) [RHEL-56837]
- nbd: Use NULL to represent a pointer (Ming Lei) [RHEL-56837]
- null_blk: Fix two sparse warnings (Ming Lei) [RHEL-56837]
- brd: implement discard support (Ming Lei) [RHEL-56837]
- blk-throttle: delay initialization until configuration (Ming Lei) [RHEL-56837]
- blk-throttle: remove CONFIG_BLK_DEV_THROTTLING_LOW (Ming Lei) [RHEL-56837]
- block: add plug while submitting IO (Ming Lei) [RHEL-56837]
- blk-lib: check for kill signal in ioctl BLKDISCARD (Ming Lei) [RHEL-56837]
- block: add a bio_await_chain helper (Ming Lei) [RHEL-56837]
- block: add a blk_alloc_discard_bio helper (Ming Lei) [RHEL-56837]
- block: add a bio_chain_and_submit helper (Ming Lei) [RHEL-56837]
- block: move discard checks into the ioctl handler (Ming Lei) [RHEL-56837]
- block: remove the discard_granularity check in __blkdev_issue_discard (Ming Lei) [RHEL-56837]
- block/ioctl: prefer different overflow check (Ming Lei) [RHEL-56837]
- null_blk: Fix the WARNING: modpost: missing MODULE_DESCRIPTION() (Ming Lei) [RHEL-56837]
- block: fix and simplify blkdevparts= cmdline parsing (Ming Lei) [RHEL-56837]
- block: add a partscan sysfs attribute for disks (Ming Lei) [RHEL-56837]
- block: add a disk_has_partscan helper (Ming Lei) [RHEL-56837]
- block: Cleanup blk_revalidate_zone_cb() (Ming Lei) [RHEL-56837]
- block: Simplify zone write plug BIO abort (Ming Lei) [RHEL-56837]
- block: Simplify blk_zone_write_plug_bio_endio() (Ming Lei) [RHEL-56837]
- block: Improve zone write request completion handling (Ming Lei) [RHEL-56837]
- block: Improve blk_zone_write_plug_bio_merged() (Ming Lei) [RHEL-56837]
- block: Fix handling of non-empty flush write requests to zones (Ming Lei) [RHEL-56837]
- block: Fix flush request sector restore (Ming Lei) [RHEL-56837]
- block: Do not remove zone write plugs still in use (Ming Lei) [RHEL-56837]
- block: Unhash a zone write plug only if needed (Ming Lei) [RHEL-56837]
- block: Hold a reference on zone write plugs to schedule submission (Ming Lei) [RHEL-56837]
- block: Fix reference counting for zone write plugs in error state (Ming Lei) [RHEL-56837]
- block: Fix zone write plug initialization from blk_revalidate_zone_cb() (Ming Lei) [RHEL-56837]
- block: Exclude conventional zones when faking max open limit (Ming Lei) [RHEL-56837]
- dm: Check that a zoned table leads to a valid mapped device (Ming Lei) [RHEL-56837]
- sbitmap: use READ_ONCE to access map->word (Ming Lei) [RHEL-56837]
- null_blk: Fix missing mutex_destroy() at module removal (Ming Lei) [RHEL-56837]
- block: check if zone_wplugs_hash exists in queue_zone_wplugs_show (Ming Lei) [RHEL-56837]
- block: use a per disk workqueue for zone write plugging (Ming Lei) [RHEL-56837]
- block/mq-deadline: Remove some unused functions (Ming Lei) [RHEL-56837]
- null_blk: Simplify null_zone_write() (Ming Lei) [RHEL-56837]
- null_blk: Do zone resource management only if necessary (Ming Lei) [RHEL-56837]
- null_blk: Have all null_handle_xxx() return a blk_status_t (Ming Lei) [RHEL-56837]
- block: Do not special-case plugging of zone write operations (Ming Lei) [RHEL-56837]
- block: Do not force select mq-deadline with CONFIG_BLK_DEV_ZONED (Ming Lei) [RHEL-56837]
- block: Remove zone write locking (Ming Lei) [RHEL-56837]
- block: Replace zone_wlock debugfs entry with zone_wplugs entry (Ming Lei) [RHEL-56837]
- block: Move zone related debugfs attribute to blk-zoned.c (Ming Lei) [RHEL-56837]
- block: Do not check zone type in blk_check_zone_append() (Ming Lei) [RHEL-56837]
- block: Remove elevator required features (Ming Lei) [RHEL-56837]
- block: mq-deadline: Remove support for zone write locking (Ming Lei) [RHEL-56837]
- block: Simplify blk_revalidate_disk_zones() interface (Ming Lei) [RHEL-56837]
- block: Remove BLK_STS_ZONE_RESOURCE (Ming Lei) [RHEL-56837]
- nvmet: zns: Do not reference the gendisk conv_zones_bitmap (Ming Lei) [RHEL-56837]
- null_blk: Introduce fua attribute (Ming Lei) [RHEL-56837]
- null_blk: Introduce zone_append_max_sectors attribute (Ming Lei) [RHEL-56837]
- null_blk: Do not request ELEVATOR_F_ZBD_SEQ_WRITE elevator feature (Ming Lei) [RHEL-56837]
- scsi: sd: Use the block layer zone append emulation (Ming Lei) [RHEL-56837]
- dm: Use the block layer zone append emulation (Ming Lei) [RHEL-56837]
- block: Allow BIO-based drivers to use blk_revalidate_disk_zones() (Ming Lei) [RHEL-56837]
- block: Implement zone append emulation (Ming Lei) [RHEL-56837]
- block: Allow zero value of max_zone_append_sectors queue limit (Ming Lei) [RHEL-56837]
- block: Fake max open zones limit when there is no limit (Ming Lei) [RHEL-56837]
- block: Introduce zone write plugging (Ming Lei) [RHEL-56837]
- block: Remember zone capacity when revalidating zones (Ming Lei) [RHEL-56837]
- block: Allow using bio_attempt_back_merge() internally (Ming Lei) [RHEL-56837]
- block: Introduce bio_straddles_zones() and bio_offset_from_zone_start() (Ming Lei) [RHEL-56837]
- block: Introduce blk_zone_update_request_bio() (Ming Lei) [RHEL-56837]
- block: Remove req_bio_endio() (Ming Lei) [RHEL-56837]
- block: Restore sector of flush requests (Ming Lei) [RHEL-56837]
- block: Call blkdev_dio_unaligned() from blkdev_direct_IO() (Ming Lei) [RHEL-56837]
- blk-cgroup: use group allocation/free of per-cpu counters API (Ming Lei) [RHEL-56837]
- pcpcntr: add group allocation/free (Ming Lei) [RHEL-56837]
- dm: use bio_list_merge_init (Ming Lei) [RHEL-56837]
- blk-cgroup: use bio_list_merge_init (Ming Lei) [RHEL-56837]
- block: add a bio_list_merge_init helper (Ming Lei) [RHEL-56837]
- blk-throttle: Only use seq_printf() in tg_prfill_limit() (Ming Lei) [RHEL-56837]
- brd: Remove use of page->index (Ming Lei) [RHEL-56837]
- signalfd: convert to ->read_iter() (Ming Lei) [RHEL-56837]
- userfaultfd: convert to ->read_iter() (Ming Lei) [RHEL-56837]
- timerfd: convert to ->read_iter() (Ming Lei) [RHEL-56837]
- new helper: copy_to_iter_full() (Ming Lei) [RHEL-56837]
- nvme-multipath: use atomic queue limits API for stacking limits (Ming Lei) [RHEL-56837]
- nvme-multipath: pass queue_limits to blk_alloc_disk (Ming Lei) [RHEL-56837]
- nvme: use the atomic queue limits update API (Ming Lei) [RHEL-56837]
- nvme: cleanup nvme_configure_metadata (Ming Lei) [RHEL-56837]
- nvme: don't query identify data in configure_metadata (Ming Lei) [RHEL-56837]
- nvme: split out a nvme_identify_ns_nvm helper (Ming Lei) [RHEL-56837]
- nvme: move common logic into nvme_update_ns_info (Ming Lei) [RHEL-56837]
- nvme: move setting the write cache flags out of nvme_set_queue_limits (Ming Lei) [RHEL-56837]
- nvme: move a few things out of nvme_update_disk_info (Ming Lei) [RHEL-56837]
- nvme: don't use nvme_update_disk_info for the multipath disk (Ming Lei) [RHEL-56837]
- nvme: move blk_integrity_unregister into nvme_init_integrity (Ming Lei) [RHEL-56837]
- nvme: cleanup the nvme_init_integrity calling conventions (Ming Lei) [RHEL-56837]
- nvme: move max_integrity_segments handling out of nvme_init_integrity (Ming Lei) [RHEL-56837]
- nvme: remove nvme_revalidate_zones (Ming Lei) [RHEL-56837]
- nvme: move NVME_QUIRK_DEALLOCATE_ZEROES out of nvme_config_discard (Ming Lei) [RHEL-56837]
- nvme: set max_hw_sectors unconditionally (Ming Lei) [RHEL-56837]
- Revert "dm: use queue_limits_set" (Ming Lei) [RHEL-56837]
- block: Do not force full zone append completion in req_bio_endio() (Ming Lei) [RHEL-56837]
- block: set default max segment size in case of virt_boundary (Ming Lei) [RHEL-56837]
- blk-iocost: do not WARN if iocg was already offlined (Ming Lei) [RHEL-56837]
- block: propagate partition scanning errors to the BLKRRPART ioctl (Ming Lei) [RHEL-56837]
- block: fix that blk_time_get_ns() doesn't update time after schedule (Ming Lei) [RHEL-56837]
- block: allow device to have both virt_boundary_mask and max segment size (Ming Lei) [RHEL-56837]
- blk-iocost: avoid out of bounds shift (Ming Lei) [RHEL-56837]
- nullblk: Fix cleanup order in null_add_dev() error path (Ming Lei) [RHEL-56837]
- block: Make blk_rq_set_mixed_merge() static (Ming Lei) [RHEL-56837]
- Revert "blk-lib: check for kill signal" (Ming Lei) [RHEL-56837]
- Revert "block/mq-deadline: use correct way to throttling write requests" (Ming Lei) [RHEL-56837]
- block: limit block time caching to in_task() context (Ming Lei) [RHEL-56837]
- block: partitions: only define function mac_fix_string for CONFIG_PPC_PMAC (Ming Lei) [RHEL-56837]
- block/swim: Convert to platform remove callback returning void (Ming Lei) [RHEL-56837]
- cdrom: gdrom: Convert to platform remove callback returning void (Ming Lei) [RHEL-56837]
- block: remove disk_stack_limits (Ming Lei) [RHEL-56837]
- md: remove mddev->queue (Ming Lei) [RHEL-56837]
- md: don't initialize queue limits (Ming Lei) [RHEL-56837]
- md/raid10: use the atomic queue limit update APIs (Ming Lei) [RHEL-56837]
- md/raid5: use the atomic queue limit update APIs (Ming Lei) [RHEL-56837]
- md/raid1: use the atomic queue limit update APIs (Ming Lei) [RHEL-56837]
- md/raid0: use the atomic queue limit update APIs (Ming Lei) [RHEL-56837]
- md: add queue limit helpers (Ming Lei) [RHEL-56837]
- virtio_blk: Do not use disk_set_max_open/active_zones() (Ming Lei) [RHEL-56837]
- aoe: fix the potential use-after-free problem in aoecmd_cfg_pkts (Ming Lei) [RHEL-56837]
- block: move capacity validation to blkpg_do_ioctl() (Ming Lei) [RHEL-56837]
- drbd: atomically update queue limits in drbd_reconsider_queue_parameters (Ming Lei) [RHEL-56837]
- drbd: split out a drbd_discard_supported helper (Ming Lei) [RHEL-56837]
- drbd: don't set max_write_zeroes_sectors in decide_on_discard_support (Ming Lei) [RHEL-56837]
- drbd: merge drbd_setup_queue_param into drbd_reconsider_queue_parameters (Ming Lei) [RHEL-56837]
- drbd: refactor the backing dev max_segments calculation (Ming Lei) [RHEL-56837]
- drbd: refactor drbd_reconsider_queue_parameters (Ming Lei) [RHEL-56837]
- drbd: pass the max_hw_sectors limit to blk_alloc_disk (Ming Lei) [RHEL-56837]
- sed-opal: Remove the ret variable from the function (Ming Lei) [RHEL-56837]
- sed-opal: Remove unnecessary ‘0’ values from ret (Ming Lei) [RHEL-56837]
- sed-opal: Remove unnecessary ‘0’ values from err (Ming Lei) [RHEL-56837]
- sed-opal: Remove unnecessary ‘0’ values from error (Ming Lei) [RHEL-56837]
- block: make block_class constant (Ming Lei) [RHEL-56837]
- dasd: use the atomic queue limits API (Ming Lei) [RHEL-56837]
- dasd: move queue setup to common code (Ming Lei) [RHEL-56837]
- dasd: cleamup dasd_state_basic_to_ready (Ming Lei) [RHEL-56837]
- nbd: use the atomic queue limits API in nbd_set_size (Ming Lei) [RHEL-56837]
- nbd: freeze the queue for queue limits updates (Ming Lei) [RHEL-56837]
- nbd: don't clear discard_sectors in nbd_config_put (Ming Lei) [RHEL-56837]
- pktcdvd: don't set max_hw_sectors on the underlying device (Ming Lei) [RHEL-56837]
- dm: use queue_limits_set (Ming Lei) [RHEL-56837]
- block: add a queue_limits_stack_bdev helper (Ming Lei) [RHEL-56837]
- block: add a queue_limits_set helper (Ming Lei) [RHEL-56837]
- ubd: open the backing files in ubd_add (Ming Lei) [RHEL-56837]
- ubd: remove the queue pointer in struct ubd (Ming Lei) [RHEL-56837]
- ubd: move set_disk_ro to ubd_add (Ming Lei) [RHEL-56837]
- ubd: move setting the variable queue limits to ubd_add (Ming Lei) [RHEL-56837]
- ubd: move setting the nonrot flag to ubd_add (Ming Lei) [RHEL-56837]
- ubd: remove ubd_disk_register (Ming Lei) [RHEL-56837]
- ubd: remove the ubd_gendisk array (Ming Lei) [RHEL-56837]
- xen-blkfront: atomically update queue limits (Ming Lei) [RHEL-56837]
- xen-blkfront: don't redundantly set max_sements in blkif_recover (Ming Lei) [RHEL-56837]
- xen-blkfront: rely on the default discard granularity (Ming Lei) [RHEL-56837]
- xen-blkfront: set max_discard/secure erase limits to UINT_MAX (Ming Lei) [RHEL-56837]
- bdev: remove SLAB_MEM_SPREAD flag usage (Ming Lei) [RHEL-56837]
- block/blk-mq: Don't complete locally if capacities are different (Ming Lei) [RHEL-56837]
- sched: Add a new function to compare if two cpus have the same capacity (Ming Lei) [RHEL-56837]
- blk-lib: check for kill signal (Ming Lei) [RHEL-56837]
- block: io wait hang check helper (Ming Lei) [RHEL-56837]
- block: cleanup __blkdev_issue_write_zeroes (Ming Lei) [RHEL-56837]
- block: blkdev_issue_secure_erase loop style (Ming Lei) [RHEL-56837]
- block: Do not include rbtree.h in blk-zoned.c (Ming Lei) [RHEL-56837]
- block: Clear zone limits for a non-zoned stacked queue (Ming Lei) [RHEL-56837]
- null_blk: Delete nullb.{queue_depth, nr_queues} (Ming Lei) [RHEL-56837]
- pktcdvd: set queue limits at disk allocation time (Ming Lei) [RHEL-56837]
- pktcdvd: stop setting q->queuedata (Ming Lei) [RHEL-56837]
- block: fix virt_boundary handling in blk_validate_limits (Ming Lei) [RHEL-56837]
- null_blk: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- null_blk: remove null_gendisk_register (Ming Lei) [RHEL-56837]
- null_blk: refactor tag_set setup (Ming Lei) [RHEL-56837]
- null_blk: initialize the tag_set timeout in null_init_tag_set (Ming Lei) [RHEL-56837]
- null_blk: remove the bio based I/O path (Ming Lei) [RHEL-56837]
- mmc: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- scm_blk: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- ubiblock: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- mtd_blkdevs: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- mspro_block: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- ms_block: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- gdrom: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- sunvdc: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- rnbd-clt: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- rbd: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- ps3disk: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- nbd: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- mtip: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- floppy: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- aoe: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- ubd: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- dcssblk: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- pmem: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- btt: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- zram: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- n64cart: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- brd: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- nfblock: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- block: pass a queue_limits argument to blk_alloc_disk (Ming Lei) [RHEL-56837]
- loop: use the atomic queue limits update API (Ming Lei) [RHEL-56837]
- loop: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- loop: cleanup loop_config_discard (Ming Lei) [RHEL-56837]
- virtio_blk: pass queue_limits to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- virtio_blk: split virtblk_probe (Ming Lei) [RHEL-56837]
- block: pass a queue_limits argument to blk_mq_alloc_disk (Ming Lei) [RHEL-56837]
- block: pass a queue_limits argument to blk_mq_init_queue (Ming Lei) [RHEL-56837]
- block: pass a queue_limits argument to blk_alloc_queue (Ming Lei) [RHEL-56837]
- block: use queue_limits_commit_update in queue_discard_max_store (Ming Lei) [RHEL-56837]
- block: add a max_user_discard_sectors queue limit (Ming Lei) [RHEL-56837]
- block: use queue_limits_commit_update in queue_max_sectors_store (Ming Lei) [RHEL-56837]
- block: add an API to atomically update queue limits (Ming Lei) [RHEL-56837]
- block: decouple blk_set_stacking_limits from blk_set_default_limits (Ming Lei) [RHEL-56837]
- block: refactor disk_update_readahead (Ming Lei) [RHEL-56837]
- block: move max_{open,active}_zones to struct queue_limits (Ming Lei) [RHEL-56837]
- drbd: fix function cast warnings in state machine (Ming Lei) [RHEL-56837]
- nvme: allow integrity when PI is not in first bytes (Ming Lei) [RHEL-56837]
- block: support PI at non-zero offset within metadata (Ming Lei) [RHEL-56837]
- block: refactor guard helpers (Ming Lei) [RHEL-56837]
- null_blk: add configfs variable shared_tags (Ming Lei) [RHEL-56837]
- block: Simplify the allocation of slab caches (Ming Lei) [RHEL-56837]
- block: optimise in irq bio put caching (Ming Lei) [RHEL-56837]
- block: extend bio caching to task context (Ming Lei) [RHEL-56837]
- blk-throttle: Eliminate redundant checks for data direction (Ming Lei) [RHEL-56837]
- block: update cached timestamp post schedule/preemption (Ming Lei) [RHEL-56837]
- block: cache current nsec time in struct blk_plug (Ming Lei) [RHEL-56837]
- block: add blk_time_get_ns() and blk_time_get() helpers (Ming Lei) [RHEL-56837]
- block: move cgroup time handling code into blk.h (Ming Lei) [RHEL-56837]
- blk-mq: special case cached requests less (Ming Lei) [RHEL-56837]
- blk-mq: introduce a blk_mq_peek_cached_request helper (Ming Lei) [RHEL-56837]
- blk-mq: move blk_mq_attempt_bio_merge out blk_mq_get_new_requests (Ming Lei) [RHEL-56837]
- Documentation: block: ioprio: Update schedulers (Ming Lei) [RHEL-56837]
- blk-mq: Remove the hctx 'run' debugfs attribute (Ming Lei) [RHEL-56837]
- block: Fix iterating over an empty bio with bio_for_each_folio_all (Ming Lei) [RHEL-56837]
- virtio_blk: remove duplicate check if queue is broken in virtblk_done (Ming Lei) [RHEL-56837]
- sbitmap: remove stale comment in sbq_calc_wake_batch (Ming Lei) [RHEL-56837]
- block: Correct a documentation comment in blk-cgroup.c (Ming Lei) [RHEL-56837]
- null_blk: Remove usage of the deprecated ida_simple_xx() API (Ming Lei) [RHEL-56837]
- block: ensure we hold a queue reference when using queue limits (Ming Lei) [RHEL-56837]
- blk-mq: rename blk_mq_can_use_cached_rq (Ming Lei) [RHEL-56837]
- block: print symbolic error name instead of error code (Ming Lei) [RHEL-56837]
- block: fix partial zone append completion handling in req_bio_endio() (Ming Lei) [RHEL-56837]
- block/iocost: silence warning on 'last_period' potentially being unused (Ming Lei) [RHEL-56837]
- block: make __get_task_ioprio() easier to read (Ming Lei) [RHEL-56837]
- block: move __get_task_ioprio() into header file (Ming Lei) [RHEL-56837]
- block: make blkcg_punt_bio_submit optional (Ming Lei) [RHEL-56837]
- block: async_bio_lock does not need to be bh-safe (Ming Lei) [RHEL-56837]
- btrfs, block: move REQ_CGROUP_PUNT to btrfs (Ming Lei) [RHEL-56837]
- btrfs, mm: remove the punt_to_cgroup field in struct writeback_control (Ming Lei) [RHEL-56837]
- scsi: block: Improve checks in blk_revalidate_disk_zones() (Ming Lei) [RHEL-56837]
- scsi: block: nullblk: Set zone limits before revalidating zones (Ming Lei) [RHEL-56837]
- sched: Show PF_flag holes (Ming Lei) [RHEL-56837]
- scsi: ufs: core: Move the 4K alignment code into the Exynos driver (Ming Lei) [RHEL-56837]
- iov_iter: Fix iov_iter_extract_pages() with zero-sized entries (Ming Lei) [RHEL-56837]
- lib/scatterlist: Fix to calculate the last_pg properly (Ming Lei) [RHEL-56837]
- lib/scatterlist: Fix to merge contiguous pages into the last SG properly (Ming Lei) [RHEL-56837]
- virtio_pmem: add the missing REQ_OP_WRITE for flush bio (Ming Lei) [RHEL-56837]
- block: bio-integrity: fix kcalloc() arguments order (Ming Lei) [RHEL-56837]
- io_uring: remove uring_cmd cookie (Ming Lei) [RHEL-56837]
- iouring: remove IORING_URING_CMD_POLLED (Ming Lei) [RHEL-56837]
- nvme: use bio_integrity_map_user (Ming Lei) [RHEL-56837]
- nvme: optimise io_uring passthrough completion (Ming Lei) [RHEL-56837]
- block: bio-integrity: directly map user buffers (Ming Lei) [RHEL-56837]
- iov_iter: Add a function to extract a page list from an iterator (Ming Lei) [RHEL-56837]
- iov_iter: Define flags to qualify page extraction. (Ming Lei) [RHEL-56837]
- ABI: sysfs-bus-pci: add documentation for p2pmem allocate (Ming Lei) [RHEL-56837]
- block: set FOLL_PCI_P2PDMA in bio_map_user_iov() (Ming Lei) [RHEL-56837]
- block: set FOLL_PCI_P2PDMA in __bio_iov_iter_get_pages() (Ming Lei) [RHEL-56837]
- lib/scatterlist: add check when merging zone device pages (Ming Lei) [RHEL-56837]
- block: add check when merging zone device pages (Ming Lei) [RHEL-56837]
- iov_iter: introduce iov_iter_get_pages_[alloc_]flags() (Ming Lei) [RHEL-56837]
- block: add a sanity check for non-write flush/fua bios (Ming Lei) [RHEL-56837]

* Wed Oct 16 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-519.el9]
- xsk: fix batch alloc API on non-coherent systems (Felix Maurer) [RHEL-58954]
- redhat: ignore rpminspect runpath report on selftests/bpf/cpuv4/urandom_read (Viktor Malik) [RHEL-59932]
- ceph: fix cap ref leak via netfs init_request (Patrick Donnelly) [RHEL-61459]
- cpufreq/amd-pstate: Catch failures for amd_pstate_epp_update_limit() (David Arcari) [RHEL-61470]
- cpufreq/amd-pstate: Remove warning for X86_FEATURE_CPPC on certain Zen models (David Arcari) [RHEL-61470]
- cpufreq/amd-pstate-ut: Don't check for highest perf matching on prefcore (David Arcari) [RHEL-61470]
- cpufreq/amd-pstate: Use topology_logical_package_id() instead of logical_die_id() (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: Fix uninitialized variable in amd_pstate_cpu_boost_update() (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: Cap the CPPC.max_perf to nominal_perf if CPB is off (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: initialize core precision boost state (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: Don't create attributes when registration fails (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: auto-load pstate driver by default (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: enable shared memory type CPPC by default (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: switch boot_cpu_has() to cpu_feature_enabled() (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: add debug message while CPPC is supported and disabled by SBIOS (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: show CPPC debug message if CPPC is not supported (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: remove unused variable nominal_freq (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: optimize the initial frequency values verification (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: Allow users to write 'default' EPP string (David Arcari) [RHEL-61470]
- cpufreq: amd-pstate: change cpu freq transition delay for some models (David Arcari) [RHEL-61470]
- cpufreq: acpi: move MSR_K7_HWCR_CPB_DIS_BIT into msr-index.h (David Arcari) [RHEL-61470]
- x86/cpufeatures: Add AMD FAST CPPC feature flag (David Arcari) [RHEL-61470]
- smb: client: stop flooding dmesg in smb2_calc_signature() (Paulo Alcantara) [RHEL-61193]
- smb: client: print failed session logoffs with FYI (Paulo Alcantara) [RHEL-61193]
- smb: client: propagate error from cifs_construct_tcon() (Paulo Alcantara) [RHEL-61193]
- smb: client: fix DFS failover in multiuser mounts (Paulo Alcantara) [RHEL-61193]
- smb: client: fix DFS interlink failover (Paulo Alcantara) [RHEL-61193]
- smb: client: improve purging of cached referrals (Paulo Alcantara) [RHEL-61193]
- smb: client: avoid unnecessary reconnects when refreshing referrals (Paulo Alcantara) [RHEL-61193]
- smb: use LIST_HEAD() to simplify code (Paulo Alcantara) [RHEL-61193]
- cifs: convert to use ERR_CAST() (Paulo Alcantara) [RHEL-61193]
- driver core: mark async_driver as a const * (Michal Schmidt) [RHEL-59894]
- driver core: make driver_detach() take a const * (Michal Schmidt) [RHEL-59894]
- driver core: make device_release_driver_internal() take a const * (Michal Schmidt) [RHEL-59894]
- driver core: driver: mark driver_add/remove_groups constant (Michal Schmidt) [RHEL-59894]
- driver core: platform: fix ups for constant struct device_driver (Michal Schmidt) [RHEL-59894]
- auxbus: make to_auxiliary_drv accept and return a constant pointer (Michal Schmidt) [RHEL-59894]
- queue_api: define queue api (Michal Schmidt) [RHEL-59892]
- mei: me: add lunar lake point M DID (David Arcari) [RHEL-61610]
- hwmon: (w83627ehf) Fix underflows seen when writing limit attributes (CKI Backport Bot) [RHEL-59361] {CVE-2024-46756}
- hwmon: (lm95234) Fix underflows seen when writing limit attributes (CKI Backport Bot) [RHEL-59369] {CVE-2024-46758}
- net: remove dev_base_lock (Ivan Vecera) [RHEL-59100]
- net: remove dev_base_lock from register_netdevice() and friends. (Ivan Vecera) [RHEL-59100]
- net: remove dev_base_lock from do_setlink() (Ivan Vecera) [RHEL-59100]
- net: add netdev_set_operstate() helper (Ivan Vecera) [RHEL-59100]
- net: remove stale mentions of dev_base_lock in comments (Ivan Vecera) [RHEL-59100]
- net-sysfs: convert netstat_show() to RCU (Ivan Vecera) [RHEL-59100]
- net-sysfs: convert dev->operstate reads to lockless ones (Ivan Vecera) [RHEL-59100]
- net-sysfs: use dev_addr_sem to remove races in address_show() (Ivan Vecera) [RHEL-59100]
- net-sysfs: convert netdev_show() to RCU (Ivan Vecera) [RHEL-59100]
- net: convert dev->reg_state to u8 (Ivan Vecera) [RHEL-59100]
- dev: annotate accesses to dev->link (Ivan Vecera) [RHEL-59100]
- ip_tunnel: annotate data-races around t->parms.link (Ivan Vecera) [RHEL-59100]
- net: annotate data-races around dev->name_assign_type (Ivan Vecera) [RHEL-59100]
- net: sysfs: fix locking in carrier read (Ivan Vecera) [RHEL-59100]
- net: core: synchronize link-watch when carrier is queried (Ivan Vecera) [RHEL-59100]
- net-sysfs: Convert to use sysfs_emit() APIs (Ivan Vecera) [RHEL-59100]
- Bluetooth: l2cap: Don't double set the HCI_CONN_MGMT_CONNECTED bit (Bastien Nocera) [RHEL-41144] {CVE-2024-36968}
- Bluetooth: L2CAP: Fix div-by-zero in l2cap_le_flowctl_init() (Bastien Nocera) [RHEL-41144] {CVE-2024-36968}
- Bluetooth: ISO: Handle PA sync when no BIGInfo reports are generated (Bastien Nocera) [RHEL-41144] {CVE-2024-36968}
- Bluetooth: ISO: Clean up returns values in iso_connect_ind() (Bastien Nocera) [RHEL-41144] {CVE-2024-36968}
- Bluetooth: ISO: Make iso_get_sock_listen generic (Bastien Nocera) [RHEL-41144] {CVE-2024-36968}
- Bluetooth: ISO: Reassemble PA data for bcast sink (Bastien Nocera) [RHEL-41144] {CVE-2024-36968}
- Bluetooth: ISO: Add hcon for listening bis sk (Bastien Nocera) [RHEL-41144] {CVE-2024-36968}
- Bluetooth: hci_event: Fix not indicating new connection for BIG Sync (Bastien Nocera) [RHEL-41144] {CVE-2024-36968}
- redhat/configs: enable GPIO expander drivers (Rupinderjit Singh) [RHEL-21124]
- redhat/configs: enable GPIO expander drivers (Rupinderjit Singh) [RHEL-21124]
- redhat/configs: enable GPIO expander drivers (Rupinderjit Singh) [RHEL-21124]
- redhat/configs: enable GPIO expander drivers (Rupinderjit Singh) [RHEL-21124]
- redhat/configs: enable GPIO expander drivers (Rupinderjit Singh) [RHEL-21124]
- redhat/configs: enable GPIO expander drivers (Rupinderjit Singh) [RHEL-21124]
- redhat/configs: enable IMX7ULP watchdog timer (Rupinderjit Singh) [RHEL-21092]
- sock_map: avoid race between sock_map_close and sk_psock_put (CKI Backport Bot) [RHEL-47670] {CVE-2024-39500}
- Bluetooth: Fix usage of __hci_cmd_sync_status (Bastien Nocera) [RHEL-51202] {CVE-2024-41062}
- Bluetooth: L2CAP: Fix deadlock (Bastien Nocera) [RHEL-51202] {CVE-2024-41062}
- bluetooth/l2cap: sync sock recv cb and release (Bastien Nocera) [RHEL-51202] {CVE-2024-41062}
- Bluetooth: compute LE flow credits based on recvbuf space (Bastien Nocera) [RHEL-51202] {CVE-2024-41062}
- redhat/configs: enable Arm SCMI support (Rupinderjit Singh) [RHEL-21190]
- xdp: Remove WARN() from __xdp_reg_mem_model() (CKI Backport Bot) [RHEL-51584] {CVE-2024-42082}
- flow_offload: add encapsulation control flag helpers (CKI Backport Bot) [RHEL-60636]
- net: nexthop: Initialize all fields in dumped nexthops (Guillaume Nault) [RHEL-61380]
- ipv4: Fix incorrect source address in Record Route option (Guillaume Nault) [RHEL-61380]
- ipv4: Fix incorrect TOS in fibmatch route get reply (Guillaume Nault) [RHEL-61380]
- ipv4: Fix incorrect TOS in route get reply (Guillaume Nault) [RHEL-61380]
- ipv4: fix source address selection with route leak (Guillaume Nault) [RHEL-61380]
- inet_diag: Initialize pad field in struct inet_diag_req_v2 (Guillaume Nault) [RHEL-61380]
- ipv4: check for NULL idev in ip_route_use_hint() (Guillaume Nault) [RHEL-61380]
- ipv4: fib: annotate races around nh->nh_saddr_genid and nh->nh_saddr (Guillaume Nault) [RHEL-61380]
- ipv4: ignore dst hint for multipath routes (Guillaume Nault) [RHEL-61380]
- ipv4: annotate data-races around fi->fib_dead (Guillaume Nault) [RHEL-61380]
- cpufreq: intel_pstate: Make hwp_notify_lock a raw spinlock (Steve Best) [RHEL-60024]
- cpufreq: intel_pstate: Set asymmetric CPU capacity on hybrid systems (Steve Best) [RHEL-60024]
- cpufreq: intel_pstate: Support Granite Rapids and Sierra Forest OOB mode (Steve Best) [RHEL-60024]
- cpufreq: intel_pstate: Update Balance performance EPP for Emerald Rapids (Steve Best) [RHEL-60024]
- cpufreq: intel_pstate: Support highest performance change interrupt (Steve Best) [RHEL-60024]
- cpufreq: intel_pstate: Replace boot_cpu_has() (Steve Best) [RHEL-60024]
- cpufreq: intel_pstate: Use HWP to initialize ITMT if CPPC is missing (Steve Best) [RHEL-60024]
- cpufreq: intel_pstate: Check turbo_is_disabled() in store_no_turbo() (Steve Best) [RHEL-60024]
- cpufreq: intel_pstate: Switch to new Intel CPU model defines (Steve Best) [RHEL-60024]
- x86/cpufeatures: Add HWP highest perf change feature flag (Steve Best) [RHEL-60024]
- x86/sched: Add basic support for CPU capacity scaling (Steve Best) [RHEL-60024]
- slab: introduce kvmalloc_array_node() and kvcalloc_node() (CKI Backport Bot) [RHEL-61721]
- mei: me: add arrow lake point H DID (Steve Best) [RHEL-61570]

* Fri Oct 11 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-518.el9]
- devlink: extend devlink_param *set pointer (Jan Stancek) [RHEL-62110]

* Thu Oct 10 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-517.el9]
- crypto: octeontx2 - add missing check for dma_map_single (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - support setting ctx ilen for inline CPT LF (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - register error interrupts for inline cptlf (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - add ctx_val workaround (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - add LF reset on queue disable (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - remove errata workaround for CN10KB or CN10KA B0 chip. (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - add devlink option to set t106 mode (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - add SGv2 support for CN10KB or CN10KA B0 (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - remove CPT block reset (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - Fix cptvf driver cleanup (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - By default allocate one CPT LF per CPT VF (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - hardware configuration for inline IPsec (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - add support for AF to CPT PF uplink mbox (Štěpán Horáček) [RHEL-31478]
- crypto: octeontx2 - Fix objects shared between several modules (Štěpán Horáček) [RHEL-31478]
- octeontx2-af: add mbox for CPT LF reset (Štěpán Horáček) [RHEL-31478]
- nexthop: fix uninitialized variable in nla_put_nh_group_stats() (Ivan Vecera) [RHEL-59118]
- nexthop: Fix splat with CONFIG_DEBUG_PREEMPT=y (Ivan Vecera) [RHEL-59118]
- nexthop: Fix out-of-bounds access during attribute validation (Ivan Vecera) [RHEL-59118]
- nexthop: Only parse NHA_OP_FLAGS for dump messages that require it (Ivan Vecera) [RHEL-59118]
- nexthop: Only parse NHA_OP_FLAGS for get messages that require it (Ivan Vecera) [RHEL-59118]
- selftests: forwarding: Add a test for NH group stats (Ivan Vecera) [RHEL-59118]
- net: nexthop: Have all NH notifiers carry NH ID (Ivan Vecera) [RHEL-59118]
- net: nexthop: Initialize NH group ID in resilient NH group notifiers (Ivan Vecera) [RHEL-59118]
- net: nexthop: Expose nexthop group HW stats to user space (Ivan Vecera) [RHEL-59118]
- net: nexthop: Add ability to enable / disable hardware statistics (Ivan Vecera) [RHEL-59118]
- net: nexthop: Add hardware statistics notifications (Ivan Vecera) [RHEL-59118]
- net: nexthop: Expose nexthop group stats to user space (Ivan Vecera) [RHEL-59118]
- net: nexthop: Add nexthop group entry stats (Ivan Vecera) [RHEL-59118]
- net: nexthop: Add NHA_OP_FLAGS (Ivan Vecera) [RHEL-59118]
- net: nexthop: Adjust netlink policy parsing for a new attribute (Ivan Vecera) [RHEL-59118]
- nexthop: Annotate struct nh_notifier_grp_info with __counted_by (Ivan Vecera) [RHEL-59118]
- nexthop: Annotate struct nh_notifier_res_table_info with __counted_by (Ivan Vecera) [RHEL-59118]
- selftests: net: Add test cases for nexthop groups with invalid neighbors (Ivan Vecera) [RHEL-59118]
- nexthop: Do not return invalid nexthop object during multipath selection (Ivan Vecera) [RHEL-59118]
- nexthop: Factor out neighbor validity check (Ivan Vecera) [RHEL-59118]
- nexthop: Factor out hash threshold fdb nexthop selection (Ivan Vecera) [RHEL-59118]
- pci/hotplug/pnv_php: Fix hotplug driver crash on Powernv (CKI Backport Bot) [RHEL-59436] {CVE-2024-46761}
- net: ip6mr: add RTM_GETROUTE netlink op (Andrea Claudi) [RHEL-50554]
- rtla: Add --trace-buffer-size option (Luis Claudio R. Goncalves) [RHEL-58061]
- net: Move {l,t,d}stats allocation to core and convert veth & vrf (Ivan Vecera) [RHEL-57740]
- net, vrf: Move dstats structure to core (Ivan Vecera) [RHEL-57740]
- x86/vmware: Add TDX hypercall support (Vitaly Kuznetsov) [RHEL-52683]
- x86/vmware: Remove legacy VMWARE_HYPERCALL* macros (Vitaly Kuznetsov) [RHEL-52683]
- x86/vmware: Correct macro names (Vitaly Kuznetsov) [RHEL-52683]
- x86/vmware: Use VMware hypercall API (Vitaly Kuznetsov) [RHEL-52683]
- drm/vmwgfx: Use VMware hypercall API (Vitaly Kuznetsov) [RHEL-52683]
- input/vmmouse: Use VMware hypercall API (Vitaly Kuznetsov) [RHEL-52683]
- ptp/vmware: Use VMware hypercall API (Vitaly Kuznetsov) [RHEL-52683]
- x86/vmware: Introduce VMware hypercall API (Vitaly Kuznetsov) [RHEL-52683]
- drm/vmwgfx: Add unwind hints around RBP clobber (Vitaly Kuznetsov) [RHEL-52683]
- objtool: Allow stack operations in UNWIND_HINT_UNDEFINED regions (Vitaly Kuznetsov) [RHEL-52683]
- x86,objtool: Split UNWIND_HINT_EMPTY in two (Vitaly Kuznetsov) [RHEL-52683]
- powerpc/64s/radix: Fix soft dirty tracking (avchouha) [RHEL-20894]
- net: intel: implement modern PM ops declarations (Corinna Vinschen) [RHEL-17488]
- net: adopt skb_network_offset() and similar helpers (Corinna Vinschen) [RHEL-17488]
- intel: legacy: field get conversion (Corinna Vinschen) [RHEL-17488]
- intel: add bit macro includes where needed (Corinna Vinschen) [RHEL-17488]
- of/irq: Prevent device address out-of-bounds read in interrupt map walk (CKI Backport Bot) [RHEL-59295] {CVE-2024-46743}
- PCI: Add missing bridge lock to pci_bus_lock() (CKI Backport Bot) [RHEL-59331] {CVE-2024-46750}
- bareudp: Pull inner IP header on xmit. (Guillaume Nault) [RHEL-59593]
- bareudp: Pull inner IP header in bareudp_udp_encap_recv(). (Guillaume Nault) [RHEL-59593]
- bareudp: Fix device stats updates. (Guillaume Nault) [RHEL-59593]
- net: create a dummy net_device allocator (Izabela Bakollari) [RHEL-59092]
- net: free_netdev: exit earlier if dummy (Izabela Bakollari) [RHEL-59092]
- net: core: Fix documentation (Izabela Bakollari) [RHEL-59092]
- net: Do not return value from init_dummy_netdev() (Izabela Bakollari) [RHEL-59092]
- xfrm: get global statistics from the offloaded device (CKI Backport Bot) [RHEL-59900]
- xfrm: generalize xdo_dev_state_update_curlft to allow statistics update (CKI Backport Bot) [RHEL-59900]
- selftests/powerpc/dexcr: Fix spelling mistake "predicition" -> "prediction" (Mamatha Inamdar) [RHEL-52762]
- Documentation: Document PowerPC kernel dynamic DEXCR interface (Mamatha Inamdar) [RHEL-52762]
- Documentation: Document PowerPC kernel DEXCR interface (Mamatha Inamdar) [RHEL-52762]
- selftests/powerpc/dexcr: Add chdexcr utility (Mamatha Inamdar) [RHEL-52762]
- selftests/powerpc/dexcr: Add DEXCR config details to lsdexcr (Mamatha Inamdar) [RHEL-52762]
- selftests/powerpc/dexcr: Attempt to enable NPHIE in hashchk selftest (Mamatha Inamdar) [RHEL-52762]
- selftests/powerpc/dexcr: Add DEXCR prctl interface test (Mamatha Inamdar) [RHEL-52762]
- powerpc/dexcr: Add DEXCR prctl interface (Mamatha Inamdar) [RHEL-52762]
- powerpc/dexcr: Reset DEXCR value across exec (Mamatha Inamdar) [RHEL-52762]
- powerpc/dexcr: Track the DEXCR per-process (Mamatha Inamdar) [RHEL-52762]
- powerpc/ptrace: Expose DEXCR and HDEXCR registers to ptrace (Mamatha Inamdar) [RHEL-52762]
- selftests/powerpc/dexcr: Add -no-pie to hashchk tests (Mamatha Inamdar) [RHEL-52762]
- net/smc: fix illegal rmb_desc access in SMC-D connection dump (Steve Best) [RHEL-27748] {CVE-2024-26615}
- ipv6: avoid possible NULL deref in rt6_uncached_list_flush_dev() (CKI Backport Bot) [RHEL-60232]
- ipv6: prevent possible UAF in ip6_xmit() (CKI Backport Bot) [RHEL-60232]
- ipv6: fix possible UAF in ip6_finish_output2() (CKI Backport Bot) [RHEL-60232]
- ipv6: prevent UAF in ip6_send_skb() (CKI Backport Bot) [RHEL-60232]
- ipv6: sr: block BH in seg6_output_core() and seg6_input_core() (CKI Backport Bot) [RHEL-60232]
- ipv6: sr: restruct ifdefines (CKI Backport Bot) [RHEL-60232]
- ipv6: fib: hide unused 'pn' variable (CKI Backport Bot) [RHEL-60232]
- ipv6: lower "link become ready"'s level message (CKI Backport Bot) [RHEL-60232]
- KVM: selftests: Make monitor_mwait require MONITOR/MWAIT feature (Maxim Levitsky) [RHEL-17448]
- proc: fix dentry/inode overinstantiating under /proc/${pid}/net (Joel Savitz) [RHEL-57703]
- remoteproc: k3-r5: Delay notification of wakeup event (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Fix error handling when power-up failed (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Acquire mailbox handle during probe routine (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Acquire mailbox handle during probe routine (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Use devm_rproc_alloc() helper (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Fix log levels where appropriate (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Fix IPC-only mode detection (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Jump to error handling labels in start/stop errors (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Do not allow core1 to power up before core0 via sysfs (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Wait for core0 power-up before powering up core1 (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Use devm_rproc_add() helper (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Use devm_ioremap_wc() helper (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Add devm action to release tsp (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Use devm_kzalloc() helper (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Use devm_ti_sci_get_by_phandle() helper (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Use devm_kcalloc() helper (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Add devm action to release reserved memory (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Use devm_rproc_alloc() helper (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Convert to platform remove callback returning void (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Use symbolic error codes in error messages (Jared Kangas) [RHEL-60788]
- remoteproc: k3-dsp: Suppress duplicate error message in .remove() (Jared Kangas) [RHEL-60788]
- remoteproc: Explicitly include correct DT includes (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Use separate compatible string for TI AM62x SoC family (Jared Kangas) [RHEL-60788]
- dt-bindings: remoteproc: ti: Add new compatible for AM62 SoC family (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Simplify cluster mode setting usage (Jared Kangas) [RHEL-60788]
- remoteproc: k3-c7x: Add support for C7xv DSP on AM62A SoC (Jared Kangas) [RHEL-60788]
- remoteproc: k3-r5: Fix refcount leak in k3_r5_cluster_of_init (Jared Kangas) [RHEL-60788]
- dt-bindings: remoteproc: k3-dsp: Update bindings for J721S2 SoCs (Jared Kangas) [RHEL-60788]
- dt-bindings: remoteproc: k3-r5f: Update bindings for J721S2 SoCs (Jared Kangas) [RHEL-60788]
- scsi: target: Remove unused declarations (Maurizio Lombardi) [RHEL-58872]
- scsi: target: Remove unused list 'device_list' (Maurizio Lombardi) [RHEL-58872]
- scsi: target: iscsi: Remove unused variable xfer_len (Maurizio Lombardi) [RHEL-58872]
- scsi: target: tcm_loop: Make tcm_loop_lld_bus const (Maurizio Lombardi) [RHEL-58872]
- x86/mm/ident_map: Use gbpages only where full GB page should be mapped. (Chris von Recklinghausen) [RHEL-26268]
- arm64: acpi: Harden get_cpu_for_acpi_id() against missing CPU entry (Mark Langsdorf) [RHEL-60765] {CVE-2024-46822}
- arm64: acpi: Move get_cpu_for_acpi_id() to a header (Mark Langsdorf) [RHEL-60765] {CVE-2024-46822}
- mei: me: add arrow lake point S DID (Steve Best) [RHEL-61378]
- powerpc/pseries/iommu: Split Dynamic DMA Window to be used in Hybrid mode (Mamatha Inamdar) [RHEL-53185]
- intel_idle: fix ACPI _CST matching for newer Xeon platforms (David Arcari) [RHEL-60894]
- devlink: extend devlink_param *set pointer (Petr Oros) [RHEL-59901]
- bonding: Fix unnecessary warnings and logs from bond_xdp_get_xmit_slave() (Hangbin Liu) [RHEL-60229]
- net: bonding: correctly annotate RCU in bond_should_notify_peers() (Hangbin Liu) [RHEL-60229]
- driver core: auxiliary bus: Fix documentation of auxiliary_device (Ivan Vecera) [RHEL-61175]
- driver core: auxiliary bus: show auxiliary device IRQs (Ivan Vecera) [RHEL-61175]
- gfs2: Randomize GLF_VERIFY_DELETE work delay (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Use mod_delayed_work in gfs2_queue_try_to_evict (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Update to the evict / remote delete documentation (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Call gfs2_queue_verify_delete from gfs2_evict_inode (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Clean up delete work processing (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Minor delete_work_func cleanup (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Return enum evict_behavior from gfs2_upgrade_iopen_glock (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Rename dinode_demise to evict_behavior (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Rename GIF_{DEFERRED -> DEFER}_DELETE (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Faster gfs2_upgrade_iopen_glock wakeups (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Fix unlinked inode cleanup (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Allow immediate GLF_VERIFY_DELETE work (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Initialize gl_no_formal_ino earlier (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Rename GLF_VERIFY_EVICT to GLF_VERIFY_DELETE (Andreas Gruenbacher) [RHEL-60945]
- gfs2: make timeout values more explicit (Wolfram Sang) [RHEL-60945]
- gfs2: Simplify function gfs2_upgrade_iopen_glock (Andreas Gruenbacher) [RHEL-60945]
- gfs2: Rename SDF_DEACTIVATING to SDF_KILL (Andreas Gruenbacher) [RHEL-60945]
- md/raid1: set max_sectors during early return from choose_slow_rdev() (Nigel Croxon) [RHEL-61196]
- md: Add new_level sysfs interface (Nigel Croxon) [RHEL-61196]
- md: Report failed arrays as broken in mdstat (Nigel Croxon) [RHEL-61196]
- md/raid5: rename wait_for_overlap to wait_for_reshape (Nigel Croxon) [RHEL-61196]
- md/raid5: only add to wq if reshape is in progress (Nigel Croxon) [RHEL-61196]
- md/raid5: Improve performance for sequential IO (Nigel Croxon) [RHEL-61196]
- md/raid5: use wait_on_bit() for R5_Overlap (Nigel Croxon) [RHEL-61196]
- md: Remove flush handling (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: make in memory structure internal (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_enabled() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_wait_behind_writes() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_free() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_set_pages() into struct bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_copy_from_slot() into struct bitmap_operation. (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge get_bitmap_from_slot() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_resize() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: pass in mddev directly for md_bitmap_resize() (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_daemon_work() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge bitmap_unplug() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_unplug_async() into md_bitmap_unplug() (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_sync_with_cluster() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_cond_end_sync() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_close_sync() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_end_sync() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: remove the parameter 'aborted' for md_bitmap_end_sync() (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_start_sync() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_endwrite() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_startwrite() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_dirty_bits() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge bitmap_write_all() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: remove md_bitmap_setallbits() (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_status() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_update_sb() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: make md_bitmap_print_sb() internal (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_flush() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_destroy() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_load() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: merge md_bitmap_create() into bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: simplify md_bitmap_create() + md_bitmap_load() (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: introduce struct bitmap_operations (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: add a new helper md_bitmap_set_pages() (Nigel Croxon) [RHEL-61196]
- md/md-cluster: use helper md_bitmap_get_stats() to get pages in resize_bitmaps() (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: add 'behind_writes' and 'behind_wait' into struct md_bitmap_stats (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: add 'file_pages' into struct md_bitmap_stats (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: add 'sync_size' into struct md_bitmap_stats (Nigel Croxon) [RHEL-61196]
- md/md-cluster: fix spares warnings for __le64 (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: add 'events_cleared' into struct md_bitmap_stats (Nigel Croxon) [RHEL-61196]
- md: use new helper md_bitmap_get_stats() in update_array_info() (Nigel Croxon) [RHEL-61196]
- md/md-bitmap: replace md_bitmap_status() with a new helper md_bitmap_get_stats() (Nigel Croxon) [RHEL-61196]
- md/raid1: use md_bitmap_wait_behind_writes() in raid1_read_request() (Nigel Croxon) [RHEL-61196]
- md/raid1: Clean up local variable 'b' from raid1_read_request() (Nigel Croxon) [RHEL-61196]
- md: Don't flush sync_work in md_write_start() (Nigel Croxon) [RHEL-61196]
- md/raid1: Fix data corruption for degraded array with slow disk (Nigel Croxon) [RHEL-61196]
- md: convert comma to semicolon (Nigel Croxon) [RHEL-61196]
- md/raid1: factor out helpers to choose the best rdev from read_balance() (Nigel Croxon) [RHEL-61196]
- md/raid1: factor out the code to manage sequential IO (Nigel Croxon) [RHEL-61196]
- md/raid1: factor out choose_bb_rdev() from read_balance() (Nigel Croxon) [RHEL-61196]
- md/raid1: factor out choose_slow_rdev() from read_balance() (Nigel Croxon) [RHEL-61196]
- md/raid1: factor out read_first_rdev() from read_balance() (Nigel Croxon) [RHEL-61196]
- md/raid1-10: factor out a new helper raid1_should_read_first() (Nigel Croxon) [RHEL-61196]
- md/raid1: fix choose next idle in read_balance() (Nigel Croxon) [RHEL-61196]
- md/raid1: record nonrot rdevs while adding/removing rdevs to conf (Nigel Croxon) [RHEL-61196]
- powerpc: Implement arch_within_stack_frames (Mamatha Inamdar) [RHEL-52737]
- l2tp: fix lockdep splat (Guillaume Nault) [RHEL-59687]
- net l2tp: drop flow hash on forward (Guillaume Nault) [RHEL-59687]
- selftests: udpgro: no need to load xdp for gro (Hangbin Liu) [RHEL-53858]
- selftests: udpgro: report error when receive failed (Hangbin Liu) [RHEL-53858]
- PCI/AER: Disable AER service on suspend (Lenny Szubowicz) [RHEL-22265]
- Bluetooth: hci_sync: Using hci_cmd_sync_submit when removing Adv Monitor (Bastien Nocera) [RHEL-17584]
- Bluetooth: MGMT: Fix failing to MGMT_OP_ADD_UUID/MGMT_OP_REMOVE_UUID (CKI Backport Bot) [RHEL-17584]
- mpls: Reduce skb re-allocations due to skb_cow() (Guillaume Nault) [RHEL-55145]

* Tue Oct 08 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-516.el9]
- memcg: protect concurrent access to mem_cgroup_idr (Rafael Aquini) [RHEL-56254] {CVE-2024-43892}
- bnxt_en: Fix double DMA unmapping for XDP_REDIRECT (Michal Schmidt) [RHEL-57259] {CVE-2024-44984}
- intel_th: pci: Add Granite Rapids SOC support (Michael Petlan) [RHEL-15664]
- dma: fix call order in dmam_free_coherent (Eder Zulian) [RHEL-54751] {CVE-2024-43856}
- dmaengine: idxd: Avoid unnecessary destruction of file_ida (Jerry Snitselaar) [RHEL-44508] {CVE-2024-38629}
- tipc: Return non-zero value from tipc_udp_addr2str() on error (Xin Long) [RHEL-55074] {CVE-2024-42284}
- net/mlx5e: SHAMPO, Fix invalid WQ linked list unlink (Michal Schmidt) [RHEL-57119] {CVE-2024-44970}
- net/mlx5e: Fix CT entry update leaks of modify header context (Michal Schmidt) [RHEL-55628] {CVE-2024-43864}
- net/mlx5: Always drain health in shutdown callback (Michal Schmidt) [RHEL-55616] {CVE-2024-43866}
- net/mlx5: SF, Stop waiting for FW as teardown was called (Michal Schmidt) [RHEL-55616]
- net/mlx5: Fix missing lock on sync reset reload (Michal Schmidt) [RHEL-55121] {CVE-2024-42268}
- ionic: fix kernel panic in XDP_TX action (CKI Backport Bot) [RHEL-47730] {CVE-2024-40907}
- r8169: Fix possible ring buffer corruption on fragmented Tx packets. (Izabela Bakollari) [RHEL-44037] {CVE-2024-38586}
- ata: libata-core: Fix double free on error (Tomas Henzl) [RHEL-53777]
- ata: libata: Fix memory leak for error path in ata_host_alloc() (Tomas Henzl) [RHEL-53777]
- ata: ahci: Clean up sysfs file on error (Tomas Henzl) [RHEL-53777]
- ata: libata-core: Fix null pointer dereference on error (Tomas Henzl) [RHEL-53777]
- ata: libata-core: Add ATA_HORKAGE_NOLPM for all Crucial BX SSD1 models (Tomas Henzl) [RHEL-53777]
- ata: ahci: Do not enable LPM if no LPM states are supported by the HBA (Tomas Henzl) [RHEL-53777]
- ata: libata-scsi: Set the RMB bit only for removable media devices (Tomas Henzl) [RHEL-53777]
- ata: libata-core: Do not try to set sleeping devices to standby (Tomas Henzl) [RHEL-53777]
- KVM: s390: fix validity interception issue when gisa is switched off (CKI Backport Bot) [RHEL-57197] {CVE-2024-45005}
- wifi: rtw89: limit the PPDU length for VHT rate to 0x40000 (Narpat Mali) [RHEL-35542]
- wifi: rtw89: 885xbx: apply common settings to 8851B, 8852B and 8852BT (Narpat Mali) [RHEL-35542]
- wifi: rtw89: 8852b: fix definition of KIP register number (Narpat Mali) [RHEL-35542]
- wifi: rtw89: 8852b: set AMSDU limit to 5000 (Narpat Mali) [RHEL-35542]

* Wed Oct 02 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-515.el9]
- smb: client: fix double put of @cfile in smb2_set_path_size() (Paulo Alcantara) [RHEL-57983]
- smb: client: fix double put of @cfile in smb2_rename_path() (Paulo Alcantara) [RHEL-57983]
- smb: client: fix hang in wait_for_response() for negproto (Paulo Alcantara) [RHEL-57983]
- smb/client: avoid dereferencing rdata=NULL in smb2_new_read_req() (Paulo Alcantara) [RHEL-57983]
- smb/client: fix typo: GlobalMid_Sem -> GlobalMid_Lock (Paulo Alcantara) [RHEL-57983]
- smb: client: ignore unhandled reparse tags (Paulo Alcantara) [RHEL-57983]
- smb3: fix problem unloading module due to leaked refcount on shutdown (Paulo Alcantara) [RHEL-57983]
- smb3: fix broken cached reads when posix locks (Paulo Alcantara) [RHEL-57983]
- smb: smb2pdu.h: Use static_assert() to check struct sizes (Paulo Alcantara) [RHEL-57983]
- smb3: fix lock breakage for cached writes (Paulo Alcantara) [RHEL-57983]
- cifs: cifs_inval_name_dfs_link_error: correct the check for fullpath (Paulo Alcantara) [RHEL-57983]
- Fix spelling errors in Server Message Block (Paulo Alcantara) [RHEL-57983]
- smb3: fix setting SecurityFlags when encryption is required (Paulo Alcantara) [RHEL-57983]
- smb: client: fix FSCTL_GET_REPARSE_POINT against NetApp (Paulo Alcantara) [RHEL-57983]
- smb3: add dynamic tracepoints for shutdown ioctl (Paulo Alcantara) [RHEL-57983]
- smb: client: handle lack of FSCTL_GET_REPARSE_POINT support (Paulo Alcantara) [RHEL-57983]
- smb3: add dynamic trace point for session setup key expired failures (Paulo Alcantara) [RHEL-57983]
- smb3: add four dynamic tracepoints for copy_file_range and reflink (Paulo Alcantara) [RHEL-57983]
- smb3: add dynamic tracepoint for reflink errors (Paulo Alcantara) [RHEL-57983]
- cifs: mount with "unix" mount option for SMB1 incorrectly handled (Paulo Alcantara) [RHEL-57983]
- cifs: fix reconnect with SMB1 UNIX Extensions (Paulo Alcantara) [RHEL-57983]
- cifs: fix potential null pointer use in destroy_workqueue in init_cifs error path (Paulo Alcantara) [RHEL-57983]
- cifs: fix noisy message on copy_file_range (Paulo Alcantara) [RHEL-57983]
- cifs: fix setting SecurityFlags to true (Paulo Alcantara) [RHEL-57983]
- cifs: fix typo in module parameter enable_gcm_256 (Paulo Alcantara) [RHEL-57983]
- smb: client: fix deadlock in smb2_find_smb_tcon() (Paulo Alcantara) [RHEL-57983]
- cifs: fix creating sockets when using sfu mount options (Paulo Alcantara) [RHEL-57983]
- smb: smb2pdu.h: Avoid -Wflex-array-member-not-at-end warnings (Paulo Alcantara) [RHEL-57983]
- smb3: fix lock ordering potential deadlock in cifs_sync_mid_result (Paulo Alcantara) [RHEL-57983]
- smb3: missing lock when picking channel (Paulo Alcantara) [RHEL-57983]
- smb: client: Fix struct_group() usage in __packed structs (Paulo Alcantara) [RHEL-57983]
- cifs: reinstate original behavior again for forceuid/forcegid (Paulo Alcantara) [RHEL-57983]
- ksmbd: common: use struct_group_attr instead of struct_group for network_open_info (Paulo Alcantara) [RHEL-57983]
- cifs: Add tracing for the cifs_tcon struct refcounting (Paulo Alcantara) [RHEL-57983]
- cifs: Fix reacquisition of volume cookie on still-live connection (Paulo Alcantara) [RHEL-57983]
- smb3: fix broken reconnect when password changing on the server by allowing password rotation (Paulo Alcantara) [RHEL-57983]
- smb3: fix Open files on server counter going negative (Paulo Alcantara) [RHEL-57983]
- smb3: retrying on failed server close (Paulo Alcantara) [RHEL-57983]
- cifs: Fix caching to try to do open O_WRONLY as rdwr on server (Paulo Alcantara) [RHEL-57983]
- netdev: add queue stat for alloc failures (CKI Backport Bot) [RHEL-57771]
- netdev: add per-queue statistics (CKI Backport Bot) [RHEL-57771]
- net/iucv: Avoid explicit cpumask var allocation on stack (Mete Durlu) [RHEL-56533] {CVE-2024-42094}
- powerpc/64s: Enable KFENCE on book3s64 (Mamatha Inamdar) [RHEL-52738]
- powerpc/perf: Fix the threshold compare group constraint for power10 (Mamatha Inamdar) [RHEL-50637]
- tools/power turbostat: version 2024.07.26 (Steve Best) [RHEL-57077]
- tools/power turbostat: Include umask=%%x in perf counter's config (Steve Best) [RHEL-57077]
- tools/power turbostat: Document PMT in turbostat.8 (Steve Best) [RHEL-57077]
- tools/power turbostat: Add MTL's PMT DC6 builtin counter (Steve Best) [RHEL-57077]
- tools/power turbostat: Add early support for PMT counters (Steve Best) [RHEL-57077]
- tools/power turbostat: Move verbose counter messages to level 2 (Steve Best) [RHEL-57077]
- tools/power turbostat: Move debug prints from stdout to stderr (Steve Best) [RHEL-57077]
- tools/power turbostat: Fix typo in turbostat.8 (Steve Best) [RHEL-57077]
- tools/power turbostat: Add perf added counter example to turbostat.8 (Steve Best) [RHEL-57077]
- tools/power turbostat: Fix formatting in turbostat.8 (Steve Best) [RHEL-57077]
- tools/power turbostat: Extend --add option with perf counters (Steve Best) [RHEL-57077]
- tools/power turbostat: Group SMI counter with APERF and MPERF (Steve Best) [RHEL-57077]
- tools/power turbostat: Add ZERO_ARRAY for zero initializing builtin array (Steve Best) [RHEL-57077]
- tools/power turbostat: Replace enum rapl_source and cstate_source with counter_source (Steve Best) [RHEL-57077]
- tools/power turbostat: Remove anonymous union from rapl_counter_info_t (Steve Best) [RHEL-57077]
- tools/power/turbostat: Switch to new Intel CPU model defines (Steve Best) [RHEL-57077]
- scsi: ufs: renesas: Fix private allocation (Radu Rendec) [RHEL-60138]
- powerpc/pseries/iommu: Define spapr_tce_table_group_ops only with CONFIG_IOMMU_API (Mamatha Inamdar) [RHEL-52741]
- powerpc/iommu: Reimplement the iommu_table_group_ops for pSeries (Mamatha Inamdar) [RHEL-52741]
- powerpc/iommu: Move dev_has_iommu_table() to iommu.c (Mamatha Inamdar) [RHEL-52741]
- vfio/spapr: Always clear TCEs before unsetting the window (Mamatha Inamdar) [RHEL-52741]
- powerpc/pseries/iommu: Use the iommu table[0] for IOV VF's DDW (Mamatha Inamdar) [RHEL-52741]
- powerpc/pseries/iommu: Fix the VFIO_IOMMU_SPAPR_TCE_GET_INFO ioctl output (Mamatha Inamdar) [RHEL-52741]
- powerpc/iommu: Move pSeries specific functions to pseries/iommu.c (Mamatha Inamdar) [RHEL-52741]
- powerpc/powernv/pci: Remove ioda1 support (Mamatha Inamdar) [RHEL-52741]
- tools/cpupower: display residency value in idle-info (Steve Best) [RHEL-59682]
- cpupower: Change the var type of the 'monitor' subcommand display mode (Steve Best) [RHEL-59682]
- ceph: remove the incorrect Fw reference check when dirtying pages (Xiubo Li) [RHEL-60255]
- pinctrl: meteorlake: Add Arrow Lake-H/U ACPI ID (Steve Best) [RHEL-60002]
- dmaengine: dw: Add memory bus width verification (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: omap-dma: Initialize sglen after allocation (Jerry Snitselaar) [RHEL-56794]
- dmaengine: dw: Add peripheral bus width verification (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: add missing MODULE_DESCRIPTION() macros (Jerry Snitselaar) [RHEL-56794]
- dmaengine: virt-dma: add missing MODULE_DESCRIPTION() macro (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: k3-udma: Fix BCHAN count with UHC and HC channels (Jerry Snitselaar) [RHEL-56794]
- dmaengine: sh: rz-dmac: Fix lockdep assert warning (Jerry Snitselaar) [RHEL-56794]
- dmaengine: qcom: gpi: clean up the IRQ disable/enable in gpi_reset_chan() (Jerry Snitselaar) [RHEL-56794]
- dmaengine: qcom: gpi: remove unused struct 'reg_info' (Jerry Snitselaar) [RHEL-56794]
- dmaengine: add channel device name to channel registration (Jerry Snitselaar) [RHEL-56794]
- dmaengine: qcom: add missing MODULE_DESCRIPTION() macros (Jerry Snitselaar) [RHEL-56794]
- dmaengine: imx-sdma: don't print warning when firmware is absent (Jerry Snitselaar) [RHEL-56794]
- firmware: add nowarn variant of request_firmware_nowait() (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: k3-udma: fix module autoloading (Jerry Snitselaar) [RHEL-56794]
- dmaengine: add missing MODULE_DESCRIPTION() macros (Jerry Snitselaar) [RHEL-56794]
- dmaengine: Add API function dmaengine_prep_peripheral_dma_vec() (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: k3-udma-glue: clean up return in k3_udma_glue_rx_get_irq() (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: k3-udma-glue: Fix of_k3_udma_glue_parse_chn_by_id() (Jerry Snitselaar) [RHEL-56794]
- dmaengine: imx-sdma: Add i2c dma support (Jerry Snitselaar) [RHEL-56794]
- dmaengine: imx-sdma: utilize compiler to calculate ADDRS_ARRAY_SIZE_V<n> (Jerry Snitselaar) [RHEL-56794]
- dmaengine: qcom: Drop hidma DT support (Jerry Snitselaar) [RHEL-56794]
- dma: Add lockdep asserts to virt-dma (Jerry Snitselaar) [RHEL-56794]
- dmaengine: imx-sdma: support dual fifo for DEV_TO_DEV (Jerry Snitselaar) [RHEL-56794]
- dmaengine: imx-sdma: Support 24bit/3bytes for sg mode (Jerry Snitselaar) [RHEL-56794]
- dmaengine: imx-sdma: Support allocate memory from internal SRAM (iram) (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: k3-psil-j721s2: Add entry for CSI2RX (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: k3-udma-glue: Add function to request RX chan for thread ID (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: k3-udma-glue: Add function to request TX chan for thread ID (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: k3-udma-glue: Update name for remote RX channel device (Jerry Snitselaar) [RHEL-56794]
- dmaengine: ti: k3-udma-glue: Add function to parse channel by ID (Jerry Snitselaar) [RHEL-56794]
- vhost/vsock: always initialize seqpacket_allow (CKI Backport Bot) [RHEL-55592] {CVE-2024-43873}
- Bluetooth: af_bluetooth: Fix deadlock (CKI Backport Bot) [RHEL-34156] {CVE-2024-26886}
- Bluetooth: l2cap: fix null-ptr-deref in l2cap_chan_timeout (CKI Backport Bot) [RHEL-36374] {CVE-2024-27399}
- Bluetooth: Ignore too large handle values in BIG (CKI Backport Bot) [RHEL-51918] {CVE-2024-42133}

* Fri Sep 27 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-514.el9]
- wifi: cfg80211: handle 2x996 RU allocation in cfg80211_calculate_bitrate_he() (Jose Ignacio Tornos Martinez) [RHEL-55579] {CVE-2024-43879}
- wifi: mac80211: fix NULL dereference at band check in starting tx ba session (Jose Ignacio Tornos Martinez) [RHEL-56191] {CVE-2024-43911}
- wifi: rtw89: Fix array index mistake in rtw89_sta_info_get_iter() (Jose Ignacio Tornos Martinez) [RHEL-54805] {CVE-2024-43842}
- scsi: smartpqi: Bump driver version to 2.1.26-030 (Don Brace) [RHEL-21268]
- scsi: smartpqi: Fix logical volume rescan race condition (Don Brace) [RHEL-21268]
- scsi: smartpqi: Add new controller PCI IDs (Don Brace) [RHEL-21268]
- gfs2: Fix NULL pointer dereference in gfs2_log_flush (Andrew Price) [RHEL-51559] {CVE-2024-42079}
- x86/mm: Fix pti_clone_pgtable() alignment assumption (Rafael Aquini) [RHEL-57170] {CVE-2024-44965}
- bnxt_en: Adjust logging of firmware messages in case of released token in __hwrm_send() (CKI Backport Bot) [RHEL-47822] {CVE-2024-40919}
- kabi: enable check-kabi (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol zlib_inflate_workspacesize to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol zlib_inflateInit2 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol zlib_inflateEnd to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol zlib_inflate to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol zgid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol zap_vma_ptes to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol yield to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xz_dec_run to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xz_dec_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xz_dec_end to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xsk_uses_need_wakeup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xsk_tx_release to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xsk_tx_peek_desc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xsk_tx_completed to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xsk_set_tx_need_wakeup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xsk_set_rx_need_wakeup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xsk_get_pool_from_qid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xsk_clear_rx_need_wakeup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xp_set_rxq_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xp_raw_get_dma to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xp_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xp_dma_unmap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xp_dma_sync_for_device_slow to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xp_dma_sync_for_cpu_slow to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xp_dma_map to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xp_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_warn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_set_features_flag to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_rxq_info_unreg_mem_model to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_rxq_info_unreg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_rxq_info_reg_mem_model to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __xdp_rxq_info_reg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_rxq_info_is_reg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_return_frame_rx_napi to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_return_frame to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_master_redirect to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_features_set_redirect_target to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_features_clear_redirect_target to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_do_redirect to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_do_flush to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xdp_convert_zc_to_xdp_frame to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xattr_full_name to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xa_store to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xas_find to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xa_set_mark to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xa_load to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __xa_insert to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xa_get_mark to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xa_find_after to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xa_find to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xa_erase to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xa_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol xa_clear_mark to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __xa_alloc_cyclic to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __xa_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol x86_spec_ctrl_base to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_return_thunk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_rsi to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_rdx to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_rdi to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_rcx to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_rbx to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_rbp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_rax to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_r9 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_r8 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_r15 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_r14 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_r13 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_r12 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_r11 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __x86_indirect_thunk_r10 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol x86_cpu_to_apicid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __write_overflow_field to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol write_inode_now to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __warn_printk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol wake_up_process to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __wake_up to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __wait_on_buffer to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol wait_for_completion_timeout to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol wait_for_completion_interruptible to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol wait_for_completion to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vzalloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vsprintf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vsnprintf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vscnprintf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vprintk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vm_zone_stat to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vm_munmap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vm_mmap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vm_event_states to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vmemmap_base to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vmalloc_to_page to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vmalloc_node to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vmalloc_base to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vmalloc_32 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vmalloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __vmalloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vlan_dev_vlan_proto to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vlan_dev_vlan_id to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vlan_dev_real_dev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __virt_addr_valid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_unlink to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_symlink to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_statfs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __vfs_setxattr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_rmdir to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_rename to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __vfs_removexattr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_readlink to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_mknod to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_mkdir to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_llseek to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_link to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_iter_write to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_iter_read to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __vfs_getxattr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_get_link to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_getattr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_fsync_range to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_fsync to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfs_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol vfree to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __var_waitqueue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_undefined to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_teardown_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_setup_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_possible_blades to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __uv_hub_info_list to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_get_hubless_system to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __uv_cpu_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_bios_obj_count to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_bios_install_heap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_bios_get_pci_topology to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_bios_get_master_nasid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_bios_get_heapsize to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_bios_get_geoinfo to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_bios_enum_ports to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol uv_bios_enum_objs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol usleep_range_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol up_write to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol up_read to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol up to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_sysctl_table to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_switchdev_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_switchdev_blocking_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_shrinker to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_reboot_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_nmi_handler to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_netevent_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_netdevice_notifier_net to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_netdevice_notifier_dev_net to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_netdevice_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_netdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_kprobe to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_inetaddr_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_inet6addr_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_filesystem to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_fib_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_chrdev_region to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __unregister_chrdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_blkdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unregister_binfmt to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unmap_mapping_range to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol unlock_page to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol udp_tunnel_nic_ops to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol udp4_hwcsum to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __udelay to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_unregister_driver to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_termios_encode_baud_rate to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_std_termios to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_register_driver to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_port_link_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_port_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_port_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __tty_insert_flip_string_flags to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_flip_buffer_push to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_driver_kref_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tty_buffer_request_room to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __tty_alloc_driver to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tsc_khz to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol try_wait_for_completion to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol try_module_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol truncate_pagecache to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol truncate_inode_pages_range to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol truncate_inode_pages_final to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol truncate_inode_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_seq_putc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_seq_printf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_raw_output_prep to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_print_flags_seq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __tracepoint_xdp_exception to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __tracepoint_mmap_lock_start_locking to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __tracepoint_mmap_lock_released to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __tracepoint_mmap_lock_acquire_returned to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_handle_return to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_event_reg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_event_raw_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_event_printf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_event_ignore_this_pid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_event_buffer_reserve to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol trace_event_buffer_commit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol touch_softlockup_watchdog to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _totalram_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tls_validate_xmit_skb to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tls_get_record to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol timer_delete_sync to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol timer_delete to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol timecounter_read to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol timecounter_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol timecounter_cyc2time to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol time64_to_tm to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol this_cpu_off to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol thaw_bdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tcp_hashinfo to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __task_pid_nr_ns to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tasklet_unlock_wait to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tasklet_setup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __tasklet_schedule to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tasklet_kill to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol tasklet_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __tasklet_hi_schedule to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sys_tz to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol system_wq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol system_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sysfs_streq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sysfs_remove_group to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sysfs_remove_file_ns to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sysfs_remove_bin_file to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __sysfs_match_string to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sysfs_emit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sysfs_create_group to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sysfs_create_file_ns to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sysfs_create_bin_file to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sysfs_add_file_to_group to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sync_mapping_buffers to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol synchronize_rcu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol synchronize_net to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol synchronize_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sync_blockdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __symbol_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __symbol_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __sw_hweight64 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __sw_hweight32 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol submit_bio_noacct to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol submit_bio to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strstr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strsep to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strrchr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strnlen_user to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strnlen to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strncpy_from_user to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strncpy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strncmp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strncasecmp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strlen to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strlcpy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strlcat to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strim to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strcspn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strcpy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strcmp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strchr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol strcat to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol static_key_slow_inc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol static_key_slow_dec to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol static_key_count to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __stack_chk_fail to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sscanf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sprintf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sort to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol softnet_data to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sock_setsockopt to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sock_sendmsg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sock_release to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sock_recvmsg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sock_gen_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sock_create_kern to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sock_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sock_alloc_file to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sn_region_size to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol snprintf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sn_partition_id to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol smp_call_function_single_async to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol smp_call_function_single to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol smp_call_function_many to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sme_me_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sk_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_vlan_pop to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_tstamp_tx to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __skb_recv_udp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_realloc_headroom to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_queue_tail to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_push to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_pull to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __skb_pad to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __skb_flow_dissect to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_ext_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_dequeue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_copy_bits to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_copy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_clone_tx_timestamp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_clone to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_checksum_help to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_checksum to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol skb_add_rx_frag to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sk_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sized_strscpy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol single_release to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol single_open_size to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol single_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol simple_write_to_buffer to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol simple_strtoull to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol simple_strtoul to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol simple_strtol to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol simple_statfs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol simple_read_from_buffer to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol simple_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol simple_attr_release to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol simple_attr_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol si_meminfo to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sigprocmask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol shrink_dcache_sb to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol shrink_dcache_parent to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __sg_page_iter_start to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __sg_page_iter_dma_next to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sg_next to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sget to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sg_copy_to_buffer to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sg_copy_from_buffer to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_user_nice to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_page_writeback to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __set_page_dirty_nobuffers to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_page_dirty_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_page_dirty to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_normalized_timespec64 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_nlink to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_freezable to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_disk_ro to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_current_groups to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_cpus_allowed_ptr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_capacity to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol set_blocksize to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol setattr_prepare to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol seq_write to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol seq_release to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol seq_read to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol seq_puts to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol seq_putc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol seq_printf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol seq_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol seq_lseek to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol send_sig_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol send_sig to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol security_sb_set_mnt_opts to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol security_sb_eat_lsm_opts to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol security_inode_init_security to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol security_free_mnt_opts to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol security_d_instantiate to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sdev_prefix_printk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __SCT__tp_func_xdp_exception to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __SCT__preempt_schedule_notrace to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __SCT__preempt_schedule to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __SCT__might_resched to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __SCT__cond_resched to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_vpd_lun_id to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_remove_host to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_remove_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_register_driver to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsilun_to_int to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_is_sdev_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_is_fc_rport to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_host_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_host_lookup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_host_busy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_host_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_done to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_device_type to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_device_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_device_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_command_size_tbl to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_change_queue_depth to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsicam_bios_param to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_bus_type to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_alloc_request to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_add_host_with_dma to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scsi_add_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol scnprintf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __SCK__tp_func_xdp_exception to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol schedule_timeout to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol schedule to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sched_numa_hop_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sched_clock_cpu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol sched_clock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rtnl_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rtnl_trylock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rtnl_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rtnl_is_locked to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rps_may_expire_flow to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol round_jiffies to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol root_device_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __root_device_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rht_bucket_nested_insert to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rht_bucket_nested to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __rht_bucket_nested to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rhltable_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rhashtable_insert_slow to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rhashtable_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rhashtable_free_and_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rhashtable_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol revert_creds to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol request_threaded_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __request_region to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __request_module to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol request_firmware_direct to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol request_firmware to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol remove_wait_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol remove_proc_entry to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol remap_pfn_range to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol release_sock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __release_region to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol release_firmware to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_sysctl_table to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_switchdev_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_switchdev_blocking_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_shrinker to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_reboot_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __register_nmi_handler to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_netevent_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_netdevice_notifier_net to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_netdevice_notifier_dev_net to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_netdevice_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_netdevice to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_netdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_kprobe to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_inetaddr_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_inet6addr_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_filesystem to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_fib_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol register_chrdev_region to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __register_chrdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __register_blkdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __register_binfmt to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __refrigerator to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol refcount_warn_saturate to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol refcount_dec_if_one to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol refcount_dec_and_mutex_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol recalc_sigpending to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __read_overflow2_field to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_user_mmap_io to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_user_mmap_entry_remove to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_user_mmap_entry_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_user_mmap_entry_insert to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_user_mmap_entry_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_resolve_route to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_resolve_addr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_reject to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_read_gid_l2_fields to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_query_gid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_listen to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_disconnect to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_destroy_qp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_destroy_id to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_create_qp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __rdma_create_kernel_id to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_connect to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_bind_addr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_alloc_hw_stats_struct to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rdma_accept to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rcuref_get_slowpath to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rcu_read_unlock_strict to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __rcu_read_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __rcu_read_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rcu_barrier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rb_next to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rb_insert_color to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rb_first to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol rb_erase to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_write_unlock_irqrestore to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_write_unlock_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_write_unlock_bh to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_write_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_write_trylock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_write_lock_irqsave to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_write_lock_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_write_lock_bh to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_write_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_unlock_irqrestore to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_unlock_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_unlock_bh to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_trylock_bh to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_trylock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_lock_irqsave to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_lock_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_lock_bh to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_spin_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_read_unlock_irqrestore to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_read_unlock_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_read_unlock_bh to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_read_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_read_lock_irqsave to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_read_lock_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_read_lock_bh to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _raw_read_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ___ratelimit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol radix_tree_tag_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol radix_tree_next_chunk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol radix_tree_lookup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol radix_tree_insert to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol radix_tree_delete to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol queue_work_on to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol queue_delayed_work_on to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol qed_put_iscsi_ops to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol qed_put_eth_ops to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol qdisc_reset to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pv_ops to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __put_user_8 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __put_user_4 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __put_user_2 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol put_unused_fd to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol put_disk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __put_devmap_managed_page_refs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol put_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __put_cred to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ptrs_per_p4d to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ptp_schedule_worker to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ptp_parse_header to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ptp_find_pin to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ptp_clock_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ptp_clock_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ptp_clock_index to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ptp_clock_event to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ptp_classify_raw to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ___pskb_trim to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __pskb_pull_tail to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pskb_expand_head to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol psample_sample_packet to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol proc_remove to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol proc_mkdir_mode to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol proc_mkdir to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol proc_dostring to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol proc_dointvec_minmax to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol proc_dointvec to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol proc_create_data to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol proc_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol priv_to_devlink to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __printk_ratelimit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _printk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol print_hex_dump to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol prepare_to_wait_exclusive to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol prepare_to_wait_event to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol prepare_to_wait to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol prepare_creds to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol posix_test_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol posix_lock_file to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol posix_acl_valid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol posix_acl_to_xattr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol posix_acl_from_xattr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol posix_acl_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol poll_initwait to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol poll_freewait to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pm_schedule_suspend to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __pm_runtime_resume to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pldmfw_op_pci_match_record to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pldmfw_flash_image to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pipe_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pipe_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pid_task to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol physical_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol phys_base to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pgprot_writecombine to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pgdir_shift to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol perf_trace_run_bpf_submit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol perf_trace_buf_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol percpu_ref_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol percpu_ref_exit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __per_cpu_offset to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pcpu_hot to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_write_config_word to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_write_config_dword to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_wake_from_d3 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_wait_for_pending_transaction to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_vfs_assigned to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_unregister_driver to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_sriov_set_totalvfs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_sriov_get_totalvfs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_set_power_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_set_master to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_select_bars to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_save_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_restore_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_restore_msi_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_request_selected_regions to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_request_regions to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_release_selected_regions to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_release_regions to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __pci_register_driver to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_read_config_word to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_read_config_dword to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_read_config_byte to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_prepare_to_sleep to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_num_vf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_msix_free_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_msix_can_alloc_dyn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_msix_alloc_irq_at to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_irq_vector to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_iov_virtfn_devfn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_iov_vf_id to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_iov_get_pf_drvdata to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_iounmap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_ioremap_bar to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_iomap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_get_dsn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_get_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_free_irq_vectors to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_find_ext_capability to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_find_capability to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pcie_relaxed_ordering_enabled to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pcie_ptm_enabled to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pcie_print_link_status to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_enable_wake to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_enable_sriov to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_enable_ptm to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_enable_msix_range to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_enable_msi to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_enable_device_mem to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_enable_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_enable_atomic_ops_to_root to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pcie_flr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pcie_capability_read_word to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pcie_capability_read_dword to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pcie_bandwidth_available to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_disable_sriov to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_disable_msix to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_disable_msi to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_disable_link_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_disable_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_dev_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_device_is_present to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_dev_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_dev_driver to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_clear_master to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_cfg_access_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_cfg_access_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_bus_type to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_alloc_irq_vectors to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pci_aer_clear_nonfatal_status to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol path_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_set_int to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_set_bool to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_ushort to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_ulong to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_uint to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_string to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_short to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_long to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_int to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_charp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_byte to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_ops_bool to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_get_int to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol param_array_ops to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol panic_notifier_list to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol panic to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __pagevec_release to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pagevec_lookup_range_tag to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol page_pool_update_nid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol page_pool_get_stats to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol page_pool_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol page_pool_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol page_pool_alloc_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol page_offset_base to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol page_frag_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __page_frag_cache_drain to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol pagecache_get_page to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol override_creds to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol on_each_cpu_cond_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __num_online_cpus to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol numa_node to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ns_to_timespec64 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol nr_cpu_ids to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol notify_change to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol noop_llseek to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol node_to_cpumask_map to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol node_states to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __node_distance to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol node_data to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol nla_find to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol new_inode to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol net_ratelimit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_tx_wake_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_tx_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_tx_stop_all_queues to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_tx_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_set_xps_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_set_tso_max_size to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_set_real_num_tx_queues to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_set_real_num_rx_queues to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_schedule_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_rx to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __netif_napi_del to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_napi_add_weight to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_device_detach to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_device_attach to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_carrier_on to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_carrier_off to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netif_carrier_event to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol net_dim to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_warn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_update_features to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_unbind_sb_channel to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_state_change to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_set_tc_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_set_sb_channel to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_set_num_tc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_rx_handler_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_rx_handler_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_rss_key_fill to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_reset_tc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_refcnt_read to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_printk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_port_same_parent_id to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_pick_tx to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_notice to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_master_upper_dev_get_rcu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_master_upper_dev_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_lower_get_next to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_features_change to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_err to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_crit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol netdev_bind_sb_channel_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __netdev_alloc_skb to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol neigh_lookup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __neigh_event_send to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol neigh_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ndo_dflt_fdb_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ndo_dflt_bridge_getlink to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __ndelay to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol napi_schedule_prep to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __napi_schedule_irqoff to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __napi_schedule to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol napi_gro_receive to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol napi_enable to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol napi_disable to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol napi_consume_skb to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol napi_complete_done to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol napi_busy_loop to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol napi_build_skb to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol napi_alloc_skb to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol names_cachep to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mutex_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mutex_trylock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mutex_lock_interruptible to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mutex_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mutex_is_locked to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __mutex_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol msleep_interruptible to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol msleep to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __msecs_to_jiffies to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mpage_writepages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mpage_readahead to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mount_nodev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mount_bdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol module_refcount to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol module_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol module_layout to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __module_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mod_timer to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mod_delayed_work_on to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mntput to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mntget to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mmu_notifier_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mmu_notifier_get_locked to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mmput to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __mmap_lock_do_trace_start_locking to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __mmap_lock_do_trace_released to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __mmap_lock_do_trace_acquire_returned to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mlxfw_firmware_flash to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol misc_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol misc_deregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol metadata_dst_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol metadata_dst_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol memset to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mem_section to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mempool_free_slab to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mempool_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mempool_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mempool_create_node to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mempool_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mempool_alloc_slab to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mempool_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol memparse to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol memory_read_from_buffer to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol memmove to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol memdup_user to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol memcpy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol memcmp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol memchr_inv to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mds_idle_clear to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mark_page_accessed to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __mark_inode_dirty to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol mark_buffer_dirty to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol loops_per_jiffy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol lookup_one_len to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol lookup_bdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol lock_sock_nested to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol locks_lock_inode_wait to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol locks_delete_block to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol lockref_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __local_bh_enable_ip to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol llist_add_batch to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __list_del_entry_valid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __list_add_valid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kvmalloc_node to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kvfree_call_rcu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kvfree to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ktime_get_with_offset to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ktime_get_ts64 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ktime_get_snapshot to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ktime_get_real_ts64 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ktime_get_real_seconds to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ktime_get_coarse_real_ts64 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ktime_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_use_mm to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_unuse_mm to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_stop to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_should_stop to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_queue_work to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_queue_delayed_work to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_destroy_worker to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_delayed_work_timer_fn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_create_worker to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_create_on_node to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_complete_and_exit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_cancel_work_sync to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_cancel_delayed_work_sync to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kthread_bind to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kstrtoull to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kstrtouint to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kstrtou8 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kstrtou16 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kstrtos16 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kstrtoll to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kstrtoint to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kstrtobool to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kstrdup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol krealloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kobject_uevent_env to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kobject_uevent to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kobject_set_name to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kobject_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kobject_init_and_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kobject_get_unless_zero to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kobject_create_and_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmemdup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmem_cache_shrink to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmem_cache_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmem_cache_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmem_cache_create_usercopy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmem_cache_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmem_cache_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmalloc_trace to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmalloc_node_trace to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __kmalloc_node to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmalloc_large to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kmalloc_caches to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __kmalloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kill_pid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kill_pgrp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kill_fasync to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kill_block_super to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kill_anon_super to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kfree to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kexec_crash_loaded to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kern_path_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kern_path to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kernel_write to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kernel_sigaction to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kernel_sendmsg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kernel_recvmsg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kernel_read to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kernel_fpu_end to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kernel_fpu_begin_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kblockd_schedule_work to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol kasprintf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol jiffies_to_usecs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol jiffies_to_msecs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol jiffies_64 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol jiffies to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iter_file_splice_write to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iterate_dir to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol is_vmalloc_addr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol is_uv_system to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iscsi_boot_create_host_kset to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol irq_set_affinity_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol irq_poll_enable to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol irq_poll_disable to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol irq_get_irq_data to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol irq_cpu_rmap_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __irq_apply_affinity_hint to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ipv6_stub to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ipv6_skip_exthdr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ipv6_find_hdr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ipv6_chk_addr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __ipv6_addr_type to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iput to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ip_tos2prio to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ip_send_check to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ip_route_output_flow to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ip_queue_xmit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __ip_dev_find to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ip6_route_output_flags to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ip6_dst_hoplimit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iowrite32be to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iov_iter_kvec to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iov_iter_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iov_iter_advance to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iounmap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ioremap_wc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ioremap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ioread8 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ioread32be to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ioread16be to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol iomem_resource to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol invalidate_mapping_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol invalidate_inode_pages2_range to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol invalidate_bdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol int_to_scsilun to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol int_pow to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __insert_inode_hash to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol inode_permission to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol inode_init_always to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol init_wait_var_entry to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __init_waitqueue_head to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol init_wait_entry to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol init_uts_ns to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol init_user_ns to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol init_timer_key to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol init_task to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __init_swait_queue_head to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol init_special_inode to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __init_rwsem to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol init_net to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol in_group_p to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol inet_del_protocol to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol inet_add_protocol to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol in_dev_finish_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol in_aton to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol in6_pton to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol in4_pton to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol import_iovec to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ilookup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol igrab to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol idr_remove to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol idr_preload to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol idr_get_next_ul to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol idr_find to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol idr_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol idr_alloc_u32 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol idr_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ida_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ida_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ida_alloc_range to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_unregister_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_umem_release to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_umem_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_umem_find_best_pgsz to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_umem_dmabuf_get_pinned to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_sg_to_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_set_device_ops to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_resize_cq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_register_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_query_port to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_modify_qp_is_ok to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_get_eth_speed to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_dispatch_event to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ibdev_warn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ibdev_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_device_set_netdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_device_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_device_get_by_netdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ibdev_err to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol I_BDEV to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_destroy_cq_user to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_dereg_mr_user to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_dealloc_pd_user to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ib_dealloc_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __ib_create_cq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __ib_alloc_pd to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _ib_alloc_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hyperv_write_cfg_blk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hyperv_reg_block_invalidate to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hyperv_read_cfg_blk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hwmon_device_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hwmon_device_register_with_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hwmon_device_register_with_groups to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __hw_addr_unsync_dev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __hw_addr_sync_dev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __hw_addr_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hugetlb_optimize_vmemmap_key to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hrtimer_start_range_ns to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hrtimer_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hrtimer_forward to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hrtimer_cancel to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol hex_dump_to_buffer to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol groups_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol groups_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol gnss_register_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol gnss_put_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol gnss_insert_raw to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol gnss_deregister_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol gnss_allocate_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol get_zeroed_page to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol get_user_pages_remote to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol get_user_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __get_user_nocheck_1 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __get_user_2 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __get_user_1 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol get_unused_fd_flags to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol get_random_bytes to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol get_fs_type to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __get_free_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol get_device_system_crosststamp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol get_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_write_end to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_write_checks to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_shutdown_super to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_setlease to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_read_dir to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_pipe_buf_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_permission to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_fillattr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_file_write_iter to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __generic_file_write_iter to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_file_splice_read to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_file_read_iter to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_file_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_file_llseek to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_error_remove_page to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol generic_delete_inode to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol gcd to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol fs_bio_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol freezing_slow_path to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol freeze_bdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol free_percpu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol free_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __free_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol free_netdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol free_irq_cpu_rmap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol free_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol free_fib_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol free_cpumask_var to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol fput to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol fortify_panic to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol forget_all_cached_acls to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol follow_up to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol folio_wait_bit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __folio_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __folio_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __folio_cancel_dirty to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __flush_workqueue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flush_work to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flush_signals to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_vlan to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_pppoe to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_ports to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_ipv6_addrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_ipv4_addrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_ip to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_eth_addrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_enc_ports to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_enc_keyid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_enc_ipv6_addrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_enc_ipv4_addrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_enc_ip to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_enc_control to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_cvlan to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_control to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_rule_match_basic to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_keys_dissector to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_indr_dev_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_indr_dev_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_indr_block_cb_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_block_cb_setup_simple to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_block_cb_lookup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_block_cb_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol flow_block_cb_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol firmware_request_nowarn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol finish_wait to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol finish_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol finish_no_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol find_vma to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol find_pid_ns to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _find_next_zero_bit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _find_next_bit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _find_next_andnot_bit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _find_next_and_bit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _find_last_bit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol find_get_pid to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol find_get_pages_range_tag to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _find_first_zero_bit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _find_first_bit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol filp_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol filp_close to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol file_write_and_wait_range to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol file_ns_capable to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol filemap_write_and_wait_range to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol filemap_fault to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol file_bdev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol fget to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __fentry__ to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol fd_install to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol event_triggers_call to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol eth_validate_addr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol eth_type_trans to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ethtool_sprintf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ethtool_op_get_ts_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ethtool_op_get_link to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ethtool_intersect_link_masks to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ethtool_convert_link_mode_to_legacy_u32 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ethtool_convert_legacy_u32_to_link_mode to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol eth_platform_get_mac_address to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol eth_get_headlen to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol ether_setup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol end_page_writeback to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol enable_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol empty_zero_page to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol emergency_restart to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol elfcorehdr_addr to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol efi to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __dynamic_pr_debug to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __dynamic_netdev_dbg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __dynamic_ibdev_dbg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __dynamic_dev_dbg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dump_stack to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dst_release to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_set_d_op to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol drop_super to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol driver_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol driver_remove_file to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol driver_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol driver_for_each_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol driver_create_file to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_rehash to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dql_reset to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dql_completed to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dput to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_prune_aliases to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_pin_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_pin_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_pin_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_pin_on_pin_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_pin_on_pin_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_pin_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_pin_change_ntf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_netdev_pin_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_netdev_pin_clear to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_device_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_device_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_device_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_device_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dpll_device_change_ntf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_path to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol down_write_trylock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol down_write to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol down_trylock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol down_read_trylock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol down_read to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol down_interruptible to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol downgrade_write to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol down to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol do_trace_netlink_extack to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol done_path_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_obtain_alias to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_move to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dmi_get_system_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dmi_find_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_unmap_page_attrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_set_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_set_coherent_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_pool_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_pool_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_pool_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_pool_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dmam_free_coherent to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_map_page_attrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dmam_alloc_attrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_make_root to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_free_attrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dma_alloc_attrs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol disable_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_invalidate to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_instantiate to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_hash_and_lookup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dget_parent to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_find_alias to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _dev_warn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_uc_del to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_uc_add_excl to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_uc_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_set_promiscuity to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_set_name to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_set_mtu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_set_mac_address to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_remove_pack to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __dev_queue_xmit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_printk_emit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devm_request_threaded_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devm_kmemdup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devm_kmalloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devm_kfree to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devm_kasprintf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devm_hwmon_device_register_with_groups to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devm_free_irq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_mc_del_global to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_mc_del to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_mc_add_global to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_mc_add_excl to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_mc_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devmap_managed_key to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __devm_add_action to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_unlock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_traps_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_traps_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_trap_groups_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_trap_groups_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_resources_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_resource_size_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_resource_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_rate_nodes_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_rate_node_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_rate_leaf_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_rate_leaf_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_port_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_port_health_reporter_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_params_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_params_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_param_driverinit_value_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_param_driverinit_value_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_trap_report to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_to_dev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_resources_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_resource_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_resource_occ_get_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_resource_occ_get_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_remote_reload_actions_performed to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_region_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_region_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_priv to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_port_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_port_type_clear to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_port_register_with_ops to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_port_health_reporter_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_port_attrs_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_port_attrs_pci_vf_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_port_attrs_pci_sf_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_port_attrs_pci_pf_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_params_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_params_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_net to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_info_version_stored_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_info_version_running_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_info_version_fixed_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_info_serial_number_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_health_reporter_state_update to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_health_reporter_priv to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_health_reporter_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_health_reporter_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_health_report to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_u8_pair_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_u64_pair_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_u32_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_u32_pair_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_string_pair_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_pair_nest_start to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_pair_nest_end to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_obj_nest_start to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_obj_nest_end to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_bool_pair_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_binary_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_binary_pair_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_binary_pair_nest_start to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_binary_pair_nest_end to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_arr_pair_nest_start to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_fmsg_arr_pair_nest_end to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_flash_update_timeout_notify to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_flash_update_status_notify to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devlink_alloc_ns to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_health_reporter_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_health_reporter_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol devl_assert_locked to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_kfree_skb_irq_reason to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_kfree_skb_any_reason to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _dev_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol device_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol device_set_wakeup_enable to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol device_remove_file to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol device_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol device_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol device_del to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol device_create_file to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol device_create to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol device_add_disk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_get_stats to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_get_iflink to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_get_by_name to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_get_by_index_rcu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_get_by_index to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _dev_err to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_driver_string to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _dev_crit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_close to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_change_flags to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_base_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_addr_del to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_addr_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dev_add_pack to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol destroy_workqueue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __destroy_inode to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dentry_open to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol del_gendisk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol delayed_work_timer_fn to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __delay to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol default_wake_function to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol default_llseek to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dec_zone_page_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_remove to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_lookup_and_remove to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_lookup to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_x32 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_u8 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_u64 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_u32 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_size_t to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_file_unsafe to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_file to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_dir to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_blob to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_create_atomic_t to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_attr_write to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol debugfs_attr_read to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol deactivate_super to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_drop to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __d_drop to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dcb_setapp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dcbnl_ieee_notify to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dcb_ieee_setapp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dcb_ieee_delapp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dcb_getapp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dca_unregister_notify to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dca_remove_requester to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dca_register_notify to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dca_add_requester to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol dca3_get_tag to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_alloc_anon to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol d_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol current_umask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol current_time to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _ctype to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol csum_partial to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol csum_ipv6_magic to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol crypto_shash_update to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol crypto_shash_final to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol crypto_destroy_tfm to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol crypto_alloc_shash to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol create_empty_buffers to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol crc32_le to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cpu_sibling_map to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __cpu_present_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __cpu_possible_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __cpu_online_mask to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cpu_number to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cpumask_local_spread to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cpu_khz to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cpu_info to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __cpuhp_setup_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __cpuhp_remove_state to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cpufreq_quick_get to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cpu_bit_bitmap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol copy_user_generic_unrolled to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol copy_user_generic_string to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol copy_user_enhanced_fast_string to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _copy_to_user to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _copy_to_iter to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __copy_overflow to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _copy_from_user to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _copy_from_iter to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol convert_art_ns_to_tsc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol consume_skb to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __const_udelay to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol config_group_init_type_name to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol config_group_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol configfs_unregister_subsystem to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol configfs_register_subsystem to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __cond_resched to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol complete_all to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol complete to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol commit_creds to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol clock_t_to_jiffies to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol clear_page_dirty_for_io to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol clear_nlink to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol clear_inode to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol class_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol class_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol class_destroy to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __check_object_size to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cdev_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cdev_del to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cdev_alloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cdev_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cc_mkdec to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol capable to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cancel_work_sync to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cancel_work to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cancel_delayed_work_sync to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cancel_delayed_work to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol call_usermodehelper to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol call_switchdev_notifiers to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol call_srcu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol call_rcu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol call_netdevice_notifiers to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol cachemode2protval to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bus_unregister_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bus_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bus_register_notifier to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bus_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bus_for_each_dev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bus_find_device to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol build_skb to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __break_lease to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_warn_invalid_xdp_action to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_trace_run7 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_trace_run5 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_trace_run4 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_trace_run3 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_trace_run2 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_trace_run1 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_stats_enabled_key to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_prog_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_prog_inc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_prog_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_master_redirect_enabled_key to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bpf_dispatcher_xdp_func to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol boot_cpu_data to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol block_write_full_page to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol block_write_begin to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blocking_notifier_chain_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blocking_notifier_chain_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blocking_notifier_call_chain to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blockdev_superblock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_status_to_errno to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_start_plug to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_stack_limits to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_set_queue_depth to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_rq_map_user_iov to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_rq_map_user to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __blk_rq_map_sg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_rq_map_kern to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_segment_boundary to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_physical_block_size to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_max_segments to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_max_hw_sectors to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_max_discard_sectors to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_logical_block_size to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_io_opt to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_io_min to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_flag_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_flag_clear to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_dma_alignment to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_queue_bounce_limit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_put_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_unfreeze_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_stop_hw_queues to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_start_request to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_run_hw_queues to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_run_hw_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_map_queues to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_init_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_init_allocated_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_freeze_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_free_tag_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_free_request to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_end_request to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __blk_mq_end_request to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_destroy_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_complete_request to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_alloc_tag_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_mq_alloc_request to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_integrity_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_finish_plug to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blk_execute_rq to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol blkdev_issue_flush to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __blk_alloc_disk to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bitmap_zalloc_node to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bitmap_zalloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_xor to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_weight to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_subset to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_set to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bitmap_release_region to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bitmap_print_to_pagebuf to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bitmap_parselist to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_or to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_intersects to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bitmap_from_arr32 to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bitmap_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bitmap_find_next_zero_area_off to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bitmap_find_free_region to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_equal to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_clear to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_andnot to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __bitmap_and to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bioset_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bioset_exit to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_put to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_kmalloc to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_integrity_prep to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_endio to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_clone_blkg_association to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_associate_blkg to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_alloc_clone to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_alloc_bioset to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bio_add_page to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bin2hex to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bdev_file_open_by_path to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol bdev_file_open_by_dev to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol balance_dirty_pages_ratelimited to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol avenrun to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol auxiliary_driver_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __auxiliary_driver_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol auxiliary_device_init to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __auxiliary_device_add to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol autoremove_wake_function to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol atomic_notifier_chain_unregister to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol atomic_notifier_chain_register to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol atomic_notifier_call_chain to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol _atomic_dec_and_lock to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol async_synchronize_full_domain to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol async_synchronize_full to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol async_schedule_node to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol arp_tbl to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol argv_split to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol argv_free to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol arch_touch_nmi_watchdog to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol alloc_workqueue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __alloc_skb to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __alloc_percpu_gfp to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __alloc_percpu to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol alloc_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol __alloc_pages to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol alloc_netdev_mqs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol alloc_etherdev_mqs to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol alloc_cpu_rmap to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol alloc_chrdev_region to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol add_wait_queue_exclusive to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol add_wait_queue to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol add_timer to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol acpi_get_table to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol acpi_disabled to stablelist (Čestmír Kalina) [RHEL-56065]
- kabi: add symbol abort_creds to stablelist (Čestmír Kalina) [RHEL-56065]
- ice: fix VSI lists confusion when adding VLANs (Michal Schmidt) [RHEL-20571]
- ice: fix accounting for filters shared by multiple VSIs (Michal Schmidt) [RHEL-20571]
- nvme-multipath: fix io accounting on failover (John Meneghini) [RHEL-56635]
- nvme: fix multipath batched completion accounting (John Meneghini) [RHEL-56635]
- netfilter: tproxy: bail out if IP has been disabled on the device (Phil Sutter) [RHEL-44369] {CVE-2024-36270}
- mm: list_lru: fix UAF for memory cgroup (Rafael Aquini) [RHEL-56160] {CVE-2024-43888}
- platform/x86: dell-smbios-wmi: Avoid false-positive memcpy() warning (David Arcari) [RHEL-56614]
- arm64: properly install vmlinuz.efi (Lenny Szubowicz) [RHEL-46772]
- buildtar: fix tarballs with EFI_ZBOOT enabled (Lenny Szubowicz) [RHEL-46772]
- wifi: iwlwifi: mvm: fix a crash on 7265 (Jose Ignacio Tornos Martinez) [RHEL-57681]
- wifi: iwlwifi: mvm: support iwl_dev_tx_power_cmd_v8 (Jose Ignacio Tornos Martinez) [RHEL-57681]
- kobject_uevent: Fix OOB access within zap_modalias_env() (CKI Backport Bot) [RHEL-55005] {CVE-2024-42292}

* Thu Sep 26 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-513.el9]
- mei: me: disable RPL-S on SPS and IGN firmwares (CKI Backport Bot) [RHEL-33327]
- powerpc/ptrace: Add thread.regs checks to all ptrace hooks (Mamatha Inamdar) [RHEL-28702]
- cpu/SMT: Enable SMT only if a core is online (Mamatha Inamdar) [RHEL-37146]
- powerpc/topology: Check if a core is online (Mamatha Inamdar) [RHEL-37146]
- gpio: Use device_get_match_data() (Joel Slebodnick) [RHEL-57710]
- gpio: davinci: Remove redundant dev_err_probe() (Joel Slebodnick) [RHEL-57710]
- gpio: davinci: make davinci_gpio_dev_pm_ops static (Joel Slebodnick) [RHEL-57710]
- gpio: davinci: correct non-kerneldoc comment (Joel Slebodnick) [RHEL-57710]
- gpio: davinci: Add irq chip flag to skip set wake (Joel Slebodnick) [RHEL-57710]
- gpio: davinci: Do not clear the bank intr enable bit in save_context (Joel Slebodnick) [RHEL-57710]
- gpio: davinci: Remove duplicate assignment of of_gpio_n_cells (Joel Slebodnick) [RHEL-57710]
- gpio: davinci: Do not mention legacy API in the code (Joel Slebodnick) [RHEL-57710]
- gpio: davinci: add support of module build (Joel Slebodnick) [RHEL-57710]
- gpio: davinci: Add support for system suspend/resume PM (Joel Slebodnick) [RHEL-57710]
- PCI: pciehp: Detect device replacement during system sleep (Myron Stowe) [RHEL-58895]
- cleanup: Standardize the header guard define's name (Myron Stowe) [RHEL-58895]
- nfsd: ensure that nfsd4_fattr_args.context is zeroed out (CKI Backport Bot) [RHEL-58883] {CVE-2024-46697}
- intel_idle: Disable promotion to C1E on Jasper Lake and Elkhart Lake (David Arcari) [RHEL-15564]
- intel_idle: add Granite Rapids Xeon support (David Arcari) [RHEL-15564]
- intel_idle: Switch to new Intel CPU model defines (David Arcari) [RHEL-15564]
- net/sched: adjust device watchdog timer to detect stopped queue at right time (Ivan Vecera) [RHEL-57767]
- net_sched: sch_sfq: annotate data-races around q->perturb_period (Ivan Vecera) [RHEL-57767]
- net_sched: sch_skbprio: implement lockless skbprio_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_pie: implement lockless pie_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_hhf: implement lockless hhf_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_hfsc: implement lockless accesses to q->defcls (Ivan Vecera) [RHEL-57767]
- net_sched: sch_fq_pie: implement lockless fq_pie_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_fq_codel: implement lockless fq_codel_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_fifo: implement lockless __fifo_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_ets: implement lockless ets_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_tfs: implement lockless etf_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_codel: implement lockless codel_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_choke: implement lockless choke_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_cbs: implement lockless cbs_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: cake: implement lockless cake_dump() (Ivan Vecera) [RHEL-57767]
- net_sched: sch_fq: implement lockless fq_dump() (Ivan Vecera) [RHEL-57767]
- flow_offload: add control flag checking helpers (Ivan Vecera) [RHEL-57767]
- flow_offload: fix flow_offload_has_one_action() kdoc (Ivan Vecera) [RHEL-57767]
- net: sched: cls_api: fix slab-use-after-free in fl_dump_key (Ivan Vecera) [RHEL-57767]
- net: sched: cake: Optimize the number of function calls and branches in heap construction (Ivan Vecera) [RHEL-57767]
- net/sched: act_skbmod: prevent kernel-infoleak (Ivan Vecera) [RHEL-57767]
- net: sched: make skip_sw actually skip software (Ivan Vecera) [RHEL-57767]
- net: sched: cls_api: add filter counter (Ivan Vecera) [RHEL-57767]
- net: sched: cls_api: add skip_sw counter (Ivan Vecera) [RHEL-57767]
- net/sched: Add module alias for sch_fq_pie (Ivan Vecera) [RHEL-57767]
- selftests: forwarding: Make tc-police pass on debug kernels (Ivan Vecera) [RHEL-57767]
- selftests/tc-testing: require an up to date iproute2 for blockcast tests (Ivan Vecera) [RHEL-57767]
- net: sched: Annotate struct tc_pedit with __counted_by (Ivan Vecera) [RHEL-57767]
- selftests: tc-testing: add mirred to block tdc tests (Ivan Vecera) [RHEL-57767]
- net/sched: Remove alias of sch_clsact (Ivan Vecera) [RHEL-57767]
- net/sched: Load modules via their alias (Ivan Vecera) [RHEL-57767]
- net/sched: Add module aliases for cls_,sch_,act_ modules (Ivan Vecera) [RHEL-57767]
- net/sched: Add helper macros with module names (Ivan Vecera) [RHEL-57767]
- taprio: validate TCA_TAPRIO_ATTR_FLAGS through policy instead of open-coding (Ivan Vecera) [RHEL-57767]
- selftests: tc-testing: return fail if a test fails in setup/teardown (Ivan Vecera) [RHEL-57767]
- selftests: tc-testing: enable all tdc tests (Ivan Vecera) [RHEL-57767]
- selftests: tc-testing: adjust fq test to latest iproute2 (Ivan Vecera) [RHEL-57767]
- selftests: tc-testing: check if 'jq' is available in taprio tests (Ivan Vecera) [RHEL-57767]
- selftests: tc-testing: add missing netfilter config (Ivan Vecera) [RHEL-57767]
- flow_offload: Annotate struct flow_action_entry with __counted_by (Ivan Vecera) [RHEL-57767]
- net: skbuff: hide csum_not_inet when CONFIG_IP_SCTP not set (Ivan Vecera) [RHEL-57767]
- sysctl: always initialize i_uid/i_gid (Pavel Reichl) [RHEL-54943] {CVE-2024-42312}
- exfat: fix potential deadlock on __exfat_get_dentry_set (Pavel Reichl) [RHEL-54936] {CVE-2024-42315}
- fs: prevent out-of-bounds array speculation when closing a file descriptor (Pavel Reichl) [RHEL-55126] {CVE-2024-42265}
- protect the fetch of ->fd[fd] in do_dup2() from mispredictions (Pavel Reichl) [RHEL-55126] {CVE-2024-42265}
- PCI: keystone: Fix NULL pointer dereference in case of DT error in ks_pcie_setup_rc_app_regs() (Myron Stowe) [RHEL-54858] {CVE-2024-43823}
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/ipl: add missing IPL_TYPE_ECKD_DUMP case to ipl_init() (Thomas Huth) [RHEL-54248]
- s390/pci: fix three typos in comments (Thomas Huth) [RHEL-54248]
- s390/scm: fix virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390: remove odd comment (Thomas Huth) [RHEL-54248]
- s390/dasd: resolve spelling mistake (Thomas Huth) [RHEL-54248]
- s390/cmma: move set_page_stable() and friends to header file (Thomas Huth) [RHEL-54248]
- s390/cmma: move parsing of cmma kernel parameter to early boot code (Thomas Huth) [RHEL-54248]
- s390/cmma: cleanup inline assemblies (Thomas Huth) [RHEL-54248]
- s390/cio: replace deprecated strncpy with strscpy (Thomas Huth) [RHEL-54248]
- s390/sclp: replace deprecated strncpy with strtomem (Thomas Huth) [RHEL-54248]
- s390/cio: fix virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/cio: export CMG value as decimal (Thomas Huth) [RHEL-54248]
- s390: delete the unused store_prefix() function (Thomas Huth) [RHEL-54248]
- s390/sclp: handle default case in sclp memory notifier (Thomas Huth) [RHEL-54248]
- s390/diag: add missing virt_to_phys() translation to diag224() (Thomas Huth) [RHEL-54248]
- s390/mm,fault: remove VM_FAULT_BADCONTEXT (Thomas Huth) [RHEL-54248]
- s390/mm,fault: simplify kfence fault handling (Thomas Huth) [RHEL-54248]
- s390/mm,fault: call do_fault_error() only from do_exception() (Thomas Huth) [RHEL-54248]
- s390/mm,fault: get rid of do_low_address() (Thomas Huth) [RHEL-54248]
- s390/mm,fault: remove VM_FAULT_PFAULT (Thomas Huth) [RHEL-54248]
- s390/mm,fault: use get_kernel_nofault() to dereference in dump_pagetable() (Thomas Huth) [RHEL-54248]
- s390/mm,fault: improve readability by using teid union (Thomas Huth) [RHEL-54248]
- s390/mm,fault: use static key for store indication (Thomas Huth) [RHEL-54248]
- s390/mm,fault: use get_fault_address() everywhere (Thomas Huth) [RHEL-54248]
- s390/mm,fault: replace WARN_ON_ONCE() with unreachable() (Thomas Huth) [RHEL-54248]
- s390/mm,fault: remove noinline attribute from all functions (Thomas Huth) [RHEL-54248]
- s390/mm,fault: remove line break (Thomas Huth) [RHEL-54248]
- s390/mm,fault: include linux/mmu_context.h (Thomas Huth) [RHEL-54248]
- s390/mm,fault: have balanced braces, remove unnecessary blanks (Thomas Huth) [RHEL-54248]
- s390/mm,fault: use pr_warn(), pr_cont(), ... instead of open-coding (Thomas Huth) [RHEL-54248]
- s390/mm,fault: use pr_warn_ratelimited() (Thomas Huth) [RHEL-54248]
- s390/mm,fault: use __ratelimit() instead of printk_ratelimit() (Thomas Huth) [RHEL-54248]
- s390/mm,fault: reverse x-mas tree coding style (Thomas Huth) [RHEL-54248]
- s390/mm,fault: remove and improve comments, adjust whitespace (Thomas Huth) [RHEL-54248]
- s390/mm: make vmemmap_free() only for CONFIG_MEMORY_HOTPLUG available (Thomas Huth) [RHEL-54248]
- s390/vmem: remove unused variable (Thomas Huth) [RHEL-54248]
- s390: add support for DCACHE_WORD_ACCESS (Thomas Huth) [RHEL-54248]
- s390: provide word-at-a-time implementation (Thomas Huth) [RHEL-54248]
- s390/extable: reduce number of extable macros (Thomas Huth) [RHEL-54248]
- s390/crash: remove unused parameter (Thomas Huth) [RHEL-54248]
- s390/kasan: handle DCSS mapping in memory holes (Thomas Huth) [RHEL-54248]
- s390/cio: fix a memleak in css_alloc_subchannel (Thomas Huth) [RHEL-54248]
- s390: use control register bit defines (Thomas Huth) [RHEL-54248]
- s390/ctlreg: add control register bits (Thomas Huth) [RHEL-54248]
- s390/irq: use CR0 defines to define CR0_IRQ_SUBCLASS_MASK (Thomas Huth) [RHEL-54248]
- s390/ctlreg: add missing defines (Thomas Huth) [RHEL-54248]
- s390/setup: make use of system_ctl_load() (Thomas Huth) [RHEL-54248]
- s390/ctlreg: add system_ctl_load() (Thomas Huth) [RHEL-54248]
- s390/early: use system_ctl_set_bit() instead of local_ctl_set_bit() (Thomas Huth) [RHEL-54248]
- s390/ctlreg: allow to call system_ctl_set/clear_bit() early (Thomas Huth) [RHEL-54248]
- s390/ctltreg: make initialization of control register save area explicit (Thomas Huth) [RHEL-54248]
- s390/ctlreg: add struct ctlreg (Thomas Huth) [RHEL-54248]
- s390/ctlreg: add type checking to __local_ctl_load() and __local_ctl_store() (Thomas Huth) [RHEL-54248]
- s390/kprobes,ptrace: open code struct per_reg (Thomas Huth) [RHEL-54248]
- s390/ctlreg: change parameters of __local_ctl_load() and __local_ctl_store() (Thomas Huth) [RHEL-54248]
- s390/ctlreg: use local_ctl_load() and local_ctl_store() where possible (Thomas Huth) [RHEL-54248]
- s390/ctlreg: add local_ctl_load() and local_ctl_store() (Thomas Huth) [RHEL-54248]
- s390/ctlreg: add local and system prefix to some functions (Thomas Huth) [RHEL-54248]
- s390/ctlreg: cleanup inline assemblies (Thomas Huth) [RHEL-54248]
- s390/ctlreg: rename ctl_reg.h to ctlreg.h (Thomas Huth) [RHEL-54248]
- s390/ctlreg: move control register code to separate file (Thomas Huth) [RHEL-54248]
- s390/smp: keep the original lowcore for CPU 0 (Thomas Huth) [RHEL-54248]
- s390/smp: disallow CPU hotplug of CPU 0 (Thomas Huth) [RHEL-54248]
- s390/smp,mcck: fix early IPI handling (Thomas Huth) [RHEL-54248]
- s390/cert_store: fix string length handling (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/vmem: do not silently ignore mapping limit (Thomas Huth) [RHEL-54248]
- s390/mm: use __set_memory() variants where useful (Thomas Huth) [RHEL-54248]
- s390/set_memory: add __set_memory() variant (Thomas Huth) [RHEL-54248]
- s390/set_memory: generate all set_memory() functions (Thomas Huth) [RHEL-54248]
- s390/mm: improve description of mapping permissions of prefix pages (Thomas Huth) [RHEL-54248]
- s390/amode31: change type of __samode31, __eamode31, etc (Thomas Huth) [RHEL-54248]
- s390/mm: simplify kernel mapping setup (Thomas Huth) [RHEL-54248]
- s390/mm: fix MAX_DMA_ADDRESS physical vs virtual confusion (Thomas Huth) [RHEL-54248]
- s390/crash: fix virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/vmem: fix virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/dcssblk: fix lockdep warning (Thomas Huth) [RHEL-54248]
- s390/monreader: fix virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/pci: use builtin_misc_device macro to simplify the code (Thomas Huth) [RHEL-54248]
- s390/ipl: refactor deprecated strncpy (Thomas Huth) [RHEL-54248]
- s390/ipl: fix virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/ipl: add common ipl parameter attribute group (Thomas Huth) [RHEL-54248]
- s390/dcssblk: fix kernel crash with list_add corruption (Thomas Huth) [RHEL-54248]
- s390/boot: fix multi-line comments style (Thomas Huth) [RHEL-54248]
- s390/boot: account Real Memory Copy and Lowcore areas (Thomas Huth) [RHEL-54248]
- s390/mm: define Real Memory Copy size and mask macros (Thomas Huth) [RHEL-54248]
- s390/boot: cleanup number of page table levels setup (Thomas Huth) [RHEL-54248]
- s390: remove <asm/export.h> (Thomas Huth) [RHEL-54248]
- s390: replace #include <asm/export.h> with #include <linux/export.h> (Thomas Huth) [RHEL-54248]
- s390: remove unneeded #include <asm/export.h> (Thomas Huth) [RHEL-54248]
- s390/smp: ensure global control register contents are in sync (Thomas Huth) [RHEL-54248]
- s390/ptrace: add missing linux/const.h include (Thomas Huth) [RHEL-54248]
- s390/cert_store: select CRYPTO_LIB_SHA256 (Thomas Huth) [RHEL-54248]
- s390/cert_store: fix error return code in fill_cs_keyring() (Thomas Huth) [RHEL-54248]
- s390/defconfigs: set CONFIG_FUNCTION_GRAPH_RETVAL=y (Thomas Huth) [RHEL-54248]
- s390/ftrace: use la instead of aghik in return_to_handler() (Thomas Huth) [RHEL-54248]
- s390/tracing: pass struct ftrace_regs to ftrace_trace_function (Thomas Huth) [RHEL-54248]
- s390: raise minimum supported machine generation to z10 [partial] (Thomas Huth) [RHEL-54248]
- s390/ebcdic: fix typo in comment (Thomas Huth) [RHEL-54248]
- s390/diag: fix diagnose 8c description (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/vmem: split pages when debug pagealloc is enabled (Thomas Huth) [RHEL-54248]
- s390/dasd: use correct number of retries for ERP requests (Thomas Huth) [RHEL-54248]
- s390: use obj-y to descend into drivers/s390/ (Thomas Huth) [RHEL-54248]
- docs: move s390 under arch (Thomas Huth) [RHEL-54248]
- docs: create a top-level arch/ directory (Thomas Huth) [RHEL-54248]
- MAINTAINERS: remove outdated linux390 link (Thomas Huth) [RHEL-54248]
- s390/hypfs: stop using ENOSYS error code (Thomas Huth) [RHEL-54248]
- s390/mm: get rid of VMEM_MAX_PHYS macro (Thomas Huth) [RHEL-54248]
- s390/extmem: improve reporting of -ERANGE error (Thomas Huth) [RHEL-54248]
- s390/mm: rework arch_get_mappable_range() callback (Thomas Huth) [RHEL-54248]
- s390/mm: remove redundant check against VMEM_MAX_PHYS (Thomas Huth) [RHEL-54248]
- s390/dcssblk: fix virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/dcssblk: use IS_ALIGNED() for alignment checks (Thomas Huth) [RHEL-54248]
- s390/kexec: make machine_kexec() depend on CONFIG_KEXEC_CORE (Thomas Huth) [RHEL-54248]
- s390/ftrace: enable HAVE_FUNCTION_GRAPH_RETVAL (Thomas Huth) [RHEL-54248]
- redhat: Set CONFIG_S390_HYPFS in the kernel configs (Thomas Huth) [RHEL-54248]
- s390/hypfs: factor out filesystem code (Thomas Huth) [RHEL-54248]
- s390/hypfs: remove open-coded PTR_ALIGN() (Thomas Huth) [RHEL-54248]
- s390/hypfs: simplify memory allocation (Thomas Huth) [RHEL-54248]
- s390/sthyi: enforce 4k alignment of vmalloc'ed area (Thomas Huth) [RHEL-54248]
- s390/diag: handle diag 204 subcode 4 address correctly (Thomas Huth) [RHEL-54248]
- redhat: Disable CONFIG_CERT_STORE for the RHEL kernel (Thomas Huth) [RHEL-54248]
- s390: add support for user-defined certificates (Thomas Huth) [RHEL-54248]
- s390: convert to ctime accessor functions (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: remove check on CPU being online (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: handle casts consistently (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: remove unnecessary debug statement (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: remove parameter in call to pr_err (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: simplify function setup_pmu_cpu (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: remove unneeded debug statements (Thomas Huth) [RHEL-54248]
- s390/entry: remove mcck clock (Thomas Huth) [RHEL-54248]
- s390/entry: rework entering DAT-on mode on CPU restart (Thomas Huth) [RHEL-54248]
- s390/mm: fence off VM macros from asm and linker (Thomas Huth) [RHEL-54248]
- s390/ptrace: make all psw related defines also available for asm (Thomas Huth) [RHEL-54248]
- s390/ptrace: remove PSW_DEFAULT_KEY from uapi (Thomas Huth) [RHEL-54248]
- s390/vdso: filter out mno-pic-data-is-text-relative cflag (Thomas Huth) [RHEL-54248]
- s390: consistently use .balign instead of .align (Thomas Huth) [RHEL-54248]
- s390/decompressor: fix misaligned symbol build error (Thomas Huth) [RHEL-54248]
- s390/vdso: check for undefined symbols after build (Thomas Huth) [RHEL-54248]
- s390/mm: do not include <asm-generic/io.h> directly (Thomas Huth) [RHEL-54248]
- s390/vmem: fix virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/defconfigs: set CONFIG_NET_TC_SKB_EXT=y (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: rework PER_CPU_DEFINE of struct cpu_cf_events (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: open access to hwctr device for CAP_PERFMON privileged process (Thomas Huth) [RHEL-54248]
- s390/boot: fix physmem_info virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/kasan: avoid short by one page shadow memory (Thomas Huth) [RHEL-54248]
- s390/kasan: fix insecure W+X mapping warning (Thomas Huth) [RHEL-54248]
- s390/crash: use the correct type for memory allocation (Thomas Huth) [RHEL-54248]
- s390: gmap use pte_unmap_unlock() not spin_unlock() (Thomas Huth) [RHEL-54248]
- s390: allow pte_offset_map_lock() to fail (Thomas Huth) [RHEL-54248]
- s390/purgatory: Do not use fortified string functions (Thomas Huth) [RHEL-54248]
- s390/zcore: conditionally clear memory on reipl (Thomas Huth) [RHEL-54248]
- s390/ipl: add REIPL_CLEAR flag to os_info (Thomas Huth) [RHEL-54248]
- s390/purgatory: disable branch profiling (Thomas Huth) [RHEL-54248]
- s390/cio: unregister device when the only path is gone (Thomas Huth) [RHEL-54248]
- s390/Kconfig: remove obsolete configs SCHED_{BOOK,DRAWER} (Thomas Huth) [RHEL-54248]
- s390/uapi: cover statfs padding by growing f_spare (Thomas Huth) [RHEL-54248]
- s390/ipl: fix IPIB virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/topology: honour nr_cpu_ids when adding CPUs (Thomas Huth) [RHEL-54248]
- s390/cio: include subchannels without devices also for evaluation (Thomas Huth) [RHEL-54248]
- s390/defconfigs: set CONFIG_INIT_STACK_NONE=y (Thomas Huth) [RHEL-54248]
- s390: select ARCH_SUPPORTS_INT128 (Thomas Huth) [RHEL-54248]
- s390/pai_ext: replace atomic_t with refcount_t (Thomas Huth) [RHEL-54248]
- s390/pai_crypto: replace atomic_t with refcount_t (Thomas Huth) [RHEL-54248]
- s390/stackleak: provide fast __stackleak_poison() implementation (Thomas Huth) [RHEL-54248]
- s390: select ARCH_USE_SYM_ANNOTATIONS (Thomas Huth) [RHEL-54248]
- s390/mm: use VM_FLUSH_RESET_PERMS in module_alloc() (Thomas Huth) [RHEL-54248]
- tools headers UAPI: Sync s390 syscall table file that wires up the memfd_secret syscall (Thomas Huth) [RHEL-54248]
- s390: wire up memfd_secret system call (Thomas Huth) [RHEL-54248]
- s390/mm: enable ARCH_HAS_SET_DIRECT_MAP (Thomas Huth) [RHEL-54248]
- s390/mm: use BIT macro to generate SET_MEMORY bit masks (Thomas Huth) [RHEL-54248]
- s390/relocate_kernel: adjust indentation (Thomas Huth) [RHEL-54248]
- s390/mcount: use SYM* macros instead of ENTRY(), etc. (Thomas Huth) [RHEL-54248]
- s390/amode31: use SYM* macros instead of ENTRY(), etc. (Thomas Huth) [RHEL-54248]
- s390/kasan: remove override of mem*() functions (Thomas Huth) [RHEL-54248]
- s390/kdump: remove nodat stack restriction for calling nodat functions (Thomas Huth) [RHEL-54248]
- s390/kdump: rework invocation of DAT-off code (Thomas Huth) [RHEL-54248]
- s390/kdump: fix virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/kdump: cleanup do_start_kdump() prototype and usage (Thomas Huth) [RHEL-54248]
- s390/kexec: turn DAT mode off immediately before purgatory (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: remove function validate_ctr_auth() by inline code (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: provide counter number to validate_ctr_version() (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: introduce static CPU counter facility information (Thomas Huth) [RHEL-54248]
- s390/mm: fix direct map accounting (Thomas Huth) [RHEL-54248]
- s390/mm: rename POPULATE_ONE2ONE to POPULATE_DIRECT (Thomas Huth) [RHEL-54248]
- s390/boot: improve install.sh script (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: simplify pr_err() statement in cpumf_pmu_enable/disable (Thomas Huth) [RHEL-54248]
- s390/kaslr: randomize amode31 base address (Thomas Huth) [RHEL-54248]
- s390/kaslr: generalize and improve random base distribution (Thomas Huth) [RHEL-54248]
- s390/boot: pin amode31 default lma (Thomas Huth) [RHEL-54248]
- s390/boot: do not change default_lma (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: remove unnecessary copy_from_user call (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: log bad return code of function cfset_all_copy (Thomas Huth) [RHEL-54248]
- s390/module: create module allocations without exec permissions (Thomas Huth) [RHEL-54248]
- s390/ftrace: do not assume module_alloc() returns executable memory (Thomas Huth) [RHEL-54248]
- s390/mm: use set_memory_*() helpers instead of open coding (Thomas Huth) [RHEL-54248]
- s390/mm: implement set_memory_rwnx() (Thomas Huth) [RHEL-54248]
- s390/ipl: fix physical-virtual confusion for diag308 (Thomas Huth) [RHEL-54248]
- s390/kaslr: randomize module base load address (Thomas Huth) [RHEL-54248]
- s390/kaslr: provide kaslr_enabled() function (Thomas Huth) [RHEL-54248]
- s390/checksum: remove not needed uaccess.h include (Thomas Huth) [RHEL-54248]
- s390: move on_thread_stack() to processor.h (Thomas Huth) [RHEL-54248]
- s390: remove arch_early_irq_init() (Thomas Huth) [RHEL-54248]
- s390/stacktrace: remove call_on_stack_noreturn() (Thomas Huth) [RHEL-54248]
- s390: use init_thread_union aka initial stack for the first process (Thomas Huth) [RHEL-54248]
- s390: make extables read-only (Thomas Huth) [RHEL-54248]
- s390/uaccess: remove extra blank line (Thomas Huth) [RHEL-54248]
- s390/uaccess: get rid of not needed local variable (Thomas Huth) [RHEL-54248]
- s390/uaccess: rename tmp1 and tmp2 variables (Thomas Huth) [RHEL-54248]
- s390/uaccess: sort EX_TABLE list for inline assemblies (Thomas Huth) [RHEL-54248]
- s390/uaccess: rename/sort labels in inline assemblies (Thomas Huth) [RHEL-54248]
- s390/uaccess: remove unused label in inline assemblies (Thomas Huth) [RHEL-54248]
- s390/uaccess: use symbolic names for inline assembly operands (Thomas Huth) [RHEL-54248]
- s390/ptrace: fix PTRACE_GET_LAST_BREAK error handling (Thomas Huth) [RHEL-54248]
- s390: reintroduce expoline dependence to scripts (Thomas Huth) [RHEL-54248]
- s390: enable ARCH_HAS_MEMBARRIER_SYNC_CORE (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: remove flag PERF_CPUM_SF_FULL_BLOCKS (Thomas Huth) [RHEL-54248]
- s390/mm: make use of atomic_fetch_xor() (Thomas Huth) [RHEL-54248]
- s390/vdso: use __ALIGN instead of open coded .align (Thomas Huth) [RHEL-54248]
- s390/expoline: use __ALIGN instead of open coded .align (Thomas Huth) [RHEL-54248]
- s390/ftrace: move hotpatch trampolines to mcount.S (Thomas Huth) [RHEL-54248]
- s390/kasan: move shadow mapping to decompressor (Thomas Huth) [RHEL-54248]
- s390/mm,pageattr: allow KASAN shadow memory (Thomas Huth) [RHEL-54248]
- s390/boot: rework decompressor reserved tracking (Thomas Huth) [RHEL-54248]
- s390/boot: rename mem_detect to physmem_info (Thomas Huth) [RHEL-54248]
- s390/boot: remove non-functioning image bootable check (Thomas Huth) [RHEL-54248]
- s390/dumpstack: resolve userspace last_break (Thomas Huth) [RHEL-54248]
- s390: simplify dynamic sysctl registration for appldata_register_ops (Thomas Huth) [RHEL-54248]
- s390: simplify one-level sysctl registration for page_table_sysctl (Thomas Huth) [RHEL-54248]
- s390: simplify one level sysctl registration for cmm_table (Thomas Huth) [RHEL-54248]
- s390: simplify one-level sysctl registration for appldata_table (Thomas Huth) [RHEL-54248]
- s390: simplify one-level syctl registration for s390dbf_table (Thomas Huth) [RHEL-54248]
- s390: simplify one-level sysctl registration for topology_ctl_table (Thomas Huth) [RHEL-54248]
- s390/setup: always inline gen_lpswe() (Thomas Huth) [RHEL-54248]
- s390: trim ancient junk from copy_thread() (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/Kconfig: sort config S390 select list again (Thomas Huth) [RHEL-54248]
- s390/decompressor: add link map saving (Thomas Huth) [RHEL-54248]
- s390/smp: perform cpu reset before delegating work to target cpu (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: use READ_ONCE_ALIGNED_128() instead of 128-bit cmpxchg (Thomas Huth) [RHEL-54248]
- s390/rwonce: add READ_ONCE_ALIGNED_128() macro (Thomas Huth) [RHEL-54248]
- s390/setup: do not complain about parameters handled in decompressor (Thomas Huth) [RHEL-54248]
- s390/irq,idle: simplify idle check (Thomas Huth) [RHEL-54248]
- s390/processor: add test_and_set_cpu_flag() and test_and_clear_cpu_flag() (Thomas Huth) [RHEL-54248]
- s390/processor: let cpu helper functions return boolean values (Thomas Huth) [RHEL-54248]
- s390: remove confusing comment from uapi types header file (Thomas Huth) [RHEL-54248]
- s390/mem_detect: do not truncate online memory ranges info (Thomas Huth) [RHEL-54248]
- s390/mm: define private VM_FAULT_* reasons from top bits (Thomas Huth) [RHEL-54248]
- s390/idle: remove arch_cpu_idle_time() and corresponding code (Thomas Huth) [RHEL-54248]
- s390/processor: always inline cpu flag helper functions (Thomas Huth) [RHEL-54248]
- s390/idle: mark arch_cpu_idle() noinstr (Thomas Huth) [RHEL-54248]
- s390/idle: move idle time accounting to account_idle_time_irq() (Thomas Huth) [RHEL-54248]
- s390/dasd: Fix potential memleak in dasd_eckd_init() (Thomas Huth) [RHEL-54248]
- s390/dasd: sort out physical vs virtual pointers usage (Thomas Huth) [RHEL-54248]
- s390/cio: replace zero-length array with flexible-array member (Thomas Huth) [RHEL-54248]
- s390/sclp: replace zero-length array with flexible-array member (Thomas Huth) [RHEL-54248]
- s390/debug: replace zero-length array with flexible-array member (Thomas Huth) [RHEL-54248]
- s390/fcx: replace zero-length array with flexible-array member (Thomas Huth) [RHEL-54248]
- s390/diag: replace zero-length array with flexible-array member (Thomas Huth) [RHEL-54248]
- s390/boot: avoid potential amode31 truncation (Thomas Huth) [RHEL-54248]
- s390/boot: move detect_facilities() after cmd line parsing (Thomas Huth) [RHEL-54248]
- s390/kasan: avoid mapping KASAN shadow for standby memory (Thomas Huth) [RHEL-54248]
- s390/boot: avoid page tables memory in kaslr (Thomas Huth) [RHEL-54248]
- s390/mem_detect: add get_mem_detect_online_total() (Thomas Huth) [RHEL-54248]
- s390/mem_detect: handle online memory limit just once (Thomas Huth) [RHEL-54248]
- s390/boot: fix mem_detect extended area allocation (Thomas Huth) [RHEL-54248]
- s390/mem_detect: rely on diag260() if sclp_early_get_memsize() fails (Thomas Huth) [RHEL-54248]
- s390/diag: make __diag8c_tmp_amode31 static (Thomas Huth) [RHEL-54248]
- s390/rethook: add local rethook header file (Thomas Huth) [RHEL-54248]
- s390/vmem: remove unnecessary KASAN checks (Thomas Huth) [RHEL-54248]
- s390/vmem: fix empty page tables cleanup under KASAN (Thomas Huth) [RHEL-54248]
- s390/kasan: update kasan memory layout note (Thomas Huth) [RHEL-54248]
- s390/mem_detect: fix detect_memory() error handling (Thomas Huth) [RHEL-54248]
- s390/hmcdrv: use strscpy() instead of strlcpy() (Thomas Huth) [RHEL-54248]
- s390/cio: introduce locking for register/unregister functions (Thomas Huth) [RHEL-54248]
- s390/mm,ptdump: avoid Kasan vs Memcpy Real markers swapping (Thomas Huth) [RHEL-54248]
- s390/boot: remove pgtable_populate_end (Thomas Huth) [RHEL-54248]
- s390/boot: avoid mapping standby memory (Thomas Huth) [RHEL-54248]
- s390/decompressor: specify __decompress() buf len to avoid overflow (Thomas Huth) [RHEL-54248]
- s390/dcssblk:: don't call bio_split_to_limits (Thomas Huth) [RHEL-54248]
- s390/purgatory: Remove unused '-MD' and unnecessary '-c' flags (Thomas Huth) [RHEL-54248]
- s390/vdso: Drop '-shared' from KBUILD_CFLAGS_64 (Thomas Huth) [RHEL-54248]
- s390/vdso: Drop unused '-s' flag from KBUILD_AFLAGS_64 (Thomas Huth) [RHEL-54248]
- s390/syscalls: get rid of system call alias functions (Thomas Huth) [RHEL-54248]
- s390/syscalls: remove trailing semicolon (Thomas Huth) [RHEL-54248]
- s390/syscalls: move __S390_SYS_STUBx() macro (Thomas Huth) [RHEL-54248]
- s390/syscalls: remove __SC_COMPAT_TYPE define (Thomas Huth) [RHEL-54248]
- s390/syscalls: remove SYSCALL_METADATA() from compat syscalls (Thomas Huth) [RHEL-54248]
- s390: discard .interp section (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: simplify PMC_INIT and PMC_RELEASE usage (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: merge source files for CPU Measurement counter facility (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: remove in-kernel counting facility interface (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: move stccm_avail() (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: move cpum_cf_ctrset_size() (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: simplify hw_perf_event_destroy() (Thomas Huth) [RHEL-54248]
- s390/cache: change type from unsigned long long to unsigned long (Thomas Huth) [RHEL-54248]
- s390/kprobes: replace kretprobe with rethook (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: diagnostic sampling buffer setup to handle virtual addresses (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: rework macro AUX_SDB_NUM_xxx (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: sampling buffer setup to handle virtual addresses (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: remove debug statements from function setup_pmc_cpu (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: move functions from header file to source file (Thomas Huth) [RHEL-54248]
- s390/vmem: use swap() instead of open coding it (Thomas Huth) [RHEL-54248]
- s390/cio: evaluate devices with non-operational paths (Thomas Huth) [RHEL-54248]
- s390/ipl: use kstrtobool() instead of strtobool() (Thomas Huth) [RHEL-54248]
- s390: move __amode31_base declaration to proper header file (Thomas Huth) [RHEL-54248]
- s390/mm: allocate Absolute Lowcore Area in decompressor (Thomas Huth) [RHEL-54248]
- s390/mm: allocate Real Memory Copy Area in decompressor (Thomas Huth) [RHEL-54248]
- s390/boot: allow setup of different virtual address types (Thomas Huth) [RHEL-54248]
- s390/kasan: remove identity mapping support (Thomas Huth) [RHEL-54248]
- s390/maccess: remove dead DAT-off code (Thomas Huth) [RHEL-54248]
- s390/mm: start kernel with DAT enabled (Thomas Huth) [RHEL-54248]
- s390: always build relocatable kernel (Thomas Huth) [RHEL-54248]
- s390/boot: detect and enable memory facilities (Thomas Huth) [RHEL-54248]
- s390/pgtable: add REGION3_KERNEL_EXEC protection (Thomas Huth) [RHEL-54248]
- s390/kasan: use set_pXe_bit() for pgtable entries setup (Thomas Huth) [RHEL-54248]
- s390/kasan: cleanup setup of untracked memory pgtables (Thomas Huth) [RHEL-54248]
- s390/kasan: cleanup setup of zero pgtable (Thomas Huth) [RHEL-54248]
- s390/kasan: sort out physical vs virtual memory confusion (Thomas Huth) [RHEL-54248]
- s390/boot: cleanup decompressor header files (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/percpu: add READ_ONCE() to arch_this_cpu_to_op_simple() (Thomas Huth) [RHEL-54248]
- s390/cpum_sf: add READ_ONCE() semantics to compare and swap loops (Thomas Huth) [RHEL-54248]
- s390/diag: use __packed __aligned (Thomas Huth) [RHEL-54248]
- s390/fs3270: fix screen reset on activate (Thomas Huth) [RHEL-54248]
- s390/fs3270: fix function prototypes (Thomas Huth) [RHEL-54248]
- s390/fs3270: use *ptr instead of struct in kzalloc (Thomas Huth) [RHEL-54248]
- s390/fs3270: remove duplicate assignment (Thomas Huth) [RHEL-54248]
- s390/fs3270: add missing braces to if/else (Thomas Huth) [RHEL-54248]
- s390/fs3270: fix whitespace errors (Thomas Huth) [RHEL-54248]
- s390/raw3270: fix nullpointer check (Thomas Huth) [RHEL-54248]
- s390/raw3270: use DEVICE_ATTR_RO() for sysfs attributes (Thomas Huth) [RHEL-54248]
- s390/raw3270: add comment to spinlock member (Thomas Huth) [RHEL-54248]
- s390/raw3270: use __packed instead of __attribute__((packed)) (Thomas Huth) [RHEL-54248]
- s390/raw3270: fix formatting issues (Thomas Huth) [RHEL-54248]
- s390/tty3270: add support for diag 8c (Thomas Huth) [RHEL-54248]
- s390/tty3270: add tty3270_create_view() (Thomas Huth) [RHEL-54248]
- s390: remove the last remnants of cputime_t (Thomas Huth) [RHEL-54248]
- s390/cpumf: support user space events for counting (Thomas Huth) [RHEL-54248]
- s390: fix -Wundef warning for CONFIG_KERNEL_ZSTD (Thomas Huth) [RHEL-54248]
- s390: define RUNTIME_DISCARD_EXIT to fix link error with GNU ld < 2.36 (Thomas Huth) [RHEL-54248]
- s390: expicitly align _edata and _end symbols on page boundary (Thomas Huth) [RHEL-54248]
- s390/debug: add _ASM_S390_ prefix to header guard (Thomas Huth) [RHEL-54248]
- s390/cio: sort out physical vs virtual pointers usage (Thomas Huth) [RHEL-54248]
- s390/sclp: allow to change sclp_console_drop during runtime (Thomas Huth) [RHEL-54248]
- s390/sclp: convert to use sysfs_emit() (Thomas Huth) [RHEL-54248]
- s390/sclp: use kstrobool() to parse sclp_con_drop parameter (Thomas Huth) [RHEL-54248]
- [s390] zcore: WRITE is "data source", not destination... (Thomas Huth) [RHEL-54248]
- s390/crashdump: fix TOD programmable field size (Thomas Huth) [RHEL-54248]
- s390/dasd: fix possible buffer overflow in copy_pair_show (Thomas Huth) [RHEL-54248]
- s390/dasd: increase printing of debug data payload (Thomas Huth) [RHEL-54248]
- s390/dasd: Fix spelling mistake "Ivalid" -> "Invalid" (Thomas Huth) [RHEL-54248]
- s390/3270: make raw3270_state_final() depend on CONFIG_TN3270_CONSOLE (Thomas Huth) [RHEL-54248]
- s390: select ARCH_WANT_HUGETLB_PAGE_OPTIMIZE_VMEMMAP (Thomas Huth) [RHEL-54248]
- s390/debug: remove function type cast (Thomas Huth) [RHEL-54248]
- s390/pci: Use irq_data_get_msi_desc() (Thomas Huth) [RHEL-54248]
- s390/ipl: Use kstrtobool() instead of strtobool() (Thomas Huth) [RHEL-54248]
- s390: use generic vga.h header file (Thomas Huth) [RHEL-54248]
- s390: use generic shmparam.h header file (Thomas Huth) [RHEL-54248]
- s390: use generic bugs.h header file (Thomas Huth) [RHEL-54248]
- s390: use generic serial.h header file (Thomas Huth) [RHEL-54248]
- s390/configs: add kasan.config addon config file (Thomas Huth) [RHEL-54248]
- s390/configs: move CONFIG_DEBUG_INFO_BTF into btf.config addon config (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/cio: fix out-of-bounds access on cio_ignore free (Thomas Huth) [RHEL-54248]
- s390/pai: rename structure member users to active_events (Thomas Huth) [RHEL-54248]
- s390/pai: rework pai_crypto mapped buffer reference count (Thomas Huth) [RHEL-54248]
- s390/pai: move enum definition to header file (Thomas Huth) [RHEL-54248]
- s390/con3215: Fix white space errors (Thomas Huth) [RHEL-54248]
- s390/con3215: Drop console data printout when buffer full (Thomas Huth) [RHEL-54248]
- s390/con3215: Simplify console write operation (Thomas Huth) [RHEL-54248]
- s390/vmur: generate uevent on unsolicited device end (Thomas Huth) [RHEL-54248]
- s390/vmur: remove unnecessary BUG statement (Thomas Huth) [RHEL-54248]
- s390/dasd: use blk_mq_alloc_disk (Thomas Huth) [RHEL-54248]
- s390/pci: remove unused bus_next field from struct zpci_dev (Thomas Huth) [RHEL-54248]
- s390/cio: remove unused ccw_device_force_console() declaration (Thomas Huth) [RHEL-54248]
- s390/qeth: Split memcpy() of struct qeth_ipacmd_addr_change flexible array (Thomas Huth) [RHEL-54248]
- s390/mm,ptdump: add real memory copy page markers (Thomas Huth) [RHEL-54248]
- s390/smp,ptdump: add absolute lowcore markers (Thomas Huth) [RHEL-54248]
- s390/delay: sync comment within __delay() with reality (Thomas Huth) [RHEL-54248]
- s390: move from strlcpy with unused retval to strscpy (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390: fix nospec table alignments (Thomas Huth) [RHEL-54248]
- s390/hypfs: avoid error message under KVM (Thomas Huth) [RHEL-54248]
- s390/tape: fix comment typo (Thomas Huth) [RHEL-54248]
- s390/hmcdrv: fix Kconfig "its" grammar (Thomas Huth) [RHEL-54248]
- s390/uvdevice: autoload module based on CPU facility (Thomas Huth) [RHEL-54248]
- s390/cpufeature: allow for facility bits (Thomas Huth) [RHEL-54248]
- kexec, KEYS, s390: Make use of built-in and secondary keyring for signature verification (Thomas Huth) [RHEL-54248]
- s390/nospec: remove unneeded header includes (Thomas Huth) [RHEL-54248]
- s390/sclp: Fix typo in comments (Thomas Huth) [RHEL-54248]
- s390/purgatory: remove duplicated build rule of kexec-purgatory.o (Thomas Huth) [RHEL-54248]
- s390/purgatory: hard-code obj-y in Makefile (Thomas Huth) [RHEL-54248]
- s390: remove unneeded 'select BUILD_BIN2C' (Thomas Huth) [RHEL-54248]
- s390/cpumf: Handle events cycles and instructions identical (Thomas Huth) [RHEL-54248]
- s390/uaccess: whitespace cleanup (Thomas Huth) [RHEL-54248]
- s390/uaccess: use __noreturn instead of __attribute__((noreturn)) (Thomas Huth) [RHEL-54248]
- s390/kexec: add __GFP_NORETRY to KEXEC_CONTROL_MEMORY_GFP (Thomas Huth) [RHEL-54248]
- s390/Kconfig.debug: fix indentation (Thomas Huth) [RHEL-54248]
- redhat: Add CONFIG_KCSAN config file (Thomas Huth) [RHEL-54248]
- s390: define get_cycles macro for arch-override (Thomas Huth) [RHEL-54248]
- s390/preempt: disable __preempt_count_add() optimization for PROFILE_ALL_BRANCHES (Thomas Huth) [RHEL-54248]
- s390/stp: clock_delta should be signed (Thomas Huth) [RHEL-54248]
- s390/stp: fix todoff size (Thomas Huth) [RHEL-54248]
- s390/consoles: improve panic notifiers reliability (Thomas Huth) [RHEL-54248]
- s390/dasd: Use kzalloc instead of kmalloc/memset (Thomas Huth) [RHEL-54248]
- s390/irq: utilize RCU instead of irq_lock_sparse() in show_msi_interrupt() (Thomas Huth) [RHEL-54248]
- s390: add KCSAN instrumentation to barriers and spinlocks (Thomas Huth) [RHEL-54248]
- redhat: Add CONFIG_S390_*_SANITY_TEST config files (Thomas Huth) [RHEL-54248]
- redhat: Add CONFIG_MARCH_Z16 and CONFIG_TUNE_Z16 config files (Thomas Huth) [RHEL-54248]
- s390/cio: simplify the calculation of variables (Thomas Huth) [RHEL-54248]
- s390/smp: sort out physical vs virtual CPU0 lowcore pointer (Thomas Huth) [RHEL-54248]
- s390/kexec: set end-of-ipl flag in last diag308 call (Thomas Huth) [RHEL-54248]
- s390/cio: Use driver_set_override() instead of open-coding (Thomas Huth) [RHEL-54248]
- s390: enable CONFIG_HARDENED_USERCOPY in debug_defconfig (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/kexec: silence -Warray-bounds warning (Thomas Huth) [RHEL-54248]
- s390: allow to compile with z16 optimizations (Thomas Huth) [RHEL-54248]
- s390: cleanup timer API use (Thomas Huth) [RHEL-54248]
- s390/test_unwind: verify __kretprobe_trampoline is replaced (Thomas Huth) [RHEL-54248]
- s390/unwind: avoid duplicated unwinding entries for kretprobes (Thomas Huth) [RHEL-54248]
- s390/kprobes: enable kretprobes framepointer verification (Thomas Huth) [RHEL-54248]
- s390/tape: use bitwise instead of arithmetic operator for flags (Thomas Huth) [RHEL-54248]
- s390/kprobes: Avoid additional kprobe in kretprobe handling (Thomas Huth) [RHEL-54248]
- s390/hypfs: fix typos in comments (Thomas Huth) [RHEL-54248]
- s390/dasd: drop unexpected word 'for' in comments (Thomas Huth) [RHEL-54248]
- s390: fix typo in syscall_wrapper.h (Thomas Huth) [RHEL-54248]
- s390/ctcm: fix typo "length to short" -> "length too short" (Thomas Huth) [RHEL-54248]
- s390/ftrace: verify opcode before applying patch (Thomas Huth) [RHEL-54248]
- s390/irq: use assignment instead of cast (Thomas Huth) [RHEL-54248]
- s390/traps: get rid of magic cast for per code (Thomas Huth) [RHEL-54248]
- s390/traps: get rid of magic cast for program interruption code (Thomas Huth) [RHEL-54248]
- s390/signal: fix typo in comments (Thomas Huth) [RHEL-54248]
- s390/asm-offsets: remove unused defines (Thomas Huth) [RHEL-54248]
- s390/test_unwind: avoid build warning with W=1 (Thomas Huth) [RHEL-54248]
- s390/extable: sort amode31 extable early (Thomas Huth) [RHEL-54248]
- s390/ftrace: make use of epsw to get psw mask (Thomas Huth) [RHEL-54248]
- s390/smp: sort out physical vs virtual pointers usage (Thomas Huth) [RHEL-54248]
- s390/test_unwind: add "backtrace" module parameter (Thomas Huth) [RHEL-54248]
- s390/qeth: Remove redundant 'flush_workqueue()' calls (Thomas Huth) [RHEL-54248]
- s390/lgr: use simple assignment instead of memcpy (Thomas Huth) [RHEL-54248]
- s390/sclp_sdias: fix sclp_sdias_copy() virtual vs physical address confusion (Thomas Huth) [RHEL-54248]
- s390/module: fix building test_modules_helpers.o with clang (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/module: test loading modules with a lot of relocations (Thomas Huth) [RHEL-54248]
- s390/dasd: use default_groups in kobj_type (Thomas Huth) [RHEL-54248]
- s390/sclp_sd: use default_groups in kobj_type (Thomas Huth) [RHEL-54248]
- s390: remove unused TASK_SIZE_OF (Thomas Huth) [RHEL-54248]
- s390/disassembler: update opcode table (Thomas Huth) [RHEL-54248]
- s390/sclp: fix memblock_phys_free() vs memblock_free() confusion (Thomas Huth) [RHEL-54248]
- s390/entry: fix duplicate tracking of irq nesting level (Thomas Huth) [RHEL-54248]
- s390: enable switchdev support in defconfig (Thomas Huth) [RHEL-54248]
- s390/vmcp: use page_to_virt instead of page_to_phys (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/vdso: filter out -mstack-guard and -mstack-size (Thomas Huth) [RHEL-54248]
- s390/vdso: remove -nostdlib compiler flag (Thomas Huth) [RHEL-54248]
- s390: replace snprintf in show functions with sysfs_emit (Thomas Huth) [RHEL-54248]
- s390/cpumf: cpum_cf PMU displays invalid value after hotplug remove (Thomas Huth) [RHEL-54248]
- s390/spinlock: remove incorrect kernel doc indicator (Thomas Huth) [RHEL-54248]
- s390/string: use generic strlcpy (Thomas Huth) [RHEL-54248]
- s390/string: use generic strrchr (Thomas Huth) [RHEL-54248]
- s390/hmcdrv: fix kernel doc comments (Thomas Huth) [RHEL-54248]
- s390/cpumf: Allow multiple processes to access /dev/hwc (Thomas Huth) [RHEL-54248]
- s390/bitops: return true/false (not 1/0) from bool functions (Thomas Huth) [RHEL-54248]
- s390/setup: convert start and end initrd pointers to virtual (Thomas Huth) [RHEL-54248]
- s390/setup: use virtual address for STSI instruction (Thomas Huth) [RHEL-54248]
- s390/cpcmd: use physical address for command and response (Thomas Huth) [RHEL-54248]
- net: s390: constify and use eth_hw_addr_set() (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- scsi: zfcp_scsi: Call scsi_done() directly (Thomas Huth) [RHEL-54248]
- s390: fix strrchr() implementation (Thomas Huth) [RHEL-54248]
- s390/sclp_vt220: fix unused function warning (Thomas Huth) [RHEL-54248]
- kprobes: add testcases for s390 (Thomas Huth) [RHEL-54248]
- s390/ftrace: add FTRACE_GEN_NOP_ASM macro (Thomas Huth) [RHEL-54248]
- s390/sclp_sd: fix warnings about missing parameter description (Thomas Huth) [RHEL-54248]
- s390/cio: derive cdev information only for IO-subchannels (Thomas Huth) [RHEL-54248]
- s390/cio: unregister the subchannel while purging (Thomas Huth) [RHEL-54248]
- s390/kprobes: add sanity check (Thomas Huth) [RHEL-54248]
- s390/cio: avoid excessive path-verification requests (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/hmcdrv_ftp: fix kernel doc comment (Thomas Huth) [RHEL-54248]
- s390: remove xpram device driver (Thomas Huth) [RHEL-54248]
- s390/cio: fix kernel doc comment (Thomas Huth) [RHEL-54248]
- s390/ctrlchar: fix kernel doc comment (Thomas Huth) [RHEL-54248]
- s390/cpum_cf: move array from header to C file (Thomas Huth) [RHEL-54248]
- s390/configs: enable CONFIG_KFENCE in debug_defconfig (Thomas Huth) [RHEL-54248]
- s390/cio: log fake IRB events (Thomas Huth) [RHEL-54248]
- s390/cio: fix race condition during online processing (Thomas Huth) [RHEL-54248]
- s390/cio: fix invalid -EBUSY on ccw_device_start (Thomas Huth) [RHEL-54248]
- s390/cio: dont unregister subchannel from child-drivers (Thomas Huth) [RHEL-54248]
- s390/net: replace in_irq() with in_hardirq() (Thomas Huth) [RHEL-54248]
- s390: remove SCHED_CORE from defconfigs (Thomas Huth) [RHEL-54248]
- s390: update defconfigs (Thomas Huth) [RHEL-54248]
- s390/diag: make restart_part2 a local label (Thomas Huth) [RHEL-54248]
- s390/cio: add rescan functionality on channel subsystem (Thomas Huth) [RHEL-54248]
- scsi: zfcp: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Thomas Huth) [RHEL-54248]
- s390: enable KCSAN (Thomas Huth) [RHEL-54248]
- s390/delay: get rid of not needed header includes (Thomas Huth) [RHEL-54248]
- s390/headers: fix code style in module.h (Thomas Huth) [RHEL-54248]
- s390/vdso: use system call functions (Thomas Huth) [RHEL-54248]
- s390/syscall: provide generic system call functions (Thomas Huth) [RHEL-54248]
- s390/jump_label: print real address in a case of a jump label bug (Thomas Huth) [RHEL-54248]
- s390/cio: remove unused include linux/spinlock.h from cio.h (Thomas Huth) [RHEL-54248]
- scsi: zfcp: Use the proper SCSI midlayer interfaces for PI (Thomas Huth) [RHEL-54248]
- s390/paes: Reestablish retry loop in paes (Thomas Huth) [RHEL-54248]
- s390/crypto: remove retry loop with sleep from PAES pkey invocation (Thomas Huth) [RHEL-54248]
- s390/crypto: use kfree_sensitive() instead of kfree() (Thomas Huth) [RHEL-54248]
- s390/crypto: fix scatterwalk_unmap() callers in AES-GCM (Thomas Huth) [RHEL-54248]
- s390/crypto: fix typos in comments (Thomas Huth) [RHEL-54248]
- crypto: s390/sha512 - Use macros instead of direct IV numbers (Thomas Huth) [RHEL-54248]
- s390/zcrypt: utilize dev_set_name() ability to use a formatted string (Thomas Huth) [RHEL-54248]
- s390/zcrypt: don't leak memory if dev_set_name() fails (Thomas Huth) [RHEL-54248]
- s390/zcrypt: remove ZCRYPT_MULTIDEVNODES kernel config option (Thomas Huth) [RHEL-54248]
- s390/zcrypt: remove unnecessary (void *) conversions (Thomas Huth) [RHEL-54248]
- s390/zcrypt: use strscpy() to instead of strncpy() (Thomas Huth) [RHEL-54248]
- s390/ap: fix memory leak in ap_init_qci_info() (Thomas Huth) [RHEL-54248]
- s390/cpufeature: rework to allow more than only hwcap bits (Thomas Huth) [RHEL-54248]
- net: phy: micrel: Fix potential null pointer dereference (CKI Backport Bot) [RHEL-37224] {CVE-2024-35891}
- mm: avoid 'might_sleep()' in get_mmap_lock_carefully() (Rafael Aquini) [RHEL-27742]
- mm: Fix access_remote_vm() regression on tagged addresses (Rafael Aquini) [RHEL-27742]
- mm/damon/core: initialize damo_filter->list from damos_new_filter() (Rafael Aquini) [RHEL-27742]
- Revert "mm,memblock: reset memblock.reserved to system init state to prevent UAF" (Rafael Aquini) [RHEL-27742]
- mm,memblock: reset memblock.reserved to system init state to prevent UAF (Rafael Aquini) [RHEL-27742]
- mm/damon/core-test: initialise context before test in damon_test_set_attrs() (Rafael Aquini) [RHEL-27742]
- mm/damon/core-test: add a test for damon_set_attrs() (Rafael Aquini) [RHEL-27742]
- gup: make the stack expansion warning a bit more targeted (Rafael Aquini) [RHEL-27742]
- mm: don't do validate_mm() unnecessarily and without mmap locking (Rafael Aquini) [RHEL-27742]
- mm: validate the mm before dropping the mmap lock (Rafael Aquini) [RHEL-27742]
- execve: always mark stack as growing down during early stack setup (Rafael Aquini) [RHEL-27742]
- xtensa: fix lock_mm_and_find_vma in case VMA not found (Rafael Aquini) [RHEL-27742]
- xtensa: fix NOMMU build with lock_mm_and_find_vma() conversion (Rafael Aquini) [RHEL-27742]
- vm: fix move_vma() memory accounting being off (Rafael Aquini) [RHEL-27742]
- mm: Update do_vmi_align_munmap() return semantics (Rafael Aquini) [RHEL-27742]
- gup: avoid stack expansion warning for known-good case (Rafael Aquini) [RHEL-27742]
- mm: Always downgrade mmap_lock if requested (Rafael Aquini) [RHEL-27742]
- mm/hugetlb: remove hugetlb_set_page_subpool() (Rafael Aquini) [RHEL-27742]
- mm: remove unnecessary pagevec includes (Rafael Aquini) [RHEL-27742]
- mm: remove references to pagevec (Rafael Aquini) [RHEL-27742]
- mm: rename invalidate_mapping_pagevec to mapping_try_invalidate (Rafael Aquini) [RHEL-27742]
- mm: remove struct pagevec (Rafael Aquini) [RHEL-27742]
- net: convert sunrpc from pagevec to folio_batch (Rafael Aquini) [RHEL-27742]
- mm: remove check_move_unevictable_pages() (Rafael Aquini) [RHEL-27742]
- mm: page_alloc: use the correct type of list for free pages (Rafael Aquini) [RHEL-27742]
- mm/vmscan: fix root proactive reclaim unthrottling unbalanced node (Rafael Aquini) [RHEL-27742]
- mm: memcg: rename and document global_reclaim() (Rafael Aquini) [RHEL-27742]
- mm: backing-dev: make bdi_class a static const structure (Rafael Aquini) [RHEL-27742]
- mm/swapfile: delete outdated pte_offset_map() comment (Rafael Aquini) [RHEL-27742]
- mm: kill [add|del]_page_to_lru_list() (Rafael Aquini) [RHEL-27742]
- mm: compaction: convert to use a folio in isolate_migratepages_block() (Rafael Aquini) [RHEL-27742]
- mm: fix shmem THP counters on migration (Rafael Aquini) [RHEL-27742]
- mm: page_alloc: make compound_page_dtors static (Rafael Aquini) [RHEL-27742]
- gup: add warning if some caller would seem to want stack expansion (Rafael Aquini) [RHEL-27742]
- mm: always expand the stack with the mmap write lock held (Rafael Aquini) [RHEL-27742]
- execve: expand new process stack manually ahead of time (Rafael Aquini) [RHEL-27742]
- exec: Remove FOLL_FORCE for stack setup (Rafael Aquini) [RHEL-27742]
- mm: make find_extend_vma() fail if write lock not held (Rafael Aquini) [RHEL-27742]
- exec: simplify initial stack size expansion (Rafael Aquini) [RHEL-27742]
- arch/arm64/mm/fault: Fix undeclared variable error in do_page_fault() (Rafael Aquini) [RHEL-27742]
- arm64/mm: Convert to using lock_mm_and_find_vma() (Rafael Aquini) [RHEL-27742]
- arm64/mm: mark private VM_FAULT_X defines as vm_fault_t (Rafael Aquini) [RHEL-27742]
- arm/mm: Convert to using lock_mm_and_find_vma() (Rafael Aquini) [RHEL-27742]
- ARM: 9131/1: mm: Fix PXN process with LPAE feature (Rafael Aquini) [RHEL-27742]
- ARM: 9130/1: mm: Provide die_kernel_fault() helper (Rafael Aquini) [RHEL-27742]
- ARM: 9126/1: mm: Kill page table base print in show_pte() (Rafael Aquini) [RHEL-27742]
- ARM: 9127/1: mm: Cleanup access_error() (Rafael Aquini) [RHEL-27742]
- ARM: 9129/1: mm: Kill task_struct argument for __do_page_fault() (Rafael Aquini) [RHEL-27742]
- ARM: 9128/1: mm: Refactor the __do_page_fault() (Rafael Aquini) [RHEL-27742]
- powerpc/mm: convert coprocessor fault to lock_mm_and_find_vma() (Rafael Aquini) [RHEL-27742]
- powerpc/mm: Convert to using lock_mm_and_find_vma() (Rafael Aquini) [RHEL-27742]
- mm: suppress mm fault logging if fatal signal already pending (Rafael Aquini) [RHEL-27742]
- mm: make the page fault mmap locking killable (Rafael Aquini) [RHEL-27742]
- mm: introduce new 'lock_mm_and_find_vma()' page fault helper (Rafael Aquini) [RHEL-27742]
- mm/memcg: remove return value of mem_cgroup_scan_tasks() (Rafael Aquini) [RHEL-27742]
- mm: kill lock|unlock_page_memcg() (Rafael Aquini) [RHEL-27742]
- kasan: add support for kasan.fault=panic_on_write (Rafael Aquini) [RHEL-27742]
- mm: compaction: skip memory hole rapidly when isolating migratable pages (Rafael Aquini) [RHEL-27742]
- mm: remove is_longterm_pinnable_page() and reimplement folio_is_longterm_pinnable() (Rafael Aquini) [RHEL-27742]
- mm/gup.c: reorganize try_get_folio() (Rafael Aquini) [RHEL-27742]
- mm/gup_test.c: convert verify_dma_pinned() to us folios (Rafael Aquini) [RHEL-27742]
- mmzone: introduce folio_migratetype() (Rafael Aquini) [RHEL-27742]
- mmzone: introduce folio_is_zone_movable() (Rafael Aquini) [RHEL-27742]
- mm/slab_common: use SLAB_NO_MERGE instead of negative refcount (Rafael Aquini) [RHEL-27742]
- mm/page_owner/cma: show pfn in cma/page_owner with hex format (Rafael Aquini) [RHEL-27742]
- mm/hugetlb: fix pgtable lock on pmd sharing (Rafael Aquini) [RHEL-27742]
- mm: ptep_get() conversion (Rafael Aquini) [RHEL-27742]
- mm: move ptep_get() and pmdp_get() helpers (Rafael Aquini) [RHEL-27742]
- mm: Convert __HAVE_ARCH_P..P_GET to the new style (Rafael Aquini) [RHEL-27742]
- mm: remove __HAVE_ARCH_PTEP_CLEAR in pgtable.h (Rafael Aquini) [RHEL-27742]
- mm: ptdump should use ptep_get_lockless() (Rafael Aquini) [RHEL-27742]
- mm: Fix a dangling Documentation/arm64 reference (Rafael Aquini) [RHEL-27742]
- mm/folio: replace set_compound_order with folio_set_order (Rafael Aquini) [RHEL-27742]
- mm: remove set_compound_page_dtor() (Rafael Aquini) [RHEL-27742]
- mm: compaction: mark kcompactd_run() and kcompactd_stop() __meminit (Rafael Aquini) [RHEL-27742]
- memory tier: remove unneeded !IS_ENABLED(CONFIG_MIGRATION) check (Rafael Aquini) [RHEL-27742]
- memory tier: remove unneeded disable_all_demotion_targets() when !CONFIG_MIGRATION (Rafael Aquini) [RHEL-27742]
- mm/khugepaged: use DEFINE_READ_MOSTLY_HASHTABLE macro (Rafael Aquini) [RHEL-27742]
- mm/folio: avoid special handling for order value 0 in folio_set_order (Rafael Aquini) [RHEL-27742]
- perf/core: allow pte_offset_map() to fail (Rafael Aquini) [RHEL-27742]
- mm/swap: swap_vma_readahead() do the pte_offset_map() (Rafael Aquini) [RHEL-27742]
- mm/pgtable: delete pmd_trans_unstable() and friends (Rafael Aquini) [RHEL-27742]
- mm/mm_init.c: drop 'nid' parameter from check_for_memory() (Rafael Aquini) [RHEL-27742]
- mm/mm_init.c: remove reset_node_present_pages() (Rafael Aquini) [RHEL-27742]
- mm/memory_hotplug: remove reset_node_managed_pages() in hotadd_init_pgdat() (Rafael Aquini) [RHEL-27742]
- mm/sparse: remove unused parameters in sparse_remove_section() (Rafael Aquini) [RHEL-27742]
- mm: vmscan: mark kswapd_run() and kswapd_stop() __meminit (Rafael Aquini) [RHEL-27742]
- mm/slab_common: reduce an if statement in create_cache() (Rafael Aquini) [RHEL-27742]
- mm/hugetlb: use a folio in hugetlb_fault() (Rafael Aquini) [RHEL-27742]
- mm/hugetlb: use a folio in hugetlb_wp() (Rafael Aquini) [RHEL-27742]
- mm/hugetlb: use a folio in copy_hugetlb_page_range() (Rafael Aquini) [RHEL-27742]
- mm: remove obsolete alloc_migrate_target() (Rafael Aquini) [RHEL-27742]
- mm: page_isolation: write proper kerneldoc (Rafael Aquini) [RHEL-27742]
- mm: page_alloc: remove unneeded header files (Rafael Aquini) [RHEL-27742]
- mm/early_ioremap.c: improve the execution efficiency of early_ioremap_setup() (Rafael Aquini) [RHEL-27742]
- mm: compaction: have compaction_suitable() return bool (Rafael Aquini) [RHEL-27742]
- mm/damon/ops-common: refactor to use {pte|pmd}p_clear_young_notify() (Rafael Aquini) [RHEL-27742]
- mm/damon/ops-common: atomically test and clear young on ptes and pmds (Rafael Aquini) [RHEL-27742]
- memblock: Update nid info in memblock debugfs (Rafael Aquini) [RHEL-27742]
- mm/mm_init.c: move set_pageblock_order() to free_area_init() (Rafael Aquini) [RHEL-27742]
- slub: Replace cmpxchg_double() (Rafael Aquini) [RHEL-27742]
- percpu: Fix self-assignment of __old in raw_cpu_generic_try_cmpxchg() (Rafael Aquini) [RHEL-27742]
- percpu: Add {raw,this}_cpu_try_cmpxchg() (Rafael Aquini) [RHEL-27742]
- instrumentation: Wire up cmpxchg128() (Rafael Aquini) [RHEL-27742]
- zram: use __bio_add_page for adding single page to bio (Rafael Aquini) [RHEL-27742]
- swap: use __bio_add_page to add page to bio (Rafael Aquini) [RHEL-27742]
- mm: khugepaged: avoid pointless allocation for "struct mm_slot" (Rafael Aquini) [RHEL-27742]
- swap: remove get/put_swap_device() in __swap_duplicate() (Rafael Aquini) [RHEL-27742]
- swap: remove __swp_swapcount() (Rafael Aquini) [RHEL-27742]
- swap: remove get/put_swap_device() in __swap_count() (Rafael Aquini) [RHEL-27742]
- mm/mm_init.c: remove free_area_init_memoryless_node() (Rafael Aquini) [RHEL-27742]
- mm: Provide a function to get an additional pin on a page (Rafael Aquini) [RHEL-27742]
- Revert "vfio/type1: Unpin zero pages" (Rafael Aquini) [RHEL-27742]
- mm: Don't pin ZERO_PAGE in pin_user_pages() (Rafael Aquini) [RHEL-27742]
- mm/mm_init.c: do not calculate zone_start_pfn/zone_end_pfn in zone_absent_pages_in_node() (Rafael Aquini) [RHEL-27742]
- mm/mm_init.c: introduce reset_memoryless_node_totalpages() (Rafael Aquini) [RHEL-27742]
- mm/vmalloc: replace the ternary conditional operator with min() (Rafael Aquini) [RHEL-27742]
- mm: vmalloc must set pte via arch code (Rafael Aquini) [RHEL-27742]
- mm/vmalloc: dont purge usable blocks unnecessarily (Rafael Aquini) [RHEL-27742]
- mm/vmalloc: add missing READ/WRITE_ONCE() annotations (Rafael Aquini) [RHEL-27742]
- mm/vmalloc: check free space in vmap_block lockless (Rafael Aquini) [RHEL-27742]
- mm/vmalloc: prevent flushing dirty space over and over (Rafael Aquini) [RHEL-27742]
- mm/vmalloc: avoid iterating over per CPU vmap blocks twice (Rafael Aquini) [RHEL-27742]
- mm/vmalloc: prevent stale TLBs in fully utilized blocks (Rafael Aquini) [RHEL-27742]
- mm: compaction: skip fast freepages isolation if enough freepages are isolated (Rafael Aquini) [RHEL-27742]
- mm: compaction: add trace event for fast freepages isolation (Rafael Aquini) [RHEL-27742]
- mm: compaction: only set skip flag if cc->no_set_skip_hint is false (Rafael Aquini) [RHEL-27742]
- mm: compaction: skip more fully scanned pageblock (Rafael Aquini) [RHEL-27742]
- mm: compaction: change fast_isolate_freepages() to void type (Rafael Aquini) [RHEL-27742]
- mm: compaction: drop the redundant page validation in update_pageblock_skip() (Rafael Aquini) [RHEL-27742]
- mm/slab: remove HAVE_HARDENED_USERCOPY_ALLOCATOR (Rafael Aquini) [RHEL-27742]
- mm/slab: rename CONFIG_SLAB to CONFIG_SLAB_DEPRECATED (Rafael Aquini) [RHEL-27742]
- splice: kdoc for filemap_splice_read() and copy_splice_read() (Rafael Aquini) [RHEL-27742]
- net: Make sock_splice_read() use copy_splice_read() by default (Rafael Aquini) [RHEL-27742]
- tty, proc, kernfs, random: Use copy_splice_read() (Rafael Aquini) [RHEL-27742]
- shmem: minor fixes to splice-read implementation (Rafael Aquini) [RHEL-27742]
- mm: shmem: fix UAF bug in shmem_show_options() (Rafael Aquini) [RHEL-27742]
- shmem: Implement splice-read (Rafael Aquini) [RHEL-27742]
- splice: Make splice from a DAX file use copy_splice_read() (Rafael Aquini) [RHEL-27742]
- splice: Make splice from an O_DIRECT fd use copy_splice_read() (Rafael Aquini) [RHEL-27742]
- splice: Check for zero count in vfs_splice_read() (Rafael Aquini) [RHEL-27742]
- splice: Make do_splice_to() generic and export it (Rafael Aquini) [RHEL-27742]
- splice: Clean up copy_splice_read() a bit (Rafael Aquini) [RHEL-27742]
- splice: Make filemap_splice_read() check s_maxbytes (Rafael Aquini) [RHEL-27742]
- splice: Fix filemap_splice_read() to use the correct inode (Rafael Aquini) [RHEL-27742]
- mm: compaction: drop redundant watermark check in compaction_zonelist_suitable() (Rafael Aquini) [RHEL-27742]
- mm: compaction: remove unnecessary is_via_compact_memory() checks (Rafael Aquini) [RHEL-27742]
- mm: compaction: refactor __compaction_suitable() (Rafael Aquini) [RHEL-27742]
- mm: compaction: simplify should_compact_retry() (Rafael Aquini) [RHEL-27742]
- mm: compaction: remove compaction result helpers (Rafael Aquini) [RHEL-27742]
- mm: compaction: avoid GFP_NOFS ABBA deadlock (Rafael Aquini) [RHEL-27742]
- memblock: Add flags and nid info in memblock debugfs (Rafael Aquini) [RHEL-27742]
- mm: page_alloc: set sysctl_lowmem_reserve_ratio storage-class-specifier to static (Rafael Aquini) [RHEL-27742]
- mm/gup: remove vmas array from internal GUP functions (Rafael Aquini) [RHEL-27742]
- mm/gup: remove vmas parameter from pin_user_pages() (Rafael Aquini) [RHEL-27742]
- io_uring: rsrc: delegate VMA file-backed check to GUP (Rafael Aquini) [RHEL-27742]
- mm: fix __access_remote_vm() GUP failure case (Rafael Aquini) [RHEL-27742]
- mm/gup: remove vmas parameter from get_user_pages_remote() (Rafael Aquini) [RHEL-27742]
- mm/gup: remove unused vmas parameter from get_user_pages() (Rafael Aquini) [RHEL-27742]
- time_namespace: always provide arch_get_vdso_data() prototype for vdso (Rafael Aquini) [RHEL-27742]
- panic: make function declarations visible (Rafael Aquini) [RHEL-27742]
- lib: devmem_is_allowed: include linux/io.h (Rafael Aquini) [RHEL-27742]
- mm: sparse: mark populate_section_memmap() static (Rafael Aquini) [RHEL-27742]
- mm: page_poison: always declare __kernel_map_pages() function (Rafael Aquini) [RHEL-27742]
- mm: percpu: unhide pcpu_embed_first_chunk prototype (Rafael Aquini) [RHEL-27742]
- mm/hugetlb: remove hugetlb_page_subpool() (Rafael Aquini) [RHEL-27742]
- x86/mm: Add early_memremap_pgprot_adjust() prototype (Rafael Aquini) [RHEL-27742]
- mm/zsmalloc: get rid of PAGE_MASK (Rafael Aquini) [RHEL-27742]
- mm: convert migrate_pages() to work on folios (Rafael Aquini) [RHEL-27742]
- filemap: remove page_endio() (Rafael Aquini) [RHEL-27742]
- mm: memory_hotplug: fix format string in warnings (Rafael Aquini) [RHEL-27742]
- migrate_pages_batch: simplify retrying and failure counting of large folios (Rafael Aquini) [RHEL-27742]
- mm: hugetlb_vmemmap: provide stronger vmemmap allocation guarantees (Rafael Aquini) [RHEL-27742]
- mm: memory-failure: move sysctl register in memory_failure_init() (Rafael Aquini) [RHEL-27742]
- mm: memory_failure: move memory_failure_attr_group under MEMORY_FAILURE (Rafael Aquini) [RHEL-27742]
- mm, oom: do not check 0 mask in out_of_memory() (Rafael Aquini) [RHEL-27742]
- THP: avoid lock when check whether THP is in deferred list (Rafael Aquini) [RHEL-27742]
- migrate_pages: avoid blocking for IO in MIGRATE_SYNC_LIGHT (Rafael Aquini) [RHEL-27742]
- memcg: dump memory.stat during cgroup OOM for v1 (Rafael Aquini) [RHEL-27742]
- memcg: use seq_buf_do_printk() with mem_cgroup_print_oom_meminfo() (Rafael Aquini) [RHEL-27742]
- mm: compaction: optimize compact_memory to comply with the admin-guide (Rafael Aquini) [RHEL-27742]
- mm/page_alloc: drop the unnecessary pfn_valid() for start pfn (Rafael Aquini) [RHEL-27742]
- Fix some coding style errors in memblock.c (Rafael Aquini) [RHEL-27742]
- cgroup: remove cgroup_rstat_flush_atomic() (Rafael Aquini) [RHEL-27742]
- memcg: remove mem_cgroup_flush_stats_atomic() (Rafael Aquini) [RHEL-27742]
- memcg: calculate root usage from global state (Rafael Aquini) [RHEL-27742]
- memcg: flush stats non-atomically in mem_cgroup_wb_stats() (Rafael Aquini) [RHEL-27742]
- writeback: move wb_over_bg_thresh() call outside lock section (Rafael Aquini) [RHEL-27742]
- memcg, oom: remove explicit wakeup in mem_cgroup_oom_synchronize() (Rafael Aquini) [RHEL-27742]
- memcg, oom: remove unnecessary check in mem_cgroup_oom_synchronize() (Rafael Aquini) [RHEL-27742]
- mm/slab: correct return values in comment for _kmem_cache_create() (Rafael Aquini) [RHEL-27742]
- mm/slab: Replace invocation of weak PRNG (Rafael Aquini) [RHEL-27742]
- mm/slab: break up RCU readers on SLAB_TYPESAFE_BY_RCU example code (Rafael Aquini) [RHEL-27742]
- mm/slab: add a missing semicolon on SLAB_TYPESAFE_BY_RCU example code (Rafael Aquini) [RHEL-27742]
- mm/slab_common: Replace invocation of weak PRNG (Rafael Aquini) [RHEL-27742]
- slub: Don't read nr_slabs and total_objects directly (Rafael Aquini) [RHEL-27742]
- slub: Remove slabs_node() function (Rafael Aquini) [RHEL-27742]
- slub: Remove CONFIG_SMP defined check (Rafael Aquini) [RHEL-27742]
- slub: Put objects_show() into CONFIG_SLUB_DEBUG enabled block (Rafael Aquini) [RHEL-27742]
- slub: Correct the error code when slab_kset is NULL (Rafael Aquini) [RHEL-27742]
- nodemask: Drop duplicate check in for_each_node_mask() (Rafael Aquini) [RHEL-27742]
- mm/slab: introduce kmem_cache flag SLAB_NO_MERGE (Rafael Aquini) [RHEL-27742]
- filemap: remove find_get_pages_range_tag() (Rafael Aquini) [RHEL-27742]
- gfs2: convert gfs2_write_cache_jdata() to use filemap_get_folios_tag() (Rafael Aquini) [RHEL-27742]
- ext4: convert mpage_prepare_extent_to_map() to use filemap_get_folios_tag() (Rafael Aquini) [RHEL-27742]
- cifs: convert wdata_alloc_and_fillpages() to use filemap_get_folios_tag() (Rafael Aquini) [RHEL-27742]
- ceph: convert ceph_writepages_start() to use filemap_get_folios_tag() (Rafael Aquini) [RHEL-27742]
- afs: Fix waiting for writeback then skipping folio (Rafael Aquini) [RHEL-27742]
- afs: Fix dangling folio ref counts in writeback (Rafael Aquini) [RHEL-27742]
- afs: convert afs_writepages_region() to use filemap_get_folios_tag() (Rafael Aquini) [RHEL-27742]
- cpufreq: amd-pstate: add check for cpufreq_cpu_get's return value (David Arcari) [RHEL-45016]
- cpufreq/amd-pstate: Add the missing cpufreq_cpu_put() (David Arcari) [RHEL-45016]
- cpufreq/amd-pstate: Fix the scaling_max_freq setting on shared memory CPPC systems (David Arcari) [RHEL-45016]
- cpufreq/amd-pstate-ut: Convert nominal_freq to khz during comparisons (David Arcari) [RHEL-45016]
- cpufreq/amd-pstate: fix setting policy current frequency value (David Arcari) [RHEL-45016]
- redhat/configs: enable CONFIG_FS_ENCRYPTION (Xiubo Li) [RHEL-49398]
- pinctrl: cherryview: Switch to use DEFINE_NOIRQ_DEV_PM_OPS() helper (Steve Dunnagan) [RHEL-40642]
- include: trace: Widen the tag buffer in trace_scmi_dump_msg (Steve Dunnagan) [RHEL-40642]
- OPP: Fix missing cleanup on error in _opp_attach_genpd() (Steve Dunnagan) [RHEL-40642]
- OPP: Fix required_opp_tables for multiple genpds using same table (Steve Dunnagan) [RHEL-40642]
- pmdomain: core: constify of_phandle_args in add device and subdomain (Steve Dunnagan) [RHEL-40642]
- pmdomain: core: constify of_phandle_args in xlate (Steve Dunnagan) [RHEL-40642]
- pinctrl: renesas: Allow the compiler to optimize away sh_pfc_pm (Steve Dunnagan) [RHEL-40642]
- dt-bindings: firmware: Support SCMI pinctrl protocol (Steve Dunnagan) [RHEL-40642]
- dt-bindings: firmware: arm,scmi: Restrict protocol child node properties (Steve Dunnagan) [RHEL-40642]
- dt-bindings: firmware: arm,scmi: Add support for powercap protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: optee: use optee system invocation (Steve Dunnagan) [RHEL-40642]
- redhat/configs: add CONFIG_PINCTRL_SCMI (Steve Dunnagan) [RHEL-40642]
- pinctrl: Implementation of the generic scmi-pinctrl driver (Steve Dunnagan) [RHEL-40642]
- MAINTAINERS: Update SCMI entry with HWMON driver (Steve Dunnagan) [RHEL-40642]
- PM: domains: Move genpd and its governor to the pmdomain subsystem (Steve Dunnagan) [RHEL-40642]
- PM: domains: Drop redundant header for genpd (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Fix wrong fastchannel initialization (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add message dump traces for bad and unexpected replies (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add helper to trace bad messages (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Check mailbox/SMT channel for consistency (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Implement is_notify_supported callback in powercap protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Implement is_notify_supported callback in reset protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Implement is_notify_supported callback in sensor protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Implement is_notify_supported callback in system power protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Implement is_notify_supported callback in power protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Use xa_insert() when saving raw queues (Steve Dunnagan) [RHEL-40642]
- pinctrl: renesas: Switch to use DEFINE_NOIRQ_DEV_PM_OPS() helper (Steve Dunnagan) [RHEL-40642]
- tee: Refactor TEE subsystem header files (Steve Dunnagan) [RHEL-40642]
- tee: Remove unused declarations (Steve Dunnagan) [RHEL-40642]
- tee: make tee_bus_type const (Steve Dunnagan) [RHEL-40642]
- tee: system session (Steve Dunnagan) [RHEL-40642]
- optee: provide optee_do_bottom_half() as a common function (Steve Dunnagan) [RHEL-40642]
- tee: optee: support tracking system threads (Steve Dunnagan) [RHEL-40642]
- tee: optee: system thread call property (Steve Dunnagan) [RHEL-40642]
- optee: remove vma linked list walk (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Update the supported clock protocol version (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Implement is_notify_supported callback in clock protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Fix the clock protocol supported version (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Fix the clock protocol version for v3.2 (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add basic support for SCMI v3.2 pincontrol protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Introduce get_max_msg_size() helper/accessor (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add support for multiple vendors custom protocols (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Simplify scmi_devm_notifier_unregister (Steve Dunnagan) [RHEL-40642]
- cpufreq: scmi: Enable boost support (Steve Dunnagan) [RHEL-40642]
- cpufreq: scmi: Set transition_delay_us (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add standard clock OEM definitions (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add clock check for extended config support (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add support for v3.2 NEGOTIATE_PROTOCOL_VERSION (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Rework clock domain info lookups (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Implement clock get permissions (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Log the perf domain names in the error paths (Steve Dunnagan) [RHEL-40642]
- OPP: Extend dev_pm_opp_data with turbo support (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add support for marking certain frequencies as turbo (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Populate fast channel rate_limit (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Populate perf commands rate_limit (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Report frequencies in the perf notifications (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Use opps_by_lvl to store opps (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Check for notification support (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Implement is_notify_supported callback in perf protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add a common helper to check if a message is supported (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Warn if domain frequency multiplier is 0 or rounded off (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Use xa_insert() to store opps (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Fix NULL pointer dereference during fastchannel init (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Populate fastchannel info only if set operations are allowed (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Check beforehand if the perf domain set operations are allowed (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add protocol versioning checks (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Increase the maximum opp count in the perf protocol (Steve Dunnagan) [RHEL-40642]
- firmware: arm_scmi: Add optional flags to extended names helper (Steve Dunnagan) [RHEL-40642]
- cpufreq: scmi: process the result of devm_of_clk_add_hw_provider() (Steve Dunnagan) [RHEL-40642]
- OPP: Rename 'rate_clk_single' (Steve Dunnagan) [RHEL-40642]
- OPP: Pass rounded rate to _set_opp() (Steve Dunnagan) [RHEL-40642]
- OPP: Relocate dev_pm_opp_sync_regulators() (Steve Dunnagan) [RHEL-40642]
- OPP: Fix _set_required_opps when opp is NULL (Steve Dunnagan) [RHEL-40642]
- OPP: The level field is always of unsigned int type (Steve Dunnagan) [RHEL-40642]
- OPP: Check for invalid OPP in dev_pm_opp_find_level_ceil() (Steve Dunnagan) [RHEL-40642]
- OPP: Don't set OPP recursively for a parent genpd (Steve Dunnagan) [RHEL-40642]
- OPP: Call dev_pm_opp_set_opp() for required OPPs (Steve Dunnagan) [RHEL-40642]
- OPP: Fix formatting of if/else block (Steve Dunnagan) [RHEL-40642]
- OPP: Protect `lazy_opp_tables` list with `opp_table_lock` (Steve Dunnagan) [RHEL-40642]
- OPP: Use _set_opp_level() for single genpd case (Steve Dunnagan) [RHEL-40642]
- OPP: Add _link_required_opps() to avoid code duplication (Steve Dunnagan) [RHEL-40642]
- OPP: Level zero is valid (Steve Dunnagan) [RHEL-40642]
- OPP: No need to defer probe from _opp_attach_genpd() (Steve Dunnagan) [RHEL-40642]
- OPP: Remove genpd_virt_dev_lock (Steve Dunnagan) [RHEL-40642]
- OPP: Reorder code in _opp_set_required_opps_genpd() (Steve Dunnagan) [RHEL-40642]
- OPP: Remove doc style comments for internal routines (Steve Dunnagan) [RHEL-40642]
- OPP: Add dev_pm_opp_find_level_floor() (Steve Dunnagan) [RHEL-40642]
- OPP: Reuse dev_pm_opp_get_freq_indexed() (Steve Dunnagan) [RHEL-40642]
- OPP: Update _read_freq() to return the correct frequency (Steve Dunnagan) [RHEL-40642]

* Mon Sep 23 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-512.el9]
- cpufreq: intel_pstate: Use Meteor Lake EPPs for Arrow Lake (Steve Best) [RHEL-58617]
- cpufreq: intel_pstate: Update Meteor Lake EPPs (Steve Best) [RHEL-58617]
- tools/power/cpupower: Fix Pstate frequency reporting on AMD Family 1Ah CPUs (Steve Best) [RHEL-57711]
- cpufreq: intel_pstate: Update Lunar Lake hybrid scaling factor (Steve Best) [RHEL-58615]
- cpufreq: intel_pstate: Update Arrow Lake hybrid scaling factor (Steve Best) [RHEL-58615]
- netfilter: flowtable: initialise extack before use (CKI Backport Bot) [RHEL-58544] {CVE-2024-45018}
- tracing/osnoise: Fix build when timerlat is not enabled (Tomas Glozar) [RHEL-39968]
- tracing/timerlat: Add interface_lock around clearing of kthread in stop_kthread() (Tomas Glozar) [RHEL-39968]
- tracing/timerlat: Only clear timer if a kthread exists (Tomas Glozar) [RHEL-39968]
- tracing/osnoise: Use a cpumask to know what threads are kthreads (Tomas Glozar) [RHEL-39968]
- cpufreq: intel_pstate: Support Emerald Rapids OOB mode (Steve Best) [RHEL-58619]
- ARM: dts: am33xx-l4: Add missing touchscreen clock properties (Joel Slebodnick) [RHEL-51597]
- iio: adc: ti_am335x_adc: Add the scale information (Joel Slebodnick) [RHEL-51597]
- iio: adc: ti_am335x_adc: Add a unit to the timeout delay (Joel Slebodnick) [RHEL-51597]
- iio: adc: ti_am335x_adc: Gather the checks on the delays (Joel Slebodnick) [RHEL-51597]
- iio: adc: ti_am335x_adc: Get rid of useless gotos (Joel Slebodnick) [RHEL-51597]
- iio: adc: ti_am335x_adc: Fix style (Joel Slebodnick) [RHEL-51597]
- iio: adc: ti_am335x_adc: Replace license text with SPDX tag (Joel Slebodnick) [RHEL-51597]
- iio: adc: ti_am335x_adc: Wait the idle state to avoid stalls (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Drop unused definitions from the header (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Convert to platform remove callback returning void (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Use devm_platform_get_and_ioremap_resource() (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Fix spelling mistake "atleast" -> "at least" (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Support the correctly spelled DT property (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Add ADC1/magnetic reader support (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Introduce a helper to deal with the type of hardware (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Add a boolean to clarify the presence of a touchscreen (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Fix an error message (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Rename a variable (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Add TSC prefix in certain macros (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Drop useless definitions from the header (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Clarify the maximum values for DT entries (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Use BIT(), GENMASK() and FIELD_PREP() when relevant (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Replace the header license text with SPDX tag (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Fix header spacing (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Use the new HZ_PER_MHZ macro (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Rename the subsystem enable macro (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Gather the ctrl register logic in one place (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Reorder the initialization steps (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Always provide an idle configuration (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Drop useless variables from the driver structure (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Mimic the probe from resume() (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Use driver data (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Move the driver structure allocation earlier (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Simplify divisor calculation (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Don't search the tree for our clock (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Reword the comment explaining the dividers (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Drop extra spacing when declaring stack variables (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Get rid of useless gotos (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Fix style (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Replace license text with SPDX tag (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Ensure a balanced number of node get/put (Joel Slebodnick) [RHEL-51597]
- mfd: ti_am335x_tscadc: Delete superfluous error message (Joel Slebodnick) [RHEL-51597]
- uki: use systemd-pcrphase dracut module (Vitaly Kuznetsov)
- selftests/thermel/intel: Add test to read workload hint (David Arcari) [RHEL-29349]
- thermal: intel: int340x: Free MSI IRQ vectors on module exit (David Arcari) [RHEL-29349]
- thermal: intel: int340x: Allow limited thermal MSI support (David Arcari) [RHEL-29349]
- thermal: intel: int340x: Fix kernel warning during MSI cleanup (David Arcari) [RHEL-29349]
- thermal: trip: Pass trip pointer to .set_trip_temp() thermal zone callback (David Arcari) [RHEL-29349]
- thermal: helpers: Introduce thermal_trip_is_bound_to_cdev() (David Arcari) [RHEL-29349]
- thermal: trip: Add conversion macros for thermal trip priv field (David Arcari) [RHEL-29349]
- thermal: intel: int340x: Enable WLT and power floor support for Lunar Lake (David Arcari) [RHEL-29349]
- thermal: intel: int340x: Support MSI interrupt for Lunar Lake (David Arcari) [RHEL-29349]
- thermal: intel: int340x: Remove unnecessary calls to free irq (David Arcari) [RHEL-29349]
- thermal: intel: int340x: Add DLVR support for Lunar Lake (David Arcari) [RHEL-29349]
- thermal: intel: int340x: Capability to map user space to firmware values (David Arcari) [RHEL-29349]
- thermal: intel: int340x: Cleanup of DLVR sysfs on driver remove (David Arcari) [RHEL-29349]
- thermal: int340x: processor_thermal: Support shared interrupts (David Arcari) [RHEL-29349]
- thermal: int3403: remove unused struct 'int3403_performance_state' (David Arcari) [RHEL-29349]
- thermal: int3400: Use sizeof(*pointer) instead of sizeof(type) (David Arcari) [RHEL-29349]
- thermal: intel: Add missing module description (David Arcari) [RHEL-29349]
- thermal: intel: int340x_thermal: replace deprecated strncpy() with strscpy() (David Arcari) [RHEL-29349]
- selftests:resctrl: Fix build failure on archs without __cpuid_count() (David Arcari) [RHEL-20790]
- x86/resctrl: Update documentation with Sub-NUMA cluster changes (David Arcari) [RHEL-20790]
- x86/resctrl: Fix arch_mbm_* array overrun on SNC (David Arcari) [RHEL-20790]
- x86/resctrl: Detect Sub-NUMA Cluster (SNC) mode (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove test name comparing from write_bm_pid_to_resctrl() (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove mongrp from CMT test (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove mongrp from MBA test (David Arcari) [RHEL-20790]
- selftests/resctrl: Convert ctrlgrp & mongrp to pointers (David Arcari) [RHEL-20790]
- selftests/resctrl: Make some strings passed to resctrlfs functions const (David Arcari) [RHEL-20790]
- selftests/resctrl: Simplify bandwidth report type handling (David Arcari) [RHEL-20790]
- selftests/resctrl: Add ->init() callback into resctrl_val_param (David Arcari) [RHEL-20790]
- selftests/resctrl: Add ->measure() callback to resctrl_val_param (David Arcari) [RHEL-20790]
- selftests/resctrl: Simplify mem bandwidth file code for MBA & MBM tests (David Arcari) [RHEL-20790]
- selftests/resctrl: Rename measure_vals() to measure_mem_bw_vals() & document (David Arcari) [RHEL-20790]
- selftests/resctrl: Cleanup bm_pid and ppid usage & limit scope (David Arcari) [RHEL-20790]
- selftests/resctrl: Use correct type for pids (David Arcari) [RHEL-20790]
- selftests/resctrl: Consolidate get_domain_id() into resctrl_val() (David Arcari) [RHEL-20790]
- selftests/resctrl: Make "bandwidth" consistent in comments & prints (David Arcari) [RHEL-20790]
- selftests/resctrl: Calculate resctrl FS derived mem bw over sleep(1) only (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix closing IMC fds on error and open-code R+W instead of loops (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix non-contiguous CBM for AMD (David Arcari) [RHEL-20790]
- selftests/resctrl: fix clang build warnings related to abs(), labs() calls (David Arcari) [RHEL-20790]
- selftests/resctrl: fix clang build failure: use LOCAL_HDRS (David Arcari) [RHEL-20790]
- selftests/resctrl: ksft_exit_skip() does not return (David Arcari) [RHEL-20790]
- selftests/resctrl: Move cleanups out of individual tests (David Arcari) [RHEL-20790]
- selftests/resctrl: Simplify cleanup in ctrl-c handler (David Arcari) [RHEL-20790]
- selftests/resctrl: Add cleanup function to test framework (David Arcari) [RHEL-20790]
- selftests/resctrl: Add non-contiguous CBMs CAT test (David Arcari) [RHEL-20790]
- selftests/resctrl: Add resource_info_file_exists() (David Arcari) [RHEL-20790]
- selftests/resctrl: Split validate_resctrl_feature_request() (David Arcari) [RHEL-20790]
- selftests/resctrl: Add a helper for the non-contiguous test (David Arcari) [RHEL-20790]
- selftests/resctrl: Add test groups and name L3 CAT test L3_CAT (David Arcari) [RHEL-20790]
- selftests/resctrl: Get domain id from cache id (David Arcari) [RHEL-20790]
- selftests/resctrl: Rename resource ID to domain ID (David Arcari) [RHEL-20790]
- selftests/resctrl: Add helper to convert L2/3 to integer (David Arcari) [RHEL-20790]
- selftests/resctrl: Pass write_schemata() resource instead of test name (David Arcari) [RHEL-20790]
- selftests/resctrl: Introduce generalized test framework (David Arcari) [RHEL-20790]
- selftests/resctrl: Create struct for input parameters (David Arcari) [RHEL-20790]
- selftests/resctrl: Restore the CPU affinity after CAT test (David Arcari) [RHEL-20790]
- selftests/resctrl: Rewrite Cache Allocation Technology (CAT) test (David Arcari) [RHEL-20790]
- selftests/resctrl: Read in less obvious order to defeat prefetch optimizations (David Arcari) [RHEL-20790]
- selftests/resctrl: Replace file write with volatile variable (David Arcari) [RHEL-20790]
- selftests/resctrl: Open perf fd before start & add error handling (David Arcari) [RHEL-20790]
- selftests/resctrl: Move cat_val() to cat_test.c and rename to cat_test() (David Arcari) [RHEL-20790]
- selftests/resctrl: Convert perf related globals to locals (David Arcari) [RHEL-20790]
- selftests/resctrl: Improve perf init (David Arcari) [RHEL-20790]
- selftests/resctrl: Consolidate naming of perf event related things (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove nested calls in perf event handling (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove unnecessary __u64 -> unsigned long conversion (David Arcari) [RHEL-20790]
- selftests/resctrl: Split show_cache_info() to test specific and generic parts (David Arcari) [RHEL-20790]
- selftests/resctrl: Split measure_cache_vals() (David Arcari) [RHEL-20790]
- selftests/resctrl: Exclude shareable bits from schemata in CAT test (David Arcari) [RHEL-20790]
- selftests/resctrl: Create cache_portion_size() helper (David Arcari) [RHEL-20790]
- selftests/resctrl: Mark get_cache_size() cache_type const (David Arcari) [RHEL-20790]
- selftests/resctrl: Refactor get_cbm_mask() and rename to get_full_cbm() (David Arcari) [RHEL-20790]
- selftests/resctrl: Refactor fill_buf functions (David Arcari) [RHEL-20790]
- selftests/resctrl: Split fill_buf to allow tests finer-grained control (David Arcari) [RHEL-20790]
- selftests/resctrl: Change function comments to say < 0 on error (David Arcari) [RHEL-20790]
- selftests/resctrl: Don't use ctrlc_handler() outside signal handling (David Arcari) [RHEL-20790]
- selftests/resctrl: Return -1 instead of errno on error (David Arcari) [RHEL-20790]
- selftests/resctrl: Convert perror() to ksft_perror() or ksft_print_msg() (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix MBM test failure when MBA unavailable (David Arcari) [RHEL-20790]
- selftests/resctrl: Move run_benchmark() to a more fitting file (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix schemata write error check (David Arcari) [RHEL-20790]
- selftests/resctrl: Reduce failures due to outliers in MBA/MBM tests (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix feature checks (David Arcari) [RHEL-20790]
- selftests/resctrl: Refactor feature check to use resource and feature name (David Arcari) [RHEL-20790]
- selftests/resctrl: Move _GNU_SOURCE define into Makefile (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove duplicate feature check from CMT test (David Arcari) [RHEL-20790]
- selftests/resctrl: Extend signal handler coverage to unmount on receiving signal (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix uninitialized .sa_flags (David Arcari) [RHEL-20790]
- selftests/resctrl: Cleanup benchmark argument parsing (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove ben_count variable (David Arcari) [RHEL-20790]
- selftests/resctrl: Make benchmark command const and build it with pointers (David Arcari) [RHEL-20790]
- selftests/resctrl: Reorder resctrl FS prep code and benchmark_cmd init (David Arcari) [RHEL-20790]
- selftests/resctrl: Simplify span lifetime (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove bw_report and bm_type from main() (David Arcari) [RHEL-20790]
- selftests/resctrl: Correct benchmark command help (David Arcari) [RHEL-20790]
- selftests/resctrl: Ensure the benchmark commands fits to its array (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix wrong format specifier (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove test type checks from cat_val() (David Arcari) [RHEL-20790]
- selftests/resctrl: Pass the real number of tests to show_cache_info() (David Arcari) [RHEL-20790]
- selftests/resctrl: Move CAT/CMT test global vars to function they are used in (David Arcari) [RHEL-20790]
- selftests/resctrl: Don't use variable argument list for ->setup() (David Arcari) [RHEL-20790]
- selftests/resctrl: Don't pass test name to fill_buf (David Arcari) [RHEL-20790]
- selftests/resctrl: Improve parameter consistency in fill_buf (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove unnecessary startptr global from fill_buf (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove "malloc_and_init_memory" param from run_fill_buf() (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove duplicated preparation for span arg (David Arcari) [RHEL-20790]
- selftests/resctrl: Express span internally in bytes (David Arcari) [RHEL-20790]
- selftests/resctrl: Convert span to size_t (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove mum_resctrlfs from struct resctrl_val_param (David Arcari) [RHEL-20790]
- selftests/resctrl: Refactor remount_resctrl(bool mum_resctrlfs) to mount_resctrl() (David Arcari) [RHEL-20790]
- selftests/resctrl: Move resctrl FS mount/umount to higher level (David Arcari) [RHEL-20790]
- selftests/resctrl: Unmount resctrl FS before starting the first test (David Arcari) [RHEL-20790]
- selftests/resctrl: Close perf value read fd on errors (David Arcari) [RHEL-20790]
- selftests/resctrl: Unmount resctrl FS if child fails to run benchmark (David Arcari) [RHEL-20790]
- selftests/resctrl: Don't leak buffer in fill_cache() (David Arcari) [RHEL-20790]
- selftests/resctrl: Add resctrl.h into build deps (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix incorrect error return on test complete (David Arcari) [RHEL-20790]
- selftests/resctrl: Remove duplicate codes that clear each test result file (David Arcari) [RHEL-20790]
- selftests/resctrl: Commonize the signal handler register/unregister for all tests (David Arcari) [RHEL-20790]
- selftests/resctrl: Cleanup properly when an error occurs in CAT test (David Arcari) [RHEL-20790]
- selftests/resctrl: Flush stdout file buffer before executing fork() (David Arcari) [RHEL-20790]
- selftests/resctrl: Return MBA check result and make it to output message (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix set up schemata with 100%% allocation on first run in MBM test (David Arcari) [RHEL-20790]
- selftests/resctrl: Use correct exit code when tests fail (David Arcari) [RHEL-20790]
- selftests/resctrl: Correct get_llc_perf() param in function comment (David Arcari) [RHEL-20790]
- selftests/resctrl: Use remount_resctrlfs() consistently with boolean (David Arcari) [RHEL-20790]
- selftests/resctrl: Change name from CBM_MASK_PATH to INFO_PATH (David Arcari) [RHEL-20790]
- selftests/resctrl: Change initialize_llc_perf() return type to void (David Arcari) [RHEL-20790]
- selftests/resctrl: Replace obsolete memalign() with posix_memalign() (David Arcari) [RHEL-20790]
- selftests/resctrl: Check for return value after write_schemata() (David Arcari) [RHEL-20790]
- selftests/resctrl: Allow ->setup() to return errors (David Arcari) [RHEL-20790]
- selftests/resctrl: Move ->setup() call outside of test specific branches (David Arcari) [RHEL-20790]
- selftests/resctrl: Return NULL if malloc_and_init_memory() did not alloc mem (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix null pointer dereference on open failed (David Arcari) [RHEL-20790]
- selftests/resctrl: Add missing SPDX license to Makefile (David Arcari) [RHEL-20790]
- selftests/resctrl: Update README about using kselftest framework to build/run resctrl_tests (David Arcari) [RHEL-20790]
- selftests/resctrl: Make resctrl_tests run using kselftest framework (David Arcari) [RHEL-20790]
- selftests/resctrl: Fix resctrl_tests' return code to work with selftest framework (David Arcari) [RHEL-20790]
- selftests/resctrl: Change the default limited time to 120 seconds (David Arcari) [RHEL-20790]
- selftests/resctrl: Kill child process before parent process terminates if SIGTERM is received (David Arcari) [RHEL-20790]
- selftests/resctrl: Print a message if the result of MBM&CMT tests is failed on Intel CPU (David Arcari) [RHEL-20790]
- selftests/resctrl: Extend CPU vendor detection (David Arcari) [RHEL-20790]
- x86/resctrl: Enable shared RMID mode on Sub-NUMA Cluster (SNC) systems (David Arcari) [RHEL-20790]
- x86/resctrl: Make __mon_event_count() handle sum domains (David Arcari) [RHEL-20790]
- x86/resctrl: Fill out rmid_read structure for smp_call*() to read a counter (David Arcari) [RHEL-20790]
- x86/resctrl: Handle removing directories in Sub-NUMA Cluster (SNC) mode (David Arcari) [RHEL-20790]
- x86/resctrl: Create Sub-NUMA Cluster (SNC) monitor files (David Arcari) [RHEL-20790]
- x86/resctrl: Allocate a new field in union mon_data_bits (David Arcari) [RHEL-20790]
- x86/resctrl: Refactor mkdir_mondata_subdir() with a helper function (David Arcari) [RHEL-20790]
- x86/resctrl: Initialize on-stack struct rmid_read instances (David Arcari) [RHEL-20790]
- x86/resctrl: Add a new field to struct rmid_read for summation of domains (David Arcari) [RHEL-20790]
- x86/resctrl: Prepare for new Sub-NUMA Cluster (SNC) monitor files (David Arcari) [RHEL-20790]
- x86/resctrl: Block use of mba_MBps mount option on Sub-NUMA Cluster (SNC) systems (David Arcari) [RHEL-20790]
- x86/resctrl: Introduce snc_nodes_per_l3_cache (David Arcari) [RHEL-20790]
- x86/resctrl: Add node-scope to the options for feature scope (David Arcari) [RHEL-20790]
- x86/resctrl: Split the rdt_domain and rdt_hw_domain structures (David Arcari) [RHEL-20790]
- x86/resctrl: Prepare for different scope for control/monitor operations (David Arcari) [RHEL-20790]
- x86/resctrl: Prepare to split rdt_domain structure (David Arcari) [RHEL-20790]
- x86/resctrl: Prepare for new domain scope (David Arcari) [RHEL-20790]
- x86/resctrl: Don't try to free nonexistent RMIDs (David Arcari) [RHEL-20790]
- x86/resctrl: Replace open coded cacheinfo searches (David Arcari) [RHEL-20790]
- cacheinfo: Add function to get cacheinfo for a given CPU and cache level (David Arcari) [RHEL-20790]
- cpu: Move CPU hotplug function declarations into their own header (David Arcari) [RHEL-20790]
- x86/resctrl: Switch to new Intel CPU model defines (David Arcari) [RHEL-20790]
- x86/resctrl: Add tracepoint for llc_occupancy tracking (David Arcari) [RHEL-20790]
- x86/resctrl: Rename pseudo_lock_event.h to trace.h (David Arcari) [RHEL-20790]
- x86/resctrl: Simplify call convention for MSR update functions (David Arcari) [RHEL-20790]
- x86/resctrl: Pass domain to target CPU (David Arcari) [RHEL-20790]
- x86/resctrl: Fix uninitialized memory read when last CPU of domain goes offline (David Arcari) [RHEL-20790]
- x86/resctrl: Remove lockdep annotation that triggers false positive (David Arcari) [RHEL-20790]
- x86/resctrl: Separate arch and fs resctrl locks (David Arcari) [RHEL-20790]
- x86/resctrl: Move domain helper migration into resctrl_offline_cpu() (David Arcari) [RHEL-20790]
- x86/resctrl: Add CPU offline callback for resctrl work (David Arcari) [RHEL-20790]
- x86/resctrl: Allow overflow/limbo handlers to be scheduled on any-but CPU (David Arcari) [RHEL-20790]
- x86/resctrl: Add CPU online callback for resctrl work (David Arcari) [RHEL-20790]
- x86/resctrl: Add helpers for system wide mon/alloc capable (David Arcari) [RHEL-20790]
- x86/resctrl: Make rdt_enable_key the arch's decision to switch (David Arcari) [RHEL-20790]
- x86/resctrl: Move alloc/mon static keys into helpers (David Arcari) [RHEL-20790]
- x86/resctrl: Make resctrl_mounted checks explicit (David Arcari) [RHEL-20790]
- x86/resctrl: Allow arch to allocate memory needed in resctrl_arch_rmid_read() (David Arcari) [RHEL-20790]
- x86/resctrl: Allow resctrl_arch_rmid_read() to sleep (David Arcari) [RHEL-20790]
- x86/resctrl: Queue mon_event_read() instead of sending an IPI (David Arcari) [RHEL-20790]
- x86/resctrl: Add cpumask_any_housekeeping() for limbo/overflow (David Arcari) [RHEL-20790]
- x86/resctrl: Move CLOSID/RMID matching and setting to use helpers (David Arcari) [RHEL-20790]
- x86/resctrl: Allocate the cleanest CLOSID by searching closid_num_dirty_rmid (David Arcari) [RHEL-20790]
- x86/resctrl: Use __set_bit()/__clear_bit() instead of open coding (David Arcari) [RHEL-20790]
- x86/resctrl: Track the number of dirty RMID a CLOSID has (David Arcari) [RHEL-20790]
- x86/resctrl: Allow RMID allocation to be scoped by CLOSID (David Arcari) [RHEL-20790]
- x86/resctrl: Access per-rmid structures by index (David Arcari) [RHEL-20790]
- x86/resctrl: Track the closid with the rmid (David Arcari) [RHEL-20790]
- x86/resctrl: Move RMID allocation out of mkdir_rdt_prepare() (David Arcari) [RHEL-20790]
- x86/resctrl: Create helper for RMID allocation and mondata dir creation (David Arcari) [RHEL-20790]
- x86/resctrl: Free rmid_ptrs from resctrl_exit() (David Arcari) [RHEL-20790]
- x86/resctrl: Implement new mba_MBps throttling heuristic (David Arcari) [RHEL-20790]
- x86/resctrl: Fix unused variable warning in cache_alloc_hsw_probe() (David Arcari) [RHEL-20790]
- md/raid5: avoid BUG_ON() while continue reshape after reassembling (CKI Backport Bot) [RHEL-56203] {CVE-2024-43914}
- tcp: move inet_twsk_schedule helper out of header (Florian Westphal) [RHEL-9279]
- net: tcp: un-pin the tw_timer (Florian Westphal) [RHEL-9279]
- net: tcp/dccp: prepare for tw_timer un-pinning (Florian Westphal) [RHEL-9279]
- tcp: annotate data-races around tw->tw_ts_recent and tw->tw_ts_recent_stamp (Florian Westphal) [RHEL-9279]
- md: fix deadlock between mddev_suspend and flush bio (Nigel Croxon) [RHEL-54757] {CVE-2024-43855}
- rhel-only: selftests/bpf: add cpuv4 variant (Artem Savkov) [RHEL-50017]
- PCI: hv: Return zero, not garbage, when reading PCI_INTERRUPT_PIN (Maxim Levitsky) [RHEL-54308]
- Input: serio - use sizeof(*pointer) instead of sizeof(type) (Maxim Levitsky) [RHEL-54308]
- Drivers: hv: Cosmetic changes for hv.c and balloon.c (Maxim Levitsky) [RHEL-54308]
- hv_balloon: Enable hot-add for memblock sizes > 128 MiB (Maxim Levitsky) [RHEL-54308]
- hv_balloon: Use kernel macros to simplify open coded sequences (Maxim Levitsky) [RHEL-54308]
- uio_hv_generic: Remove use of PAGE_SIZE (Maxim Levitsky) [RHEL-54308]
- uio_hv_generic: Enable interrupt for low speed VMBus devices (Maxim Levitsky) [RHEL-54308]
- uio_hv_generic: Query the ringbuffer size for device (Maxim Levitsky) [RHEL-54308]
- Drivers: hv: vmbus: Add utility function for querying ring size (Maxim Levitsky) [RHEL-54308]
- Drivers: hv: vmbus: Don't free ring buffers that couldn't be re-encrypted (Maxim Levitsky) [RHEL-54308]
- uio_hv_generic: Don't free decrypted memory (Maxim Levitsky) [RHEL-54308]
- hv_netvsc: Don't free decrypted memory (Maxim Levitsky) [RHEL-54308]
- Drivers: hv: vmbus: Track decrypted status in vmbus_gpadl (Maxim Levitsky) [RHEL-54308]
- Drivers: hv: vmbus: Leak pages if set_memory_encrypted() fails (Maxim Levitsky) [RHEL-54308]
- hv: vmbus: Convert sprintf() family to sysfs_emit() family (Maxim Levitsky) [RHEL-54308]
- mshyperv: Introduce hv_numa_node_to_pxm_info() (Maxim Levitsky) [RHEL-54308]
- x86/hyperv: Cosmetic changes for hv_apic.c (Maxim Levitsky) [RHEL-54308]
- x86/hyperv: Use Hyper-V entropy to seed guest random number generator (Maxim Levitsky) [RHEL-54308]
- x86/hyperv: Cosmetic changes for hv_spinlock.c (Maxim Levitsky) [RHEL-54308]
- hyperv-tlfs: Rename some HV_REGISTER_* defines for consistency (Maxim Levitsky) [RHEL-54308]
- hv: vmbus: Convert to platform remove callback returning void (Maxim Levitsky) [RHEL-54308]
- mshyperv: Introduce hv_get_hypervisor_version function (Maxim Levitsky) [RHEL-54308]
- PCI: hv: Fix ring buffer size calculation (Maxim Levitsky) [RHEL-54308]
- x86/hyperv: Use per cpu initial stack for vtl context (Maxim Levitsky) [RHEL-54308]
- Drivers: hv: vmbus: make hv_bus const (Maxim Levitsky) [RHEL-54308]
- x86/hyperv: Allow 15-bit APIC IDs for VTL platforms (Maxim Levitsky) [RHEL-54308]
- x86/hyperv: Make encrypted/decrypted changes safe for load_unaligned_zeropad() (Maxim Levitsky) [RHEL-54308]
- x86/mm: Regularize set_memory_p() parameters and make non-static (Maxim Levitsky) [RHEL-54308]
- x86/hyperv: Use slow_virt_to_phys() in page transition hypervisor callback (Maxim Levitsky) [RHEL-54308]
- Drivers: hv: vmbus: Update indentation in create_gpadl_header() (Maxim Levitsky) [RHEL-54308]
- Drivers: hv: vmbus: Remove duplication and cleanup code in create_gpadl_header() (Maxim Levitsky) [RHEL-54308]
- Drivers: hv: vmbus: Calculate ring buffer size for more efficient use of memory (Maxim Levitsky) [RHEL-54308]
- hv_utils: Allow implicit ICTIMESYNCFLAG_SYNC (Maxim Levitsky) [RHEL-54308]
- scsi: storvsc: Fix ring buffer size calculation (Maxim Levitsky) [RHEL-54308]
- virtio/vsock: send credit update during setting SO_RCVLOWAT (Maxim Levitsky) [RHEL-54308]
- redhat: kernel.spec: add missing sound/soc/sof/sof-audio.h to kernel-devel package (Jaroslav Kysela) [RHEL-16610]

* Wed Sep 18 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-511.el9]
- ipv4: Set scope explicitly in ip_route_output(). (CKI Backport Bot) [RHEL-57748]
- ACPI: thermal_lib: Initialize temp_decik to zero (Mark Langsdorf) [RHEL-54149]
- ACPI: thermal_lib: include "internal.h" for function prototypes (Mark Langsdorf) [RHEL-54149]
- ACPI: thermal: Register thermal zones without valid trip points (Mark Langsdorf) [RHEL-54149]
- ACPI: thermal: Use library functions to obtain trip point temperature values (Mark Langsdorf) [RHEL-54149]
- ACPI: thermal_lib: Add functions returning temperature in deci-Kelvin (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: Don't use "proxy" headers (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: Make container_of() no-op where it makes sense (Mark Langsdorf) [RHEL-54149]
- ACPI: NHLT: Drop redundant types (Mark Langsdorf) [RHEL-54149]
- ACPI: NHLT: Streamline struct naming (Mark Langsdorf) [RHEL-54149]
- ACPI: NHLT: Reintroduce types the table consists of (Mark Langsdorf) [RHEL-54149]
- ACPI: NHLT: Introduce API for the table (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: allow _UID matching for integer zero (Mark Langsdorf) [RHEL-54149]
- ACPI: processor_idle: Fix invalid comparison with insertion sort for latency (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Ignore camera graph port nodes on all Dell Tiger, Alder and Raptor Lake models (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: Force StorageD3Enable on more products (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Avoid enumerating devices with clearly invalid _STA values (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Skip IRQ override on Asus Vivobook Pro N6506MV (Mark Langsdorf) [RHEL-54149]
- hwmon: (acpi_power_meter) Ensure IPMI space handler is ready on Dell systems (Mark Langsdorf) [RHEL-54149]
- ACPI: IPMI: Add helper to wait for when SMI is selected (Mark Langsdorf) [RHEL-54149]
- ACPI: property: Add reference to UEFI DSD Guide (Mark Langsdorf) [RHEL-54149]
- ACPI/IORT: Handle memory address size limits as limits (Mark Langsdorf) [RHEL-54149]
- ACPI: PM: s2idle: Evaluate all Low-Power S0 Idle _DSM functions (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Do IRQ override on TongFang GXxHRXx and GMxHGxx (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Do IRQ override on GMxBGxx (XMG APEX 17 M23) (Mark Langsdorf) [RHEL-54149]
- ACPICA: Detect FACS even for hardware reduced platforms (Mark Langsdorf) [RHEL-54149]
- ACPI: AC: Properly notify powermanagement core about changes (Mark Langsdorf) [RHEL-54149]
- ACPI: EC: Avoid returning AE_OK on errors in address space handler (Mark Langsdorf) [RHEL-54149]
- ACPI: EC: Abort address space access upon error (Mark Langsdorf) [RHEL-54149]
- ACPI: APEI: EINJ: Fix einj_dev release leak (Mark Langsdorf) [RHEL-54149]
- ACPI: EC: Evaluate _REG outside the EC scope more carefully (Mark Langsdorf) [RHEL-54149]
- ACPICA: Add a depth argument to acpi_execute_reg_methods() (Mark Langsdorf) [RHEL-54149]
- ACPI: EC: Install address space handler at the namespace root (Mark Langsdorf) [RHEL-54149]
- ACPI/NUMA: Squash acpi_numa_memory_affinity_init() into acpi_parse_memory_affinity() (Mark Langsdorf) [RHEL-54149]
- ACPI/NUMA: Squash acpi_numa_slit_init() into acpi_parse_slit() (Mark Langsdorf) [RHEL-54149]
- ACPI/NUMA: Remove architecture dependent remainings (Mark Langsdorf) [RHEL-54149]
- x86/numa: Fix SRAT lookup of CFMWS ranges with numa_fill_memblks() (Mark Langsdorf) [RHEL-54149]
- ACPI: video: Add backlight=native quirk for Lenovo Slim 7 16ARH7 (Mark Langsdorf) [RHEL-54149]
- ACPI: platform-profile: add platform_profile_cycle() (Mark Langsdorf) [RHEL-54149]
- ACPICA: events/evgpeinit: don't forget to increment registered GPE count (Mark Langsdorf) [RHEL-54149]
- ACPICA: Modify ACPI_OBJECT_COMMON_HEADER (Mark Langsdorf) [RHEL-54149]
- ACPICA: Fix various spelling mistakes in text files and code comments (Mark Langsdorf) [RHEL-54149]
- ACPI: disable -Wstringop-truncation (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: Add PNP_UART1_SKIP quirk for Lenovo Blade2 tablets (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: utils: Mark SMO8810 accel on Dell XPS 15 9550 as always present (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Do not increase dep_unmet for already met dependencies (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: Move LPSS to x86 folder (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: Move blacklist to x86 folder (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: Move acpi_cmos_rtc to x86 folder (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: Introduce a Makefile (Mark Langsdorf) [RHEL-54149]
- ACPI: LPSS: Remove nested ifdeffery for CONFIG_PM (Mark Langsdorf) [RHEL-54149]
- ACPI: LPSS: Advertise number of chip selects via property (Mark Langsdorf) [RHEL-54149]
- ACPI: APEI: EINJ: mark remove callback as __exit (Mark Langsdorf) [RHEL-54149]
- ACPI: store owner from modules with acpi_bus_register_driver() (Mark Langsdorf) [RHEL-54149]
- ACPI: DPTF: Add Lunar Lake support (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Introduce typedef:s for struct acpi_hotplug_context members (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Use standard error checking pattern (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Move misleading comment to acpi_dma_configure_id() (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Use list_first_entry_or_null() in acpi_device_hid() (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: Indicate support for IRQ ResourceSource thru _OSC (Mark Langsdorf) [RHEL-54149]
- ACPI: Fix Generic Initiator Affinity _OSC bit (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: Indicate support for the Generic Event Device thru _OSC (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: Indicate support for more than 16 p-states thru _OSC (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: Indicate support for _TFP thru _OSC (Mark Langsdorf) [RHEL-54149]
- ACPICA: debugger: check status of acpi_evaluate_object() in acpi_db_walk_for_fields() (Mark Langsdorf) [RHEL-54149]
- ACPI: APEI: EINJ: mark remove callback as non-__exit (Mark Langsdorf) [RHEL-54149]
- ACPI: PM: Improve kerneldoc comments for suspend and hibernation functions (Mark Langsdorf) [RHEL-54149]
- ACPI: Document handle_eject_request() arguments (Mark Langsdorf) [RHEL-54149]
- EINJ: Add CXL error type support (Mark Langsdorf) [RHEL-54149]
- redhat/configs: Support for CXL protocol Error INJection (Mark Langsdorf) [RHEL-54149]
- EINJ: Migrate to a platform driver (Mark Langsdorf) [RHEL-54149]
- ACPI: HMAT: Introduce 2 levels of generic port access class (Mark Langsdorf) [RHEL-54149]
- base/node / ACPI: Enumerate node access class for 'struct access_coordinate' (Mark Langsdorf) [RHEL-54149]
- ACPI: HMAT: Remove register of memory node for generic target (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Use IRQ override on Maibenben X565 (Mark Langsdorf) [RHEL-54149]
- ACPI: CPPC: enable AMD CPPC V2 support for family 17h processors (Mark Langsdorf) [RHEL-54149]
- ACPI: APEI: Skip initialization of GHES_ASSIST structures for Machine Check Architecture (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Consolidate Device Check and Bus Check notification handling (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Rework Device Check and Bus Check notification handling (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Make acpi_processor_add() check the device enabled bit (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Relocate acpi_bus_trim_one() (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Fix device check notification handling (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Add MAIBENBEN X577 to irq1_edge_low_force_override (Mark Langsdorf) [RHEL-54149]
- ACPI: pfr_update: Convert to platform remove callback returning void (Mark Langsdorf) [RHEL-54149]
- ACPI: pfr_telemetry: Convert to platform remove callback returning void (Mark Langsdorf) [RHEL-54149]
- ACPI: fan: Convert to platform remove callback returning void (Mark Langsdorf) [RHEL-54149]
- ACPI: GED: Convert to platform remove callback returning void (Mark Langsdorf) [RHEL-54149]
- ACPI: DPTF: Convert to platform remove callback returning void (Mark Langsdorf) [RHEL-54149]
- ACPI: AGDI: Convert to platform remove callback returning void (Mark Langsdorf) [RHEL-54149]
- ACPI: TAD: Convert to platform remove callback returning void (Mark Langsdorf) [RHEL-54149]
- ACPI: APEI: GHES: Convert to platform remove callback returning void (Mark Langsdorf) [RHEL-54149]
- ACPI: property: Polish ignoring bad data nodes (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: Add DELL0501 handling to acpi_quirk_skip_serdev_enumeration() (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: Move acpi_quirk_skip_serdev_enumeration() out of CONFIG_X86_ANDROID_TABLETS (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Do IRQ override on Lunnen Ground laptops (Mark Langsdorf) [RHEL-54149]
- ACPI: use %%pe for better readability of errors while printing (Mark Langsdorf) [RHEL-54149]
- ACPI: property: Ignore bad graph port nodes on Dell XPS 9315 (Mark Langsdorf) [RHEL-54149]
- ACPI: utils: Make acpi_handle_path() not static (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Add IRQ override quirk for ASUS ExpertBook B2502FBA (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Defer enumeration of devices with a _DEP pointing to IVSC device (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: make acpi_bus_type const (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1502CVA (Mark Langsdorf) [RHEL-54149]
- ACPI: video: Handle fetching EDID that is longer than 256 bytes (Mark Langsdorf) [RHEL-54149]
- ACPI: cpufreq: Add highest perf change notification (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1502CGA (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Add DMI quirks for ASUS Vivobook E1504GA and E1504GAB (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Add Infinity laptops to irq1_edge_low_force_override (Mark Langsdorf) [RHEL-54149]
- ACPI: button: trigger wakeup key events (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Add another DMI match for the TongFang GMxXGxx (Mark Langsdorf) [RHEL-54149]
- ACPI: EC: Use a threaded handler for dedicated IRQ (Mark Langsdorf) [RHEL-54149]
- ACPI: OSL: Use spin locks without disabling interrupts (Mark Langsdorf) [RHEL-54149]
- acpi: numa: Add helper function to retrieve the performance attributes (Mark Langsdorf) [RHEL-54149]
- acpi: numa: Add setting of generic port system locality attributes (Mark Langsdorf) [RHEL-54149]
- acpi: Break out nesting for hmat_parse_locality() (Mark Langsdorf) [RHEL-54149]
- acpi: numa: Add genport target allocation to the HMAT parsing (Mark Langsdorf) [RHEL-54149]
- acpi: numa: Create enum for memory_target access coordinates indexing (Mark Langsdorf) [RHEL-54149]
- base/node / acpi: Change 'node_hmem_attrs' to 'access_coordinates' (Mark Langsdorf) [RHEL-54149]
- acpi, hmat: calculate abstract distance with HMAT (Mark Langsdorf) [RHEL-54149]
- memory tiering: add abstract distance calculation algorithms management (Mark Langsdorf) [RHEL-54149]
- lib/firmware_table: tables: Add CDAT table parsing support (Mark Langsdorf) [RHEL-54149]
- ACPICA: Add a define for size of struct acpi_srat_generic_affinity device_handle (Mark Langsdorf) [RHEL-54149]
- ACPI: APEI: set memory failure flags as MF_ACTION_REQUIRED on synchronous events (Mark Langsdorf) [RHEL-54149]
- ACPI: utils: Introduce helper for _DEP list lookup (Mark Langsdorf) [RHEL-54149]
- ACPI: LPSS: Fix the fractional clock divider flags (Mark Langsdorf) [RHEL-54149]
- ACPI: NUMA: Fix the logic of getting the fake_pxm value (Mark Langsdorf) [RHEL-54149]
- ACPI: NUMA: Optimize the check for the availability of node values (Mark Langsdorf) [RHEL-54149]
- ACPI: NUMA: Remove unnecessary check in acpi_parse_gi_affinity() (Mark Langsdorf) [RHEL-54149]
- ACPI: watchdog: fix kernel-doc warnings (Mark Langsdorf) [RHEL-54149]
- acpi: property: Let args be NULL in __acpi_node_get_property_reference (Mark Langsdorf) [RHEL-54149]
- ACPI: extlog: fix NULL pointer dereference check (Mark Langsdorf) [RHEL-54149]
- ACPI: OSL: Allow Notify () handlers to run on all CPUs (Mark Langsdorf) [RHEL-54149]
- ACPI: OSL: Rearrange workqueue selection in acpi_os_execute() (Mark Langsdorf) [RHEL-54149]
- ACPI: OSL: Rework error handling in acpi_os_execute() (Mark Langsdorf) [RHEL-54149]
- PNP: ACPI: fix fortify warning (Mark Langsdorf) [RHEL-54149]
- ACPI: video: Add quirk for the Colorful X15 AT 23 Laptop (Mark Langsdorf) [RHEL-54149]
- ACPI: LPSS: use acpi_dev_uid_match() for matching _UID (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: update acpi_dev_hid_uid_match() to support multiple types (Mark Langsdorf) [RHEL-54149]
- ACPI: bus: update acpi_dev_uid_match() to support multiple types (Mark Langsdorf) [RHEL-54149]
- drivers: base: Implement weak arch_unregister_cpu() (Mark Langsdorf) [RHEL-54149]
- drivers: base: Allow parts of GENERIC_CPU_DEVICES to be overridden (Mark Langsdorf) [RHEL-54149]
- drivers: base: Use present CPUs in GENERIC_CPU_DEVICES (Mark Langsdorf) [RHEL-54149]
- ACPI: Move ACPI_HOTPLUG_CPU to be disabled on arm64 and riscv (Mark Langsdorf) [RHEL-54149]
- hwmon: (acpi_power_meter) Fix 4.29 MW bug (Mark Langsdorf) [RHEL-54149]
- x86/acpi: Use %%rip-relative addressing in wakeup_64.S (Mark Langsdorf) [RHEL-54149]
- genirq: Set IRQF_COND_ONESHOT in request_irq() (Mark Langsdorf) [RHEL-54149]
- genirq: Introduce IRQF_COND_ONESHOT and use it in pinctrl-amd (Mark Langsdorf) [RHEL-54149]
- platform/x86: intel: int0002_vgpio: Pass IRQF_ONESHOT to request_irq() (Mark Langsdorf) [RHEL-54149]
- pinctrl: amd: Add IRQF_ONESHOT to the interrupt request (Mark Langsdorf) [RHEL-54149]
- ACPI: OSL: Use a threaded interrupt handler for SCI (Mark Langsdorf) [RHEL-54149]
- ACPI: video: check for error while searching for backlight device parent (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Fix an error message in DisCo for Imaging support (Mark Langsdorf) [RHEL-54149]
- ACPI: Run USB4 _OSC() first with query bit set (Mark Langsdorf) [RHEL-54149]
- ACPI: video: Drop should_check_lcd_flag() (Mark Langsdorf) [RHEL-54149]
- ACPI: property: Replicate DT-aligned u32 properties from DisCo for Imaging (Mark Langsdorf) [RHEL-54149]
- ACPI: property: Dig "rotation" property for devices with CSI2 _CRS (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Extract MIPI DisCo for Imaging data into swnodes (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Extract _CRS CSI-2 connection information into swnodes (Mark Langsdorf) [RHEL-54149]
- ACPI: scan: Extract CSI-2 connection graph from _CRS (Mark Langsdorf) [RHEL-54149]
- device property: Add SOFTWARE_NODE() macro for defining software nodes (Mark Langsdorf) [RHEL-54149]
- ACPI: property: Support using strings in reference properties (Mark Langsdorf) [RHEL-54149]
- hwmon: (acpi_power_meter) replace open-coded kmemdup_nul (Mark Langsdorf) [RHEL-54149]
- PNP: ACPI: replace deprecated strncpy() with strscpy() (Mark Langsdorf) [RHEL-54149]
- ACPI: AC: Rename ACPI device from device to adev (Mark Langsdorf) [RHEL-54149]
- acpi, hmat: refactor hmat_register_target_initiators() (Mark Langsdorf) [RHEL-54149]
- ACPI: AC: Replace acpi_driver with platform_driver (Mark Langsdorf) [RHEL-54149]
- PNP: ACPI: Fix string truncation warning (Mark Langsdorf) [RHEL-54149]
- ACPI: tiny-power-button: Eliminate the driver notify callback (Mark Langsdorf) [RHEL-54149]
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1502CBA (Mark Langsdorf) [RHEL-54149]
- ACPI: x86: utils: Add Picasso to the list for forcing StorageD3Enable (Mark Langsdorf) [RHEL-54149]
- PM: ACPI: reboot: Reinstate S5 for reboot (Mark Langsdorf) [RHEL-54149]
- kernel/reboot: Add SYS_OFF_MODE_RESTART_PREPARE mode (Mark Langsdorf) [RHEL-54149]
- hwmon: (acpi_power_meter) Switch to DEFINE_SIMPLE_DEV_PM_OPS() and pm_sleep_ptr() (Mark Langsdorf) [RHEL-54149]
- ACPI: video: Add Toshiba Satellite/Portege Z830 quirk (Mark Langsdorf) [RHEL-54149]
- ACPI: video: Simplify acpi_video_unregister_backlight() (Mark Langsdorf) [RHEL-54149]
- ACPI: video: Remove acpi_video_bus from list before tearing it down (Mark Langsdorf) [RHEL-54149]
- ACPI: OSI: Remove Linux-HPI-Hybrid-Graphics _OSI string (Mark Langsdorf) [RHEL-54149]
- ACPI: OSI: Remove Linux-Dell-Video _OSI string (Mark Langsdorf) [RHEL-54149]
- ACPI: OSI: Remove Linux-Lenovo-NV-HDMI-Audio _OSI string (Mark Langsdorf) [RHEL-54149]
- ACPICA: executer/exsystem: Fix some typo mistakes (Mark Langsdorf) [RHEL-54149]
- hwmon: (acpi_power_meter) Fix style issues (Mark Langsdorf) [RHEL-54149]
- arm64: Use do_kernel_power_off() (Mark Langsdorf) [RHEL-54149]
- efi: Fix efi_power_off() not being run before acpi_power_off() when necessary (Mark Langsdorf) [RHEL-54149]
- ACPI: power: Switch to sys-off handler API (Mark Langsdorf) [RHEL-54149]
- ACPICA: executer/exsystem: Inform users about ACPI spec violation (Mark Langsdorf) [RHEL-54149]
- ACPICA: executer/exsystem: Add units to time variable names (Mark Langsdorf) [RHEL-54149]
- s390/dasd: Remove DMA alignment (Mete Durlu) [RHEL-58207]
- pipe: wakeup wr_wait after setting max_usage (Brian Foster) [RHEL-37087] {CVE-2023-52672}
- fs/pipe: use spinlock in pipe_read() only if there is a watch_queue (Brian Foster) [RHEL-37087]
- fs/pipe: remove unnecessary spinlock from pipe_write() (Brian Foster) [RHEL-37087]
- fs/pipe: move check to pipe_has_watch_queue() (Brian Foster) [RHEL-37087]
- pipe: reduce padding in struct pipe_inode_info (Brian Foster) [RHEL-37087]
- pipe: make poll_usage boolean and annotate its access (Brian Foster) [RHEL-37087]
- bonding: fix xfrm real_dev null pointer dereference (CKI Backport Bot) [RHEL-57241] {CVE-2024-44989}
- bonding: fix null pointer deref in bond_ipsec_offload_ok (CKI Backport Bot) [RHEL-57235] {CVE-2024-44990}
- ibmveth: Recycle buffers during replenish phase (Mamatha Inamdar) [RHEL-52913]
- ibmveth: Optimize poll rescheduling process (Mamatha Inamdar) [RHEL-52913]
- gpio: pca953x: fix pca953x_irq_bus_sync_unlock race (CKI Backport Bot) [RHEL-53831] {CVE-2024-42253}

* Mon Sep 16 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-510.el9]
- perf: Fix event leak upon exec and file release (Michael Petlan) [RHEL-55606] {CVE-2024-43869}
- perf: Fix event leak upon exit (Michael Petlan) [RHEL-55603] {CVE-2024-43870}
- task_work: Introduce task_work_cancel() again (Michael Petlan) [RHEL-55603]
- task_work: s/task_work_cancel()/task_work_cancel_func()/ (Michael Petlan) [RHEL-55603]
- net: openvswitch: fix overwriting ct original tuple for ICMPv6 (cki-backport-bot) [RHEL-44213] {CVE-2024-38558}
- net: drop bad gso csum_start and offset in virtio_net_hdr (Laurent Vivier) [RHEL-54891] {CVE-2024-43817}
- net: change maximum number of UDP segments to 128 (Laurent Vivier) [RHEL-54891] {CVE-2024-43817}
- net: more strict VIRTIO_NET_HDR_GSO_UDP_L4 validation (Laurent Vivier) [RHEL-54891] {CVE-2024-43817}
- net: missing check virtio (Laurent Vivier) [RHEL-54891] {CVE-2024-43817}
- fuse: Initialize beyond-EOF page contents before setting uptodate (CKI Backport Bot) [RHEL-56932] {CVE-2024-44947}
- wifi: mac80211: Avoid address calculations via out of bounds array indexing (CKI Backport Bot) [RHEL-51285] {CVE-2024-41071}
- nvme-pci: add missing condition check for existence of mapped data (Maurizio Lombardi) [RHEL-55099] {CVE-2024-42276}
- sctp: fix association labeling in the duplicate COOKIE-ECHO case (Ondrej Mosnacek) [RHEL-48647]
- s390/ap: Refine AP bus bindings complete processing (Cédric Le Goater) [RHEL-50373]
- ice: Add netif_device_attach/detach into PF reset flow (Michal Schmidt) [RHEL-56084]
- ext4: make sure the first directory block is not a hole (CKI Backport Bot) [RHEL-54975] {CVE-2024-42304}
- ext4: check dot and dotdot of dx_root before making dir indexed (CKI Backport Bot) [RHEL-54964] {CVE-2024-42305}

* Fri Sep 13 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-509.el9]
- RDMA/mana_ib: Set correct device into ib (Maxim Levitsky) [RHEL-54330]
- net: mana: Fix possible double free in error handling path (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Ignore optional access flags for MRs (Maxim Levitsky) [RHEL-54330]
- net: mana: Add support for page sizes other than 4KB on ARM64 (Maxim Levitsky) [RHEL-54330]
- net: mana: Use mana_cleanup_port_context() for rxq cleanup (Maxim Levitsky) [RHEL-54330]
- net: mana: Allow variable size indirection table (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Process QP error events in mana_ib (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: extend query device (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: set node_guid (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Modify QP state (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Implement uapi to create and destroy RC QP (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Create and destroy RC QP (Maxim Levitsky) [RHEL-54330]
- net: mana: Fix the extra HZ in mana_hwc_send_request (Maxim Levitsky) [RHEL-54330]
- net: mana: Enable MANA driver on ARM64 with 4K page size (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: implement uapi for creation of rnic cq (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: boundary check before installing cq callbacks (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: introduce a helper to remove cq callbacks (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: create and destroy RNIC cqs (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: create EQs for RNIC CQs (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Fix missing ret value (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Configure mac address in RNIC (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Adding and deleting GIDs (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Enable RoCE on port 1 (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Implement port parameters (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Create and destroy rnic adapter (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Add EQ creation for rnic adapter (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Use num_comp_vectors of ib_device (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: remove useless return values from dbg prints (Maxim Levitsky) [RHEL-54330]
- net: mana: Avoid open coded arithmetic (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Prefer struct_size over open coded arithmetic (Maxim Levitsky) [RHEL-54330]
- net: mana: Add flex array to struct mana_cfg_rx_steer_req_v2 (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Use struct mana_ib_queue for RAW QPs (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Use struct mana_ib_queue for WQs (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Use struct mana_ib_queue for CQs (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Introduce helpers to create and destroy mana queues (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Use virtual address in dma regions for MRs (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Fix bug in creation of dma regions (Maxim Levitsky) [RHEL-54330]
- net: mana: Assigning IRQ affinity on HT cores (Maxim Levitsky) [RHEL-54330]
- net: mana: add a function to spread IRQs per CPUs (Maxim Levitsky) [RHEL-54330]
- cpumask: define cleanup function for cpumasks (Maxim Levitsky) [RHEL-54330]
- cpumask: add cpumask_weight_andnot() (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Introduce mana_ib_install_cq_cb helper function (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Introduce mana_ib_get_netdev helper function (Maxim Levitsky) [RHEL-54330]
- RDMA/mana_ib: Introduce mdev_to_gc helper function (Maxim Levitsky) [RHEL-54330]
- ping: fix address binding wrt vrf (Antoine Tenart) [RHEL-50920]
- mtd: spi-nor: core: Introduce method for RDID op (Joel Slebodnick) [RHEL-40636]
- mtd: spi-nor: core: Use auto-detection only once (Joel Slebodnick) [RHEL-40636]
- mtd: spi-nor: Introduce spi_nor_match_id() (Joel Slebodnick) [RHEL-40636]
- mtd: spi-nor: Rename method, s/spi_nor_match_id/spi_nor_match_name (Joel Slebodnick) [RHEL-40636]

* Thu Sep 12 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-508.el9]
- usb: xhci: prevent potential failure in handle_tx_event() for Transfer events without TRB (Desnes Nunes) [RHEL-52378] {CVE-2024-42226}
- redhat: set defaults for RHEL 9.5 (Lucas Zampieri)
- redhat/configs: Make CONFIG_REGULATOR_GPIO built-in (Luiz Capitulino) [RHEL-21095]
- redhat/configs: enable a bunch of regulators (Luiz Capitulino) [RHEL-21095]
- md-cluster: fix no recovery job when adding/re-adding a disk (Nigel Croxon) [RHEL-46615]
- md-cluster: fix hanging issue while a new disk adding (Nigel Croxon) [RHEL-46615]
- md/raid5: recheck if reshape has finished with device_lock held (Nigel Croxon) [RHEL-46615]
- md: Don't wait for MD_RECOVERY_NEEDED for HOT_REMOVE_DISK ioctl (Nigel Croxon) [RHEL-46615]
- md-cluster: Constify struct md_cluster_operations (Nigel Croxon) [RHEL-46615]
- md/raid5: fix spares errors about rcu usage (Nigel Croxon) [RHEL-46615]
- md: pass in max_sectors for pers->sync_request() (Nigel Croxon) [RHEL-46615]
- md: factor out helpers for different sync_action in md_do_sync() (Nigel Croxon) [RHEL-46615]
- md: replace last_sync_action with new enum type (Nigel Croxon) [RHEL-46615]
- md: use new helpers in md_do_sync() (Nigel Croxon) [RHEL-46615]
- md: don't fail action_store() if sync_thread is not registered (Nigel Croxon) [RHEL-46615]
- md: remove parameter check_seq for stop_sync_thread() (Nigel Croxon) [RHEL-46615]
- md: replace sysfs api sync_action with new helpers (Nigel Croxon) [RHEL-46615]
- md: factor out helper to start reshape from action_store() (Nigel Croxon) [RHEL-46615]
- md: add new helpers for sync_action (Nigel Croxon) [RHEL-46615]
- md: add a new enum type sync_action (Nigel Croxon) [RHEL-46615]
- md: rearrange recovery_flags (Nigel Croxon) [RHEL-46615]
- md/md-bitmap: fix writing non bitmap pages (Nigel Croxon) [RHEL-46615]
- md: make md_flush_request() more readable (Nigel Croxon) [RHEL-46615]
- md: change the return value type of md_write_start to void (Nigel Croxon) [RHEL-46615]
- md: do not delete safemode_timer in mddev_suspend (Nigel Croxon) [RHEL-46615]
- lib: objagg: Fix general protection fault (Waiman Long) [RHEL-54790 RHEL-54793] {CVE-2024-43846}
- Revert "x86/topology: Switch over to GENERIC_CPU_DEVICES" (David Arcari) [RHEL-58031]
- Revert "x86/topology: use weak version of arch_unregister_cpu()" (David Arcari) [RHEL-58031]
- Revert "x86/topology: convert to use arch_cpu_is_hotpluggable()" (David Arcari) [RHEL-58031]
- Revert "x86/cpu: Move leftover contents of topology.c to setup.c" (David Arcari) [RHEL-58031]
- x86/resctrl: Remove redundant variable in mbm_config_write_domain() (David Arcari) [RHEL-57701]
- x86/resctrl: Read supported bandwidth sources from CPUID (David Arcari) [RHEL-57701]
- x86/resctrl: Remove hard-coded memory bandwidth limit (David Arcari) [RHEL-57701]

* Wed Sep 11 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-507.el9]
- block: fix deadlock between sd_remove & sd_release (CKI Backport Bot) [RHEL-54997] {CVE-2024-42294}
- gpio: prevent potential speculation leaks in gpio_device_get_desc() (CKI Backport Bot) [RHEL-56213] {CVE-2024-44931}
- redhat: hmac sign the UKI for FIPS (Vitaly Kuznetsov)
- Also make vmlinuz-virt.efi world readable (Vitaly Kuznetsov)
- ice: fix truesize operations for PAGE_SIZE >= 8192 (Petr Oros) [RHEL-37905]
- ice: fix ICE_LAST_OFFSET formula (Petr Oros) [RHEL-37905]
- ice: fix page reuse when PAGE_SIZE is over 8k (Petr Oros) [RHEL-37905]
- usb: cdns3: Fix spelling mistake "supporte" -> "supported" (Martin McConnell) [RHEL-54566]
- usb: cdns3: fixed memory use after free at cdns3_gadget_ep_disable() (Martin McConnell) [RHEL-54566]
- usb: cdns3: fix memory double free when handle zero packet (Martin McConnell) [RHEL-54566]
- usb: cdnsp: fixed issue with incorrect detecting CDNSP family controllers (Martin McConnell) [RHEL-54566]
- usb: cdnsp: blocked some cdns3 specific code (Martin McConnell) [RHEL-54566]
- usb: cdns3: Fix uvc fail when DMA cross 4k boundery since sg enabled (Martin McConnell) [RHEL-54566]
- usb: cdns3: fix iso transfer error when mult is not zero (Martin McConnell) [RHEL-54566]
- usb: cdns3: fix uvc failure work since sg support enabled (Martin McConnell) [RHEL-54566]
- usb: cdns3: Use dev_err_probe (Martin McConnell) [RHEL-54566]
- usb: cdns3: starfive: don't misuse /** comment (Martin McConnell) [RHEL-54566]
- usb: cdnsp: Replace snprintf() with the safer scnprintf() variant (Martin McConnell) [RHEL-54566]
- usb: cdns3: skip set TRB_IOC when usb_request: no_interrupt is true (Martin McConnell) [RHEL-54566]
- usb: cdnsp: Fix deadlock issue during using NCM gadget (Martin McConnell) [RHEL-54566]
- usb:cdnsp: remove TRB_FLUSH_ENDPOINT command (Martin McConnell) [RHEL-54566]
- usb: cdns3: Modify the return value of cdns_set_active () to void when CONFIG_PM_SLEEP is disabled (Martin McConnell) [RHEL-54566]
- usb: cdnsp: Fixes issue with dequeuing not queued requests (Martin McConnell) [RHEL-54566]
- usb: cdns3: Add PHY mode switch to usb2 PHY (Martin McConnell) [RHEL-54566]
- usb: cdns3: starfive: Convert to platform remove callback returning void (Martin McConnell) [RHEL-54566]
- usb: cdns3: Put the cdns set active part outside the spin lock (Martin McConnell) [RHEL-54566]
- usb: cdns3: fix incorrect calculation of ep_buf_size when more than one config (Martin McConnell) [RHEL-54566]
- usb: cdns3: imx: Rework system PM to avoid duplicated operations (Martin McConnell) [RHEL-54566]
- usb: cdns3: optimize OUT transfer by copying only actual received data (Martin McConnell) [RHEL-54566]
- usb: cdns3: improve handling of unaligned address case (Martin McConnell) [RHEL-54566]
- usb: cdns3: Add StarFive JH7110 USB driver (Martin McConnell) [RHEL-54566]
- usb: cdns3: imx: simplify clock name usage (Martin McConnell) [RHEL-54566]
- usb: cdns3: fix NCM gadget RX speed 20x slow than expection at iMX8QM (Martin McConnell) [RHEL-54566]
- usb: cdns3-ti: Convert to platform remove callback returning void (Martin McConnell) [RHEL-54566]
- usb: cdns3-plat: Convert to platform remove callback returning void (Martin McConnell) [RHEL-54566]
- usb: cdns3-imx: Convert to platform remove callback returning void (Martin McConnell) [RHEL-54566]
- usb: cdnsp: Fixes error: uninitialized symbol 'len' (Martin McConnell) [RHEL-54566]
- usb: cdnsp: changes PCI Device ID to fix conflict with CNDS3 driver (Martin McConnell) [RHEL-54566]
- usb: cdns3: Fix issue with using incorrect PCI device function (Martin McConnell) [RHEL-54566]
- usb: cdnsp: Fixes issue with redundant Status Stage (Martin McConnell) [RHEL-54566]
- usb: cdns3: change some trace event __dynamic_array() to __get_buf() (Martin McConnell) [RHEL-54566]
- usb: cdns3: change trace event cdns3_ring() operation (Martin McConnell) [RHEL-54566]
- usb: cdnsp: : add scatter gather support for ISOC endpoint (Martin McConnell) [RHEL-54566]
- usb: cdns3: remove fetched trb from cache before dequeuing (Martin McConnell) [RHEL-54566]
- usb: cdnsp: fix lack of ZLP for ep0 (Martin McConnell) [RHEL-54566]
- usb: cdnsp: fix issue with ZLP - added TD_SIZE = 1 (Martin McConnell) [RHEL-54566]
- usb: cdnsp: Fix issue with Clear Feature Halt Endpoint (Martin McConnell) [RHEL-54566]
- usb: cdns3: host: fix endless superspeed hub port reset (Martin McConnell) [RHEL-54566]
- usb: cdns3: adjust the partial logic of cdnsp_pci_remove (Martin McConnell) [RHEL-54566]
- usb: cdns3: remove dead code (Martin McConnell) [RHEL-54566]
- Bluetooth: MGMT: Add error handling to pair_device() (CKI Backport Bot) [RHEL-56148] {CVE-2024-43884}
- PCI/DPC: Fix use-after-free on concurrent DPC and hot-removal (Myron Stowe) [RHEL-54981] {CVE-2024-42302}
- ASoC: TAS2781: Fix tasdev_load_calibrated_data() (CKI Backport Bot) [RHEL-55177] {CVE-2024-42278}
- cgroup/cpuset: Prevent UAF in proc_cpuset_show() (Waiman Long) [RHEL-54775 RHEL-54779] {CVE-2024-43853}
- net: add and use __skb_get_hash_symmetric_net (Hangbin Liu) [RHEL-54921]
- net: add and use skb_get_hash_net (Hangbin Liu) [RHEL-54921]
- net: flow_dissector: use DEBUG_NET_WARN_ON_ONCE (CKI Backport Bot) [RHEL-54921] {CVE-2024-42321}
- ice: Adjust PTP init for 2x50G E825C devices (Petr Oros) [RHEL-29210]
- ice: Add NAC Topology device capability parser (Petr Oros) [RHEL-29210]
- ice: Add support for E825-C TS PLL handling (Petr Oros) [RHEL-29210]
- ice: Change CGU regs struct to anonymous (Petr Oros) [RHEL-29210]
- ice: Introduce ETH56G PHY model for E825C products (Petr Oros) [RHEL-29210]
- ice: Introduce ice_get_base_incval() helper (Petr Oros) [RHEL-29210]
- ice: Move CGU block (Petr Oros) [RHEL-29210]
- ice: Add PHY OFFSET_READY register clearing (Petr Oros) [RHEL-29210]
- ice: Implement Tx interrupt enablement functions (Petr Oros) [RHEL-29210]
- ice: Introduce helper to get tmr_cmd_reg values (Petr Oros) [RHEL-29210]
- ice: Introduce ice_ptp_hw struct (Petr Oros) [RHEL-29210]
- Bluetooth: Fix use-after-free bugs caused by sco_sock_timeout (CKI Backport Bot) [RHEL-17953 RHEL-36378] {CVE-2024-27398}
- Bluetooth: btintel: Fixe build regression (Bastien Nocera) [RHEL-37353] {CVE-2024-35933}
- Bluetooth: btintel: Fix null ptr deref in btintel_read_version (CKI Backport Bot) [RHEL-37353] {CVE-2024-35933}
- Bluetooth: fix connection setup in l2cap_connect (Bastien Nocera) [RHEL-38459] {CVE-2024-36013}
- Bluetooth: HCI: Remove HCI_AMP support (Bastien Nocera) [RHEL-38459] {CVE-2024-36013}
- Bluetooth: Remove HCI_POWER_OFF_TIMEOUT (Bastien Nocera) [RHEL-38459] {CVE-2024-36013}
- Bluetooth: hci_event: Remove code to removed CONFIG_BT_HS (Bastien Nocera) [RHEL-38459] {CVE-2024-36013}
- Bluetooth: Remove usage of the deprecated ida_simple_xx() API (Bastien Nocera) [RHEL-38459] {CVE-2024-36013}
- Bluetooth: L2CAP: Fix slab-use-after-free in l2cap_connect() (Bastien Nocera) [RHEL-38459] {CVE-2024-36013}
- Bluetooth: Remove BT_HS (Bastien Nocera) [RHEL-38459] {CVE-2024-36013}
- Bluetooth: qca: add missing firmware sanity checks (CKI Backport Bot) [RHEL-39643] {CVE-2024-36880}
- Bluetooth: hci_sock: Fix not validating setsockopt user input (Bastien Nocera) [RHEL-37411] {CVE-2024-35963}
- Bluetooth: SCO: Fix not validating setsockopt user input (Bastien Nocera) [RHEL-37396] {CVE-2024-35967}
- Bluetooth: L2CAP: Fix not validating setsockopt user input (Bastien Nocera) [RHEL-37404] {CVE-2024-35965}
- Bluetooth: ISO: Fix not validating setsockopt user input (Bastien Nocera) [RHEL-37406] {CVE-2024-35964}
- Bluetooth: RFCOMM: Fix not validating setsockopt user input (Bastien Nocera) [RHEL-37400] {CVE-2024-35966}
- Bluetooth: Fix memory leak in hci_req_sync_complete() (CKI Backport Bot) [RHEL-37378] {CVE-2024-35978}
- Bluetooth: msft: fix slab-use-after-free in msft_do_close() (CKI Backport Bot) [RHEL-38463] {CVE-2024-36012}
- rtc: tps6594: Fix memleak in probe (Joel Slebodnick) [RHEL-45915]
- redhat/configs: add config file for tps6594 pfsm (Joel Slebodnick) [RHEL-45915]
- redhat/configs: add config file for tps6594 esm (Joel Slebodnick) [RHEL-45915]
- redhat/configs: add config file for tps6594 rtc drv (Joel Slebodnick) [RHEL-45915]
- redhat/configs: add config file for tps6594 regulator (Joel Slebodnick) [RHEL-45915]
- redhat/configs: add config file for tps6594 pinctrl (Joel Slebodnick) [RHEL-45915]
- redhat/configs: add config file for tps6594 spi (Joel Slebodnick) [RHEL-45915]
- redhat/configs: add config file for tps6594 i2c (Joel Slebodnick) [RHEL-45915]
- regulator: tps6594-regulator: Correct multi-phase configuration (Joel Slebodnick) [RHEL-45915]
- rtc: tps6594: Add driver for TPS6594 RTC (Joel Slebodnick) [RHEL-45915]
- pinctrl: tps6594: Add driver for TPS6594 pinctrl and GPIOs (Joel Slebodnick) [RHEL-45915]
- regulator: tps6594-regulator: Fix random kernel crash (Joel Slebodnick) [RHEL-45915]
- misc: tps6594: Remove redundant dev_err_probe() for platform_get_irq_byname() (Joel Slebodnick) [RHEL-45915]
- misc: tps6594-esm: Disable ESM for rev 1 PMIC (Joel Slebodnick) [RHEL-45915]
- misc: tps6594-esm: Convert to platform remove callback returning void (Joel Slebodnick) [RHEL-45915]
- misc: tps6594-pfsm: Convert to platform remove callback returning void (Joel Slebodnick) [RHEL-45915]
- misc: tps6594-pfsm: Add driver for TI TPS6594 PFSM (Joel Slebodnick) [RHEL-45915]
- misc: tps6594-esm: Add driver for TI TPS6594 ESM (Joel Slebodnick) [RHEL-45915]
- regulator: tps6594-regulator: Add driver for TI TPS6594 regulators (Joel Slebodnick) [RHEL-45915]
- mfd: tps6594: Add null pointer check to tps6594_device_init() (Joel Slebodnick) [RHEL-45915]
- mfd: tps6594: Fix an error code in probe() (Joel Slebodnick) [RHEL-45915]
- mfd: tps6594: Add driver for TI TPS6594 PMIC (Joel Slebodnick) [RHEL-45915]
- mfd: tps80031: Remove driver (Joel Slebodnick) [RHEL-45915]
- dt-bindings: mfd: Add TI TPS6594 PMIC (Joel Slebodnick) [RHEL-45915]
- x86/mce: Implement recovery for errors in TDX/SEAM non-root mode (David Arcari) [RHEL-28497]

* Fri Sep 06 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-506.el9]
- powercap: idle_inject: Simplify if condition (David Arcari) [RHEL-53594]
- powercap: intel_rapl: Switch to new Intel CPU model defines (David Arcari) [RHEL-53594]
- powercap: intel_rapl_msr: Switch to new Intel CPU model defines (David Arcari) [RHEL-53594]
- powercap: intel_rapl_tpmi: Enable PMU support (David Arcari) [RHEL-53594]
- powercap: intel_rapl: Introduce APIs for PMU support (David Arcari) [RHEL-53594]
- powercap: intel_rapl: Sort header files (David Arcari) [RHEL-53594]
- powercap: intel_rapl: Add support for ArrowLake-H platform (David Arcari) [RHEL-53594]
- Update 9.6 selt-tests (Lucas Zampieri)

* Wed Sep 04 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-505.el9]
- PCI: Revert the cfg_access_lock lockdep mechanism (Myron Stowe) [RHEL-50255]
- PCI: Make pcie_bandwidth_capable() static (Myron Stowe) [RHEL-50255]
- x86/pci: Remove OLPC dead code (Myron Stowe) [RHEL-50255]
- PCI: Clean up accessor macro formatting (Myron Stowe) [RHEL-50255]
- PCI/ERR: Cleanup misleading indentation inside if conditions (Myron Stowe) [RHEL-50255]
- PCI: Annotate pci_cache_line_size variables as __ro_after_init (Myron Stowe) [RHEL-50255]
- PCI: Constify pcibus_class (Myron Stowe) [RHEL-50255]
- Revert "genirq/msi: Provide constants for PCI/IMS support" (Myron Stowe) [RHEL-50255]
- Revert "x86/apic/msi: Enable PCI/IMS" (Myron Stowe) [RHEL-50255]
- Revert "iommu/vt-d: Enable PCI/IMS" (Myron Stowe) [RHEL-50255]
- Revert "iommu/amd: Enable PCI/IMS" (Myron Stowe) [RHEL-50255]
- Revert "PCI/MSI: Provide IMS (Interrupt Message Store) support" (Myron Stowe) [RHEL-50255]
- Revert "PCI/MSI: Provide pci_ims_alloc/free_irq()" (Myron Stowe) [RHEL-50255]
- PCI: endpoint: pci-epf-test: Clean up pci_epf_test_unbind() (Myron Stowe) [RHEL-50255]
- PCI: endpoint: pci-epf-test: Simplify pci_epf_test_set_bar() loop (Myron Stowe) [RHEL-50255]
- PCI: endpoint: pci-epf-test: Remove superfluous code (Myron Stowe) [RHEL-50255]
- PCI: endpoint: Allocate a 64-bit BAR if that is the only option (Myron Stowe) [RHEL-50255]
- PCI: endpoint: pci-epf-test: Simplify pci_epf_test_alloc_space() loop (Myron Stowe) [RHEL-50255]
- PCI: tegra194: Fix probe path for Endpoint mode (Myron Stowe) [RHEL-50255]
- PCI: rockchip-ep: Remove wrong mask on subsys_vendor_id (Myron Stowe) [RHEL-50255]
- PCI: rockchip-ep: Set a 64-bit BAR if requested (Myron Stowe) [RHEL-50255]
- PCI: mt7621: Fix string truncation in mt7621_pcie_parse_port() (Myron Stowe) [RHEL-50255]
- PCI: endpoint: Remove "core_init_notifier" flag (Myron Stowe) [RHEL-50255]
- PCI: dwc: ep: Call dw_pcie_ep_init_registers() API directly from all glue drivers (Myron Stowe) [RHEL-50255]
- PCI: dwc: ep: Rename dw_pcie_ep_init_complete() to dw_pcie_ep_init_registers() (Myron Stowe) [RHEL-50255]
- PCI: dwc: ep: Introduce dw_pcie_ep_cleanup() API for drivers supporting PERST# (Myron Stowe) [RHEL-50255]
- PCI: dwc: ep: Rename dw_pcie_ep_exit() to dw_pcie_ep_deinit() (Myron Stowe) [RHEL-50255]
- PCI: dwc: ep: Remove deinit() callback from struct dw_pcie_ep_ops (Myron Stowe) [RHEL-50255]
- PCI: dwc: ep: Add Kernel-doc comments for APIs (Myron Stowe) [RHEL-50255]
- PCI: dwc: ep: Fix DBI access failure for drivers requiring refclk from host (Myron Stowe) [RHEL-50255]
- PCI: cadence: Set a 64-bit BAR if requested (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: rockchip,rk3399-pcie: Add missing maxItems to ep-gpios (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: rcar-gen4-pci-ep: Add R-Car V4H compatible (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: rcar-gen4-pci-host: Add R-Car V4H compatible (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: layerscape-pci: Convert to YAML format (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: mediatek,mt7621: Add missing child node reg (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: cdns,cdns-pcie-host: Drop redundant msi-parent and pci-bus.yaml (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: ti,am65: Fix remaining binding warnings (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: ti,j721e-pci-host: Add support for J722S SoC (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: rcar-pci-host: Add missing IOMMU properties (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: ti,j721e-pci-host: Add device-id for TI's J784S4 SoC (Myron Stowe) [RHEL-50255]
- PCI/PM: Avoid D3cold for HP Pavilion 17 PC/1972 PCIe Ports (Myron Stowe) [RHEL-50255]
- PCI: of_property: Return error for int_map allocation failure (Myron Stowe) [RHEL-50255]
- PCI/MSI: Make error path handling follow the standard pattern (Myron Stowe) [RHEL-50255]
- PCI: hotplug: Remove obsolete sgi_hotplug TODO notes (Myron Stowe) [RHEL-50255]
- PCI: hotplug: Document unchecked return value of pci_hp_add_bridge() (Myron Stowe) [RHEL-50255]
- PCI: Do not wait for disconnected devices when resuming (Myron Stowe) [RHEL-50255]
- x86/pci: Skip early E820 check for ECAM region (Myron Stowe) [RHEL-50255]
- PCI: Remove unused pci_enable_device_io() (Myron Stowe) [RHEL-50255]
- ata: pata_cs5520: Remove unnecessary call to pci_enable_device_io() (Myron Stowe) [RHEL-50255]
- PCI: Update pci_find_capability() stub return types (Myron Stowe) [RHEL-50255]
- PCI: Remove PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- scsi: vmw_pvscsi: Do not use PCI_IRQ_LEGACY instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- scsi: pmcraid: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- scsi: mpt3sas: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- scsi: megaraid_sas: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- scsi: ipr: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- scsi: hpsa: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- scsi: arcmsr: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- wifi: rtw89: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- wifi: rtw88: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- wifi: ath10k: Refer to INTX instead of LEGACY (Myron Stowe) [RHEL-50255]
- r8169: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- net: alx: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- net: atlantic: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- net: amd-xgbe: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- VMCI: Use PCI_IRQ_ALL_TYPES to remove PCI_IRQ_LEGACY use (Myron Stowe) [RHEL-50255]
- RDMA/vmw_pvrdma: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- IB/qib: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- drm/amdgpu: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- mfd: intel-lpss: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- ntb: idt: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- platform/x86: intel_ips: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- tty: 8250_pci: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- usb: hcd-pci: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- ASoC: Intel: avs: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- Documentation: PCI: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- PCI/portdrv: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- PCI/MSI: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (Myron Stowe) [RHEL-50255]
- PCI: Clarify intent of LT wait (Myron Stowe) [RHEL-50255]
- PCI: Wait for Link Training==0 before starting Link retrain (Myron Stowe) [RHEL-50255]
- PCI/EDR: Align EDR_PORT_LOCATE_DSM with PCI Firmware r3.3 (Myron Stowe) [RHEL-50255]
- PCI/EDR: Align EDR_PORT_DPC_ENABLE_DSM with PCI Firmware r3.3 (Myron Stowe) [RHEL-50255]
- PCI/DOE: Support discovery version 2 (Myron Stowe) [RHEL-50255]
- PCI: Lock upstream bridge for pci_reset_function() (Myron Stowe) [RHEL-50255]
- PCI/ASPM: Clean up ASPM disable/enable mask calculation (Myron Stowe) [RHEL-50255]
- PCI/ASPM: Consolidate link state defines (Myron Stowe) [RHEL-50255]
- PCI/AER: Update aer-inject tool source URL (Myron Stowe) [RHEL-50255]
- PCI: Mask Replay Timer Timeout errors for Genesys GL975x SD host controller (Myron Stowe) [RHEL-50255]
- of: unittest: Add tests for address translations (Myron Stowe) [RHEL-50255]
- of: address: Fix address translation when address-size is greater than 2 (Myron Stowe) [RHEL-50255]
- PCI: of: Destroy changeset when adding PCI device node fails (Myron Stowe) [RHEL-50255]
- PCI: of_property: Handle interrupt parsing failures (Myron Stowe) [RHEL-50255]
- PCI: Create device tree node for bridge (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: Drop unneeded quotes (Myron Stowe) [RHEL-50255]
- PCI/DOE: Relax restrictions on request and response size (Myron Stowe) [RHEL-50255]
- PCI/DOE: Make mailbox creation API private (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: ti,j721e-pci-host: Simplify 'device-id' schema (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: cdns-ep: Fix 'unevaluatedProperties' warnings (Myron Stowe) [RHEL-50255]
- dt-bindings: PCI: Fix 'unevaluatedProperties' warnings (Myron Stowe) [RHEL-50255]
- ptp: annotate data-race around q->head and q->tail (Hangbin Liu) [RHEL-38600]
- Input: gpio_keys_polled - suppress deferred probe error for gpio (Luiz Capitulino) [RHEL-52234]
- Input: gpio_keys_polled - simplify with dev_err_probe() (Luiz Capitulino) [RHEL-52234]
- redhat/configs: enable CONFIG_KEYBOARD_GPIO_POLLED driver (Luiz Capitulino) [RHEL-52234]
- net/smc: reduce rtnl pressure in smc_pnet_create_pnetids_list() (Mete Durlu) [RHEL-37349] {CVE-2024-35934}
- net/iucv: fix use after free in iucv_sock_close() (Mete Durlu) [RHEL-53992]
- tools/virtio: Add dma sync api for virtio test (Eric Auger) [RHEL-3230]
- virtio_ring: fix syncs DMA memory with different direction (Eric Auger) [RHEL-3230]
- virtio: packed: fix unmap leak for indirect desc table (Eric Auger) [RHEL-3230]
- virtio_net: fix missing dma unmap for resize (Eric Auger) [RHEL-3230]
- virtio_net: avoid data-races on dev->stats fields (Eric Auger) [RHEL-3230]
- virtio_net: fix the missing of the dma cpu sync (Eric Auger) [RHEL-3230]
- virtio_net: merge dma operations when filling mergeable buffers (Eric Auger) [RHEL-3230]
- virtio_ring: introduce dma sync api for virtqueue (Eric Auger) [RHEL-3230]
- virtio_ring: introduce dma map api for virtqueue (Eric Auger) [RHEL-3230]
- virtio_ring: introduce virtqueue_reset() (Eric Auger) [RHEL-3230]
- virtio_ring: separate the logic of reset/enable from virtqueue_resize (Eric Auger) [RHEL-3230]
- virtio_ring: correct the expression of the description of virtqueue_resize() (Eric Auger) [RHEL-3230]
- virtio_ring: skip unmap for premapped (Eric Auger) [RHEL-3230]
- virtio_ring: introduce virtqueue_dma_dev() (Eric Auger) [RHEL-3230]
- virtio_ring: support add premapped buf (Eric Auger) [RHEL-3230]
- virtio_ring: introduce virtqueue_set_dma_premapped() (Eric Auger) [RHEL-3230]
- virtio_ring: put mapping error check in vring_map_one_sg (Eric Auger) [RHEL-3230]
- virtio_ring: check use_dma_api before unmap desc for indirect (Eric Auger) [RHEL-3230]
- s390/dasd: fix error recovery leading to data corruption on ESE devices (Mete Durlu) [RHEL-55873]

* Mon Sep 02 2024 Rado Vrbovsky <rvrbovsk@redhat.com> [5.14.0-504.el9]
- Bump RHEL MINOR to 9.6 (Rado Vrbovsky)
- block: initialize integrity buffer to zero before writing it to media (Ming Lei) [RHEL-54768] {CVE-2024-43854}
- perf/x86/amd/uncore: Fix DF and UMC domain identification (David Arcari) [RHEL-43147]
- x86/mm/numa: Move early mptable evaluation into common code (David Arcari) [RHEL-43147]
- x86/cpu: Move leftover contents of topology.c to setup.c (David Arcari) [RHEL-43147]
- x86/topology: convert to use arch_cpu_is_hotpluggable() (David Arcari) [RHEL-43147]
- x86/topology: use weak version of arch_unregister_cpu() (David Arcari) [RHEL-43147]
- x86/topology: Switch over to GENERIC_CPU_DEVICES (David Arcari) [RHEL-43147]
- x86/topology: remove arch_*register_cpu() exports (David Arcari) [RHEL-43147]
- x86/topology/intel: Unlock CPUID before evaluating anything (David Arcari) [RHEL-43147]
- x86/topology/amd: Evaluate SMT in CPUID leaf 0x8000001e only on family 0x17 and greater (David Arcari) [RHEL-43147]
- x86/topology: Handle bogus ACPI tables correctly (David Arcari) [RHEL-43147]
- x86/topology/amd: Ensure that LLC ID is initialized (David Arcari) [RHEL-43147]
- x86/xen: return a sane initial apic id when running as PV guest (David Arcari) [RHEL-43147]
- x86/cpu/amd: Move TOPOEXT enablement into the topology parser (David Arcari) [RHEL-43147]
- x86/cpu/amd: Make the NODEID_MSR union actually work (David Arcari) [RHEL-43147]
- x86/cpu/amd: Make the CPUID 0x80000008 parser correct (David Arcari) [RHEL-43147]
- x86/topology: Don't update cpu_possible_map in topo_set_cpuids() (David Arcari) [RHEL-43147]
- x86/topology: Handle the !APIC case gracefully (David Arcari) [RHEL-43147]
- x86/topology: Don't evaluate logical IDs during early boot (David Arcari) [RHEL-43147]
- x86/cpu/topology: Add support for the AMD 0x80000026 leaf (David Arcari) [RHEL-43147]
- x86/topology: Ignore non-present APIC IDs in a present package (David Arcari) [RHEL-43147]
- x86/apic: Build the x86 topology enumeration functions on UP APIC builds too (David Arcari) [RHEL-43147]
- x86/cpu/topology: Get rid of cpuinfo::x86_max_cores (David Arcari) [RHEL-43147]
- docs: move x86 documentation into Documentation/arch/ [partial] (David Arcari) [RHEL-43147]
- x86/cpu: Remove x86_coreid_bits (David Arcari) [RHEL-43147]
- x86/mm/numa: Use core domain size on AMD (David Arcari) [RHEL-43147]
- x86/cpu/topology: Provide __num_[cores|threads]_per_package (David Arcari) [RHEL-43147]
- x86/cpu/topology: Rename smp_num_siblings (David Arcari) [RHEL-43147]
- arch/x86/kernel/setup.c: fixup rh_check_supported (David Arcari) [RHEL-43147]
- x86/cpu/topology: Retrieve cores per package from topology bitmaps (David Arcari) [RHEL-43147]
- x86/cpu/topology: Use topology logical mapping mechanism (David Arcari) [RHEL-43147]
- x86/smpboot: Change smp_store_boot_cpu_info() to static (David Arcari) [RHEL-43147]
- x86/cpu/topology: Provide logical pkg/die mapping (David Arcari) [RHEL-43147]
- x86/cpu/topology: Simplify cpu_mark_primary_thread() (David Arcari) [RHEL-43147]
- x86/cpu/topology: Mop up primary thread mask handling (David Arcari) [RHEL-43147]
- x86/cpu/topology: Use topology bitmaps for sizing (David Arcari) [RHEL-43147]
- x86/xen/smp_pv: Register the boot CPU APIC properly (David Arcari) [RHEL-43147]
- x86/cpu/topology: Let XEN/PV use topology from CPUID/MADT (David Arcari) [RHEL-43147]
- x86/acpi: Dont invoke topology_register_apic() for XEN PV (David Arcari) [RHEL-43147]
- x86/xen/smp_pv: Count number of vCPUs early (David Arcari) [RHEL-43147]
- x86/xen/smp_pv: Register fake APICs (David Arcari) [RHEL-43147]
- x86/mpparse: Switch to new init callbacks (David Arcari) [RHEL-43147]
- x86/mpparse: Provide separate early/late callbacks (David Arcari) [RHEL-43147]
- x86/dtb: Rename x86_dtb_init() (David Arcari) [RHEL-43147]
- x86/mpparse: Prepare for callback separation (David Arcari) [RHEL-43147]
- x86/xen/smp_pv: Prepare for separate mpparse callbacks (David Arcari) [RHEL-43147]
- x86/mpparse: Rename default_find_smp_config() (David Arcari) [RHEL-43147]
- x86/xen/smp_pv: Remove cpudata fiddling (David Arcari) [RHEL-43147]
- x86/cpu/topology: Assign hotpluggable CPUIDs during init (David Arcari) [RHEL-43147]
- x86/cpu/topology: Reject unknown APIC IDs on ACPI hotplug (David Arcari) [RHEL-43147]
- x86/topology: Add a mechanism to track topology via APIC IDs (David Arcari) [RHEL-43147]
- x86/cpu: Detect real BSP on crash kernels (David Arcari) [RHEL-43147]
- x86/cpu/topology: Rework possible CPU management (David Arcari) [RHEL-43147]
- x86/cpu/topology: Sanitize the APIC admission logic (David Arcari) [RHEL-43147]
- x86/cpu/topology: Use a data structure for topology info (David Arcari) [RHEL-43147]
- x86/cpu/topology: Simplify APIC registration (David Arcari) [RHEL-43147]
- x86/cpu/topology: Confine topology information (David Arcari) [RHEL-43147]
- x86/mpparse: Use new APIC registration function (David Arcari) [RHEL-43147]
- x86/acpi: Use new APIC registration functions (David Arcari) [RHEL-43147]
- x86/cpu/topology: Provide separate APIC registration functions (David Arcari) [RHEL-43147]
- x86/cpu/topology: Move registration out of APIC code (David Arcari) [RHEL-43147]
- x86/apic/msi: Use DOMAIN_BUS_GENERIC_MSI for HPET/IO-APIC domain search (David Arcari) [RHEL-43147]
- x86/apic: Use a proper define for invalid ACPI CPU ID (David Arcari) [RHEL-43147]
- x86/apic: Remove yet another dubious callback (David Arcari) [RHEL-43147]
- x86/apic: Remove the pointless writeback of boot_cpu_physical_apicid (David Arcari) [RHEL-43147]
- x86/mpparse: Remove the physid_t bitmap wrapper (David Arcari) [RHEL-43147]
- x86/apic: Remove check_apicid_used() and ioapic_phys_id_map() (David Arcari) [RHEL-43147]
- x86/ioapic: Simplify setup_ioapic_ids_from_mpc_nocheck() (David Arcari) [RHEL-43147]
- x86/ioapic: Make io_apic_get_unique_id() simpler (David Arcari) [RHEL-43147]
- x86/apic: Get rid of get_physical_broadcast() (David Arcari) [RHEL-43147]
- x86/ioapic: Replace some more set bit nonsense (David Arcari) [RHEL-43147]
- x86/platform/ce4100: Dont override x86_init.mpparse.setup_ioapic_ids (David Arcari) [RHEL-43147]
- x86/apic: Remove unused phys_pkg_id() callback (David Arcari) [RHEL-43147]
- arch/x86: Fix typos (David Arcari) [RHEL-43147]
- x86/cpu/topology: Make the APIC mismatch warnings complete (David Arcari) [RHEL-43147]
- x86/cpu: Remove topology.c (David Arcari) [RHEL-43147]
- x86/cpu: Make topology_amd_node_id() use the actual node info (David Arcari) [RHEL-43147]
- x86/cpu: Use common topology code for HYGON (David Arcari) [RHEL-43147]
- x86/cpu: Use common topology code for AMD (David Arcari) [RHEL-43147]
- x86/cpu: Provide an AMD/HYGON specific topology parser (David Arcari) [RHEL-43147]
- x86/cpu: Provide cpuid_read() et al. (David Arcari) [RHEL-43147]
- x86/cpu: Use common topology code for Intel (David Arcari) [RHEL-43147]
- x86/cpu: Provide a sane leaf 0xb/0x1f parser (David Arcari) [RHEL-43147]
- x86/cpu: Move __max_die_per_package to common.c (David Arcari) [RHEL-43147]
- x86/cpu: Use common topology code for Centaur and Zhaoxin (David Arcari) [RHEL-43147]
- x86/cpu: Add legacy topology parser (David Arcari) [RHEL-43147]
- x86/cpu: Provide cpu_init/parse_topology() (David Arcari) [RHEL-43147]
- drivers: base: Move cpu_dev_init() after node_dev_init() (David Arcari) [RHEL-43147]
- base/node.c: initialize the accessor list before registering (David Arcari) [RHEL-43147]
- Revert "x86/topology: Fix max_siblings calculation for some hybrid cpus" (David Arcari) [RHEL-43147]


###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
